
/*
 *                                           
 * this function sets the ALCD of the phy      
 *                                             
 * Active link cable diagnostic: 
 * offers a passive method to estimate the cable length present during an active link. 
 * It uses passive digital signal processing based on adapted data,
 * thus enabling the measurement of cable length with an active link partner.
 * The ALCD cable length measurement accuracy is 5 m.
 * for the pair used in the Rx path (as a result of the passive nature of the test, only the pair on the Rx path is measured).
 * To perform an ALCD test, do the following:
 * 1. Ensure the device is currently under a 100BT link. 
 * 2. If the user has performed TDR before performing an ALCD test, the user is advised to reset the device. 
 *
 */
 

#include < stdio.h >
#include <math.h> 
#include "registers.h"
#include "loopback.h"
#include "read_write.h"
#include "Resource files/et1000.h"



int ALCD(int phy_id, int *result_alcd)
{
int  error=0;
int alcd_data_1=0;
int alcd_data_2=0;
int cagc_data=0;
double  offset = 0;
double  poly_coeff_2=0;
double  poly_coeff_1=0;    
double  FAGC_multiply_DFE = 0;
double CAGC_NORM = 0;
double ABS_GAIN, alcd_pre;
	
	//
	alcd_data_1 |= 0x8002; 
    error = phy_write(phy_id, ALCD_1, alcd_data_1); //write
    if (error < 0)
	{
	     return error;
	}	
	alcd_data_1 = phy_read(phy_id, ALCD_1); 
	if (alcd_data_1 < 0)// error
	{
		return error = alcd_data_1;
	}
    alcd_data_1 &= 0xFF0 ;   //read bits 11:4
	alcd_data_1 = alcd_data_1 >> 4;
	alcd_data_1 = -(256 - alcd_data_1); //2's comp

    //
	alcd_data_2 = phy_read(phy_id, ALCD_3);//read register 0x021D(h) bits 11:0 
	if (alcd_data_2 < 0)// error
	{
		return error = alcd_data_2;
	}
    alcd_data_2 &= 0xFFF ;   //bits 11:0

	//
	cagc_data = phy_read(phy_id, ALCD_2); 
	if (cagc_data < 0)// error
	{
		return error = cagc_data;
	}
    cagc_data &= 0x000F;   //read bits 3:0
	//cagc_data = cagc_data >> 12;
	

    alcd_data_1 = abs(alcd_data_1);

  if (cagc_data > 6)
        CAGC_NORM = -cagc_data + 6;
  else
        CAGC_NORM = cagc_data;
 
  CAGC_NORM = CAGC_NORM + 9;
  
  ABS_GAIN = alcd_data_2 * exp(CAGC_NORM/20);
  alcd_pre = log10(ABS_GAIN * alcd_data_1) * 100 - 200;
  poly_coeff_2 = 0.0024;
  poly_coeff_1 = -0.0142;
  offset = -74.7;

 
	
    *result_alcd = poly_coeff_2 * pow(alcd_pre, 2) + poly_coeff_1 * alcd_pre + offset;

     Sleep(500);




 	        //*result_alcd = -1;	



		return 0;
}



