/*****************************************************************************
 * atmitems.h
 * ATM Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Netcom Systems, Inc.
 * Copyright (c) 1999.  All Rights Reserved
 ****************************************************************************/

#ifndef _ATMITEMS_H_
#define _ATMITEMS_H_

#include "ettypes.h"
#include "wanitems.h"

#if defined WIN16
#define ATM_MAX_ARRAY_DIM				256
#else
#define ATM_MAX_ARRAY_DIM				2048
#endif

#if defined WIN16
#define ATM_MAX_ARRAY_DIM_512			256
#else
#define ATM_MAX_ARRAY_DIM_512			512
#endif
#define ATM_MAX_CONNECTIONS			ATM_MAX_ARRAY_DIM
#define ATM_MAX_SETUP_CONNECTIONS   8388606
#define ATM_MAX_STREAMS					ATM_MAX_ARRAY_DIM
#define ATM_MAX_MODS						100
#define ATM_MAX_MOD_DATA				12
#define ATM_MAX_DELTA					20
#define MAX_EVENT_DATA_LEN				140

/****************************************************************************/
/*  NOTE:																						 */
/*		In this header file ATM-1 refers to the following family of cards:	 */
/*	  	AT-9015, AT-9020, AT-9025, AT-9034, AT-9045, and AT-9155					 */
/*		ATM-2 refers to the AT-9034B, AT-9045B, AT-9155C, and AT-9622 card.	 */
/****************************************************************************/

/* some type defines */
/* ATM Forum floating point format for */
/*			    expressing rates				*/
/*													*/
/* 15 14 13 12 11 10 9 8 7 6 5 4 3 2 1 */
/* 0  nz <---- e ----> <----- m -----> */
/*													*/
/*	where:										*/
/*	rate = [ (2^^e) * (1 + m /512) * nz */
/*				in cells/sec					*/
/*												   */
#ifndef atmfloat
#define atmfloat unsigned short
#endif

/* ATM type1 defines to indicate structure type */


		/* Parameter setups */
#define ATM_LINE 							2		/* Physical and ATM layer config				*/
#define ATM_CONNECTION 					724		/* SVC-only. Define a connection
															for sigtest.									*/
#define ATM_CONN_COPY 					725		/* SVC-only. Copy connections for
															sigtest.											*/
#define ATM_CONN_MODIFY             701	/* SVC-only. Fill field of connection
															for sigtest.									*/
#define ATM_CONN_MODIFY_ARRAY       702	/* SVC-only. Mod field of connection
															for sigtest.									*/
#define ATM_CALL_SETUP					720		/* SVC-only. Set the traffic desc.
															for sigtest.									*/

#define ATM_CALL_ADDR_LIST				733		/* SVC-only. Set the called address
															for sigtest.									*/
#define ATM_ILMI							9		/* SVC-only. Set ILMI timers & ESI.		*/
#define ATM_SSCOP							709		/* SVC-only. Set SSCOP timers & config.	*/
#define ATM_UNI							714		/* SVC-only. Set UNI timers & version.	*/
#define ATM_ELAN_REGISTER				735		/* SVC-only. Define and register LEC.		*/
#define ATM_ELAN_DEREGISTER			728		/* SVC-only. Deregister an existing LEC.	*/
#define ATM_START_SETUP					14		/* SVC-only. Start a signaling test.		*/
#define ATM_STOP_SETUP					710		/* SVC-only. Stop a signaling test.		*/

#define ATM_INCOMING_SVC_METHOD		47 	/* SVC-only. Incoming SVC method.			*/

#define ATM_STREAM	 					50		/* Defines traffic/connection
															characteristics.  (Use with
															ATM_FRAME_DEF).								*/
#define ATM_FRAME_DEF					52		/* Defines Frame content.
															(Use with ATM_STREAM).						*/
#define ATM_STREAM_CONTROL				53		/* Start, stop, reset, etc. a stream.		*/
#define ATM_TRIGGER						54		/* Configure triggers in ATM-1.				*/
#define ATM_CLASSICAL_IP				55 	/* Configure CLIP ARP server info.			*/
#define ATM_DS3_E3_LINE_PARAM			56		/* Config ATM and PHY for DS3 or E3.		*/

#define ATM_GLOBAL_TRIGGER_PARAMS	57		/* Define global trigger event.		     	*/
#define ATM_CONN_TRIGGER_PARAMS		58		/* Define per conn trigger event,
															based on the connection ID.				*/
#define ATM_STREAM_TRIGGER_PARAMS	59 	/* Define per conn trigger event,
															based on the stream ID.						*/

#define ATM_DS1_E1_LINE_PARAM 		717		/* Config ATM and PHY for DS1 or E1.		*/

#define ATM_PVCAD_PARAMS				70 	/* Set port# in ILMI GETNEXT method.		*/
#define ATM_PVCAD_SEND_GETNEXT		71 	/* PVC Auto-Discovery state machine.		*/
#define ATM_PVCAD_RESPONSE				72 	/* Get the VPI/VCI status...        		*/
#define ATM_PVCAD_DISABLE				73

#define ATM_VCDB_PURGE					78 	/* SVC-only. Delete the VC DataBase.		*/
#define ATM_VCDB_CLEAR_FLAG			94 	/* SVC-only. VC Clear LOSS flags.			*/

#define ATM_PER_CONN_BURST          704 	/* Burst count per connection.				*/
#define ATM_PER_PORT_BURST          705 	/* Burst count per port.						*/
#define ATM_PER_STREAM_BURST			716	/* Burst count per stream.						*/

#define ATM_STREAM_PARAMS_COPY		731 	/* Copy Stream params to a given
															# of streams.									*/
#define ATM_STREAM_PARAMS_MODIFY		732 	/* Modify Stream params of a given
															# of streams.									*/
#define ATM_STREAM_PARAMS_FILL     	729 	/* Fill in Stream params for a
															given # of streams.							*/
#define ATM_FRAME_COPY					715 	/* Copy Frame params to a given
															# of streams.									*/

#define ATM_SCHED_PARAMS				711 	/* Cell-scheduling method for
															transmission.									*/

#define ATM_LOGFILE_CONTROL			111 	/* Reserves memory used to store
															trace events.  It is also used
															to clear the contents of the
															log file.										*/
#define ATM_PROTOCOL_TRACE_CONTROL	113 	/* Used to trace certain types
															of events.										*/

/* these defines are usd to handle messageds for UNI 4.0 */
#define ATM_CONNECTIONEX				200	/* SVC-only. Define a connection
															extended for sigtest.						*/
#define ATM_CALL_SETUPEX				201	/* SVC-only. Set the traffic desc.
															for sigtest.									*/


		/* Information retrieval */
#define ATM_CARD_INFO					706		/* Query card for firmware version.			*/
#define ATM_CARD_TYPE					160 	/* Get card rate (model number).				*/
#define ATM_SONET_INFO					707		/* Get the SONET alarms and counts.			*/
#define ATM_LAYER_INFO					708		/* Get the ATM layer counts.					*/
#define ATM_AAL5_INFO				   19		/* Get the AAL5 layer counts.					*/
#define ATM_ELAN_INFO					20		/* SVC-only. Gets the ELAN status.			*/
#define ATM_ILMI_INFO					21		/* SVC-only. Gets the ILMI status
															and counts.										*/
#define ATM_SAAL_INFO					730		/* SVC-only. Gets the SAAL status.			*/

#define ATM_CONN_INFO					719		/* SVC-only. Gets status of one or
															many connections.								*/
#define ATM_CONN_INFO_SUMMARY       27		/* SVC-only. Gets summary results
															of sigtest.										*/
#define ATM_CONN_64_INFO				34		/* SVC-only. Gets 64-bits status of
															one or many connectons.						*/
#define ATM_CONN_64_INFO_SUMMARY    35		/* SVC-only. Gets 64-bits summary
															results of sigtest.							*/

#define ATM_SIG_EMUL_INFO				30		/* SVC-only. Gets the signaling
															emulator stats.								*/
#define ATM_UNI_RESTART_ACK_STATS	45		/* SVC-only. Gets UNI RESTART
															command status.								*/

#define ATM_CONN_TRIGGER_INFO			718		/* Get per conn trigger counts.				*/

#define ATM_VCDB_COUNTS					77 	/* SVC-only. Counts of SVCs in each
															entry state.									*/
#define ATM_VCDB_LIST_INFO				79 	/* SVC-only. Gets the VC DataBase info.	*/

#define ATM_VCC_INFO						82		/* Get per VCC counts based on Conn.
															index.											*/
#define ATM_TRIGGER_INFO				84		/* ATM-1:Get trigger count and time.		*/
#define ATM_STREAM_DETAIL_INFO		87		/* Get status of one or many streams.		*/
#define ATM_STREAM_SEARCH_INFO		89		/* Return info for matching streams.		*/
#define ATM_CLASSICAL_IP_INFO			90		/* CLIP counts and ARP status.				*/
#define ATM_CARD_CAPABILITY			91		/* Get card-specific limits.					*/
#define ATM_DS3_E3_LINE_INFO			92		/* Get the DS3/E3 alarms and counts.		*/
#define ATM_DS1_E1_LINE_INFO			93		/* Get the DS1/E1 alarms and counts.		*/
#define ATM_LOGFILE_READ_INFO			112 	/* Used to read the trace events
															stored in the logfile.						*/
#define ATM_EXT_VCC_INFO				117 	/* Get Extended version of the
															Per-VCC counts based
															on Conn. index.								*/
#define ATM_STREAM_VCC_INFO 			120 	/* Get per VCC counts based on
															Stream index.									*/
#define ATM_STREAM_EXT_VCC_INFO	 	123 	/* Get Extended version of the
															Per-VCC counts based on Stream idx.		*/


#define ATM_STREAM_TRIGGER_INFO		126	/* Get per conn trigger counts
															based on the Stream-index
															Note: Uses the ATMConnTriggerInfo
															structure, similar to
															ATM_CONN_TRIGGER_INFO.						*/

#define ATM_STREAM_TRIGGER_TIME_INFO 129	/* Same as ATM_STREAM_TRIGGER_INFO
															with the addition of a timestamp
															field.											*/

		/* Commands */
#define ATM_CONN_PARAMS_RESET			36		/* SVC-only. Reset the signaling
															test connections.								*/
#define ATM_CONN_PARAMS_COMPLETE		722		/* SVC-only. Reset the signaling test.	*/
#define ATM_ILMI_REGISTER				727		/* SVC-only. Register an ATM address.		*/
#define ATM_ILMI_DEREGISTER			721		/* SVC-only. Deregister an ATM address.	*/
#define ATM_SAAL_ESTABLISH				40		/* SVC-only. Establish the SAAL
															at interface.									*/
#define ATM_SAAL_RELEASE				712		/* SVC-only. Release the SAAL
															at interface.									*/
#define ATM_SIG_EMUL_RESET				713		/* SVC-only. Release all calls from
															Emulator.										*/
#define ATM_ILMI_STATIC_REGISTER		726		/* SVC-only. Force an ATM address
															statically.										*/
#define ATM_UNI_RESTART					44		/* SVC-only. Inform to release calls.   	*/
#define ATM_SIG_EMUL_TEARDOWN			46		/* SVC-only. Teardown calls flag.			*/

#define ATM_CLIP_ESTABLISH_CLIENT   95
#define ATM_CLIP_RELEASE_CLIENT     703

#define ATM_FRAME_CLEAR					723 	/* De-allocates the "Source" Frame
															stored in memory.								*/


/* ATM type3 defines */

#define ATM_PVC	0
#define ATM_SVC	1
#define ATM_LANE	2

/****************************************************************************/
/*
 * ATM LED definitions
 */
#define ATM_LED_STATUS_TX				0x0002
#define ATM_LED_STATUS_ALARM_RED		0x0004
#define ATM_LED_STATUS_ALARM_YELLOW	0x000C
#define ATM_LED_STATUS_TRIG			0x0008
#define ATM_LED_STATUS_LOS				0x0010
#define ATM_LED_STATUS_RX				0x0020


/* LED protocol state information */
#define ATM_LED_STATE_MASK					0xFF00
#define ATM_LED_STATE_PHY_DOWN			0x0000
#define ATM_LED_STATE_PHY_UP				0x0100
#define ATM_LED_STATE_ILMI_UP				0x0200
#define ATM_LED_STATE_ILMI_AND_SAAL_UP	0x0300
#define ATM_LED_STATE_SAAL_UP				0x0400

/****************************************************************************/

/*
 * General ATM address data structure
 */
typedef struct tagATMAddress
{
	unsigned char	ucPrefix[13];	/* Network Prefix bytes 		*/
	unsigned char	ucEsi[6];		/* End System Identifier bytes	*/
	unsigned char	ucSel;			/* Selector byte				*/
} ATMAddress;

/*
 * The maximum number of ATM addresses which can be assigned under
 * SmartSignaling.
 */
#define ATM_MAX_CALL_ADDRESSES		128

/* ucPrefix[0] field contains Authority and Format Identifier (AFI) */
#define ATM_DCC_AFI		0x39
#define ATM_ICD_AFI		0x47
#define ATM_E164_AFI		0x45

/*****************************************************************************/
/* The maximum number of ports per card supported on different platforms */
#define ATM_155_MAX_PORTS						1
#define ATM_25_MAX_PORTS						1

/* The maximum number of cells per second for each interface */
#define ATM_OC12_LINE_CELL_RATE				1412830L
#define ATM_155_LINE_CELL_RATE				353207L
#define ATM_DS3_CELL_LINE_CELL_RATE			104268L
#define ATM_DS3_PLCP_LINE_CELL_RATE			96000L
#define ATM_E3_CELL_LINE_CELL_RATE			80000L
#define ATM_E3_PLCP_LINE_CELL_RATE			72000L
#define ATM_25_LINE_CELL_RATE					59259L
#define ATM_E1_CELL_LINE_CELL_RATE			4528
#define ATM_E1_PLCP_LINE_CELL_RATE			4210
#define ATM_DS1_CELL_LINE_CELL_RATE			3622
#define ATM_DS1_PLCP_LINE_CELL_RATE			3333


/*******************************************************************
ATMLineParams Description:
The ATMLineParams structure is used to configure the physical layer
and the ATM layer for the following cards: AT-9622, AT-9155, AT-9025.
The following values are valid for each card:

AT-9622:
  ucFramingMode    - ATM_OC12_FRAMING or ATM_STM4_FRAMING
  ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
  ucCellScrambling - 0 (disabled) or 1 (enabled)
  ucHecCoset       - 0 (disabled) or 1 (enabled)
  ucRxErroredCells - ATM_DROP_ERRORED_CELLS or
                     ATM_CORRECT_ERRORED_CELLS or
                     ATM_RX_ERRORED_CELLS
  ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
                     ATM_LOOPBACK_LOCAL_PHY or
                     ATM_LOOPBACK_REMOTE_PHY
  ucIdleCellHeader - Contains idle cell header without HEC byte

 AT-9155:
  ucFramingMode    - ATM_OC3_FRAMING or ATM_STM1_FRAMING
  ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
  ucCellScrambling - 0 (disabled) or 1 (enabled)
  ucHecCoset       - 0 (disabled) or 1 (enabled)
  ucRxErroredCells - ATM_DROP_ERRORED_CELLS or
							ATM_CORRECT_ERRORED_CELLS or
                     ATM_RX_ERRORED_CELLS
  ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
							ATM_LOOPBACK_LOCAL_PHY or
							ATM_LOOPBACK_REMOTE_PHY
  ucIdleCellHeader - Contains idle cell header without HEC byte

 AT-9025:
  ucFramingMode    - ATM_25_FRAMING
  ucTxClockSource  - ATM_INTERNAL_CLOCK
  ucCellScrambling - 1 (enabled)
  ucHecCoset       - 1 (enabled)
  ucRxErroredCells - ATM_DROP_ERRORED_CELLS or ATM_RX_ERRORED_CELLS
  ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
                     ATM_LOOPBACK_LOCAL_PHY or
                     ATM_LOOPBACK_REMOTE_PHY
  ucIdleCellHeader - Contains idle cell header without HEC byte
 */

typedef struct tagATMLineParams
{
	/* Line interface control flags */
	unsigned char ucFramingMode;		/* Physical layer framing	   */
	unsigned char ucTxClockSource;	/* Transmit clock source	   */
	unsigned char ucCellScrambling;	/* Cell Payload Scrambling	   */
	unsigned char ucHecCoset;			/* HEC Coset Usage			   */
	unsigned char ucRxErroredCells;	/*	Receive HEC error handling */
	unsigned char ucLoopbackEnable;	/* Loopback mode					*/

	/* Idle cell definition */
	unsigned char ucIdleCellHeader[4];	/* Idle cell value			*/

} ATMLineParams;
/* ATMLineParams Comment:
*/

/*******************************************************************
ATMDS3E3LineParams Description:
The ATMDS3E3LineParams structure is used to configure the physical
layer and the ATM layer for the following cards : AT-9034, AT-9034B
AT-9045, and AT-9045B.
The following values are valid for each card:

AT-9034: (ATM-1), AT-9034B (ATM-2)
	ucFramingMode    - ATM_E3_CELL_FRAMING or ATM_E3_PLCP_FRAMING
	ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
	ucCellScrambling - 0 (disabled) or 1 (enabled)
	ucHecCoset       - 0 (disabled) or 1 (enabled)
	ucRxErroredCells - ATM_DROP_ERRORED_CELLS or
							  ATM_CORRECT_ERRORED_CELLS or
							  ATM_RX_ERRORED_CELLS
	ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
							  ATM_LOOPBACK_LOCAL_PHY or
							  ATM_LOOPBACK_REMOTE_PHY
	ucLineBuildout   - 0
	ucIdleCellHeader - Contains idle cell header without HEC byte

 AT-9045 (ATM-1), AT-9045B (ATM-2):
	ucFramingMode    - ATM_DS3_CELL_FRAMING or ATM_DS3_PLCP_FRAMING
	ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
	ucCellScrambling - 0 (disabled) or 1 (enabled)
	ucHecCoset       - 0 (disabled) or 1 (enabled)
	ucRxErroredCells - ATM_DROP_ERRORED_CELLS or
							  ATM_CORRECT_ERRORED_CELLS or
							  ATM_RX_ERRORED_CELLS
	ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
							  ATM_LOOPBACK_LOCAL_PHY or
							  ATM_LOOPBACK_REMOTE_PHY
	ucLineBuildout -   ATM_DS3_SHORT_BUILDOUT or
							 ATM_DS3_LONG_BUILDOUT
	ucIdleCellHeader - Contains idle cell header without HEC byte
*/

typedef struct tagATMDS3E3LineParams
{
	/* Line interface control flags */
	unsigned char ucFramingMode;		/* Physical layer framing	   */
	unsigned char ucTxClockSource;	/* Transmit clock source	   */
	unsigned char ucCellScrambling;	/* Cell Payload Scrambling	   */
	unsigned char ucHecCoset;			/* HEC Coset Usage			   */
	unsigned char ucRxErroredCells;	/*	Receive HEC error handling */
	unsigned char ucLoopbackEnable;	/* Loopback mode					*/
	unsigned char ucLineBuildout;		/* Pulse shaping for PHY	   */

	/* Idle cell definition */
	unsigned char ucIdleCellHeader[4];	/* Idle cell value		   */

} ATMDS3E3LineParams;
/* ATMDS3E3LineParams Comment:
*/

/*******************************************************************
ATMDS1E1LineParams Description:
The ATMDS1E1LineParams structure is used to configure the physical
layer and the ATM layer for the following cards : AT-9015, AT-9020.
The following values are valid for each card:

AT-9015:
  ucFramingMode    - ATM_DS 1_CELL_FRAMING or ATM_DS1_PLCP_FRAMING
  ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
  ucCellScrambling - 0 (disabled) or 1 (enabled)
  ucHecCoset       - 0 (disabled) or 1 (enabled)
  ucRxErroredCells - ATM_DROP_ERRORED_CELLS or 
                     ATM_CORRECT_ERRORED_CELLS or
 					 ATM_RX_ERRORED_CELLS
  ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
							ATM_LOOPBACK_LOCAL_PHY or
							ATM_LOOPBACK_REMOTE_PHY
  ucLineBuildout   - ATM_DS1_0_TO_133_BUILDOUT or
                     ATM_DS1_133_TO_266_BUILDOUT or
                     ATM_DS1_266_TO_399_BUILDOUT or
							ATM_DS1_399_TO_266_BUILDOUT or
							ATM_DS1_533_TO_655_BUILDOUT or
                     ATM_DS1_N7X5_DB_BUILDOUT or
                     ATM_DS1_N15_DB_BUILDOUT or
							ATM_DS1_N22X5_DB_BUILDOUT
  ucLineCoding     - ATM_DS1_AMI_ENCODING or
							ATM_DS1_B8ZS_ENCODING
  ucLineFraming    - ATM_DS1_D4_LINE_FRAMING or
					  ATM_DS1_ESF_LINE_FRAMING
  ucIdleCellHeader - Contains idle cell header without HEC byte

AT-9020:
  ucFramingMode    - ATM_E1_CELL_FRAMING or
							ATM_E1_PLCP_FRAMING
  ucTxClockSource  - ATM_INTERNAL_CLOCK or ATM_LOOP_TIMED_CLOCK
  ucCellScrambling - 0 (disabled) or 1 (enabled)
  ucHecCoset       - 0 (disabled) or 1 (enabled)
  ucRxErroredCells - ATM_DROP_ERRORED_CELLS or
                     ATM_CORRECT_ERRORED_CELLS or
                     ATM_RX_ERRORED_CELLS
  ucLoopBackEnable - ATM_LOOPBACK_DISABLED or
                     ATM_LOOPBACK_LOCAL_PHY or
                     ATM_LOOPBACK_REMOTE_PHY
  ucLineBuildout   - ATM_E1_BUILDOUT or
  ucLineCoding     - ATM_E1_AMI_ENCODING or
							ATM_E1_HDB3_ENCODING
  ucLineFraming    - 0
  ucIdleCellHeader - Contains idle cell header without HEC byte
*/

typedef struct tagATMDS1E1LineParams
{
	/* Line interface control flags */
	unsigned char	ucFramingMode;		/* Physical layer framing     */
	unsigned char	ucTxClockSource;  /* Transmit clock source      */
	unsigned char	ucCellScrambling; /* Cell Payload Scrambling    */
	unsigned char	ucHecCoset;			/* HEC Coset Usage            */
	unsigned char	ucRxErroredCells; /* Receive HEC error handling	*/
	unsigned char	ucLoopbackEnable; /* Loopback mode              */
	unsigned char	ucLineBuildout;   /* Pulse shaping for PHY		*/
	unsigned char	ucLineCoding;     /* Line symbol coding			*/
	unsigned char	ucLineFraming;    /* Framing format for PHY		*/

	/* Idle cell definition */
	unsigned char	ucIdleCellHeader[4];	/* Idle cell value			*/
} ATMDS1E1LineParams;
/* ATMDS1E1LineParams Comment:
*/


/* Line interface control flags */
#define ATM_OC3_FRAMING					0
#define ATM_STM1_FRAMING				1
#define ATM_OC12_FRAMING				2
#define ATM_STM4_FRAMING				3
#define ATM_ATM25_FRAMING				4
#define ATM_DS3_CELL_FRAMING			5
#define ATM_DS3_PLCP_FRAMING			6
#define ATM_E3_CELL_FRAMING			7
#define ATM_E3_PLCP_FRAMING			8
#define ATM_DS1_CELL_FRAMING			9
#define ATM_DS1_PLCP_FRAMING			10
#define ATM_E1_CELL_FRAMING			11
#define ATM_E1_PLCP_FRAMING			12

#define ATM_INTERNAL_CLOCK				0
#define ATM_LOOP_TIMED_CLOCK			1

#define ATM_DROP_ERRORED_CELLS		0
#define ATM_CORRECT_ERRORED_CELLS	1
#define ATM_RX_ERRORED_CELLS			2

#define ATM_LOOPBACK_DISABLED			0
#define ATM_LOOPBACK_LOCAL_PHY		1
#define ATM_LOOPBACK_REMOTE_PHY		2
#define ATM_LOOPBACK_OUTPUT_TX_RX	1
#define ATM_LOOPBACK_INPUT_RX_TX		2

#define ATM_DS3_SHORT_BUILDOUT		WAN_DS3_SHORT_BUILDOUT
#define ATM_DS3_LONG_BUILDOUT			WAN_DS3_LONG_BUILDOUT
#define ATM_DS1_0_TO_133_BUILDOUT	WAN_DS1_0_TO_133_BUILDOUT		/* 0 to 133 feet		*/
#define ATM_DS1_133_TO_266_BUILDOUT	WAN_DS1_133_TO_266_BUILDOUT	/* 133 to 266 feet	*/
#define ATM_DS1_266_TO_399_BUILDOUT	WAN_DS1_266_TO_399_BUILDOUT	/* 266 to 399 feet	*/
#define ATM_DS1_399_TO_533_BUILDOUT	WAN_DS1_399_TO_533_BUILDOUT	/* 399 to 533 feet	*/
#define ATM_DS1_533_TO_655_BUILDOUT	WAN_DS1_533_TO_655_BUILDOUT	/* 533 to 655 feet	*/
#define ATM_DS1_N7X5_DB_BUILDOUT		WAN_DS1_N7X5_DB_BUILDOUT		/* -7.5 dB of attenuation	*/
#define ATM_DS1_N15_DB_BUILDOUT		WAN_DS1_N15_DB_BUILDOUT			/* -15 dB of attenuation	*/
#define ATM_DS1_N22X5_DB_BUILDOUT	WAN_DS1_N22X5_DB_BUILDOUT		/* -22.5 dB of attenuation	*/

#define ATM_E1_BUILDOUT					WAN_E1_BUILDOUT

#define ATM_DS1_AMI_ENCODING			WAN_DS1_AMI_ENCODING
#define ATM_DS1_B8ZS_ENCODING			WAN_DS1_B8ZS_ENCODING

#define ATM_DS1_D4_LINE_FRAMING		WAN_DS1_D4_LINE_FRAMING
#define ATM_DS1_ESF_LINE_FRAMING		WAN_DS1_ESF_LINE_FRAMING

#define ATM_E1_HDB3_ENCODING			WAN_E1_HDB3_ENCODING
/* The value of this constant should be 2 since this is what the AT-9020 card expects (CR19369) */
#define ATM_E1_AMI_ENCODING	      2 /* previously set to WAN_E1_AMI_ENCODING */

/*****************************************************************************/
/*
 * FRACTIONAL CELL TIME (currently represented in 23.8 integer format)
 * e.g. 17.25 = 17.25 * 256 = 0x00001140
 */
typedef long ATMCellTime;
#define ATM_CELL_TIME_FRAC				8

/*******************************************************************
ATMStream Description:
The ATMStream structure is used to define what is signaled for a
data stream and what the performance of the data stream will be once
it is established.
Defined values for

Connection type:
STR_CONN_TYPE_PVC					0
STR_CONN_TYPE_SVC					1
STR_CONN_TYPE_INCOMING_SVC		2

Encapsulation type:
STR_ENCAP_TYPE_NULL						0
STR_ENCAP_TYPE_LANE_802_3				1
STR_ENCAP_TYPE_LANE_802_5				2
STR_ENCAP_TYPE_RFC1577					3
STR_ENCAP_TYPE_LLC_PPP					4
STR_ENCAP_TYPE_VC_MULTIPLEXED_PPP	5
STR_ENCAP_TYPE_LLC_PPPOE				6	- PPPoE only
STR_ENCAP_TYPE_LLC_VCM_PPPOE			7  - PPPoE only

Rate class:
STR_RATE_CLASS_CBR					0
STR_RATE_CLASS_VBR					1
STR_RATE_CLASS_UBR					2
STR_RATE_CLASS_ABR					3


ATM traffic descriptor type (Forward and Backward):
ATM_TD_QUAL_PEAK_RATES			0
ATM_TD_QUAL_PEAK_RATES_W_TAG	1
ATM_TD_COMBO_RATES			  	2
ATM_TD_COMBO_RATES_W_TAG	  	3
ATM_TD_AGGR_PEAK_RATE		  	4
ATM_TD_AGGR_COMBO_RATES			5
ATM_TD_BEST_EFFORT			  	6
ATM_TD_NONE							7

Quality of service class:
ATM_QOS_CLASS_0				  	0
ATM_QOS_CLASS_1				  	1
ATM_QOS_CLASS_2				  	2
ATM_QOS_CLASS_3				  	3
ATM_QOS_CLASS_4				  	4

 Broadband bearer capability class:
ATM_B_BC_CLASS_X					16
ATM_B_BC_CLASS_A					1
ATM_B_BC_CLASS_C					3

Broadband bearer capability timing requirement:
ATM_B_BC_NO_TIMING_INFO			0
ATM_B_BC_END_TO_END_TIMING		1
ATM_B_BC_NO_END_TO_END_TIMING	2

Broadband bearer capability traffic type:
ATM_B_BC_TYPE_NONE				0
ATM_B_BC_TYPE_CBR				4
ATM_B_BC_TYPE_VBR				8

Broadband bearer capability clipping susceptibility:
ATM_B_BC_SUSC_CLIP				32
ATM_B_BC_NOT_SUSC_CLIP			0

typedef long ATMCellTime;
FRACTIONAL CELL TIME (currently represented in 23.8 integer format)
e.g. 17.25 = 17.25 * 256 = 0x00001140(4416)

*/

typedef struct tagATMStream
{
	unsigned short	uiIndex;			/* Stream Index                   			*/

	/* Connection parameters */
	unsigned char	ucConnType;		/* use Connection type" defines
												STR_CONN_TYPE_PVC
												STR_CONN_TYPE_SVC
												STR_CONN_TYPE_INCOMING_SVC     			*/
	unsigned char	ucEncapType;	/* use "encapsulation type" defines
												STR_ENCAP_TYPE_NULL (SNAP)
												STR_ENCAP_TYPE_LANE_802_3
												STR_ENCAP_TYPE_LANE_802_5
												STR_ENCAP_TYPE_RFC1577 (Classical IP)
												STR_ENCAP_TYPE_LLC_PPP
												STR_ENCAP_TYPE_VC_MULTIPLEXED_PPP		*/

	unsigned char	ucGenRateClass;/* use "rate class" defines
												STR_RATE_CLASS_CBR
												STR_RATE_CLASS_VBR
												STR_RATE_CLASS_UBR
												STR_RATE_CLASS_ABR							*/
	unsigned long	ulGenPCR;		/* Peak Cell Rate (cells/sec)     			*/
	unsigned long	ulGenSCR;		/* Sustainable Cell Rate (cells/sec) 		*/
	unsigned long	ulGenMBS;		/* Maximum Burst Size (cells)	    			*/
	ATMCellTime		ctGenCDVT;		/* Cell Delay Variation Tolerance(Time)	
									1 ctGenCDVT is equivalent to 265 units
									*/

	/*
	 * Signaled rate parameters
	 */
	/* ATM Traffic Descriptor Information Element */
	/* Forward connection */
	unsigned char	ucFwdTdType;	/* one of ATM_TD values (Traffic Desc)		*/
	unsigned long	ulFwdPCR0;		/* PCR 0 rate (cells/sec)						*/
	unsigned long	ulFwdPCR01;		/* PCR 0+1 rate (cells/sec)					*/
	unsigned long	ulFwdSCR0;		/* SCR 0 rate (cells/sec)						*/
	unsigned long	ulFwdSCR01;		/* SCR 0+1 rate (cells/sec)					*/
	unsigned long	ulFwdMBS0;		/* MBS 0 (cells)									*/
	unsigned long	ulFwdMBS01;		/* MBS 0+1 (cells)								*/

	/* Backward connection */
	unsigned char	ucBwdTdType;	/* one of ATM_TD values (Traffic Desc)		*/
	unsigned long	ulBwdPCR0;		/* PCR 0 rate (cells/sec)						*/
	unsigned long	ulBwdPCR01;		/* PCR 0+1 rate (cells/sec)					*/
	unsigned long	ulBwdSCR0;		/* SCR 0 rate (cells/sec)						*/
	unsigned long	ulBwdSCR01;		/* SCR 0+1 rate (cells/sec)					*/
	unsigned long	ulBwdMBS0;		/* MBS 0 (cells)									*/
	unsigned long	ulBwdMBS01;		/* MBS 0+1 (cells)								*/

	/* Quality of Service Information Element */
	unsigned char	ucFwdQoS;		/* Forward - one of ATM_QOS values			*/
	unsigned char	ucBwdQoS;		/* Backward - one of ATM_QOS values			*/

	/* Broadband Bearer Capability Information Element */
	unsigned char	ucBcClass;		/* One of ATM_B_BC_CLASS values				*/
	unsigned char	ucTimingReq;	/* One of ATM_B_BC timing values				*/
	unsigned char	ucTrafficType;	/* One of ATM_B_BC_TYPE values				*/
	unsigned char	ucClipping;		/* One of ATM_B_BC clipping values			*/

	/* Cell header */
	unsigned long	ulCellHeader;	/* Specified for PVC, ignored for SVC		*/

	/* Destination addresses.  The following are to be specified for SVC's.	*/
	unsigned char	ucDestAtmAddr[20];/* Specified for SVC, ignored PVC*/
	unsigned char	ucDestMacAddr[6];	/* Specified for LANE or ignored.		*/
	unsigned char	ucDestIpAddr[4];	/* Specified for CLIP or ignored.  This
													is the Gateway address.					*/

	/* Encapsulation-specific fields */
	unsigned char	ucSnapHeader[5];			/* Not Used								*/
	unsigned char	ucElanInst;					/* LANE only 0 to LECs - 1			*/
} ATMStream;		/* STREAM_PARAMS; */
/* ATMStream Comment:
This structure defines the information elements used in signaling
a new connection if it is an SVC and the actual generation
characteristics of the stream once a connection is established
(SVC or PVC).  This structure is not intended to be used by a
signaling test, but it is intended to be used for all other
applications.
Before modifying an existing stream, the stream must be disconnected.
*/


/* Connection type */
#define STR_CONN_TYPE_PVC					0
#define STR_CONN_TYPE_SVC					1
#define STR_CONN_TYPE_INCOMING_SVC		2

/* Encapsulation type */
#define STR_ENCAP_TYPE_NULL					0
#define STR_ENCAP_TYPE_LANE_802_3			1
#define STR_ENCAP_TYPE_LANE_802_5			2
#define STR_ENCAP_TYPE_RFC1577				3
#define STR_ENCAP_TYPE_LLC_PPP				4
#define STR_ENCAP_TYPE_VC_MULTIPLEXED_PPP	5
#define STR_ENCAP_TYPE_LLC_PPPOE				6
#define STR_ENCAP_TYPE_LLC_VCM_PPPOE		7

/* Rate class */
#define STR_RATE_CLASS_CBR					0
#define STR_RATE_CLASS_VBR					1
#define STR_RATE_CLASS_UBR					2
#define STR_RATE_CLASS_ABR					3

/*******************************************************************
ATMFrameDefinition Description:
This structure allows the user to define a frame's contents and to
associate a frame with a particular stream.  When this data is sent
to the card the frame definition will fail if the stream index is
greater than the maximum number of streams supported by our card or
if the stream to which the frame will be bound has not been defined
yet or if the associated stream does exist and the connection is open.
The frame length defines the length of the user data to be segmented
in the aal5 layer.  The custom frame data is placed into the frame
first.  If there is still more data required to complete the frame
then the remaining bytes of the frame are filled with the fill
pattern.  This data structure is intended to be used with the frame
length set equal to or greater than the data length.  If the data
length is greater than the frame length then only the first frame
length bytes of the custom data are used in the definition of the
frame.
The ulFrameFlags field can be used to inject CRC-32 or length errors by
setting this field to FRAME_FLAG_CRC32_ERROR or FRAME_FLAG_LENGTH_ERROR,
respectively.  If the user wishes to use this frame as the basis for
other stream's frames, then this field should be set to
FRAME_FLAG_SOURCE_FRAME_FOR_COPY.
For Example:
	uiDataLength = 10
	uiFrameLength = 14
	ucFrameData[] = 0x0102030405060708090A0B0C0D....
	uiFrameFillPattern = 0xABCD
	The defined frame becomes: 0x0102030405060708090AABCDABCD

Example 2:
	uiDataLength = 10
	uiFrameLength = 8
	ucFrameData[] = 0x0102030405060708090A0B0C0D....
	uiFrameFillPattern = 0xABCD
	The defined frame becomes: 0x0102030405060708
*/
typedef struct tagATMFrameDefinition
{
	unsigned short	uiStreamIndex;	/* Stream identifier/index				*/
	unsigned short	uiFrameLength;	/* The total length of the frame		*/
	unsigned short	uiDataLength;	/* The length of the custom data		*/
	unsigned short	uiFrameFillPattern;	/* Fill pattern word				*/
	unsigned long	ulFrameFlags;	/* Special frame generation flags	*/
	unsigned char	ucFrameData[2048];	/* Custom frame data				*/
} ATMFrameDefinition;
/* ATMFrameDefinition Comment:
*/

/* Frame flags */
#define FRAME_FLAG_CRC32_ERROR					0x00000001	/* ATM-2 only */
#define FRAME_FLAG_LENGTH_ERROR					0x00000002	/* ATM-2 only */
#define FRAME_FLAG_SOURCE_FRAME_FOR_COPY		0x00000004	/* ATM-2 only */

/*****************************************************************************
ATMConnection Description:
Defines the content of a connection for the signaling test.  This
structure assumes that the ATM address list and the call parameters
for the signaling test have already been defined.  Essentially,
there are three types of signaling tests which can be run: a smooth
test, a bursty test, and a random distribution test.  A signaling
test works by creating a series of machines which will attempt to
establish a connection and teardown a certain number of times as
defined by ulCallCountLimit.  The parameters at the top of the
structure define what is signaled to the DUT when a call connection
is attempted.  The "stop on error" field allows this machine to quit
attempting further calls if one of its previous calls were released
by the switch while a call was proceeding or after a call was
established.  There are three types of initiating timings as
follows:

  SMOOTH: The time from a call teardown to a call initiation is
		constant and defined by the ulInterCallGap.

  BURSTY: The time from a call teardown to a call initiation is
		initially defined by the ulBurstGap for the first
		ulBurstCount calls and then defined by the
		ulInterCallGap for the remaining calls.

  RANDOM: The time from a call teardown to a call initiation is
		calculated between each call to be
		ulInterCallGap + random(ulInterCallGapDelta).

  There are also three types of completion timings as follows:
  CONST:  The time from a call connection to initiating a call
		  teardown is constant and defined by ulCallLength.
		  Calls will be torn down at this time independent
		  of their current connection state.

  CONST_FROM_SETUP: The time from a call setup to initiating a
		  call teardown is constant and defined by ulCallLength.
		  Calls which are not complete at this point in time
		  will be allowed to complete before a new call is
		  initiated.

  RANDOM: The time from a call connection to initiating a call
		  teardown is calculated for each call to be
		  ulCallLength + random(ulRandomLengthDelta)
		  Calls will be torn down at this time independent
		  of their current connection state.

  Connection type:
  ATM_CONN_TYPE_PVC							0
  ATM_CONN_TYPE_SVC							1

  Rate class:
  ATM_RATE_CLASS_CBR						0
  ATM_RATE_CLASS_VBR						1
  ATM_RATE_CLASS_UBR						2

  Call distribution type:
  ATM_CALL_DIST_SMOOTH				   	0
  ATM_CALL_DIST_BURSTY						1
  ATM_CALL_DIST_RANDOM				   	2

  Call length type:
  ATM_CALL_LENGTH_CONST					0
  ATM_CALL_LENGTH_CONST_FROM_SETUP		1
  ATM_CALL_LENGTH_RANDOM					2
  ATM_CALL_LENGTH_FOREVER					3
  ATM_CALL_LENGTH_FOREVER_FREE			4
  
  typedef long ATMCellTime;
  FRACTIONAL CELL TIME (currently represented in 23.8 integer format)
  e.g. 17.25 = 17.25 * 256 = 0x00001140(4416)
 */
typedef struct tagATMConnection
{
	unsigned long 	ulIndex;			/* Connection Number								*/
	unsigned char	ucType;			/* PVC or SVC										*/
	unsigned char	ucRateClass;	/* CBR, VBR, or UBR 								*/
	unsigned long	ulRatePCR;		/* CBR, VBR, UBR Peak Cell Rate				*/
	unsigned long	ulRateSCR;   	/*	VBR Sustainable Cell Rate 					*/
	unsigned long	ulRateMBS;		/*	VBR Max Burst Size							*/
	ATMCellTime		ctCellDelayVar;/* CBR, VBR Cell Delay Variation				
									1 ctCellDelayVar is equivalent to 265 units
									*/
	unsigned long	ulCellHeader;	/* Cell header - for GFC, PT, CLP			*/

/* The remaining fields are only significant for SVC connections  			*/
/* Delay/gap/timer values are specified in 1 microsecond ticks    			*/

	unsigned short	uiCallSetupIndex;		/* Corresponding call info index		*/
	unsigned short	uiAddressIndex;  		/* Corresponding ATM addr. index		*/

	unsigned char	ucCallDistType;  		/* One of ATM_CALL_DIST types			*/
	unsigned char	ucCallLengthType;		/* One of ATM_CALL_LENGTH types		*/

	unsigned char	ucStopOnError;			/* Stop on unexpected call release	*/
	unsigned char	ucLogEvents;			/* Set to 0									*/

	unsigned char	ucEnableCellLoadGen;	/* Set to 0									*/

	unsigned long	ulCallStartDelay;		/* Time from start to first call		*/
	unsigned long	ulCallCountLimit;		/* The no. of calls to attempt 		*/

	unsigned long	ulCallLength;			/* Minimum wait before teardown 		*/
													/* in microseconds            		*/
	unsigned long	ulRandomLengthDelta;	/* The time variation					*/

	unsigned long	ulInterCallGap;		/* Min wait before initiation  		*/
	unsigned long	ulRandomGapDelta;		/* The time variation					*/

	unsigned long	ulBurstCount;	  		/* Number of calls to burst			*/
	unsigned long	ulInterBurstGap; 		/* Min wait before teardown    		*/
} ATMConnection;
/* ATMConnection Comment:
*/

/*******************************************************************
ATMConnectionEx Description:
Same as the ATMConnection structure definition with the addition of
ABR.

  Rate class:
  ATM_RATE_CLASS_CBR						0
  ATM_RATE_CLASS_VBR						1
  ATM_RATE_CLASS_UBR						2
  ATM_RATE_CLASS_ABR						3


  typedef long ATMCellTime;
  FRACTIONAL CELL TIME (currently represented in 23.8 integer format)
  e.g. 17.25 = 17.25 * 256 = 0x00001140(4416)
*/

typedef struct tagATMConnectionEx
{
	unsigned long 	ulIndex;					/* Connection Number 					*/
	unsigned char	ucType;					/* PVC or SVC								*/
	unsigned char	ucRateClass;			/* CBR, VBR, or UBR or ABR*/
	unsigned long	ulRatePCR;				/* CBR, VBR, UBR , ABR Peak Cell Rate	*/
	unsigned long	ulRateSCR;				/*	VBR Sustainable Cell Rate 			*/
	unsigned long	ulRateMBS;				/*	VBR Max Burst Size					*/
	ATMCellTime		ctCellDelayVar;		/* CBR, VBR Cell Delay Variation		
										1 ctCellDelayVar is equivalent to 265 units
										*/
	unsigned long	ulCellHeader;			/* Cell header - for GFC, PT, CLP	*/

/* The remaining fields are only significant for SVC connections  			*/
/* Delay/gap/timer values are specified in 1 microsecond ticks    			*/

	unsigned short	uiCallSetupIndex;		/* Corresponding call info index		*/
	unsigned short	uiAddressIndex;  		/* Corresponding ATM addr. index		*/

	unsigned char	ucCallDistType;  		/* One of ATM_CALL_DIST types			*/
	unsigned char	ucCallLengthType;		/* One of ATM_CALL_LENGTH types		*/

	unsigned char	ucStopOnError;			/* Stop on unexpected call release	*/
	unsigned char	ucLogEvents;			/* Set to 0									*/

	unsigned char	ucEnableCellLoadGen;	/* Set to 0									*/

	unsigned long	ulCallStartDelay;		/* Time from start to first call		*/
	unsigned long	ulCallCountLimit;		/* The no. of calls to attempt 		*/

	unsigned long	ulCallLength;	 		/* Minimum wait before teardown 		*/
													/* in microseconds            		*/
	unsigned long	ulRandomLengthDelta;	/* The time variation					*/

	unsigned long	ulInterCallGap;  		/* Min wait before initiation  		*/
	unsigned long	ulRandomGapDelta;		/* The time variation					*/

	unsigned long	ulBurstCount;	  		/* Number of calls to burst			*/
	unsigned long	ulInterBurstGap; 		/* Min wait before teardown    		*/

	/*	for UNI 4.0 ABR service	*/
	unsigned long	ulRateMCR;				/* Minimum Cell Rate						*/
} ATMConnectionEx;
/* ATMConnectionEx Comment:
*/

/* Connection type */
#define ATM_CONN_TYPE_PVC						0
#define ATM_CONN_TYPE_SVC						1

/* Rate class */
#define ATM_RATE_CLASS_CBR						0
#define ATM_RATE_CLASS_VBR						1
#define ATM_RATE_CLASS_UBR						2
#define ATM_RATE_CLASS_ABR						3

/* Call distribution type */
#define ATM_CALL_DIST_SMOOTH				   0
#define ATM_CALL_DIST_BURSTY					1
#define ATM_CALL_DIST_RANDOM				   2

/* Call length type */
#define ATM_CALL_LENGTH_CONST					0
#define ATM_CALL_LENGTH_CONST_FROM_SETUP	1
#define ATM_CALL_LENGTH_RANDOM				2
#define ATM_CALL_LENGTH_FOREVER				3
#define ATM_CALL_LENGTH_FOREVER_FREE		4

/* These definitions define how long the signaling test should
	leave a call in the established state.
	ATM_CALL_LENGTH_CONST:	The call_length defines the minimum amount of
									in milliseconds from the time the call established
									message is received until the call release message
									is sent.

	ATM_CALL_LENGTH_CONST_FROM_SETUP:
									The call_length defines the minimum amount of
									in milliseconds from the time the call setup
									message is sent until the call release message
									is sent.

	ATM_CALL_LENGTH_RANDOM:
									The call_length + a random number between 0 and
									call_length_random_delta defines the minimum
									amount of in milliseconds from the time the
									call setup message is sent until the call
									release message is sent.

	  ATM_CALL_LENGTH_FOREVER:
									The call is never torn down until a message
									is received which instructs the test to release
									all of its calls.

	ATM_CALL_LENGTH_FOREVER_FREE:
										The internal call data structure is freed to be
									reused, but the call is not released.  The call
									will stay up until a UNI RESTART is sent to the
									switch.  This is useful for setting up large
									numbers of calls in the switch without accounting
									for each and every call.
*/

/* Call delay/timer/gap period */
#define ATM_CALL_TMR_TICKS_PER_SEC			1000
#define ATM_CALL_TMR_TICK_RESOLUTION		1000000L

/*******************************************************************
ATMConnectionCopyParams Description:
The copy params structure allows a sequence of connections already
configured on the target card to be copied to another range of
connections.  This structure allows the user to copy an existing
range of existing connections to a new range of connections in
preparation for a signaling test.  This parameter is used to bypass
the lengthy downloads which would result from sending all of the
duplicated connection data over the serial port.  This structure
specifies a source connection index which specifies the first
connection to be copied.  This structure defines the first target
destination index of the copy.  Finally, the structure includes the
desired number of connections to copy. The actual number of copies
which will be made may be reduced from the desired if a connection
is attempted to be used as both a source and a destination within the
same command.

 Example 1: ("Normal" operation)
  Source = 1, Dest = 5, Count = 3
	  Before                 After
 Index	Configuration	Index	Configuration
	1         A            1          A
	2         B            2          B
	3         C            3          C
	4         D            4          D
	5         E            5          A
	6         F            6          B
	7         G            7          C
	8         H            8          H

Example 2: ("Incorrect" operation)
  Source = 1, Dest = 3, Count = 4
	  Before						After
 Index	Configuration   Index	Configuration
	1         A            1          A
	2         B            2          B
	3         C            3          A
	4         D            4          B
	5         E            5          E
	6         F            6          F
	7         G            7          G
	8         H            8          H

Example 2 fails when the source of a copy is the same as the
destination address of the first copy (3).  In this case only
two connections were copied instead of the requested 4.
*/

typedef struct tagATMConnectionCopyParams
{
	unsigned long ulSrcIndex;	/* The starting source range index	*/
	unsigned long ulDstIndex;	/* The starting dest range index		*/
	unsigned long ulCount;		/* The number of conns to copy		*/
} ATMConnectionCopyParams;
/* ATMConnectionCopyParams Comment:
*/


/*******************************************************************
ATMConnectionModify Description:
The modify connections structure allows a sequence of connections
already configured on the target card to have one of their fields
modified with successively increasing values.  This structure will
modify a particular field of ulCount successive connections with a
constantly changing value.  The parameter identified in ulType
indicates which field of the connection structure is of interest.
The identified field of the connection at uiSrcIndex is taken to be
the starting value for the modify.  The value is increased by
delta and the new value is written into the next connection
(connection number ulSrcIndex+1).  The new value is increased again
by delta and written to the next connection.  This process repeats
until ulCount connections have been written with a new value.

The ulType field of interest is identified by one of the following:
ATM_CALL_PARAM_CONN_TYPE                 	0
ATM_CALL_PARAM_RATE_CLASS                	1
ATM_CALL_PARAM_PCR                       	2
ATM_CALL_PARAM_SCR                       	3
ATM_CALL_PARAM_MBS                       	4
ATM_CALL_PARAM_CDVT                      	5
ATM_CALL_PARAM_CELL_HEADER               	6
ATM_CALL_PARAM_CALL_SETUP_PARAMS_INDEX   	7
ATM_CALL_PARAM_CALL_ADDR_INDEX           	8
ATM_CALL_PARAM_CALL_DIST_TYPE            	9
ATM_CALL_PARAM_CALL_LENGTH_TYPE		   	10
ATM_CALL_PARAM_CALL_STOP_ON_ERROR       	11
ATM_CALL_PARAM_CALL_LOG_EVENTS          	12
ATM_CALL_PARAM_CELL_LOAD_GEN_ENABLE     	13
ATM_CALL_PARAM_CALL_DELAY_FROM_START    	14
ATM_CALL_PARAM_CALL_COUNT_LIMIT         	15
ATM_CALL_PARAM_CALL_LENGTH              	16
ATM_CALL_PARAM_CALL_LENGTH_RND_DELTA    	17
ATM_CALL_PARAM_INTER_CALL_GAP           	18
ATM_CALL_PARAM_INTER_CALL_GAP_RND_DELTA	19
ATM_CALL_PARAM_BURST_COUNT              	20
ATM_CALL_PARAM_INTER_BURST_GAP          	21



For Example:
  Source = 3, Count = 3, Delta = 2
	  Before				After
 Index   Value       Index   Value
	1      10           1      10
	2       8           2       8
	3       3           3       3
	4      30           4       5
	5      27           5       7
	6      58           6       9
	7      15           7      15
	8      12           8      12
	9       1           9       1
*/

typedef struct tagATMConnectionModify
{
	unsigned long	ulSrcIndex;	/* Conn holds starting field value	*/
	unsigned long	ulCount;		/* Number of conns to change		 	*/
	unsigned long	ulType;		/* Identifies which field to change.*/
	long		      lDelta;		/* Successive increment value			*/
} ATMConnectionModify;
/* ATMConnectionModify Comment:
*/

/*******************************************************************
ATMConnectionModifyArray Description:
The modify connections array structure allows a sequence of
connections already configured on the target card to have one of
their fields modified with user-supplied data.

The ulSrcIndex specifies the index of the first connection
which is modified.  It modifies a particular field of ulCount successive
connections with user specified values.

The parameter identified in ulID indicates which field of the
Connection structure is to be modified. This is defined as follows:
ATM_CALL_PARAM_CONN_TYPE                 	0
ATM_CALL_PARAM_RATE_CLASS                	1
ATM_CALL_PARAM_PCR                       	2
ATM_CALL_PARAM_SCR                       	3
ATM_CALL_PARAM_MBS                       	4
ATM_CALL_PARAM_CDVT                      	5
ATM_CALL_PARAM_CELL_HEADER               	6
ATM_CALL_PARAM_CALL_SETUP_PARAMS_INDEX   	7
ATM_CALL_PARAM_CALL_ADDR_INDEX           	8
ATM_CALL_PARAM_CALL_DIST_TYPE            	9
ATM_CALL_PARAM_CALL_LENGTH_TYPE		   	10
ATM_CALL_PARAM_CALL_STOP_ON_ERROR       	11
ATM_CALL_PARAM_CALL_LOG_EVENTS          	12
ATM_CALL_PARAM_CELL_LOAD_GEN_ENABLE     	13
ATM_CALL_PARAM_CALL_DELAY_FROM_START    	14
ATM_CALL_PARAM_CALL_COUNT_LIMIT         	15
ATM_CALL_PARAM_CALL_LENGTH              	16
ATM_CALL_PARAM_CALL_LENGTH_RND_DELTA    	17
ATM_CALL_PARAM_INTER_CALL_GAP           	18
ATM_CALL_PARAM_INTER_CALL_GAP_RND_DELTA	19
ATM_CALL_PARAM_BURST_COUNT              	20
ATM_CALL_PARAM_INTER_BURST_GAP          	21

 The ulValues array contains the values which
will be placed into the successive connections.

For Example:
  Count = 3, SrcIndex = 2, Values = { 6, 5, 4 }
	  Before				After
 Index   Value      Index    Value
	1      10          1       10
	2       8          2        6
	3       3          3        5
	4      30          4        4
	5      27          5       27
	6      58          6       58
	7       9          7        9
	8      12          8       12
	9       1          9        1
*/

typedef struct tagATMConnectionModifyArray
{
	unsigned long		ulSrcIndex;
	unsigned long		ulCount;
	unsigned long		ulID;				/* Defined below */
	unsigned long		ulArraySize; 	/* reserved - Currently
												 it is the same as ulCount */
	unsigned long		ulValues[ATM_MAX_ARRAY_DIM];
} ATMConnectionModifyArray;
/* ATMConnectionModifyArray Comment:
*/

/*******************************************************************
 Connection parameter id's
 These defines map to the fields of the ATMConnection structure
 above.
 These id's are used to specify the ulType in ATMConnectionModify
 and the ulID in ATMConnectionModifyArray structures respectively.
*/
#define ATM_CALL_PARAM_CONN_TYPE                 0
#define ATM_CALL_PARAM_RATE_CLASS                1
#define ATM_CALL_PARAM_PCR                       2
#define ATM_CALL_PARAM_SCR                       3
#define ATM_CALL_PARAM_MBS                       4
#define ATM_CALL_PARAM_CDVT                      5
#define ATM_CALL_PARAM_CELL_HEADER               6
#define ATM_CALL_PARAM_CALL_SETUP_PARAMS_INDEX   7
#define ATM_CALL_PARAM_CALL_ADDR_INDEX           8
#define ATM_CALL_PARAM_CALL_DIST_TYPE            9
#define ATM_CALL_PARAM_CALL_LENGTH_TYPE		   10
#define ATM_CALL_PARAM_CALL_STOP_ON_ERROR       11
#define ATM_CALL_PARAM_CALL_LOG_EVENTS          12
#define ATM_CALL_PARAM_CELL_LOAD_GEN_ENABLE     13
#define ATM_CALL_PARAM_CALL_DELAY_FROM_START    14
#define ATM_CALL_PARAM_CALL_COUNT_LIMIT         15
#define ATM_CALL_PARAM_CALL_LENGTH              16
#define ATM_CALL_PARAM_CALL_LENGTH_RND_DELTA    17
#define ATM_CALL_PARAM_INTER_CALL_GAP           18
#define ATM_CALL_PARAM_INTER_CALL_GAP_RND_DELTA	19
#define ATM_CALL_PARAM_BURST_COUNT              20
#define ATM_CALL_PARAM_INTER_BURST_GAP          21


/*******************************************************************
ATMCallSetupParams Description:
This structure is invoked if running UNI 3.0/3.1
The ATMCallSetupParams structure defines what is signaled by the
signaling test when attempting to make a call setup.  This structure
is only used for the signaling test and should not be used when
attempting to establish an SVC over which data will actually be
sent.

 Defined values for
  ATM traffic descriptor type (Forward and Backward):
  ATM_TD_QUAL_PEAK_RATES			0
  ATM_TD_QUAL_PEAK_RATES_W_TAG	1
  ATM_TD_COMBO_RATES					2
  ATM_TD_COMBO_RATES_W_TAG			3
  ATM_TD_AGGR_PEAK_RATE				4
  ATM_TD_AGGR_COMBO_RATES			5
  ATM_TD_BEST_EFFORT					6
  ATM_TD_NONE 							7

 Quality of service class:
  ATM_QOS_CLASS_0						0
  ATM_QOS_CLASS_1						1
  ATM_QOS_CLASS_2						2
  ATM_QOS_CLASS_3						3
  ATM_QOS_CLASS_4						4

 Broadband bearer capability class:
  ATM_B_BC_CLASS_X					16
  ATM_B_BC_CLASS_A					1
  ATM_B_BC_CLASS_C					3

 UNI 3.0/3.1 only
 Broadband bearer capability timing requirement:
  ATM_B_BC_NO_TIMING_INFO			0
  ATM_B_BC_END_TO_END_TIMING		1
  ATM_B_BC_NO_END_TO_END_TIMING	2


 Broadband bearer capability traffic type:
  ATM_B_BC_TYPE_NONE					0
  ATM_B_BC_TYPE_CBR					4
  ATM_B_BC_TYPE_VBR					8


 Broadband bearer capability clipping susceptibility:
  ATM_B_BC_SUSC_CLIP					32
  ATM_B_BC_NOT_SUSC_CLIP			0
 */

typedef struct 	tagATMCallSetupParams
{
	unsigned short	uiCallSetupIndex;		/* The index of the machine 				*/

	/* ATM Traffic Descriptor Information Element */
	unsigned long	ulFwdTrafficDescriptorType; /* one of ATM_TD from below		*/
	unsigned long	ulFwdPCR_0;				/* Peak cell rate 0 in cells/sec			*/
	unsigned long	ulFwdPCR_01;			/* Peak cell rate 0+1 in cells/sec		*/
	unsigned long	ulFwdSCR_0;				/* Sus cell rate 0 in cells/sec			*/
	unsigned long	ulFwdSCR_01;			/* Sus cell rate 0+1in cells/sec			*/
	unsigned long	ulFwdMBS_0;				/* Maximum Burst Size 0 in cells			*/
	unsigned long	ulFwdMBS_01;			/* Maximum Burst Size 0+1 in cells		*/

	unsigned long	ulBwdTrafficDescriptorType; /* one of ATM_TD from below		*/
	unsigned long	ulBwdPCR_0;				/* Peek cell rate 0 in cells/sec			*/
	unsigned long	ulBwdPCR_01;			/* Peek cell rate 0+1 in cells/sec		*/
	unsigned long	ulBwdSCR_0;				/* Sus cell rate 0 in cells/sec			*/
	unsigned long	ulBwdSCR_01;			/* Sus cell rate 0+1in cells/sec			*/
	unsigned long	ulBwdMBS_0;				/* Maximum Burst Size 0 in cells			*/
	unsigned long	ulBwdMBS_01;			/* Maximum Burst Size 0+1 in cells		*/

	/* Quality of Service Information Element */
	unsigned char	ucFwdQOS;				/* Forward - one of ATM_QOS values		*/
	unsigned char	ucBwdQOS;				/* Backward - one of ATM_QOS values		*/

	/* Broadband Bearer Capability Information Element */
	unsigned char	ucBbcClass;				/* One of ATM_B_BC_CLASS values			*/
	unsigned char	ucBbcTimingReq;		/* One of ATM_B_BC timing values			*/
	unsigned char	ucBbcTrafficType;		/* One of ATM_B_BC_TYPE values			*/
	unsigned char	ucBbcSusceptibleToClipping;	/* ATM_B_BC clipping values	*/
} ATMCallSetupParams;
/* ATMCallSetupParams Comment:
*/

/*******************************************************************
ATMCallSetupParamsEx Description:
Same as the ATMCallSetupParams structure definition, difference
being in some of the Traffic configuration parameters, defined
as follows:

Defined values for

 ATM traffic descriptor type (Forward and Backward):
  ATM_TD_QUAL_PEAK_RATES			0
  ATM_TD_QUAL_PEAK_RATES_W_TAG		1
  ATM_TD_COMBO_RATES				2
  ATM_TD_COMBO_RATES_W_TAG			3
  ATM_TD_AGGR_PEAK_RATE				4
  ATM_TD_AGGR_COMBO_RATES			5
  ATM_TD_BEST_EFFORT				6
  ATM_TD_ABR						7

Quality of service class (Forward and Backward):
 ATM_QOS_CLASS_0					0
 ATM_QOS_CLASS_1					1
 ATM_QOS_CLASS_2					2
 ATM_QOS_CLASS_3					3
 ATM_QOS_CLASS_4					4

 Broadband bearer capability class:
  ATM_B_BC_CLASS_X					16
  ATM_B_BC_CLASS_A					1
  ATM_B_BC_CLASS_C					3
  ATM_B_BC_CLASS_VP					24

Broadband bearer capability traffic type (UNI 3.0/3.1):
 ATM_B_BC_TYPE_NONE					0
 ATM_B_BC_TYPE_CBR					4
 ATM_B_BC_TYPE_VBR					8


Broadband bearer capability (ATC) traffic type (UNI 4.0):
  ATM_B_BC_UNI40_NONE					0
  ATM_B_BC_UNI40_CBR					5
  ATM_B_BC_UNI40_CBR_01					7
  ATM_B_BC_UNI40_REAL_TIME_VBR			9
  ATM_B_BC_UNI40_REAL_TIME_VBR_01		19
  ATM_B_BC_UNI40_NONE_REAL_TIME_VBR  	10
  ATM_B_BC_UNI40_NONEREAL_TIME_VBR_01	11
  ATM_B_BC_UNI40_ABR					12
 */

typedef struct tagATMCallSetupParamsEx
{
	unsigned short	uiCallSetupIndex;		/* The index of the machine			*/

	/* ATM Traffic Descriptor Information Element */
	unsigned long	ulFwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulFwdPCR_0;				/* Peak cell rate 0 in cells/sec		*/
	unsigned long	ulFwdPCR_01;			/* Peak cell rate 0+1 in cells/sec	*/
	unsigned long	ulFwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulFwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulFwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulFwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	unsigned long	ulBwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulBwdPCR_0;				/* Peek cell rate 0 in cells/sec		*/
	unsigned long	ulBwdPCR_01;			/* Peek cell rate 0+1 in cells/sec	*/
	unsigned long	ulBwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulBwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulBwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulBwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	/* Quality of Service Information Element */
	unsigned char	ucFwdQOS;				/* Forward - one of ATM_QOS values	*/
	unsigned char	ucBwdQOS;				/* Backward - one of ATM_QOS values	*/

	/* Broadband Bearer Capability Information Element */
	unsigned char	ucBbcClass;				/* One of ATM_B_BC_CLASS values		*/
	unsigned char	ucBbcTimingReq;		/* One of ATM_B_BC timing values		*/
	unsigned char	ucBbcTrafficType;		/* One of ATM_B_BC_TYPE values		*/
	unsigned char	ucBbcSusceptibleToClipping;	/* ATM_B_BC clipping values*/

	/*	for UNI 4.0 ABR service	*/
	/*	part of the Traffic Descriptors	*/
	unsigned long	ulFwdMCR_01;			/* Foward MCR value						*/
	unsigned long	ulBwdMCR_01;			/* Backward MCR value					*/

	/*	part of the Broadband Bearer Capbility IE	*/
	unsigned char	ucATC;					/* ATM Transfer Capbility				*/
	unsigned char	ucATC_present;			/* Checks whether the ATC is present*/

	/*	ABR Setup Parameters	*/
	unsigned char	ucInc;					/* Bit mask for field inclusion.
													 * 0xFF means all fields.				*/
	unsigned long	ulRM_FRTT;				/* Forward RM fixed round trip time */

	unsigned long	ulFwdICR_01;			/* Forward initial cell rate			*/
	unsigned long	ulFwdTBE_01;			/* Forward transient exposure buffer*/
	unsigned long	ulFwdRIF_01;			/* Forward increase factor				*/
	unsigned long	ulFwdRDF_01;			/* Forward decrease factor				*/

	unsigned long	ulBwdICR_01;			/* Backward initial cell rate			*/
	unsigned long	ulBwdTBE_01;			/* Backward transient exposure buffer*/
	unsigned long	ulBwdRIF_01;			/* Backward increase factor			*/
	unsigned long	ulBwdRDF_01;			/* Backward decrease factor			*/

	/* ABR Additional Parameters */
	/* Forward additional parameter record */
	 unsigned char ucFwdNrm_present; 	/* Indicates if Fwd Nrm is present	*/
	 unsigned char ucFwdTrm_present; 	/* Indicates if Fwd Trm is present	*/
	 unsigned char ucFwdCdf_present; 	/* Indicates if Fwd CDF is present	*/
	 unsigned char ucFwdAdtf_present; 	/* Indicates if Fwd ADTF is present	*/

	 unsigned short usFwdNrm;
	 unsigned short usFwdTrm;
	 unsigned short usFwdCdf;
	 unsigned short usFwdAdtf;

	 /* Backward additional parameter record */
	 unsigned char ucBwdNrm_present;		/* Indicates if Bwd Nrm is present	*/
	 unsigned char ucBwdTrm_present; 	/* Indicates if Bwd Trm is present 	*/
	 unsigned char ucBwdCdf_present; 	/* Indicates if Bwd CDF is present 	*/
	 unsigned char ucBwdAdtf_present; 	/* Indicates if Bwd ADTF is present */

	 unsigned short usBwdNrm;
	 unsigned short usBwdTrm;
	 unsigned short usBwdCdf;
	 unsigned short usBwdAdtf;

	 unsigned char ucEnableABRSetupParam;	/* Indicates if the ABR Setup IE
															should be sent						*/
	 unsigned char ucEnableABRAddlParam;	/* Indicates if the ABR Addl IE
															should be sent 					*/
} ATMCallSetupParamsEx;
/* ATMCallSetupParamsEx Comment:
*/

/* Max. number of call setup params */
#define ATM_MAX_CALL_SETUP_PARAMS		64

/* ATM traffic descriptor type */
#define ATM_TD_QUAL_PEAK_RATES			0	/* CBR pcr_0, pcr_01					  */
#define ATM_TD_QUAL_PEAK_RATES_W_TAG	1	/* CBR pcr_0, pcr_01, w_tag		  */
#define ATM_TD_COMBO_RATES					2	/* VBR pcr_01, scr_0, mbs_0		  */
#define ATM_TD_COMBO_RATES_W_TAG			3	/* VBR pcr_01, scr_0, mbs_0, w_tag */
#define ATM_TD_AGGR_PEAK_RATE				4	/* CBR pcr_01							  */
#define ATM_TD_AGGR_COMBO_RATES			5	/* VBR pcr_01, scr_01, mbs_01		  */
#define ATM_TD_BEST_EFFORT					6	/* UBR pcr_01 (fwd), pcr_01 (bwd)  */
#define ATM_TD_NONE							7	/* Applicable if running UNI 3.0/3.1 */
#define ATM_TD_ABR							7	/* ABR pcr_01, mcr_01.
														 * Applicable if running UNI 4.0 	*/

/* Quality of service class */
#define ATM_QOS_CLASS_0						0
#define ATM_QOS_CLASS_1						1
#define ATM_QOS_CLASS_2						2
#define ATM_QOS_CLASS_3						3
#define ATM_QOS_CLASS_4						4

/* Broadband bearer capability class */
#define ATM_B_BC_CLASS_X					16
#define ATM_B_BC_CLASS_A					1
#define ATM_B_BC_CLASS_C					3
#define ATM_B_BC_CLASS_VP 					24

/* Broadband bearer capability timing requirement */
#define ATM_B_BC_NO_TIMING_INFO			0
#define ATM_B_BC_END_TO_END_TIMING		1
#define ATM_B_BC_NO_END_TO_END_TIMING	2

/* Broadband bearer capability traffic type (UNI 3.0/3.1)*/
#define ATM_B_BC_TYPE_NONE					0
#define ATM_B_BC_TYPE_CBR					4
#define ATM_B_BC_TYPE_VBR					8

/* Broadband bearer capability (ATC) traffic type (UNI 4.0) */
#define ATM_B_BC_UNI40_NONE						0
#define ATM_B_BC_UNI40_CBR						5
#define ATM_B_BC_UNI40_CBR_01					7
#define ATM_B_BC_UNI40_REAL_TIME_VBR			9
#define ATM_B_BC_UNI40_REAL_TIME_VBR_01			19
#define ATM_B_BC_UNI40_NON_REAL_TIME_VBR		10
#define ATM_B_BC_UNI40_NON_REAL_TIME_VBR_01		11
#define ATM_B_BC_UNI40_ABR						12

/* Broadband bearer capability clipping susceptibility */
#define ATM_B_BC_SUSC_CLIP					32
#define ATM_B_BC_NOT_SUSC_CLIP				0

/*******************************************************************
ATMCallAddrList Description:
This structure is used to define the called ATM addresses for a
signaling test.
*/

typedef struct	tagATMCallAddrList
{
	unsigned short		uiStartAddrIndex;	/* Index of first element	*/
	unsigned short		uiCount;			/* Number of array elements	*/
	ATMAddress        atmAddress[ATM_MAX_CALL_ADDRESSES];
													/* List of addresses to load	*/
} ATMCallAddrList;
/* ATMCallAddrList Comment:
*/

/*******************************************************************
ATMILMIParams Description: ILMI Address Registration Params.
The ATMILMIParams structure is used to indicate to the card what
the desired end system identifier is and what the proper timeout
values are for ILMI.  These are the values which are used by ILMI
to identify to the network what the ATM address of the card will be.

Defined values for Default timer values:
 ILMI_DEFAULT_TMR_COLD_START	  	500
 ILMI_DEFAULT_TMR_REG_TIMEOUT		500

 ILMI_TMR_TICKS_PER_SEC				100
 ILMI_TMR_TICK_RESOLUTION		  	ILMI_TMR_TICKS_PER_SEC
*/

typedef struct tagATMILMIParams
{
	unsigned long	ulColdStartTimer;	/* Timeout time in .01 S resolution	*/
	unsigned long	ulRegTimeoutTimer;	/* Timeout time in .01 S resolution	*/
	unsigned char	ucESI[6];			/* End System Identifier */
} ATMILMIParams;
/* ATMILMIParams Comment:
*/

/* Default timer values */
#define ILMI_DEFAULT_TMR_COLD_START			500	/* 5 second timeout	*/
#define ILMI_DEFAULT_TMR_REG_TIMEOUT		500	/* 5 second timeout	*/

#define ILMI_TMR_TICKS_PER_SEC				100
#define ILMI_TMR_TICK_RESOLUTION				ILMI_TMR_TICKS_PER_SEC


/*******************************************************************
ATMILMIStaticParams Description: ILMI Static Address Registration
Params. The following structure is used to specify to the firmware a
particular ATM address to be used.  This function is most frequently
used when connecting to management entities within a switch.
*/

typedef struct tagATMILMIStaticParams
{
	 ATMAddress		atmAddress;
} ATMILMIStaticParams;
/* ATMILMIStaticParams Comment:
*/

/*******************************************************************
ATMSSCOPParams Description: SSCOP PARAMS (See ITU-T Rec. Q.2110 for
more information).
Defines Maximum and Timer values for use in configuring the SSCOP
level of the ATM interface.

Defined values for

Default parameter values:
 SSCOP_DEFAULT_MAX_CC			4
 SSCOP_DEFAULT_MAX_PD			25
 SSCOP_DEFAULT_MAX_STAT			67
 SSCOP_DEFAULT_MAX_RESEQ		16
 SSCOP_DEFAULT_RX_WINDOW		  32

Default timer values:
 SSCOP_DEFAULT_TMR_CC				100
 SSCOP_DEFAULT_TMR_KEEP_ALIVE		200
 SSCOP_DEFAULT_TMR_NO_RESP_3_0	1000
 SSCOP_DEFAULT_TMR_POLL_3_0		10
 SSCOP_DEFAULT_TMR_NO_RESP_3_1	700
 SSCOP_DEFAULT_TMR_POLL_3_1		75
 SSCOP_DEFAULT_TMR_IDLE				1500

 SSCOP_TMR_TICKS_PER_SEC			100
 SSCOP_TMR_TICK_RESOLUTION			SSCOP_TMR_TICKS_PER_SEC
*/

typedef struct tagATMSSCOPParams
{
	unsigned long	ulMaxCC;
	unsigned long	ulMaxPD;
	unsigned long	ulMaxStat;
	unsigned long	ulMaxReseq;
	unsigned long	ulRxWindow;

	unsigned long	ulTmrCC;
	unsigned long	ulTmrKeepAlive;
	unsigned long	ulTmrNoResp;
	unsigned long	ulTmrPoll;
	unsigned long	ulTmrIdle;
} ATMSSCOPParams;
/* ATMSSCOPParams Comment:
*/

/* Default parameter values */
#define SSCOP_DEFAULT_MAX_CC				4
#define SSCOP_DEFAULT_MAX_PD				25
#define SSCOP_DEFAULT_MAX_STAT			67
#define SSCOP_DEFAULT_MAX_RESEQ			16
#define SSCOP_DEFAULT_RX_WINDOW		   32

/* Default timer values */
#define SSCOP_DEFAULT_TMR_CC				100
#define SSCOP_DEFAULT_TMR_KEEP_ALIVE	200
#define SSCOP_DEFAULT_TMR_NO_RESP_3_0	1000		/* UNI 3.0 */
#define SSCOP_DEFAULT_TMR_POLL_3_0		10			/* UNI 3.0 */
#define SSCOP_DEFAULT_TMR_NO_RESP_3_1	700		/* UNI 3.1 */
#define SSCOP_DEFAULT_TMR_POLL_3_1		75			/* UNI 3.1 */
#define SSCOP_DEFAULT_TMR_IDLE			1500

#define SSCOP_TMR_TICKS_PER_SEC			100
#define SSCOP_TMR_TICK_RESOLUTION		SSCOP_TMR_TICKS_PER_SEC


/*******************************************************************
ATMUNIParams Description:
UNI SIGNALING PARAMS (See ATM Forum UNI 3.X/4.0 specification for more
info).

Defined values for

UNI Version:
 UNI_VERSION_3_0_USER		0x00000030L
 UNI_VERSION_3_1_USER		0x00000031L
 UNI_VERSION_3_0_NET			0x80000030L
 UNI_VERSION_3_1_NET			0x80000031L
 UNI_VERSION_4_0_USER		0x00000040L
 UNI_VERSION_4_0_NET			0x80000040L

Default timer values:
UNI_DEFAULT_TMR_T303			400
UNI_DEFAULT_TMR_T308			3000
UNI_DEFAULT_TMR_T310			1000
UNI_DEFAULT_TMR_T313			400
UNI_DEFAULT_TMR_T322			400
UNI_DEFAULT_TMR_T398			400
UNI_DEFAULT_TMR_T399			1400
UNI_DEFAULT_TMR_T309_3_0	9000
UNI_DEFAULT_TMR_T309_3_1	1000
UNI_DEFAULT_TMR_T316			12000
UNI_DEFAULT_TMR_T317			18000

UNI_DEFAULT_TMR_TEARDOWN	1

UNI_TMR_TICKS_PER_SEC		100
UNI_TMR_TICK_RESOLUTION		UNI_TMR_TICKS_PER_SEC
*/

typedef struct tagATMUNIParams
{
	unsigned long	ulVer;

	unsigned long	ulTmrT303;
	unsigned long	ulTmrT308;
	unsigned long	ulTmrT310;
	unsigned long	ulTmrT313;
	unsigned long	ulTmrT322;

	unsigned long	ulTmrT398;
	unsigned long	ulTmrT399;
	unsigned long	ulTmrT309;
	unsigned long	ulTmrT316;
	unsigned long	ulTmrT317;
	unsigned long  ulTmrTeardown;
} ATMUNIParams;
/* ATMUNIParams Comment:
*/

/* UNI version */
#define UNI_VERSION_3_0_USER		0x00000030L
#define UNI_VERSION_3_1_USER		0x00000031L
#define UNI_VERSION_3_0_NET		0x80000030L
#define UNI_VERSION_3_1_NET		0x80000031L
#define UNI_VERSION_4_0_USER		0x00000040L
#define UNI_VERSION_4_0_NET		0x80000040L


#define UNI_VERSION_NET_MASK		0x80000000L

/* Default timer values */
#define UNI_DEFAULT_TMR_T303		400
#define UNI_DEFAULT_TMR_T308		3000
#define UNI_DEFAULT_TMR_T310		1000
#define UNI_DEFAULT_TMR_T313		400
#define UNI_DEFAULT_TMR_T322		400
#define UNI_DEFAULT_TMR_T398		400
#define UNI_DEFAULT_TMR_T399		1400
#define UNI_DEFAULT_TMR_T309_3_0	9000		/* UNI 3.0 */
#define UNI_DEFAULT_TMR_T309_3_1	1000		/* UNI 3.1 */
#define UNI_DEFAULT_TMR_T316		12000
#define UNI_DEFAULT_TMR_T317		18000

#define UNI_DEFAULT_TMR_TEARDOWN	1			/* number of 10 ms intervals */

#define UNI_TMR_TICKS_PER_SEC		100
#define UNI_TMR_TICK_RESOLUTION	UNI_TMR_TICKS_PER_SEC

/*******************************************************************/
/*
 * ELAN REGISTRATION PARAMS
 */
#ifndef ATM_MAX_ELAN_NAME
#define ATM_MAX_ELAN_NAME		32 /* Longest ELAN name length */
#endif
/*******************************************************************/
/* ATMELANRegister Description:
Defined values for

ELAN initialization method:
ATM_ELAN_INIT_NORMAL						0
ATM_ELAN_INIT_LECS_DIRECT				1
ATM_ELAN_INIT_LES_DIRECT	  			2

ELAN type (C2):
ATM_ELAN_TYPE_802_3						0
ATM_ELAN_TYPE_802_5						1

ELAN MTU (C3):
ATM_ELAN_MTU_UNSPEC						0
ATM_ELAN_MTU_1516							1
ATM_ELAN_MTU_4544							2
ATM_ELAN_MTU_9234							3
ATM_ELAN_MTU_18190  						4

Control timeout in seconds (C7):
ATM_ELAN_MIN_CONTROL_TIMEOUT			10
ATM_ELAN_DEFAULT_CONTROL_TIMEOUT		120
ATM_ELAN_MAX_CONTROL_TIMEOUT			300

ARP retry count (C13):
ATM_ELAN_MIN_ARP_RETRY_COUNT			0
ATM_ELAN_DEFAULT_ARP_RETRY_COUNT		1
ATM_ELAN_MAX_ARP_RETRY_COUNT			2

Aging time in seconds (C17):
ATM_ELAN_MIN_AGING_TIME					10
ATM_ELAN_DEFAULT_AGING_TIME	 		300
ATM_ELAN_MAX_AGING_TIME					300

Expected ARP response time in seconds (C20):
ATM_ELAN_MIN_ARP_RESPONSE_TIME		1
ATM_ELAN_DEFAULT_ARP_RESPONSE_TIME	1
ATM_ELAN_MAX_ARP_RESPONSE_TIME	  	30
*/

typedef struct tagATMELANRegister
{
	unsigned char		ucInstance;		/* Identifies which ELAN */

	/* Join parameters */
	unsigned char		ucInitMethod;	/* One of ATM_ELAN_INIT from below	*/

	/* manual ATM address for direct joins */
	ATMAddress			ManualAtmAddr;	/* LES or LECS address if required	*/

	/* LEC parameters */
	unsigned char		ucC2Type;		/* One of ATM_ELAN_TYPE		*/
	unsigned char		ucC3Mtu;			/* Max Transfer Unit, One of ATM_ELAN_MTU */

	/* Target ELAN name (may be NULLified) */
	unsigned char		ucC5Name[ATM_MAX_ELAN_NAME];

	/* Base MAC address and count */
	unsigned char		ucC6MacAddr[6];		/* ELAN MAC address	*/
	unsigned short		uiC7ControlTimeout;	/* Timeout in seconds, control conn*/
	unsigned short		uiC13ArpRetryCount;
	unsigned short		uiC20ArpResponseTime;/* Max wait time for ARP response*/
} ATMELANRegister;
/* ATMELANRegister Comment:
*/

#define ATM_MAX_ELANS								8

/* ELAN initialization method */
#define ATM_ELAN_INIT_NORMAL						0
#define ATM_ELAN_INIT_LECS_DIRECT				1	/* use manual_atm_address */
#define ATM_ELAN_INIT_LES_DIRECT					2	/* use manual_atm_address */

/* ELAN type (C2) */
#define ATM_ELAN_TYPE_802_3						0
#define ATM_ELAN_TYPE_802_5						1

/* ELAN MTU (C3) */
#define ATM_ELAN_MTU_UNSPEC						0
#define ATM_ELAN_MTU_1516							1
#define ATM_ELAN_MTU_4544							2
#define ATM_ELAN_MTU_9234							3
#define ATM_ELAN_MTU_18190							4

/* Control timeout in seconds (C7) */
#define ATM_ELAN_MIN_CONTROL_TIMEOUT			10
#define ATM_ELAN_DEFAULT_CONTROL_TIMEOUT		120
#define ATM_ELAN_MAX_CONTROL_TIMEOUT			300

/* ARP retry count (C13) */
#define ATM_ELAN_MIN_ARP_RETRY_COUNT			0
#define ATM_ELAN_DEFAULT_ARP_RETRY_COUNT		1
#define ATM_ELAN_MAX_ARP_RETRY_COUNT			2

/* Aging time in seconds (C17) */
#define ATM_ELAN_MIN_AGING_TIME					10
#define ATM_ELAN_DEFAULT_AGING_TIME				300
#define ATM_ELAN_MAX_AGING_TIME					300

/* Expected ARP response time in seconds (C20) */
#define ATM_ELAN_MIN_ARP_RESPONSE_TIME			1
#define ATM_ELAN_DEFAULT_ARP_RESPONSE_TIME	1
#define ATM_ELAN_MAX_ARP_RESPONSE_TIME			30

/*******************************************************************
ATMELANDeregister Description:
Allows the user to deregister from a specific ELAN.
*/

typedef struct tagATMELANDeregister
{
	unsigned char		ucInstance;
} ATMELANDeregister;
/* ATMELANDeregister Description:
*/

/*******************************************************************
ATMClassicalIP Description: CLASSICAL IP OVER ATM (RFC1577) Params.
This structure provides the user with all of the information
necessary to work with a CLIP ARP server.  The ulInterCallGap
specifies the time between successive data direct VCC connection
attempts to another IP client.  This can be an issue when a single
ARP server response is capable of satisfying multiple ARP requests.
Rather than bursting all of the connections to the destination
client at once, the call gap allows the user to slow down the rate
of connection.  If  all connections should be connected as quickly
as possible, then there is nothing that precludes this value from
being 0.
*/

typedef struct tagATMClassicalIP
{
	unsigned char		ucArpServerAtmAddr[20];	/* The server's ATM address	*/
	unsigned char		ucArpClientIpAddr[4];	/* The card's IP address		*/
	unsigned long		ulInterArpGap;				/* millisec between ARP retries*/
	unsigned long		ulInterCallGap;			/* millisec between data conn's*/
	unsigned short		uiArpRetries;				/* Max number of ARP retries	*/
	unsigned char		ucInvArpReplyOff;			/* boolean - TRUE: Disable Inv. ARP Reply
																- Default is FALSE. */
} ATMClassicalIP;			/* RFC1577_PARAMS; */
/* ATMClassicalIP Comment:
*/

/*******************************************************************
 ATMStartCardSetupParams Description:
The following structure may be used to begin the signaling test on a
few of the connections already established on the card. The user can
use this structure to start a signaling test using a specific range
of connections.  Another way to start the test is to use the Start
or Group Start feature which starts all configured connections.
*/

typedef struct tagATMStartCardSetupParams
{
	unsigned long		ulConnIndex;/* The first index for the test			*/
	unsigned long		ulCount;		/* The subsequent indices for the test	*/
} ATMStartCardSetupParams;
/* ATMStartCardSetupParams Comment:
*/

/*******************************************************************
ATMStopCardSetupParams Description:
The following structure may be used to stop the signaling test on a
few of the connections already established on the card.  Another way
to stop the test is to use the Stop or Group Stop feature which
starts all configured connections.  The ucStopNewCalls will prevent
any more additional calls from being initiated while the test is
being stopped, and the ucTeardownCalls will not only stop new calls,
but tear down the existing calls as well.
*/
typedef struct tagATMStopCardSetupParams
{
	unsigned long		ulConnIndex;	/* First index to stop			*/
	unsigned long		ulCount;			/* Subsequent indices to stop	*/

	unsigned char		ucStopNewCalls;		/* Stop new outgoing calls		*/
	unsigned char		ucStopCellLoadGen;	/* Set to 1						*/
	unsigned char		ucTeardownCalls;		/* Stop and teardown the calls*/
} ATMStopCardSetupParams;
/* ATMStopCardSetupParams Comment:
*/

/*******************************************************************
ATMStreamControl Description:
The ATMStreamControl structure allows the user to perform one action
on a range of streams.  There are five actions which can be
performed.  The basic life of a stream is as follows:  When
initializing in a new application it is best to issue a stream
ATM_STR_ACTION_DISCONNECT and ATM_STR_ACTION_RESET to all possible
streams to remove any previously configured information from the card.
Next,  a frame is defined and bound to a stream.  Then the stream
is bound to a connection using an ATM_STR_ACTION_CONNECT The stream is
then started and stopped as appropriate and it may even be disconnected
and reconnected a number of times depending upon the application.
In the end the stream is stopped and a ATM_STR_ACTION_RESET should
be sent to destroy the stream.

Defined values for action:
 ATM_STR_ACTION_RESET		0
 ATM_STR_ACTION_CONNECT		1
 ATM_STR_ACTION_DISCONNECT	2
 ATM_STR_ACTION_START		3
 ATM_STR_ACTION_STOP			4
*/

typedef struct	tagATMStreamControl
{
	unsigned char		ucAction;	/* Use one of the following
					ATM_STR_ACTION_RESET       Deletes a stream
					ATM_STR_ACTION_CONNECT     Initiate a conn for stream xmit
					ATM_STR_ACTION_DISCONNECT  Close a conn used for stream xmit
					ATM_STR_ACTION_START			Start xmitting data on open conn
					ATM_STR_ACTION_STOP			Stop xmitting data on open conn */
	unsigned long		ulStreamIndex;	/* First stream in the range		*/
	unsigned long		ulStreamCount;	/* Subsequent stream count			*/
} ATMStreamControl;			/*	STREAM_CONTROL_REQ; */
/* ATMStreamControl Comment:
*/

#define ATM_STR_ACTION_RESET			0	/* Deletes a stream					*/
#define ATM_STR_ACTION_CONNECT		1	/* Initiate a conn for stream xmit	*/
#define ATM_STR_ACTION_DISCONNECT	2	/* Close a conn used for stream xmit*/
#define ATM_STR_ACTION_START			3	/* Start xmitting data on open conn	*/
#define ATM_STR_ACTION_STOP			4	/* Stop xmitting data on open conn	*/

/*******************************************************************
ATMTrigger Description:
The ATMTrigger structure defines the events which are used to fire a
trigger in ATM-1.  There are two types of triggers - frame mode and
cell mode.  In cell mode each cell is tested to see if it matches
the defined event conditions.  In cell mode the offset is specified
in bytes from the start of the cell.  In frame mode the offset is
specified in bytes from the start of the ATM cell payload.  The
header bytes are not included in the offset count at all.  Mask
values determine which bits are compared in the pattern against the
frame.  If the bit in the mask is set then the corresponding bit in
the pattern is tested.  If the bit is zero, then the corresponding
bit is ignored.  The match field causes the trigger to be fired on
either a matching pattern (if match=1) or a non-matching pattern
(if match=0).

ATM-2 Trigger Parameters
Trigger 1 - Per Connection
Trigger 2 - Global

Defined values for

Trigger mode:
 ATM_TRIGGER_MODE_CELL	0
 ATM_TRIGGER_MODE_AAL5	1

Trigger direction:
 ATM_TRIGGER_DIR_RX		0
 ATM_TRIGGER_DIR_TX		1

Comparison combination:
ATM_COMP1_ONLY								0
ATM_COMP2_ONLY								1
ATM_COMP1_AND_COMP2						2
ATM_COMP1_OR_COMP2	 					3
*/

typedef struct tagATMTrigger
{
	/* Trigger control */
	unsigned char		ucEnable;			/* Enable/Disable triggers	*/
	unsigned char		ucMode;				/*	Cell or frame level		*/
	unsigned char		ucDirection;		/* Transmit or receive		*/
	unsigned char		ucCompCombo;		/* One of ATM_COMP values	*/
	unsigned char		ucHeaderNoMatch;	/* Event is a non match of  header	*/
	unsigned char		ucComp1NoMatch;	/* Event is non match of Comp 1		*/
	unsigned char		ucComp2NoMatch;	/* Event is non match of Comp 2		*/

	/* Cell header comparator parameters */
	unsigned long		ulHeaderPattern;	/* GFC/VPI/VCI/PT/CLP pattern	*/
	unsigned long		ulHeaderMask;		/* Bit Mask where 1=test, 0=ignore	*/

	/* Data comparator parameters */
	unsigned short		uiComp1Offset;		/*Offset into frame for pattern test*/
	unsigned short		uiComp1Range;		/* Number of bytes to test				*/
	unsigned char		ucComp1Pattern[6];	/* Pattern to match					*/
	unsigned char		ucComp1Mask[6];	/* Bit mask for pattern					*/

	unsigned short		uiComp2Offset;		/*Offset into frame for pattern test*/
	unsigned short		uiComp2Range;		/* Number of bytes to test				*/
	unsigned char		ucComp2Pattern[6];	/* Pattern to match					*/
	unsigned char		ucComp2Mask[6];	/* Bit mask for pattern					*/
} ATMTrigger;	/*	TRIGGER_PARAMS; */
/* ATMTrigger Comment:
*/

/*******************************************************************
ATMGlobalTrigger Description:
The ATMGlobalTrigger structure defines global trigger conditions
which apply to all received frames.  In ATM-2 the triggers are only
active on the receive side.  Each VCC has its own latency and
trigger counter to facilitate measurement of per connection
statistics.  There are two events which can be defined.  The first
event is associated with comparator two and is a global event.  This
occurrence of this event is tested against all frames received on all
connections.  The second event is defined per connection.  There is
no mask, but each connection may specify a pattern which will be
used to test frames received only on that connection.

Defined values for the Comparison combination:

ATM_COMP1_ONLY								0
ATM_COMP2_ONLY								1
ATM_COMP1_AND_COMP2						2
ATM_COMP1_OR_COMP2	 					3
*/

typedef struct tagATMGlobalTrigger
{
	 /* Trigger control */
	 unsigned char	ucEnable;				/* 0 - disable trigger
														1 - enable trigger and latch the timestamp on
															 the first triggered frame
														2 - enable trigger and latch the timestamp on
															 the last triggered frame */

	 unsigned char     ucCompCombo;		/* Comparison combination	*/

	 /* Global Trigger parameters */
	 unsigned long	    ulComp2Pattern;	/* Global event pattern	*/

	 unsigned short	 uiComp1Offset;	/* Per conn triggers' pattern offset*/
	 unsigned short    uiComp2Offset;	/* Global trigger pattern offset		*/

	 unsigned long	    ulComp1Mask;		/* Mask bits for per conn event		*/
	 unsigned long     ulComp2Mask;		/* Mask bits for global event			*/

} ATMGlobalTrigger;
/* ATMGlobalTrigger Comment:
*/

/*******************************************************************
ATMConnTriggerParams Description:
ATMConnTriggerParams allows the user to define a trigger event
pattern to be used for a particular connection.  The per connection
trigger is associated with comparator one.
*/

typedef struct tagATMConnTriggerParams
{
	 unsigned short    uiConnIndex;		/* Connection to test	*/
	 unsigned long	    ulComp1Pattern;	/* Pattern to test for per conn */
} ATMConnTriggerParams;
/* ATMConnTriggerParams Comment:
NOTE::::This structure is used to configure ATM-2 triggers, based on either
		  a stream index or a connection index.
*/


/* Trigger control */
#define ATM_TRIGGER_MODE_CELL						0
#define ATM_TRIGGER_MODE_AAL5						1

#define ATM_TRIGGER_DIR_RX							0
#define ATM_TRIGGER_DIR_TX							1

#define ATM_COMP1_ONLY								0
#define ATM_COMP2_ONLY								1
#define ATM_COMP1_AND_COMP2						2
#define ATM_COMP1_OR_COMP2							3


/*******************************************************************
ATMCardInfo Description:
This structure will return the revision information associated with
the firmware, and diagnostic and identification information
associated with the hardware.
The format for the main firmware version, iMainFwVersion, is as follows:

Bit 15:         General release flag: Set: Released, Unset: Beta
Bits 0-14:      Versioning information
Major release:  (ushort & 0x7FFF /100)%10
Minor release:  (ushort & 0x7FFF)%100
Build:          (ushort/1000)&0x1F;

The format for all other version/revision information is:
Major release:  ushort/100
Minor release:  ushort%100

There are no build numbers or release bits associated with these
files.
*/

typedef struct tagATMCardInfo
{
	unsigned short	uiMainFwVersion;      /*Card firmware version*/
	unsigned short	uiSarBootFwVersion;
	unsigned short	uiSarMainFwVersion;
	unsigned short	uiPciFpgaVersion;
	unsigned short	uiGapFpgaVersion;
	unsigned short	uiBptrgFpgaVersion;

	unsigned short	uiAm29240Revision;	/* ATM-1 ONLY	*/
	unsigned short	uiBt8222Revision;		/* ATM-1 ONLY	*/
	unsigned short	uiL64363Revision;		/* ATM-1 ONLY	*/

	unsigned short	uiImageCheck;
	unsigned short	uiDiagFlags;			/* Diagnostic flag field; reserved for
													   internal testing. */
	unsigned short	uiProductCode;
} ATMCardInfo;
/* ATMCardInfo Comment:
To get the major and minor release values from iMainFwVersion, you must
do a bitwise AND with 7FFF. This removes the most significant bit
the General Release Flag) so that you can interpret the value.
*/

#define ATM_TXD_MEMORY_FAILURE	0x0080


/*******************************************************************/
/* ATMCardType Description:
This structure contains the specified card rate. Use this number to
determine the ATM card model.

Possible values for uiProductCode:
AT9622_PRODUCT_CODE   9622
AT9155_PRODUCT_CODE   9155
AT9045_PRODUCT_CODE   9045
AT9034_PRODUCT_CODE   9034
AT9025_PRODUCT_CODE   9025
AT9020_PRODUCT_CODE   9020
AT9015_PRODUCT_CODE   9015
UNSPEC_PRODUCT_CODE   9000
*/

typedef struct tagATMCardType
{
	unsigned short uiProductCode;
	unsigned short uiReserved[15];
} ATMCardType;
/* ATMCardType Comment:
*/

/*******************************************************************/
/* Version indices for ATM-1 */
#define ATM1_MAIN_FW_VERSION						0
#define ATM1_SAR_BOOT_FW_VERSION					1
#define ATM1_SAR_MAIN_FW_VERSION					2
#define ATM1_PCI_FPGA_VERSION						3
#define ATM1_GAP_FPGA_VERSION						4
#define ATM1_BPTRG_FPGA_VERSION					5
#define ATM1_AM29240_VERSION						6
#define ATM1_BT8222_VERSION						7
#define ATM1_L64363_VERSION						8

/* Version indices for ATM-2 */
#define ATM2_MAIN_FW_VERSION						0
#define ATM2_SAR_FW_VERSION						1
#define ATM2_SAR_FPGA_VERSION						2
#define ATM2_TXQ_FPGA_VERSION						3
#define ATM2_TXD_FPGA_VERSION						4
#define ATM2_RXT_FPGA_VERSION						5
#define ATM2_RXD_FPGA_VERSION						6

/* Diagnostic flags */
#define ATM_FRAMER_PART_NUM_FAILURE				0x0001
#define ATM_FRAMER_CONFIG_FAILURE				0x0002
#define ATM_SAR_IMAGE_CHECK_FAILURE				0x0004
#define ATM_SAR_PCI_FAILURE						0x0008
#define ATM_SAR_BOOT_FAILURE		   			0x0010
#define ATM_SAR_MEMORY_FAILURE					0x0020
#define ATM_SAR_CONFIG_FAILURE					0x0040

/*******************************************************************
 ATMCardCapabilities Description:
Specific card capabilities are returned in this structure.  This information
can be used to execute code without concern for the specific card model.  It
can also be used, in addition to ATMCardType, to determine the specific card
model revision.

Defined values for uiSupportedFeatures:
ATM_FEATURES_GLOBAL_TRIGGERS		0x0000
ATM_FEATURES_PER_CONN_TRIGGERS	0x0001
ATM_FEATURES_PER_CONN_BURST		0x0002
ATM_FEATURES_PER_PORT_BURST		0x0004
ATM_FEATURES_PROTOCOL_TRACE		0x0008
ATM_FEATURES_STREAM_COPY_PASTE	0x0010
ATM_FEATURES_MULTI_BURST			0x0040	- only supported on ATM-2 cards

Support for ucUNI_Version:
ATM_UNI_VERSION_40				40
*/

typedef struct tagATMCardCapabilities
{
	unsigned long	ulLineCellRate;			/* Max rate in cells/sec		*/
	unsigned short	uiMaxStream;				/* Max number of streams		*/
	unsigned short	uiMaxConnection;			/* Max number of connections	*/
	unsigned short	uiMaxCalls;					/* Max number of active SVCs	*/
	unsigned short	uiMaxHostTxBuffer;		/* reserved							*/
	unsigned short	uiMaxHostRxBuffer;		/* reserved							*/

	unsigned short	uiMaxLaneClients;
	unsigned short	uiMaxVPIBits;
	unsigned short	uiMaxVCIBits;
	unsigned short uiSupportedFeatures;	/* Use one of the following defined below */
	unsigned short uiMaxRateWithTeardown;
	unsigned short uiMaxRateWithoutTeardown;

	unsigned char	ucUNI_Version;			/* for UNI 4.0 and up, this is used
													 * to determine if the firmware supports
													 * UNI 4.0 or higher versions */
	/*	unsigned char	ucReserved[3]; */
	/* ushort	uiReserved[3];*/
} ATMCardCapabilities;
/* ATMCardCapabilities Comment:
*/

#define ATM_FEATURES_GLOBAL_TRIGGERS	0x0000
#define ATM_FEATURES_PER_CONN_TRIGGERS	0x0001
/* Specific to determining whether Burst Count/connection is supported */
#define ATM_FEATURES_PER_CONN_BURST		0x0002
/* Specific to determining whether Burst Count/port is supported */
#define ATM_FEATURES_PER_PORT_BURST		0x0004
/* Specific to determining whether Protocol Event tracing is supported */
#define ATM_FEATURES_PROTOCOL_TRACE		0x0008
#define 	ATM_FEATURES_STREAM_COPY_PASTE	0x0010
#define ATM_FEATURES_MULTI_BURST				0x0040

/******** these defines are used to support UNI 4.0 ****************/
#define ATM_UNI_VERSION_40				40	/* val = 40 indicates UNI 4.0 support */
													/* val = 00 indiactes no UNI 4.0 support*/

/*******************************************************************
 ATMSonetLineInfo Description:
SONET OC3/STS-1 Line Statistics.  This structure defines the statistics
returned by the AT-9025 and AT-9155, AT-9155C and the AT-9622 cards.
Defined values for the

SONET alarm flags:
 SONET_SECTION_LOS_ALARM		0x0001
 SONET_SECTION_OOF_ALARM		0x0002
 SONET_SECTION_LOF_ALARM		0x0004
 SONET_LINE_AIS_ALARM			0x0008
 SONET_LINE_FERF_ALARM			0x0010
 SONET_LINE_LOP_ALARM			0x0020
 SONET_PATH_AIS_ALARM			0x0040
 SONET_PATH_FERF_ALARM			0x0080
 SONET_PATH_YELLOW_ALARM		0x0100
 SONET_LOCD_ALARM					0x0200

ATM25 alarm flags:
 ATM25_LOS_ALARM					0x0001
*/

typedef struct tagATMSonetLineInfo
{
	/* Alarm conditions	*/
	unsigned short	uiAlarmCurrent;	/* All alarms currently active			*/
	unsigned short	uiAlarmHistory;	/* All alarms since last counter clear	*/

	/* Error counts since last counter clear	*/
	unsigned long	ulSectionBip8;		/* Section Bit Interleaved Parity		*/
	unsigned long	ulLineBip24;		/* Line Bit Interleaved Parity			*/
	unsigned long	ulLineFebe;			/* Line Far End Block Error				*/
	unsigned long	ulPathBip8;			/* Path Bit Interleaved Parity			*/
	unsigned long	ulPathFebe;			/* Path Far End Block Error				*/

	/* Current error rates in events per second	*/
	unsigned short	uiSectionBip8Rate;
	unsigned short	uiLineBip24Rate;
	unsigned short	uiLineFebeRate;
	unsigned short	uiPathBip8Rate;
	unsigned short	uiPathFebeRate;
} ATMSonetLineInfo;
/* ATMSonetLineInfo Comment:
*/

/* Max Seconds to wait for SONET to come up */
#define ATM_SONET_TIMEOUT		5

/* SONET alarm flags */
#define SONET_SECTION_LOS_ALARM		0x0001
#define SONET_SECTION_OOF_ALARM		0x0002
#define SONET_SECTION_LOF_ALARM		0x0004
#define SONET_LINE_AIS_ALARM			0x0008
#define SONET_LINE_FERF_ALARM			0x0010
#define SONET_LINE_LOP_ALARM			0x0020
#define SONET_PATH_AIS_ALARM			0x0040
#define SONET_PATH_FERF_ALARM			0x0080
#define SONET_PATH_YELLOW_ALARM		0x0100
#define SONET_LOCD_ALARM				0x0200
/* ATM25 alarm flags */
#define ATM25_LOS_ALARM					0x0001

/*******************************************************************
ATMDS3E3LineInfo Description:
DS3/E3 Line Statistics.  This structure defines the statistics
returned by the AT-9034, AT-9034B, AT-9045, and AT-9045B cards.

Defined values for DS3/E3 alarm flags:
 ATM_DS3_E3_LOCD_ALARM				0x0001
 ATM_ATM_DS3_E3_OOF_ALARM			0x0002
 ATM_DS3_E3_FERF_ALARM				0x0004
 ATM_DS3_E3_AIS_ALARM				0x0008
 ATM_DS3_E3_IDLE_ALARM				0x0010
 ATM_DS3_E3_LOS_ALARM				0x0020
 ATM_DS3_E3_YELLOW_ALARM			0x0040
 ATM_DS3_E3_PLCP_OOF_ALARM			0x0080
 ATM_DS3_E3_PLCP_LOF_ALARM			0x0100
 ATM_DS3_E3_PLCP_YELLOW_ALARM		0x0200
*/

typedef struct tagATMDS3E3LineInfo
{
	 unsigned short	uiAlarmCurrent;
	 unsigned short	uiAlarmHistory;

	 unsigned long		ulCodeViolationCount;
	 unsigned long		ulFrameErrorCount;
	 unsigned long		ulParityErrorCount;
	 unsigned long		ulCParityErrorCount;
	 unsigned long		ulFebeErrorCount;
	 unsigned long		ulFerfErrorCount;
	 unsigned long		ulPlcpFrameErrorCount;
	 unsigned long		ulPlcpBipErrorCount;
	 unsigned long		ulPlcpFebeErrorCount;

	 unsigned long		ulCodeViolationRate;
	 unsigned long		ulFrameErrorRate;
	 unsigned long		ulParityErrorRate;
	 unsigned long		ulCParityErrorRate;
	 unsigned long		ulFebeErrorRate;
	 unsigned long		ulFerfErrorRate;
	 unsigned long		ulPlcpFrameErrorRate;
	 unsigned long		ulPlcpBipErrorRate;
	 unsigned long		ulPlcpFebeErrorRate;
} ATMDS3E3LineInfo;
/* ATMDS3E3LineInfo Comment:
*/

/* DS3/E3 alarm flags */
#define ATM_DS3_E3_LOCD_ALARM				0x0001
#define ATM_ATM_DS3_E3_OOF_ALARM			0x0002
#define ATM_DS3_E3_FERF_ALARM				0x0004
#define ATM_DS3_E3_AIS_ALARM				0x0008
#define ATM_DS3_E3_IDLE_ALARM				0x0010
#define ATM_DS3_E3_LOS_ALARM				0x0020
#define ATM_DS3_E3_YELLOW_ALARM			0x0040
#define ATM_DS3_E3_PLCP_OOF_ALARM		0x0080
#define ATM_DS3_E3_PLCP_LOF_ALARM		0x0100
#define ATM_DS3_E3_PLCP_YELLOW_ALARM	0x0200

/*******************************************************************/
/* ATMDS1E1LineInfo Description:
This structure defines the statistics returned by the AT-9015 and
AT-9020 cards.

Defined values for DS1 alarm flags:
 ATM_DS1_E1_LOCD_ALARM				 	WAN_DS1_E1_LOCD_ALARM
 ATM_DS1_E1_OOF_ALARM				 	WAN_DS1_E1_OOF_ALARM
 ATM_DS1_E1_LOS_ALARM				 	WAN_DS1_E1_LOS_ALARM
 ATM_DS1_E1_YELLOW_ALARM			 	WAN_DS1_E1_YELLOW_ALARM
 ATM_DS1_E1_AIS_ALARM				 	WAN_DS1_E1_AIS_ALARM
 ATM_DS1_E1_B8ZS_ALARM				 	WAN_DS1_E1_B8ZS_ALARM
 ATM_DS1_E1_EXCESS_ZEROS_ALARM	 	WAN_DS1_E1_EXCESS_ZEROS_ALARM
 ATM_DS1_E1_PLCP_OOF_ALARM				WAN_DS1_E1_PLCP_OOF_ALARM
 ATM_DS1_E1_PLCP_LOF_ALARM				WAN_DS1_E1_PLCP_LOF_ALARM
 ATM_DS1_E1_PLCP_YELLOW_ALARM			WAN_DS1_E1_PLCP_YELLOW_ALARM
 ATM_DS1_E1_SEV_ERROR_FRAME_ALARM 	WAN_DS1_E1_SEV_ERROR_FRAME_ALARM
*/

typedef struct tagATMDS1E1LineInfo
{
	 unsigned short	uiAlarmCurrent;
	 unsigned short	uiAlarmHistory;

	 unsigned long		ulCodeViolationCount;
	 unsigned long		ulFrameErrorCount;
	 unsigned long		ulSyncErrorCount;
	 unsigned long		ulFebeErrorCount;
	 unsigned long		ulPlcpOofErrorCount;
	 unsigned long		ulPlcpFrameErrorCount;
	 unsigned long		ulPlcpBipErrorCount;
	 unsigned long		ulPlcpFebeErrorCount;

	 unsigned long		ulCodeViolationRate;
	 unsigned long		ulFrameErrorRate;
	 unsigned long		ulSyncErrorRate;
	 unsigned long		ulFebeErrorRate;
	 unsigned long		ulPlcpOofErrorRate;
	 unsigned long		ulPlcpFrameErrorRate;
	 unsigned long		ulPlcpBipErrorRate;
	 unsigned long		ulPlcpFebeErrorRate;
} ATMDS1E1LineInfo;
/* ATMDS1E1LineInfo Comment:
*/

/* DS1 alarm flags */
#define ATM_DS1_E1_LOCD_ALARM				 	WAN_DS1_E1_LOCD_ALARM
#define ATM_DS1_E1_OOF_ALARM				 	WAN_DS1_E1_OOF_ALARM
#define ATM_DS1_E1_LOS_ALARM				 	WAN_DS1_E1_LOS_ALARM
#define ATM_DS1_E1_YELLOW_ALARM			 	WAN_DS1_E1_YELLOW_ALARM
#define ATM_DS1_E1_AIS_ALARM				 	WAN_DS1_E1_AIS_ALARM
#define ATM_DS1_E1_B8ZS_ALARM				 	WAN_DS1_E1_B8ZS_ALARM
#define ATM_DS1_E1_EXCESS_ZEROS_ALARM	 	WAN_DS1_E1_EXCESS_ZEROS_ALARM
#define ATM_DS1_E1_PLCP_OOF_ALARM			WAN_DS1_E1_PLCP_OOF_ALARM
#define ATM_DS1_E1_PLCP_LOF_ALARM			WAN_DS1_E1_PLCP_LOF_ALARM
#define ATM_DS1_E1_PLCP_YELLOW_ALARM		WAN_DS1_E1_PLCP_YELLOW_ALARM
#define ATM_DS1_E1_SEV_ERROR_FRAME_ALARM 	WAN_DS1_E1_SEV_ERROR_FRAME_ALARM


/*******************************************************************
ATMLayerInfo Description:
The ATMLayerInfo structure returns all of the counts and rates
associated with the ATM layer.
*/
typedef struct tagATMLayerInfo
{
	U64				ullTxCell;
	unsigned long	ulTxCellRate;

	U64				ullRxCell;
	unsigned long	ulRxCellRate;
	U64				ullRxHecCorrErrors;
	unsigned long	ulRxHecCorrErrorsRate;
	U64				ullRxHecUncorrErrors;
	unsigned long	ulRxHecUncorrErrorsRate;
} ATMLayerInfo;
/* ATMLayerInfo Comment:
*/

/*******************************************************************
ATMAAL5LayerInfo Description:
The ATMAAL5LayerInfo structure returns all of the counts and rates
associated with the AAL5 layer.
*/

typedef struct tagATMAAL5LayerInfo
{
	unsigned long	ulTimeStamp;		/* Time when the statistics were latched */
	unsigned long	ulTxCell;
	unsigned long	ulTxFrame;

	unsigned long	ulRxCell;
	unsigned long	ulRxFrame;
	unsigned long	ulRxCRC32Errors;	/* ATM-2 platform only	*/
	unsigned long	ulRxLengthErrors;	/* ATM-2 platform only	*/
} ATMAAL5LayerInfo;
/* ATMAAL5LayerInfo Comment:
*/

/*******************************************************************
ATMVCCIStatus Description:
ATMVCCIStatus records transmit and receive counts on a given virtual
circuit connection.
*/

typedef struct tagATMVCCIStatus
{
	unsigned long	ulCellHeader;	/* The cell header of the VCC of interest	*/
	unsigned long	ulTimeStamp;	/* Time when the stats were latched			*/
	unsigned long	ulTxFrame;		/* Frames transmitted with this header		*/
	unsigned long	ulRxFrame;		/* Frames received with this header			*/
} ATMVCCIStatus;				/*  VCC_STATS; */
/* ATMVCCIStatus Comment:
ATMVCCIStatus records transmit and receive counts on a given
virtual circuit connection.  The time stamp records the time in
units of 100 ns when the statistics were latched.
*/

/*******************************************************************
ATMVCCInfo Description:
ATMVCCInfo records transmit and receive counts on a range of virtual
circuit connections.
*/

typedef struct tagATMVCCInfo
{
	unsigned short	uiIndex;
	unsigned short	uiCount;
	ATMVCCIStatus	status[ATM_MAX_ARRAY_DIM+2]; /* index 0 and 1 are reserved */
} ATMVCCInfo;		/* VCC_STATS_HDR; */
/* ATMVCCInfo Comment:
NOTE::::This structure is used to obtain the VCC stats based on the connection or
stream indices.
*/

/*******************************************************************
ATMTriggerInfo Description:
The ATMTriggerInfo structure contains the time of the firing of the
first trigger since the last clear counters and the number of
trigger fires since the last clear counters. Used with ATM-1 only.
*/

typedef struct tagATMTriggerInfo
{
	unsigned long	ulTrigger;	/* Trigger event counter			*/
	unsigned long	ulLatency;	/* Latency until first trigger fired	*/
} ATMTriggerInfo;			/* TRIGGER_STATS; */
/* ATMTriggerInfo Comment:
*/

/*******************************************************************/
/* ATMConnTriggerStatus Description:
The ATMConnTriggerInfo structure contains the time of the firing of
the first trigger since the last clear counters and the number of
trigger fires since the last clear counters. Used with ATM-2 only.
*/

typedef struct tagATMConnTriggerStatus
{
	unsigned long	ulTrigger;		/* Trigger events on the receive side	*/
	unsigned long	ulTxTimestamp;	/* time the first cell exits the card	*/
	unsigned long	ulRxTimestamp;	/* time the first trigger received	*/
} ATMConnTriggerStatus;
/* ATMConnTriggerStatus Comment:
*/

/*******************************************************************/
/* ATMConnTriggerInfo Description:
ATMConnTriggerInfo records transmit and receive trigger counts on a
range of virtual circuit connections.
*/

typedef struct tagATMConnTriggerInfo
{
	unsigned short	uiStartConnIndex;
	unsigned short	uiConnCount;
	ATMConnTriggerStatus status[ATM_MAX_ARRAY_DIM+2]; /* index 0&1 are reserved */
} ATMConnTriggerInfo;
/* ATMConnTriggerInfo Comment:
Note: When there are multiple streams bound to a connection (i.e.,
		LANE data connection), the command will return statistics for
		that connection multiple times.
		This structure can be used when obtaining ATM-2 triggers, based on either
		a stream index or a connection index.
*/

/*******************************************************************
ATMStreamDetailedStatus Description:
The stream detailed status returns state and status information
associated with a particular stream.
Defined values for

Stream states:
ATM_STR_STATE_IDLE						0
ATM_STR_STATE_ADDR_RES_PROCEEDING		1
ATM_STR_STATE_ADDR_RES_FAILED			2
ATM_STR_STATE_ADDR_RES_RETRY			3
ATM_STR_STATE_CONN_PROCEEDING			4
ATM_STR_STATE_CONN_ESTABLISHED			5
ATM_STR_STATE_CONN_RELEASED				6
ATM_STR_STATE_CONN_FAILED				7
*/

typedef struct tagATMStreamDetailedStatus
{
	unsigned short	uiStreamIndex;
	unsigned short	uiConnIndex;		/* Associated connection index		*/

	unsigned long	ulCellHeader;
	unsigned char	ucStreamState;		/* One of ATM_STR_STATE_XXXX		*/

	unsigned char	ucArpRetryCount;	/* Number of LEC attempts to ARP	*/
	unsigned long	ulArpRespLatency;	/* ARP response time for CLIP		*/

	unsigned char	ucSvcCallState;		/* One of CALL_STATE_XXXX			*/
	unsigned char	ucSvcCauseLoc;		/* UNI cause location				*/
	unsigned char	ucSvcCauseCode;		/* UNI cause code (UNI 3.1 Annex E)	*/
	unsigned long	ulSvcSetupLatency;	/* Call setup latency in 100 ns		*/
} ATMStreamDetailedStatus;				/* STREAM_DETAILED_STATUS;			*/
/* ATMStreamDetailedStatus Comment:
*/

/*******************************************************************/
/* ATMStreamDetailedInfo Description:
ATMStreamDetailed info allows the user to get a range of indices
for detailed status.
*/

typedef struct tagATMStreamDetailedInfo
{
	unsigned short				uiStartIndex;
	unsigned short				uiCount;
	ATMStreamDetailedStatus status[ATM_MAX_ARRAY_DIM];
} ATMStreamDetailedInfo;
/* ATMStreamDetailedInfo Comment:
*/

/* Stream states */
#define ATM_STR_STATE_IDLE					0
#define ATM_STR_STATE_ADDR_RES_PROCEEDING	1
#define ATM_STR_STATE_ADDR_RES_FAILED		2
#define ATM_STR_STATE_ADDR_RES_RETRY		3
#define ATM_STR_STATE_CONN_PROCEEDING		4
#define ATM_STR_STATE_CONN_ESTABLISHED		5
#define ATM_STR_STATE_CONN_RELEASED			6
#define ATM_STR_STATE_CONN_FAILED			7


/*****************************************************************************
ATMStreamSearchInfo Description:
The Stream Search requests the state and status information
associated with streams, that fall within the range specified
by the ulSearchRangeLow - ulSearchRangeHigh values.  It uses
the ReturnItemId and uiSearchItemId, as a basis for the search,
and returns the values of the ReturnItemId using the ulItem array.

Defined values for uiReturnItemId/uiSearchItemId:
ATM_STR_STATUS_STREAM_INDEX			0	(2-bytes)
ATM_STR_STATUS_CONN_INDEX				1	(2-bytes)
ATM_STR_STATUS_CELL_HEADER				2	(4-bytes)
ATM_STR_STATUS_STREAM_STATE			3	(1-byte)
ATM_STR_STATUS_ARP_RETRY_COUNT		4	(1-byte)
ATM_STR_STATUS_ARP_RESP_LATENCY		5	(4-bytes)
ATM_STR_STATUS_SVC_CALL_STATE			6	(1-byte)
ATM_STR_STATUS_SVC_CAUSE_LOC			7	(1-byte)
ATM_STR_STATUS_SVC_CAUSE_CODE			8	(1-byte)
ATM_STR_STATUS_SVC_SETUP_LATENCY		9	(4-bytes)

Example:
	StreamSrchInfo.uiStartIndex = 0;
	StreamSrchInfo.uiCount = 10;
	StreamSrchInfo.uiReturnItemId = ATM_STR_STATUS_CELL_HEADER;
	StreamSrchInfo.uiSearchItemId = ATM_STR_STATUS_STREAM_STATE;
	StreamSrchInfo.ulSearchRangeLow = 5;
	StreamSrchInfo.ulSearchRangeHigh = 5;

	HTGetStructure $ATM_STREAM_SEARCH_INFO 0 10 0 StreamSrchInfo 0 Hub Slot Port;

	Results obtained:
		ulItem[0] = 0x210
		ulItem[1] = 0x220
		ulItem[2] = 0x230
      ...
*/

typedef struct tagATMStreamSearchInfo
{
	unsigned short	uiStartIndex;
	unsigned short	uiCount;
	unsigned short	uiReturnItemId;
	unsigned short	uiSearchItemId;
	unsigned long	ulSearchRangeLow;
	unsigned long	ulSearchRangeHigh;
	unsigned short	uiReturnItemSize;
	unsigned short	uiReserved;
	unsigned long	ulItem[2048];
} ATMStreamSearchInfo;					/* STREAM_SEARCH_INFO; */
/* ATMStreamSearchInfo Comment:
*/

/* Stream status item id's */
#define ATM_STR_STATUS_STREAM_INDEX			0
#define ATM_STR_STATUS_CONN_INDEX			1
#define ATM_STR_STATUS_CELL_HEADER			2
#define ATM_STR_STATUS_STREAM_STATE			3
#define ATM_STR_STATUS_ARP_RETRY_COUNT		4
#define ATM_STR_STATUS_ARP_RESP_LATENCY		5
#define ATM_STR_STATUS_SVC_CALL_STATE		6
#define ATM_STR_STATUS_SVC_CAUSE_LOC		7
#define ATM_STR_STATUS_SVC_CAUSE_CODE		8
#define ATM_STR_STATUS_SVC_SETUP_LATENCY	9

/*******************************************************************
ATMConnectionStatus Description:
ATMConnectionStatus structure returns the connection statistics
associated with SmartSignaling.
*/

typedef struct tagATMConnectionStatus
{
	unsigned long	ulCellHeader;

	unsigned long	ulCallsAttempted;
	unsigned long	ulCallsEstablished;
	unsigned long	ulCallsFailed;
	unsigned long	ulCallsReleasedInError;

	unsigned char	ucState;
	unsigned char	ucUNICallState;
	unsigned char	ucLastCauseLoc;
	unsigned char	ucLastCauseCode;

	unsigned long	ulMinRTSetupLatency;
	unsigned long	ulMaxRTSetupLatency;
	unsigned long  ulTotRTSetupLatency;

	unsigned long  ulMinTeardownAckLatency;
	unsigned long  ulMaxTeardownAckLatency;
	unsigned long  ulTotTeardownAckLatency;

	unsigned long  ulTestDuration;
} ATMConnectionStatus;
/* ATMConnectionStatus Comment:
*/

/*******************************************************************
ATMConnectionInfo Description:
ATMConnectionInfo summary structure returns the connection
statistics associated with SmartSignaling for all of the connections
in the range requested.
*/

typedef struct tagATMConnectionInfo
{
	unsigned long	ulIndex;
	unsigned long	ulCount;
	ATMConnectionStatus status[ATM_MAX_ARRAY_DIM_512];
} ATMConnectionInfo;
/* ATMConnectionInfo Comment:
*/

/*******************************************************************
ATMConnectionInfoSummary Description:
*/

typedef struct tagATMConnectionInfoSummary
{
	unsigned long	ulIndex;
	unsigned long	ulCount;

	unsigned long	ulCallsAttempted;
	unsigned long	ulCallsEstablished;
	unsigned long	ulCallsFailed;
	unsigned long	ulCallsReleasedInError;
	unsigned long	ulCallsActive;

	unsigned long	ulMinRTSetupLatency;
	unsigned long	ulMaxRTSetupLatency;
	unsigned long	ulTotRTSetupLatency;
	unsigned long	ulMinTeardownAckLatency;
	unsigned long	ulMaxTeardownAckLatency;
	unsigned long	ulTotTeardownAckLatency;
	unsigned long	ulTestDuration;
	unsigned long	ulFirstFailedIndex;
} ATMConnectionInfoSummary;
/* ATMConnectionInfoSummary Comment:
*/

/*******************************************************************
ATMConnection64Status Description:
ATMConnection64Status structure returns the connection statistics-(64bits)
associated with SmartSignaling.
*/

typedef struct tagATMConnection64Status
{
	unsigned long	ulCellHeader;
	unsigned long	ulCallsAttempted;
	unsigned long	ulCallsEstablished;
	unsigned long	ulCallsFailed;
	unsigned long	ulCallsReleasedInError;

	unsigned char	ucState;
	unsigned char	ucUNICallState;
	unsigned char	ucLastCauseLoc;
	unsigned char	ucLastCauseCode;

	U64				ullMinRTSetupLatency;
	U64				ullMaxRTSetupLatency;
	U64			   ullTotRTSetupLatency;
	U64			   ullMinTeardownAckLatency;
	U64			   ullMaxTeardownAckLatency;
	U64			   ullTotTeardownAckLatency;
	U64			   ullTestDuration;
} ATMConnection64Status;
/* ATMConnection64Status Comment:
*/

/*******************************************************************
ATMConnection64Info Description:
ATMConnectionInfo summary structure returns the connection
statistics(64-bits) associated with SmartSignaling for all of the connections
in the range requested.
*/

typedef struct tagATMConnection64Info
{
	unsigned long	ulIndex;
	unsigned long	ulCount;
	ATMConnection64Status status[ATM_MAX_ARRAY_DIM_512];
} ATMConnection64Info;
/* ATMConnection64Info Comment:
*/

/*******************************************************************
ATMConnection64InfoSummary Description:
*/

typedef struct tagATMConnection64InfoSummary
{
	unsigned long	ulIndex;
	unsigned long	ulCount;

	unsigned long	ulCallsAttempted;
	unsigned long	ulCallsEstablished;
	unsigned long	ulCallsFailed;
	unsigned long	ulCallsReleasedInError;
	unsigned long	ulCallsActive;

	U64				ullMinRTSetupLatency;
	U64				ullMaxRTSetupLatency;
	U64				ullTotRTSetupLatency;
	U64				ullMinTeardownAckLatency;
	U64				ullMaxTeardownAckLatency;
	U64				ullTotTeardownAckLatency;
	U64				ullTestDuration;
	unsigned long	ulFirstFailedIndex;
	unsigned long	ulFirstActiveFailedIndex;
} ATMConnection64InfoSummary;
/* ATMConnection64InfoSummary Comment:
*/

/* Connection states */
#define CONN_STATE_IDLE 				0
#define CONN_STATE_INITIAL_DELAY		1
#define CONN_STATE_CALL_PROCEEDING		2
#define CONN_STATE_CALL_ESTABLISHED		3
#define CONN_STATE_CALL_RELEASED		4
#define CONN_STATE_INTER_CALL_DELAY		5
#define CONN_STATE_INTER_BURST_DELAY	6
#define CONN_STATE_STOPPED				7
#define CONN_STATE_STOPPED_ON_ERROR		8

/* UNI call states */
#define CALL_STATE_IDLE					0
#define CALL_STATE_CALL_INITIATED		1
#define CALL_STATE_OUTGOING_CALL_PROC	3
#define CALL_STATE_INCOMING_CALL_PRES	6
#define CALL_STATE_CONNECT_REQUEST		8
#define CALL_STATE_INCOMING_CALL_PROC	9
#define CALL_STATE_ACTIVE				10
#define CALL_STATE_RELEASE_REQUEST		11
#define CALL_STATE_RELEASE_INDICATION	12

/* Cause location codes */
#define CAUSE_LOC_USER 					0
#define CAUSE_LOC_PRIV_LOCAL 			1
#define CAUSE_LOC_PUB_LOCAL 			2
#define CAUSE_LOC_TRANS_NET 			3
#define CAUSE_LOC_PUB_REM 				4
#define CAUSE_LOC_PRIV_REM 				5
#define CAUSE_LOC_INTL_NET 				6
#define CAUSE_LOC_NET_BEYOND 			7

/* Cause codes */
#define CAUSE_UNASSIGNED_NUM 			1
#define CAUSE_NO_ROUTE_TO_TRANSIT_NET	2
#define CAUSE_NO_ROUTE_TO_DEST			3
#define CAUSE_VPI_VCI_UNACCEPTABLE		10
#define CAUSE_NORMAL_CALL_CLEAR			16
#define CAUSE_USER_BUSY					17
#define CAUSE_NO_USER_RESPONDING		18
#define CAUSE_CALL_REJECTED				21
#define CAUSE_NUMBER_CHANGED			22
#define CAUSE_CLIR						23
#define CAUSE_DEST_OUT_OF_ORDER			27
#define CAUSE_INV_NUMBER_FORMAT			28
#define CAUSE_RSP_TO_STATUS_ENQ			30
#define CAUSE_NORMAL_UNSPEC				31
#define CAUSE_VPCI_VCI_UNAVAILABLE		35
#define CAUSE_UCR_UNAVAILABLE_3_0		51
#define CAUSE_UCR_UNAVAILABLE			37
#define CAUSE_VPCI_VCI_ASSIGN_FAIL		36
#define CAUSE_TEMP_FAILURE				41
#define CAUSE_ACCESS_INF_DISC			43
#define CAUSE_NO_VPCI_VCI_AVAILABLE		45
#define CAUSE_RES_UNAVAIL				47
#define CAUSE_QOS_UNAVAILABLE			49
#define CAUSE_BC_NOT_AUTH				57
#define CAUSE_BC_NOT_AVAILABLE			58
#define CAUSE_OPT_UNAVAILABLE		    63
#define CAUSE_BC_NOT_IMPLEMENTED		65
#define CAUSE_TD_UNSUPPORTED			73
#define CAUSE_AAL_NOT_SUPPORTED			78
#define CAUSE_AAL_NOT_SUPPORTED_3_0		93
#define CAUSE_INV_CALL_REF				81
#define CAUSE_CHAN_NO_EXIST				82
#define CAUSE_INCOMP_DEST				88
#define CAUSE_INV_EP_REF				89
#define CAUSE_INV_TRANS_NET				91
#define CAUSE_TOO_MANY_PEND_ADD_PARTY	92
#define CAUSE_REQ_IE_MISSING			96
#define CAUSE_MSG_INV_OR_NOT_AVAIL		97
#define CAUSE_IE_INV_OR_NOT_AVAIL		99
#define CAUSE_IE_CONTENT_ERROR			100
#define CAUSE_MSG_INCOMP_CALL_STATE		101
#define CAUSE_TIMER_RECOVERY			102
#define CAUSE_INCOR_MSG_LEN		   		104
#define CAUSE_PROTOCOL_ERROR		   	111

/* Setup latency timer resolution */
#define SETUP_LATENCY_TMR_TICKS_PER_SEC	10000000L

/*****************************************************************************
IlmiInfo Description:

Defined values for the State:
 ATM_ILMI_UME_INACTIVE		0
 ATM_ILMI_UME_DOWN			1
 ATM_ILMI_UME_COLD_START	2
 ATM_ILMI_UME_RUNNING		3
*/

typedef struct tagATMILMIInfo
{
	unsigned char	ucState;

	unsigned short	uiColdStarts;
	unsigned short	uiGoodPackets;
	unsigned short	uiBadPackets;
	unsigned short	uiSentPackets;

	ATMAddress		RegAddr;
} ATMILMIInfo;
/* ATMILMIInfo Comment:
*/

/* Max Seconds to wait for ILMI to come up */
#define ATM_ILMI_REG_TIMEOUT		20

/* UNI Management Entity (UME) states */
#define ATM_ILMI_UME_INACTIVE		0
#define ATM_ILMI_UME_DOWN			1
#define ATM_ILMI_UME_COLD_START		2
#define ATM_ILMI_UME_RUNNING		3

/*****************************************************************************
ATMSaalInfo Description:

Defined values for

SSCOP States:
 SSCOP_STATE_IDLE 					1
 SSCOP_STATE_OUT_CONN_PEND 			2
 SSCOP_STATE_IN_CONN_PEND 			3
 SSCOP_STATE_OUT_DISCONN_PEND 		4
 SSCOP_STATE_OUT_RESYNC_PEND 		5
 SSCOP_STATE_IN_RESYNC_PEND 		6
 SSCOP_STATE_OUT_RECOV_PEND 		7
 SSCOP_STATE_RECOV_RSP_PEND 		8
 SSCOP_STATE_IN_RECOV_PEND 			9
 SSCOP_STATE_DATA_XFER_RDY 			10
 SSCOP_STATE_CC_RESYNC_PEND 		11

SAAL States:
 SAAL_STATE_IDLE 					1
 SAAL_STATE_CONN_PEND 				2
 SAAL_STATE_DISCONN_PEND 			3	
 SAAL_STATE_CONNECTED				4
*/

typedef struct tagATMSAALInfo
{
	unsigned char	ucSscopState;
	unsigned char	ucSaalState;

	unsigned long	ulVtSendState;	/*ITU-T Recommendation Q.2110 p17 (pp16-22) */
	unsigned long	ulVtPollSend;
	unsigned long	ulVtMaxSend;
	unsigned long	ulVtPollData;

	unsigned long	ulVrRxState;
	unsigned long	ulVrHighestExpected;
	unsigned long	ulVrMaxReceive;
} ATMSAALInfo;
/* ATMSAALInfo Comment:
*/

/* Max Seconds to wait for SAAL to come up */
#define ATM_SAAL_TIMEOUT		10

/* SSCOP states */
#define SSCOP_STATE_IDLE 				1
#define SSCOP_STATE_OUT_CONN_PEND 		2
#define SSCOP_STATE_IN_CONN_PEND 		3
#define SSCOP_STATE_OUT_DISCONN_PEND 	4
#define SSCOP_STATE_OUT_RESYNC_PEND 	5
#define SSCOP_STATE_IN_RESYNC_PEND 		6
#define SSCOP_STATE_OUT_RECOV_PEND 		7
#define SSCOP_STATE_RECOV_RSP_PEND 		8
#define SSCOP_STATE_IN_RECOV_PEND 		9
#define SSCOP_STATE_DATA_XFER_RDY 		10
#define SSCOP_STATE_CC_RESYNC_PEND 		11

/* SAAL states */
#define SAAL_STATE_IDLE 				1
#define SAAL_STATE_CONN_PEND 			2
#define SAAL_STATE_DISCONN_PEND 	   3
#define SAAL_STATE_CONNECTED		   4

/*****************************************************************************
ATMSigEmulationInfo Description:
 */
typedef struct tagATMSigEmulatorInfo
{
	unsigned long	ulCallsHandled;
	unsigned long	ulCallsProgressing;
	unsigned long	ulCallsActive;
} ATMSigEmulatorInfo;
/* ATMSigEmulatorInfo Comment:
*/

/*****************************************************************************
ATMSigRestartAckInfo Description:

Defineed values for the Restart States:
 AFSIG_RESTART_IDLE					0
 AFSIG_RESTART_PROCEEDING			1
 AFSIG_RESTART_SUCCESS				2
 AFSIG_RESTART_FAIL					3
*/

typedef struct tagATMSigRestartAckInfo
{
	unsigned char	ucCurrentState;
} ATMSigRestartAckInfo;
/* ATMSigRestartAckInfo Comment:
*/


/*
 * Restart States at the User/Network Side of the UNI
 */
#define AFSIG_RESTART_IDLE					0
#define AFSIG_RESTART_PROCEEDING			1
#define AFSIG_RESTART_SUCCESS				2
#define AFSIG_RESTART_FAIL					3

/*****************************************************************************
ATMSigTraceParams Description:

Defined values for Sig trace stop config:
 SIG_TRACE_STOP_ON_SEVERE_ERROR			0
 SIG_TRACE_STOP_ON_TRACE_BUFFER_FULL	1
*/

typedef struct tagATMSigTraceParams
{
	unsigned char	ucStopConfig;
} ATMSigTraceParams;
/* ATMSigTraceParams Comment:
*/

#define SIG_TRACE_STOP_ON_SEVERE_ERROR		0
#define SIG_TRACE_STOP_ON_TRACE_BUFFER_FULL	1

/*****************************************************************************
ATMSigTraceEventInfo Description:
*/

typedef struct tagATMSigTraceEventInfo
{
	unsigned long	ulEventCount;
} ATMSigTraceEventInfo;
/* ATMSigTraceEventInfo Comment:
*/


/*****************************************************************************
ATMSigTraceEventData Description:

Defined values for Signaling events:
 SIG_EVENT_SAAL_ESTABLISH		1
 SIG_EVENT_SAAL_RELEASE			2
 SIG_EVENT_OUTGOING_SETUP		3
 SIG_EVENT_INCOMING_SETUP		4
 SIG_EVENT_OUTGOING_CONNECT		5
 SIG_EVENT_INCOMING_CONNECT		6
 SIG_EVENT_OUTGOING_RELEASE		7
 SIG_EVENT_INCOMING_RELEASE		8
*/

typedef struct tagATMSigTraceEventData
{
	unsigned char	ucEvent;
	unsigned char	ucCardNumber;
	unsigned char	ucCauseLocation;
	unsigned char	ucCauseCode;
	unsigned long	ulCallSeqNumber;
	unsigned long	ulTimeStamp;
} ATMSigTraceEventData;
/* ATMSigTraceEventData Comment:
*/

/* Signaling events */
#define SIG_EVENT_SAAL_ESTABLISH		1
#define SIG_EVENT_SAAL_RELEASE			2
#define SIG_EVENT_OUTGOING_SETUP		3
#define SIG_EVENT_INCOMING_SETUP		4
#define SIG_EVENT_OUTGOING_CONNECT		5
#define SIG_EVENT_INCOMING_CONNECT		6
#define SIG_EVENT_OUTGOING_RELEASE		7
#define SIG_EVENT_INCOMING_RELEASE		8

/****************************************************************************
ATMELANInfo Description:

Defined values for ELAN States:
 ATM_ELAN_INACTIVE				0
 ATM_ELAN_LECS_SVC_WAIT			1
 ATM_ELAN_LECS_CONFIG_WAIT		2
 ATM_ELAN_LES_SVC_WAIT			3
 ATM_ELAN_LES_JOIN_WAIT			4
 ATM_ELAN_BUS_ARP_WAIT			5
 ATM_ELAN_BUS_SVC_WAIT			6
 ATM_ELAN_AVAILABLE				7
 ATM_ELAN_UNAVAILABLE			8
*/

typedef struct tagATMELANInfo
{
	unsigned char	ucInstance;
	unsigned char	ucState;

	unsigned char	ucC2Type;
	unsigned char	ucC3MTU;
	unsigned char	ucC5Name[ATM_MAX_ELAN_NAME];
	unsigned short	uiC14LecIndex;

	unsigned short	uiCtrlDirectConnIndex;
	unsigned short	uiCtrlDistConnIndex;
	unsigned short	uiMcastSendConnIndex;
	unsigned short	uiMcastFwdConnIndex;

	ATMAddress		LesAtmAddr;
	ATMAddress		BusAtmAddr;
} ATMELANInfo;
/* ATMELANInfo Comment:
*/

/* ELAN states */
#define ATM_ELAN_INACTIVE                   0
#define ATM_ELAN_LECS_SVC_WAIT				1
#define ATM_ELAN_LECS_CONFIG_WAIT  			2
#define ATM_ELAN_LES_SVC_WAIT               3
#define ATM_ELAN_LES_JOIN_WAIT              4
#define ATM_ELAN_BUS_ARP_WAIT               5
#define ATM_ELAN_BUS_SVC_WAIT               6
#define ATM_ELAN_AVAILABLE                  7
#define ATM_ELAN_UNAVAILABLE                8


/*****************************************************************************
ATMClassicalIPInfo Description: CLASSICAL IP OVER ATM (RFC1577) STATUS
This retrieves the RFC 1577 Status information.

Defined values for CIP States:
 ATM_ARP_CONN_INACTIVE		0
 ATM_ARP_CONN_PROCEEDING	1
 ATM_ARP_CONN_ESTABLISHED	2
 ATM_ARP_CONN_RELEASED		3
 ATM_ARP_CONN_FAILED		4
*/

typedef struct tagATMClassicalIPInfo
{
	 /* ARP server SVC state */
	unsigned char	ucSvcCallState;
	unsigned char	ucSvcCauseLoc;
	unsigned char	ucSvcCauseCode;

	unsigned char	ucReserved;

	 /* Packet counters */
	unsigned short	uiArpRequestPackets;
	unsigned short	uiArpResponsePackets;
	unsigned short	uiInarpRequestPackets;
	unsigned short	uiInarpResponsePackets;
} ATMClassicalIPInfo;			/* RFC1577_STATUS; */
/* ATMClassicalIPInfo Comment:
*/


/* Max Seconds to wait for CLIP to establish */
#define ATM_CLIP_TIMEOUT 			10

/* CIP States */
#define ATM_ARP_CONN_INACTIVE		0
#define ATM_ARP_CONN_PROCEEDING		1
#define ATM_ARP_CONN_ESTABLISHED	2
#define ATM_ARP_CONN_RELEASED		3
#define ATM_ARP_CONN_FAILED			4

/*****************************************************************************
ATMSigEmulTeardown Description: SIGNALING EMULATOR TEARDOWN FLAG (SigTest)

Defined values for TearDown:
 SIG_EMUL_NO_TEARDOWN	0
 SIG_EMUL_TEARDOWN		1
*/

typedef struct 	tagATMSigEmulTeardown
	{
	unsigned char 			ucTeardown;
	unsigned char			ucReserved1[3];
	unsigned long			ucReserved2[3];
	} ATMSigEmulTeardown;
/* ATMSigEmulTeardown Comment:
*/

#define SIG_EMUL_NO_TEARDOWN	0
#define SIG_EMUL_TEARDOWN		1

/*****************************************************************************
ATMPVCADNewParams Description:

Defined values for the Tmr Outstanding Req ID:
 PVCAD_DEFAULT_PORT								0
 PVCAD_DEFAULT_OUTSTANDING_REQID_TIMEOUT		100
*/

typedef struct		tabATMPVCADNewParams
{
	 unsigned long      	ulTmrOutstandingReqid;
	 unsigned long       ulPort;
} ATMPVCADNewParams;
/* ATMPVCADNewParams Comment:
*/

#define PVCAD_DEFAULT_PORT							0
#define PVCAD_DEFAULT_OUTSTANDING_REQID_TIMEOUT		100

/*****************************************************************************/
/*
 * PVC AUTO-DISCOVERY ILMI GETNEXT
 */
typedef struct		tagATMPVCADVPIVCIForGetnext
{
	 unsigned char 	ucReserved;    /* see states below */
	 unsigned char		ucVPI;
	 unsigned short	uiVCI;
	 unsigned long		ulReserved;
} ATMPVCADVPIVCIForGetnext;
/* ATMPVCADVPIVCIForGetnext Comment:
*/

/*****************************************************************************
ATMPVCADResponse Description:

Defined values for Virtual Connection entry type
 - Obtained by issuing a call to HTGetEnhancedStatus
 VC_TYPE_PVC								0x01
 VC_TYPE_SVC								0x02

Defined Virtual Connection LED Status
 VCDB_UPDATED								0x00020000
 VCDB_LOSS_OF_TRANS							0x00040000
 VCDB_LOSS_OF_DELETED						0x00080000
 VCDB_RENUMBERED							0x00100000

Defined Virtual Connection entry state
 VCDB_STATE_NEW		  						0x01
 VCDB_STATE_MODIFIED  						0x02
 VCDB_STATE_DELETED							0x04
 VCDB_STATE_STABLE	  						0x08
 VCDB_STATE_TRANSITORY						0x10
*/

typedef struct		tagATMPVCADResponse
{
	unsigned char 	ucEntryState;    		/* see states below */
	unsigned char	ucVPI;
	unsigned short	uiVCI;
	unsigned long	ulPVCStatus;         /* see states below */
	/* ATM Traffic Descriptor Information Element */
	unsigned long	ulFwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulFwdPCR_0;				/* Peak cell rate 0 in cells/sec		*/
	unsigned long	ulFwdPCR_01;			/* Peak cell rate 0+1 in cells/sec	*/
	unsigned long	ulFwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulFwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulFwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulFwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	unsigned long	ulBwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulBwdPCR_0;				/* Peek cell rate 0 in cells/sec		*/
	unsigned long	ulBwdPCR_01;			/* Peek cell rate 0+1 in cells/sec	*/
	unsigned long	ulBwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulBwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulBwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulBwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	/* Quality of Service Information Element */
	unsigned char	ucFwdQOS;				/* Forward - one of ATM_QOS values		*/
	unsigned char	ucBwdQOS;				/* Backward - one of ATM_QOS values		*/
	unsigned char	ucReserved[2];			/* Backward - one of ATM_QOS values		*/

} ATMPVCADResponse;
/* ATMPVCADResponse Comment:
*/

/*****************************************************************************
ATMVCDBListReq Description: Virtual Connection List Retrieval
*/

typedef struct		tagATMVCDBListReq
{
	 unsigned long		ulStartEntryNum;
	 unsigned char		ucEntryState;
	 unsigned char		ucReserved[3];
	 unsigned long		ulEntryCount;
} ATMVCDBListReq;
/* ATMVCDBListReq Comment:
*/

/*****************************************************************************
ATMVCDBListHdr Description:
*/

typedef struct		tagATMVCDBListHdr
{
	unsigned long		ulStartEntryNum;
	unsigned char		ucEntryState;
	unsigned char		ucReserved[3];
	unsigned long		ulEntryCount;
} ATMVCDBListHdr;
/* ATMVCDBListHdr Comment:
*/


/*****************************************************************************
ATMVCDEntryParams Description:

Defined PVC status
 PVC_UNKNOWN_STATUS							1
 PVC_END2END_UP_STATUS						2
 PVC_END2END_DOWN_STATUS					3
 PVC_LOCAL_UP_END2END_UNKNOWN_STATUS		4
 PVC_LOCAL_DOWN_STATUS						5
*/

typedef struct		tagATMVCDBEntryParams
{
	unsigned long	ulPVCStatus; 			/* see PVC status above */
													/* unused for SVC      */
} ATMVCDBEntryParams;
/* ATMVCDBEntryParams Comment:
*/

/* Virtual Connection entry type  - Obtained by issuing a call to HTGetEnhancedStatus */
#define VC_TYPE_PVC									0x01
#define VC_TYPE_SVC									0x02

/* Virtual Connection LED Status */
#define VCDB_UPDATED								0x00020000
#define VCDB_LOSS_OF_TRANS							0x00040000
#define VCDB_LOSS_OF_DELETED						0x00080000
#define VCDB_RENUMBERED								0x00100000

/* Virtual Connection entry state */
#define VCDB_STATE_NEW		  						0x01
#define VCDB_STATE_MODIFIED  						0x02
#define VCDB_STATE_DELETED							0x04
#define VCDB_STATE_STABLE	  						0x08
#define VCDB_STATE_TRANSITORY						0x10


/* PVC status */
#define PVC_UNKNOWN_STATUS							1
#define PVC_END2END_UP_STATUS						2
#define PVC_END2END_DOWN_STATUS						3
#define PVC_LOCAL_UP_END2END_UNKNOWN_STATUS			4
#define PVC_LOCAL_DOWN_STATUS						5

/*****************************************************************************
ATMVCDBClearFlagReq Description:

Defined values for VC Clear LOSS flags:
 LOSS_OF_DELETED_FLAG			0x0001
 LOSS_OF_TRANSITORY_FLAG		0x0002
 RENUMBERED_FLAG				0x0004
*/

typedef struct		tagATMVCDBClearFlagReq
{
	unsigned short		uiFlags;
	/*unsigned short		uiReserved; */
} ATMVCDBClearFlagReq;
/* ATMVCDBClearFlagReq Comment:
*/

#define	LOSS_OF_DELETED_FLAG		0x0001
#define	LOSS_OF_TRANSITORY_FLAG		0x0002
#define	RENUMBERED_FLAG				0x0004

/*****************************************************************************
ATMVCDBEntryRtvl Description:
VC entry retreival structure Description
Defined values for

ATM traffic descriptor type (Forward and Backward):
 ATM_TD_QUAL_PEAK_RATES				0
 ATM_TD_QUAL_PEAK_RATES_W_TAG		1
 ATM_TD_COMBO_RATES					2
 ATM_TD_COMBO_RATES_W_TAG			3
 ATM_TD_AGGR_PEAK_RATE				4
 ATM_TD_AGGR_COMBO_RATES			5
 ATM_TD_BEST_EFFORT					6
 ATM_TD_NONE						7

Quality of service class:
 ATM_QOS_CLASS_0				  	0
 ATM_QOS_CLASS_1				  	1
 ATM_QOS_CLASS_2				  	2
 ATM_QOS_CLASS_3				  	3
 ATM_QOS_CLASS_4				  	4

Broadband bearer capability class:
 ATM_B_BC_CLASS_X					16
 ATM_B_BC_CLASS_A					1
 ATM_B_BC_CLASS_C					3

Broadband bearer capability timing requirement:
 ATM_B_BC_NO_TIMING_INFO			0
 ATM_B_BC_END_TO_END_TIMING			1
 ATM_B_BC_NO_END_TO_END_TIMING		2

Broadband bearer capability traffic type:
 ATM_B_BC_TYPE_NONE					0
 ATM_B_BC_TYPE_CBR					4
 ATM_B_BC_TYPE_VBR					8

Broadband bearer capability clipping susceptibility:
 ATM_B_BC_SUSC_CLIP					32
 ATM_B_BC_NOT_SUSC_CLIP				0
*/

typedef struct		tagATMVCDBEntryRtvl
{
	unsigned long		ulEntryNum;			/* Entry number in the datatbase 	*/
	unsigned long		ulStateTimestamp;	/* Timestamp for changing state	 	*/
	unsigned char		ucEntryState; 		/* see VC entry state above 			*/
	unsigned char		ucEncapType; 		/* see Stream Params 					*/
	unsigned char		ucReserved1;		/* padding								 	*/
	unsigned char		ucVPI;
	unsigned short 	uiVCI;
	unsigned short		uiConnIndex; 		/* Connection Index						*/
	unsigned long		ulCallRef; 			/* 24-bit number chosen by the      */
													/* switch to uniquely identify a call */

	/* ATM Traffic Descriptor Information Element */
	unsigned long	ulFwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulFwdPCR_0;				/* Peak cell rate 0 in cells/sec		*/
	unsigned long	ulFwdPCR_01;			/* Peak cell rate 0+1 in cells/sec	*/
	unsigned long	ulFwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulFwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulFwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulFwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	unsigned long	ulBwdTrafficDescriptorType; /* one of ATM_TD from below	*/
	unsigned long	ulBwdPCR_0;				/* Peek cell rate 0 in cells/sec		*/
	unsigned long	ulBwdPCR_01;			/* Peek cell rate 0+1 in cells/sec	*/
	unsigned long	ulBwdSCR_0;				/* Sus cell rate 0 in cells/sec		*/
	unsigned long	ulBwdSCR_01;			/* Sus cell rate 0+1in cells/sec		*/
	unsigned long	ulBwdMBS_0;				/* Maximum Burst Size 0 in cells		*/
	unsigned long	ulBwdMBS_01;			/* Maximum Burst Size 0+1 in cells	*/

	/* Quality of Service Information Element */
	unsigned char	ucFwdQOS;				/* Forward - one of ATM_QOS values		*/
	unsigned char	ucBwdQOS;				/* Backward - one of ATM_QOS values		*/
	unsigned char	ucReserved2[2];					/* Backward - one of ATM_QOS values		*/

	/* Broadband Bearer Capability Information Element */
	unsigned char	ucBbcClass;				/* One of ATM_B_BC_CLASS values			*/
	unsigned char	ucBbcTimingReq;		/* One of ATM_B_BC timing values			*/
	unsigned char	ucBbcTrafficType;		/* One of ATM_B_BC_TYPE values			*/
	unsigned char	ucBbcSusceptibleToClipping;	/* ATM_B_BC clipping values*/
	ATMAddress		AtmCaller; 				/* unused for PVC */
	unsigned char	ucIPAddr[4]; 			/*only used for classical IP SVCs*/
	unsigned char	ucReserved3[4];
} ATMVCDBEntryRtvl;
/* ATMVCDBEntryRtvl Comment:
*/

/*****************************************************************************
ATMVCDBInfo Description:
*/

typedef struct		tagATMVCDBInfo
{
	unsigned long		ulStartEntryNum;  /* Starting index */
	unsigned char		ucEntryState;		/* Of the state that we want to retrieve */
	unsigned char		ucReserved[3];
	unsigned long		ulEntryCount; 		/* Number of entries to retrieves */
	ATMVCDBEntryRtvl  status[ATM_MAX_ARRAY_DIM_512];
}	ATMVCDBInfo;
/* ATMVCDBInfo Comment:
*/

/*****************************************************************************
ATMVCDBPurge Description: VCDB purge the datatbase
*/

typedef struct		tagATMVCDBPurge
{
	unsigned char		ucEntryState;
	/*unsigned char		ucReserved[3]; */
} ATMVCDBCPurge;
/* ATMVCDBPurge Comment:
*/


/*****************************************************************************
ATMIncoming SVC method Description:
Defines how the card should accept calls via the Method:

IN_SVC_DONT_ADD_TO_DATABASE				0
IN_SVC_CONN_AS_SNAP_OR_LANE				1
IN_SVC_CONN_AS_CLIP_OR_LANE				2
*/

typedef struct 	tagATMIncomingSVCMethod
	{
	unsigned char	ucReserved[3];
	unsigned char	ucMethod;			/* Use one of the following defined below */
	} ATMIncomingSVCMethod;
/* ATMIncomingSVCMethod Comment:
*/

#define IN_SVC_DONT_ADD_TO_DATABASE				0	/* default */
#define IN_SVC_CONN_AS_SNAP_OR_LANE				1
#define IN_SVC_CONN_AS_CLIP_OR_LANE				2


/* PVC Auto-Discovery states */
typedef enum
{
	 PVCAD_DOWN = 0,
	 PVCAD_INACTIVE,
	 PVCAD_CHECKING_VCCS,
	 PVCAD_RUNNING
} PVCAD_STATE;

/*****************************************************************************
ATMVCDBCounts Description: VC Database Counts.
*/

typedef struct		tagATMVCCounts
{
	 unsigned long		ulNewSVCCount;
	 unsigned long		ulStableSVCCount;
	 unsigned long		ulModifiedSVCCount;
	 unsigned long		ulDeletedSVCCount;
	 unsigned long		ulTransitorySVCCount;
	 /*unsigned char	ucReserved[8]; */
} ATMVCDBCounts;
/* ATMVCDBCounts Comment:
*/

/*****************************************************************************
ATMPerConnBurstCount Description: Burst Count per connection or per stream
This feature enables applications controlling the ATM cards to specify the
quantity of frames to transmit and then stop for each connection or per stream.
The Burst size can be unique for each connection or each stream.
Supported on both ATM-1 and ATM-2 type cards, with the exception of the
Multi-burst feature, which is only available on the ATM-2 cards.  Check the
Supported Feature bit - ATM_FEATURES_MULTI_BURST in the CardCapabilities
structure to determine whether multi-burst is supported.

Defined values for ucFunction:
 ATM_BURST_DISABLE					0
 ATM_BURST_ENABLE 					1
 ATM_MULTI_BURST_ENABLE				2	- only supported on ATM-2 cards
 ATM_CONT_MULTI_BURST_ENABLE		3	- only supported on ATM-2 cards

Defined value for ulFrameBurstSize:
 ATM_MAX_BURST_SIZE			0x001FFFFF
*/

 typedef struct 	tagATMPerConnBurstCount
	{
	unsigned short	uiStartConnIdx;
	unsigned short	uiConnCount;
	unsigned char	ucFunction;				/* Use one of the following defined below */
	unsigned char	ucReserved;
	unsigned short	uiMultiBurstCount;		/* Range: 1 to 65535 */
	unsigned long	ulInterBurstGap;		/* Units of milliseconds */
	unsigned long	ulFrameBurstSize;		/* Rabge: 1 to 2,097,151 */
	} ATMPerConnBurstCount;
/* ATMPerConnBurstCount Comment:
Note:	This structure can be used to set the burst count, either by
		a stream index or a connection index.
*/

#define MAX_ATM_BURST_SIZE	0x001FFFFF


/*****************************************************************************
ATMPerPortBurstCount Description:  Burst Count per port.
This feature enables applications controlling the ATM cards to specify the
quantity of frames to transmit and then stop on a per-port basis (inclusive
of all active connections).  The burst size can be unique for each connection.
Supported on both ATM-1 and ATM-2 type cards.
Defined values for ucFunction:
 ATM_BURST_DISABLE		0
 ATM_BURST_ENABLE 		1

Defined value for ulFrameBurstSize:
 ATM_MAX_PORT_BURST_SIZE		0xFFFFFFFF
*/

 typedef struct 	tagATMPerPortBurstCount
	{
	unsigned char	ucFunction;			/* Use one of the following defined below */
	unsigned char	ucReserved[3];
	unsigned long	ulReserved;
	unsigned long	ulFrameBurstSize;	/* Range: 1 to 4,294,967,295 ( all 32-bits ) */
	} ATMPerPortBurstCount;
/* ATMPerPortBurstCount Comment:
Note:	This structure can be used to set the burst count for a port.
*/

#define ATM_MAX_PORT_BURST_SIZE	0xFFFFFFFF

#define ATM_BURST_DISABLE				0
#define ATM_BURST_ENABLE				1
#define ATM_MULTI_BURST_ENABLE	  		2
#define ATM_CONT_MULTI_BURST_ENABLE		3

/*****************************************************************************
ATMStreamParamsCopy Description:
These features help to reduce the setup time associated with configuring
streams.  Based on an existing "Source" Stream, the Stream Copy feature can
be used to create any given number of streams with the same parameters.
Feature supported on all ATM interfaces.

 Example:	If a stream exists with the stream index of 5 and the user wishes
				to create 8 new streams using the same parameters, beginning at the
				stream index of 16, using the ATM_STREAM_PARAMS_COPY command:
	uiSrcStrNum = 5
	uiDstStrNum = 16
	uiDstStrCount = 8
*/

 typedef struct 	tagATMStreamParamsCopy
	{
	unsigned short	uiSrcStrNum;		/* "Source" stream index. */
	unsigned short	uiDstStrNum;		/* Starting stream idx in which the info
													of the "Source" Stream is to be copied to. */
	unsigned short	uiDstStrCount;		/* The number of streams to be created with the
													"Source" Stream's info.  */
	unsigned short	uiReserved;
	unsigned long	ulReserved;
	} ATMStreamParamsCopy;
/* ATMStreamParamsCopy Comment:
*/

/*****************************************************************************
ATMStreamParamsModify Description:
The Stream Modify feature can be used to modify the parameters of any given number
of streams which already exist, with an absolute value.
Feature supported on all ATM interfaces.

 Example1:	Assume the user wishes to modify the Peak Cell Rate to 500 cells/sec
				for 5 streams on the card.  Using the ATM_STREAM_PARAMS_MODIFY command:
	uiStartStrNum = 0
	uiStrCount = 5
	uiParamItemID = ATM_STR_PARAM_GEN_PCR
	uiParamCount =  5
	ucData = 0x000001F4

 Example2:	Assume the user wishes to modify the Peak Cell Rate of 5 streams
				to be a different value, not neccessarily in a fixed incremental
				delta, i.e. Stream#0 with a PCR of 1000
								Stream#1 with a PCR of 1050
								Stream#2 with a PCR of 3000
								Stream#3 with a PCR of 5000
								Stream#4 with a PCR of 10,000
	uiStartStrNum = 0
	uiStrCount = 5
	uiParamItemID = ATM_STR_PARAM_GEN_PCR
	uiParamCount =  5
	ucData = 0x00003E80000041A00000BB80000138800002710

The field to be modified is specified by uiParamItemID are specified
as follows:
ATM_STR_PARAM_GEN_RATE_CLASS		0
ATM_STR_PARAM_GEN_PCR			  	1
ATM_STR_PARAM_GEN_SCR			  	2
ATM_STR_PARAM_GEN_MBS			  	3
ATM_STR_PARAM_GEN_CDVT				4
ATM_STR_PARAM_SIG_FW_PCR_0			5
ATM_STR_PARAM_SIG_FW_PCR_01	  		6
ATM_STR_PARAM_SIG_FW_SCR_0			7
ATM_STR_PARAM_SIG_FW_SCR_01	  		8
ATM_STR_PARAM_SIG_FW_MBS_0			9
ATM_STR_PARAM_SIG_FW_MBS_01			10
ATM_STR_PARAM_SIG_BW_PCR_0			11
ATM_STR_PARAM_SIG_BW_PCR_01	  		12
ATM_STR_PARAM_SIG_BW_SCR_0			13
ATM_STR_PARAM_SIG_BW_SCR_01	  		14
ATM_STR_PARAM_SIG_BW_MBS_0			15
ATM_STR_PARAM_SIG_BW_MBS_01			16
ATM_STR_PARAM_SIG_FW_TD_TYPE		17
ATM_STR_PARAM_SIG_BW_TD_TYPE		18
ATM_STR_PARAM_SIG_FW_QOS			19
ATM_STR_PARAM_SIG_BW_QOS			20
ATM_STR_PARAM_SIG_BC_CLASS			21
ATM_STR_PARAM_SIG_TIMING			22
ATM_STR_PARAM_SIG_TRAFFIC_TYPE		23
ATM_STR_PARAM_SIG_CLIPPING			24
ATM_STR_PARAM_CELL_HEADER			25
ATM_STR_PARAM_DEST_ATM_ADDR			26
ATM_STR_PARAM_DEST_MAC_ADDR			27
ATM_STR_PARAM_DEST_IP_ADDR		  	28
ATM_STR_PARAM_SNAP_HDR				29
ATM_STR_PARAM_ELAN_INST				30
*/

 typedef struct 	tagATMStreamParamsModify
	{
	unsigned short	uiStartStrNum;		/* Stream index of the first stream to be modified. */
	unsigned short	uiStrCount;			/* The number of streams which are to be modified. */
	unsigned short	uiParamItemID;		/* Parameter ID which is to be modified  on all
													requested streams - use one of the following
													defined below. */
	unsigned short	uiParamCount;		/* The number of elements to be specified
													for the uiParamItemID value.  This does not
													include the parameter size */
	unsigned char	ucData[ATM_MAX_ARRAY_DIM]; /* Array contains the number of bytes
																specified by the uiParamCount*ParamSize */
  } ATMStreamParamsModify;
/* ATMStreamParamsModify Comment:
*/

#define ATM_STR_PARAM_GEN_RATE_CLASS		0
#define ATM_STR_PARAM_GEN_PCR				1
#define ATM_STR_PARAM_GEN_SCR				2
#define ATM_STR_PARAM_GEN_MBS				3
#define ATM_STR_PARAM_GEN_CDVT				4
#define ATM_STR_PARAM_SIG_FW_PCR_0			5
#define ATM_STR_PARAM_SIG_FW_PCR_01			6
#define ATM_STR_PARAM_SIG_FW_SCR_0			7
#define ATM_STR_PARAM_SIG_FW_SCR_01			8
#define ATM_STR_PARAM_SIG_FW_MBS_0			9
#define ATM_STR_PARAM_SIG_FW_MBS_01			10
#define ATM_STR_PARAM_SIG_BW_PCR_0			11
#define ATM_STR_PARAM_SIG_BW_PCR_01			12
#define ATM_STR_PARAM_SIG_BW_SCR_0			13
#define ATM_STR_PARAM_SIG_BW_SCR_01			14
#define ATM_STR_PARAM_SIG_BW_MBS_0			15
#define ATM_STR_PARAM_SIG_BW_MBS_01			16
#define ATM_STR_PARAM_SIG_FW_TD_TYPE		17
#define ATM_STR_PARAM_SIG_BW_TD_TYPE		18
#define ATM_STR_PARAM_SIG_FW_QOS			19
#define ATM_STR_PARAM_SIG_BW_QOS			20
#define ATM_STR_PARAM_SIG_BC_CLASS			21
#define ATM_STR_PARAM_SIG_TIMING			22
#define ATM_STR_PARAM_SIG_TRAFFIC_TYPE		23
#define ATM_STR_PARAM_SIG_CLIPPING			24
#define ATM_STR_PARAM_CELL_HEADER			25
#define ATM_STR_PARAM_DEST_ATM_ADDR			26
#define ATM_STR_PARAM_DEST_MAC_ADDR			27
#define ATM_STR_PARAM_DEST_IP_ADDR		  	28
#define ATM_STR_PARAM_SNAP_HDR				29
#define ATM_STR_PARAM_ELAN_INST				30


/*****************************************************************************
ATMStreamParamsFill Description:
The Stream Fill feature also can be used to modify the parameters of any given
number of streams which already exist, with a stream index of a stream whose
parameter value should be used, as an initial value, and a delta to increment
that value by for each successive stream.
Feature supported on all ATM interfaces.

 Example:	If the user wishes to set the destination ATM addresses of
				streams 4-11 to values which increment the ESI field of stream
				3 by one for each successive streams.  Using the
				ATM_STREAM_PARAMS_FILL:
	uiSrcStrNum = 3
	uiDstStrNum = 4
	uiDstStrCount = 8
	uiParamItemID = ATM_STR_PARAM_DEST_ATM_ADDR
	ucDelta = 0x0000000000000000000000000000000000000100

  If the destination ATM address for stream 3 was 0x390348800000000000000000000000000000004500
  then streams 4-11 will have the following destination ATM Addresses:
  stream 4: 0x390348800000000000000000000000000000004600
  stream 5: 0x390348800000000000000000000000000000004700
  stream 6: 0x390348800000000000000000000000000000004800
  stream 7: 0x390348800000000000000000000000000000004900
  stream 8: 0x390348800000000000000000000000000000004A00
  stream 9: 0x390348800000000000000000000000000000004B00
  stream 10: 0x390348800000000000000000000000000000004C00
  stream 11: 0x390348800000000000000000000000000000004D00

The field to be modified is specified by uiParamItemID are specified
as follows:
ATM_STR_PARAM_GEN_RATE_CLASS		0
ATM_STR_PARAM_GEN_PCR			  	1
ATM_STR_PARAM_GEN_SCR			  	2
ATM_STR_PARAM_GEN_MBS			  	3
ATM_STR_PARAM_GEN_CDVT				4
ATM_STR_PARAM_SIG_FW_PCR_0			5
ATM_STR_PARAM_SIG_FW_PCR_01	  		6
ATM_STR_PARAM_SIG_FW_SCR_0			7
ATM_STR_PARAM_SIG_FW_SCR_01	  		8
ATM_STR_PARAM_SIG_FW_MBS_0			9
ATM_STR_PARAM_SIG_FW_MBS_01			10
ATM_STR_PARAM_SIG_BW_PCR_0			11
ATM_STR_PARAM_SIG_BW_PCR_01	  		12
ATM_STR_PARAM_SIG_BW_SCR_0			13
ATM_STR_PARAM_SIG_BW_SCR_01	  		14
ATM_STR_PARAM_SIG_BW_MBS_0			15
ATM_STR_PARAM_SIG_BW_MBS_01			16
ATM_STR_PARAM_SIG_FW_TD_TYPE		17
ATM_STR_PARAM_SIG_BW_TD_TYPE		18
ATM_STR_PARAM_SIG_FW_QOS			19
ATM_STR_PARAM_SIG_BW_QOS			20
ATM_STR_PARAM_SIG_BC_CLASS			21
ATM_STR_PARAM_SIG_TIMING			22
ATM_STR_PARAM_SIG_TRAFFIC_TYPE		23
ATM_STR_PARAM_SIG_CLIPPING			24
ATM_STR_PARAM_CELL_HEADER			25
ATM_STR_PARAM_DEST_ATM_ADDR			26
ATM_STR_PARAM_DEST_MAC_ADDR			27
ATM_STR_PARAM_DEST_IP_ADDR		  	28
ATM_STR_PARAM_SNAP_HDR				29
ATM_STR_PARAM_ELAN_INST				30
*/
 typedef struct 	tagATMStreamParamsFill
	{
	unsigned short	uiSrcStrNum;		/* Stream index of the stream whose value for the
										   desired param is to be used as an initial value
								 		   for the fill. */
	unsigned short	uiDstStrNum;		/* Stream index of the first stream whose param is
										   to be filled. */
	unsigned short	uiDstStrCount;		/* The number of streams which are to be filled. */
	unsigned short	uiParamItemID;		/* Parameter ID which is to be filled on all
										   requested streams.*/
	unsigned char	ucDelta[ATM_MAX_DELTA];		/* Successive increment values	*/
	} ATMStreamParamsFill;
/* ATMStreamParamsFill Comment:
*/


/*****************************************************************************
ATMFrameCopyReq Description:   ATM Frame Copy Request and ATM Frame Copy Mod
This features help to reduce the setup time associated with configuring
frames.  The Frame Copy feature can be used to copy, or modify a source
frame, and use it for other streams.  Modifications can be made on a per-stream
basis.  In other words, changes made to a source frame for one stream do not
have to apply to frames used for other streams.

The source frame is created using the usual ATM_FRAME_DEF command to create a
frame for one stream on the card.  Note, that however, the bit in the ulFrameFlags
field of the source frame should be set to FRAME_FLAG_SOURCE_FLAG_FOR_COPY.

The FrameCopyReq structure contains information about the starting stream index,
the count and the # of modifications to be made, including an array of modifications
(ATMFrameCopyMod) containing specific information about the stream index, the offset,
length and actual data, to be modified.

 Example:	Assume the user wishes to create a frame for stream 0 and wants to
				use that frame as a source to copy to other streams.  Using the
				ATM_FRAME_DEF command:
	uiStreamIndex = 0
	uiFrameLength = 60
	uiDataLength = 20
	uiFrameFillPattern = 0xABCD
	ulFrameFlags = 0x00000004
	ucFrameData[2048] = 0x0102030405060708090A0B0C0D0E0F1011121214

		Now assume the user wishes to use this same frame for streams 1-3, but
		wants to 1) replace the first 3 bytes and bytes 10-16 of the frame for
		stream 1 with 0x111111 and 0x22222222222222 respectively
		2) replace bytes 6-11 of the frame for stream 2 with 0x333333333333
		3) make no changes to the frame for stream 3.

		Using the ATM_FRAME_COPY command:
	uiStartStrNum = 1
	uiStrCount = 3
	uiNumMods = 3
	ModArray[i].uiStrIdx = 1
	ModArray[i].uiDataOffset = 0
	ModArray[i].ucDataLen = 3
	ModArray[i].ucData = 0x111111

	ModArray[i].uiStrIdx = 1
	ModArray[i].uiDataOffset = 9
	ModArray[i].ucDataLen = 7
	ModArray[i].ucData = 0x22222222222222

	ModArray[i].uiStrIdx = 2
	ModArray[i].uiDataOffset = 5
	ModArray[i].ucDataLen = 6
	ModArray[i].ucData = 0x333333333333
	where i is the index into the number of modifications loop

All of these features are supported on all ATM interfaces.
*/

  typedef struct 	tagATMFrameCopyMod
	{
	unsigned short	uiStrIdx;			/* Stream index of the stream, that this
													frame modification applies to. */
	unsigned short	uiDataOffset;		/* The offset from the first byte of the
													AAL5 frame, which this modification
													starts from. */
	unsigned char	ucDataLen;			/* The length in bytes of this mod.
													NOTE:: SHOULD NOT be greater than
													ATM_MAX_MOD_DATA */
	unsigned char  ucReserved[3];
	unsigned char 	ucData[ATM_MAX_MOD_DATA];
	} ATMFrameCopyMod;



 typedef struct 	tagATMFrameCopyReq
	{
	unsigned short	uiStartStrNum;		/* Stream index of the first stream to be
													copied to. */
	unsigned short	uiStrCount;			/* The number of streams, which the frame,
													stored in memory, is used as a basis for
													modification. */
	unsigned short	uiNumMods;			/* The number of FrameCopyMod structures
													which immediately follow this structure. */
	ATMFrameCopyMod ModArray[ATM_MAX_MODS];
	} ATMFrameCopyReq;
/* ATMFrameCopyReq Comment:
*/

/*****************************************************************************
ATMSchedParams Description:  ATM Cell Scheduling Method
This feature provides the ability to schedule N connections equally and at a
specific percentage of line rate.  There are two types of scheduling.
1.	Generic Cell Rate Algorithm (GCRA).  In this mode, the user selects a
		transmission rate as defined by the generator peak cell rate.  Here,
		each connection may be scheduled at a different rate and with different
		characteristics.  This is the default mode of operation.

2.	The second method is to have all connections scheduled equally.  The user
		selects the amount of bandwidth the connections should use as a percent
		of total bandwidth.  Here, the user controls the rate of transmission in
		one percent intervals from one percent to one hundred percent.  All
		connections are scheduled exactly the same number of times so all
		connections are guaranteed to transmit at the same rate.
This feature is only available on the ATM-2 interface.

Defined values for the Scheduling Type:
 SCHED_TYPE_EARLY			0
 SCHED_TYPE_EQUALLY 		1
*/

 typedef struct 	tagATMSchedParams
	{
	unsigned long	ulUtilization;		/* The amount of bandwidth as a percent of
													the total line rate.  Percent can range
													from 1 -100, inclusive, in steps of 1.
													This does not apply to the Early Sched. Type */
	unsigned short	uiSchedType;		/* Determines the type of scheduling used the
													next time streams are scheduled.  Use one of
													the following defined below. */
	unsigned short	uiReserved;
	unsigned long	ulReserved1;
	unsigned long	ulReserved2;
	} ATMSchedParams;
/* ATMSchedParams Comment:
*/

#define SCHED_TYPE_EARLY			0
#define SCHED_TYPE_EQUALLY			1

/*****************************************************************************
 Protocol Event Trace
The next three structures enable logging of events within several sub-systems
(defined below).  There strucutres correspond to the following features
respectively:
1. LogFile Control: 	Reserves memory where all trace events are stored for
							retrieval.
2.	Trace Control:		Configures the ATM card to trace certain types of events
							within several sub-systems. (Connection, ILMI, LANE, SAAL)
3. LogFile Read:		Enables the user to read the contents of the logfile.
This feature is only available on the ATM-2 interface.
*/

typedef struct 	tagATMPETLogFileReq
	{
	unsigned char	ucFunction;			/* Use one of the following below */
	unsigned char	ucReserved[3];
	unsigned long	ulLogFileSize;		/* Use one of the following below */
	} ATMPETLogFileReq;
/* ATMPETLogFileReq Comments:
*/

#define LOGFILE_CREATE_STOP_ON_FULL				0
#define LOGFILE_CREATE_OVERWRITE_ON_FULL		1
#define LOGFILE_CLOSE			 				2
#define LOGFILE_CLEAR							3

#define LOGFILE_SIZE_512						512
#define LOGFILE_SIZE_1024						1024
#define LOGFILE_SIZE_2048						2048
#define LOGFILE_SIZE_4096						4096
#define LOGFILE_SIZE_8192						8192
#define LOGFILE_SIZE_12288						12288
#define LOGFILE_SIZE_16384						16384
#define LOGFILE_SIZE_20480						20480

typedef struct 	tagATMPETReq
	{
	unsigned long	ulReserved1;
	unsigned long	ulReserved2;
	unsigned long	ulConnTraceEvents;		/* A bitmask which specifies the type of
															events to be traced by the connection
															manager subsystem. */
	unsigned long	ulILMITraceEvents;		/* A bitmask which specifies the type of
															events to be traced by the ILMI subsystem */
	unsigned long	ulLANETraceEvents;		/* A bitmask which specifies the type of
															events to be traced by the LAN Emulation
															subsystem */
	unsigned long	ulSAALTraceEvents;		/* A bitmask which specifies the type of
															events to be traced by the signaling
															subsystem */
	} ATMPETReq;
/* ATMPETReq Comment:
*/

/* For Connection, ILMI, and LANE Subsystems */
#define PET_SERR					0x00000001	/* Severe Error */
#define PET_NERR					0x00000002	/* Normal Error */
#define PET_WARN					0x00000004	/* Warning */
#define PET_ASSERT					0x00000008	/* Assertion Failure */
#define PET_TRAN					0x00000010	/* State Transition */
#define PET_EVENT					0x00000020	/* Normal Event */
#define PET_RCTRL					0x00000040	/* Received Control Frame */
#define PET_XCTRL					0x00000080	/* Transmitted Control Frame */
#define PET_RDATA					0x00000100	/* Received Data Frame */
#define PET_XDATA					0x00000200	/* Transmitted Data Frame */
#define PET_TRACE					0x00000400	/* Code path trace */
#define PET_TIMER					0x00000800	/* Timer Events */
#define PET_MEM						0x00001000	/* Memory Management Events */
#define PET_MSG						0x00002000	/* Message Events */

/* For SAAL Subsytem */
#define PET_SSCOP_PROT_ERR			0x00000001
#define PET_SSCOP_API_TRAFFIC		0x00000002
#define PET_SSCOP_HEADLINES 		0x00000004
#define PET_SSCOP_MSG_TRAFFIC		0x00000008
#define PET_SSCOP_STATE_CHANGE		0x00000010
#define PET_SSCOP_TMR_ACTIVITY		0x00000020
#define PET_SIG_PROT_ERR			0x00000100
#define PET_SIG_API_TRAFFIC 		0x00000200
#define PET_SIG_HEADLINES			0x00000400
#define PET_SIG_MSG_TRAFFIC 		0x00000800
#define PET_SIG_STATE_CHANGE 		0x00001000
#define PET_SIG_TMR_ACTIVITY 		0x00002000

typedef struct		tagATMPETReadReq
	{
	unsigned long	ulReserved;
	unsigned short	uiReserved;
	unsigned short	uiEntryCount;
	} ATMPETReadReq;
/* ATMPETReadReq Comment:
*/

typedef struct		tagATMPETListHdr
	{
	unsigned long	ulReserved;
	unsigned short	uiReserved;
	unsigned short	uiEntryCount;
	} ATMPETListHdr;
/* ATMPETListHdr Comment:
*/


typedef struct 	tagATMPETEntryRtvl
	{
	unsigned long	ulRefNum;			/* 32-bit reference num. which is unique
													to each entry. */
	unsigned long	ulTimeStamp;		/* 32-bit timestamp in units of milliseconds */
	unsigned char	ucEventData[MAX_EVENT_DATA_LEN];	/* A null-terminated ASCII
																		character string describing
																		the event */
	} ATMPETEntryRtvl;
/* ATMPETEntryRtvl Comment:
*/

typedef struct		tagATMPETInfo
	{
	unsigned long	ulReserved;
	unsigned short	uiReserved;
	unsigned short	uiEntryCount; 		/* Number of entries to retrieve, starting
													from the oldest one in the logfile.
													Max Number of bytes = 20480. */
	ATMPETEntryRtvl	status[ATM_MAX_ARRAY_DIM_512];
	}	ATMPETInfo;
/* ATMPETInfo Comment:
*/

/*******************************************************************
ATMExtVCCIStatus Description: Extended Per Connection Statistics.
ATMExtVCCIStatus records transmit and receive counts including Receive
CRC-32 error and Receive Trigger counts on a given virtual circuit
connection.
*/

typedef struct tagATMExtVCCIStatus
{
	unsigned long	ulConnIndex;	/* The conn. id of the VCC  of interest 	*/
	unsigned long	ulCellHeader;	/* The cell header of the VCC of interest	*/
	unsigned long	ulTimeStamp;	/* Time when the stats were latched			*/
	unsigned long	ulTxFrame;		/* Frames transmitted with this header		*/
	unsigned long	ulRxFrame;		/* Frames received with this header			*/
	unsigned long	ulRxCRC32Err;	/* Receive CRC-32 errors - ATM1/ATM2		*/
	unsigned long	ulRxTriggerCt;	/* Receive Trigger counts - ATM2 only 		*/
	unsigned long	ulReserved[2];
} ATMExtVCCIStatus;				/*  Extended VCC_STATS; */
/* ATMExtVCCIStatus Comment:
ATMExtVCCIStatus records transmit and receive counts, as well as
the number of CRC-32 errors and the Trigger counts on the receive end
of a given virtual circuit connection.  The time stamp records the time
in units of 100 ns when the statistics were latched.
Note: The RxCRC32Err is also available on the ATM1, with an ATM Fw version
3.02 or higher.
*/

/*******************************************************************
ATMExtVCCInfo Description:
ATMExtVCCInfo retrieves the Extended VCC information.
*/

typedef struct tagATMExtVCCInfo
{
	unsigned short	uiIndex;
	unsigned short	uiCount;
	ATMExtVCCIStatus	status[ATM_MAX_ARRAY_DIM+2]; /* index 0 and 1 are reserved */
} ATMExtVCCInfo;		/* EXT_VCC_STATS_HDR; */
/* ATMExtVCCInfo Comment:
NOTE::::This structure is used to obtain the Ext. VCC stats based on the connection or
stream indices.
*/

/*******************************************************************
ATMStreamTriggerTimeStatus Description:
The ATMStreamTriggerTimeInfo structure contains the time of the firing of
the first trigger since the last clear counters and the number of
trigger fired since the last clear counters. Used with ATM-2 only.
*/

typedef struct tagATMStreamTriggerTimeStatus
{
	unsigned long	ulTrigger;		/* Trigger events on the receive side	*/
	unsigned long	ulTxTimestamp;	/* time the first cell exits the card	*/
	unsigned long	ulRxTimestamp;	/* time the first trigger received	*/
	unsigned long	ulTimestamp;	/* Timestamp with 100nS resolution.
												Time when statistics were obtained */
} ATMStreamTriggerTimeStatus;
/* ATMStreamTriggerTimeStatus Comment:
*/

/*******************************************************************
ATMStreamTriggerTimeInfo Description:
ATMStreamTriggerTimeInfo records transmit and receive trigger counts
as well as a timestamp as to when the statistics were obtained.
This structure is similar to the ATMConnTriggerInfo with the addition
of the Timestamp field in the ATMStreamTriggerTimeStatus structure.
*/

typedef struct tagATMStreamTriggerTimeInfo
{
	unsigned short	uiStartIndex;
	unsigned short	uiCount;
	ATMStreamTriggerTimeStatus status[ATM_MAX_ARRAY_DIM+2];

} ATMStreamTriggerTimeInfo;
/* ATMStreamTriggerTimeInfo Comment:
Note: When there are multiple streams bound to a connection (i.e.,
		LANE data connection), this command will return statistics for
		that connection multiple times.
*/
/*****************************************************************************/
/*
 * CONFIGURE DUT PARAMS
 */

typedef struct 	tagATMConfigureDUT
	{
	unsigned short			iPortID;
	unsigned short			iIlmiMethod;	/* 0: Dynamic ; 1: Static */
	ATMDS1E1LineParams		Line;			/* configuration to match DUT */
	char					Reserved1[3];
	ATMSSCOPParams			SSCOP;
	ATMUNIParams			UNI;
	ATMILMIParams			ILMI;
	ATMILMIStaticParams		ILMIStatic;
	unsigned char			ucConnectionType;
	unsigned char			ucEncaptionType;
	unsigned char			ucVPI;
	unsigned char			ucVCI[2];
	ATMClassicalIP			ClassicalIP;
			/*unsigned char			ucArpServerAtmAddress[20];*/
	char 					Reserved2[75];
	} ATMConfigureDUT;


/*****************************************************************************/
/* Obsolete definitions */
#define BURST_DISABLE				0
#define BURST_ENABLE		  		1

#define MAX_ATM_BURST_SIZE	0x001FFFFF
#define MAX_ATM_PORT_BURST_SIZE	0xFFFFFFFF


#endif
/* _ATMITEMS_H_ */

