
/*****************************************************************************
 * atmsgapi.h
 * ATM SmartSignaling API definitions
 *
 *	Netcom Systems, Inc.
 *	Copyright (C) 1993-1999. All Rights Reserved.
 *
*****************************************************************************/

#ifndef __atm_signal_h
#define __atm_signal_h

#if   defined WIN32
#include <pshpack4.h>
#endif

#include "ettypes.h"


/* Test Error code... */
#define TEST_ATM_NOT_INITIALIZED			-110
#define TEST_ATM_DUT_EXCEEDED_LIMITS	-111
#define TEST_ATM_ILMI_NOT_ESTABLISHED	-112
#define TEST_ATM_ELAN_NOT_ESTABLISHED	-113
#define TEST_ATM_STREAM_NOT_CONNECTED	-114
#define TEST_ATM_SONET_NOT_ESTABLISHED	-115
#define TEST_ATM_SAAL_NOT_ESTABLISHED	-116
#define TEST_ATM_AVAILABLE4				-117
#define TEST_ATM_SSCOP_NOT_ESTABLISHED	-118
#define TEST_ATM_UNI_NOT_ESTABLISHED	-119
#define TEST_ATM_CLIP_ARP_NOT_ESTABLISHED	-120
#define TEST_ATM_DS1_E1_LINE_NOT_ESTABLISHED	-121
#define TEST_ATM_DS3_E3_LINE_NOT_ESTABLISHED	-122

/* Test Types */
#define		TEST_ATM_NONE		 						0
#define		TEST_ATM_MAX_CALL_SETUPS				1
#define		TEST_ATM_FIRST_TEST						TEST_ATM_MAX_CALL_SETUPS
#define		TEST_ATM_PEAK_CALL_SETUPS				2
#define		TEST_ATM_SUSTAINABLE_CALL_SETUPS		3
#define		TEST_ATM_POLICING_OVERSUBSCRIPTION	4
#define		TEST_ATM_LAST_TEST						TEST_ATM_POLICING_OVERSUBSCRIPTION

/* some ATM defines */
#define	ATM_MAX_PORTS				40
#define	ATM_320_PORTS				320

/* traffic direction */
#define	ATM_DIR_FORWARD			1
#define	ATM_DIR_BACKWARD			2
#define	ATM_DIR_FWD_BWD			3

/* traffic pattern selection */
#define	TRAFFIC_PATTERN_1_1		0
#define	TRAFFIC_PATTERN_1_N		1
#define	TRAFFIC_PATTERN_N_1		2
#define	TRAFFIC_PATTERN_N_N		3
#define	TRAFFIC_PATTERN_M_N		4

/* TestEngine states */
#define	ENGINE_IDLE_NOT_RUNNING			4
#define	ENGINE_CONFIGURING_SYSTEM		5
#define	ENGINE_RUNNING_TEST				6
#define	ENGINE_GETTING_RESULTS			7
#define	ENGINE_EVALUATING_RESULTS		8
#define	ENGINE_IDLE_RUNNING_TEST		9
#define	ENGINE_ABORTING_TEST				10
#define	ENGINE_IDLE_CAN_RESTART_TEST	11
#define	ENGINE_RESETTING					12
#define	ENGINE_TEST_DONE					13
#define  ENGINE_SETUP_LINE					14
#define  ENGINE_SETUP_ILMI					15
#define  ENGINE_SETUP_SSCOP				16
#define  ENGINE_CHECK_SONET				17
#define  ENGINE_ESTABLISH_SAAL			18
#define  ENGINE_CHECK_SAAL					19
#define  ENGINE_SETUP_STREAM				20
#define  ENGINE_SETUP_FRAME				21
#define  ENGINE_REGISTER_ILMI				22
#define  ENGINE_CHECK_ILMI					23
#define  ENGINE_REGISTER_ELAN				24
#define  ENGINE_CHECK_ELAN					25
#define  ENGINE_SETUP_STREAM_CONNECT	26
#define  ENGINE_DEREGISTER_ELAN			27
#define  ENGINE_DEREGISTER_ILMI			28
#define  ENGINE_RELEASE_SAAL				29
#define  ENGINE_REPORT_STREAM_ERROR		30
#define  ENGINE_SHOW_INTERDATA			31
#define  ENGINE_BROADCAST_PACKETS		32
#define  ENGINE_CALL_ADDRESS				33
#define  ENGINE_SETUP_CLIP_ARP_SVR		34
#define  ENGINE_ESTABLISH_CLIP_CLIENT	35
#define  ENGINE_CHECK_CLIP					36
#define  ENGINE_RELEASE_CLIP_CLIENT		37
#define  ENGINE_CHECK_DS1_E1_LINE		38
#define  ENGINE_CHECK_DS3_E3_LINE		39


#include "atmitems.h"
#include "testcmmn.h"


/*****************************************************************************
 * ATMSysResults Description:
 *
 * This structure returns the results for the overall test results.
 * This is interpreted according to the test being executed and is
 * in addition to the individual Port Results of ATMPortResults
 * structure defined later.
 *
 * For Call Capacity the meanings of the ATMSysResults are as follows:
 *
 * dResultA is the measured test duration from the first call setup.
 * dResultB is the measured test duration from the first call setup
 * 			initialized to the last call setup acknowledged over all
 * 			ports tested.
 * dResultC is the sum of all call setups attempted by all ports tested
 * dResultD is the sum of all call setups established by all ports
 * 			tested.
 * dResultE is the rate of all call setups established over all ports
 * dResultF is unused.
 *
 * For Peak Call Rate the meanings of the ATMSysResults are as follows:
 *
 * dResultA is the measured test duration from the first call setup.
 * dResultB is the average test duration from the first call setup
 * 			initialized to the last call setup torn down over all
 * 			ports tested.
 * dResultC is the sum of all call setups attempted by all ports
 * 			tested.
 * dResultD is the sum of all call setups established by all ports
 * 			tested.
 * dResultE is the rate of all call setups established over all ports
 * dResultF is unused.
 *
 *****************************************************************************/

typedef struct		tagATMSysResults
 {
 short  iTestState;  /* State of the test as enumerated in the    	*/
							/* ENGINE_xxx defines above                  	*/
 double dResultA; 	/* Results place holder - see above description */
 double dResultB; 	/* Results place holder - see above description */
 double dResultC; 	/* Results place holder - see above description */
 double dResultD; 	/* Results place holder - see above description */
 double dResultE; 	/* Results place holder - see above description */
 double dResultF; 	/* Results place holder - see above description */
 }	ATMSysResults;


/*****************************************************************************
 *
 * ATMPortResults Description:
 * This structure is used to store the results and the statistics of all
 * Call Setups issued per port.
*****************************************************************************/

typedef struct		tagATMPortResults
 {
 unsigned char ucState;							/* state of the test as enumerated	*/
														/* in the ENGINE_xxx defines above.	*/
 unsigned long ulCallsAttempted;				/* Call Setups attempted on  			*/
														/* this port.                			*/
 unsigned long ulCallsEstablished;  		/* Call Setups successfully  			*/
														/* established on this port. 			*/
 double        dRateEstablished;    		/* rate of established Call 			*/
														/* Setups on this port.      			*/
 unsigned long ulCallsFailed;       		/* Call Setups which failed  			*/
														/* on this port.             			*/
 unsigned long ulCallsErrored;      		/* Call Setups with error   			*/
														/* cause codes on this port. 			*/
 unsigned long ulLastErrorPort;     		/* port number which gave an 			*/
														/* error cause code.         			*/
 unsigned long ulLastErrorLocation; 		/* Error Location code of the			*/
														/* last errored call setup.  			*/
 unsigned long ulLastErrorCause;    		/* Error Cause code of the   			*/
														/* last errored call setup.			*/
 unsigned char szLastErrorLocation[40]; 	/* message describing the 				*/
														/* error location code of the last	*/
														/* errored call setup. 					*/
 unsigned char szLastErrorCause[40]; 		/* message describing the    			*/
														/* cause code of the last errored	*/
														/* call setup.								*/
 double        dMinRTSetupLatency;   		/* Min. Round Trip Latency	measured	*/
														/* over all Call Setups established.*/
 double        dMaxRTSetupLatency;   		/* Max. Round Trip Latency measured	*/
														/* over all Call Setups established.*/
 double        dTotRTSetupLatency;   		/* Average Round Trip Latency			*/
														/* measured over all Call Setups est*/
	}	ATMPortResults;


/*****************************************************************************
*
* ATMPVCResults Description:
*****************************************************************************/

typedef struct	 	tagATMVCResults
	{
	unsigned long	ulNumTxFrames;
	unsigned long	ulNumRxFrames;
	unsigned long	ulTrigger;
	unsigned char	ucVpi;
	unsigned char	uiVci;
	}	ATMVCResults;


/*****************************************************************************
 *
 * ATMSignalingStruct Description:
 * This structure is used by the NSATMTestStart API call.  It setups the
 * test parameters, assigns ports used, call setup parameters, stores the
 * overall system and individual port statistics, and also allows for the
 * configuration of the phy, SSCOP/SAAL, UNI, as well as ILMI.
 ****************************************************************************/

typedef struct 	tagATMSignalingStruct
 {
 short              iDirection; /* Specifies direction of the Call */
	/* Setups for this test. Values may be one of the following:    */
	/*   ATM_DIR_FORWARD   Uni-Directional Call Setups from ports   */
	/*                     in iSource[] to ports in iDest[].        */
	/*   ATM_DIR_BACKWARD  Uni-Directional Call Setups from ports   */
	/*                     in iDest[] to ports in iSource[].        */
	/*   ATM_DIR_FWD_BWD   Bi-Directional Call Setups from ports    */
	/*                     in iSource[] to ports in iDest[], and    */
	/*                     also from iDest[] to iSource[].          */

 short              iPattern; /* Specifies the Call Setup "traffic */
	/* pattern" for configuring the test. Values may be one of the  */
	/* following:                                                   */
	/*   TRAFFIC_PATTERN_1_1  Use one to one port pairings for      */
	/*                        Call Setups from each port in         */
	/*                        iSource[index] to the same index      */
	/*                        port at iDest[index].                 */
	/*   TRAFFIC_PATTERN_1_N  Use one to N port matching for Call   */
	/*                        Setups from the first port in         */
	/*                        iSource[] to all N ports in iDest[]   */
	/*   TRAFFIC_PATTERN_N_1  Use N to one port matching for Call   */
	/*                        Setups from all N ports in iSource[]  */
	/*                        to the first port in iDest[].         */
	/*   TRAFFIC_PATTERN_N_N  Use an N to N full mesh pattern of    */
	/*                        Call Setups from all N ports in       */
	/*                        iSource[] to all of the same N ports  */
	/*                        in iSource[]                          */
	/*   TRAFFIC_PATTERN_M_N  Use an M to N port matching for       */
	/*                        Call Setups from the first M ports    */
	/*                        in iSource[] to the first N ports in  */
	/*                        iDest[].                              */
 short              iSource[ATM_MAX_PORTS];/* Zero terminated list */
	/* of port numbers each of which specifies an ATM Signaling     */
	/* SmartCard which will source Call Setups. The list of ports   */
	/* must end with an iSource[] entry of zero. The iPattern value */
	/* will determine how each port in the iSource[] array is used. */
 short              iDest[ATM_MAX_PORTS];  /* Zero terminated list */
	/* of port numbers each of which specifies an ATM Signaling     */
	/* SmartCard which will act as a destination port for Call      */
	/* Setups. The list of ports must end with an iSource[] entry   */
	/* of zero. The iPattern value will determine how each port in  */
	/* the iSource[] array is used.                                 */
 ATMCallSetupParams CallSetup[ATM_MAX_PORTS];  /* The Call Setup	 */
  /* definition for all Call Setups used during this test. 			 */
 ATMSysResults      SysResults; /* The overall system results.     */
 ATMPortResults     PortResults[ATM_MAX_PORTS];/* Per port results.*/
 ATMConfigureDUT    ConfigDUT[ATM_MAX_PORTS];/* Port settings to   */
	/* use in order to over-ride the test default settings.         */
 unsigned long      ulOptions;  /* Specifies whether to default    */
	/* the DUT configuration, or to use the settings in the         */
	/* ATMConfigureDUT above. Setting this value to zero will use   */
	/* defaults for all SSCOP, UNI, ILMI, and Line parameters. This */
	/* field should only be used if the DUT requires special values */
	/* for these interfaces (the SSCOP, UNI, ILMI, and Line         */
	/* parameter structures are defined in atmitems.h). This field  */
	/* is a bit-wise OR of the following values:                    */
	/*   ATM_USE_SSCOP  use the ATMSSCOP settings in ConfigDUT[].   */
	/*   ATM_USE_UNI    use the ATMUNI settings in ConfigDUT[].     */
	/*   ATM_USE_ILMI   use the ATMILMI settings in ConfigDUT[].    */
	/*   ATM_USE_LINE   use the ATMLine settings in ConfigDUT[].    */
	/* To run the test without a Device Under Test (DUT) use        */
	/*   ATM_NO_DUT     runs without ILMI, SSCOP protocol exchanges */
	/*                  Can ONLY run one to one traffic pattern     */
	/*                  with direct cabling between ATM Signaling   */
	/*                  SmartCards											 */
	ATMVCResults	VCResults[ATM_MAX_STREAMS];
 }	ATMSignalingStruct;


/*****************************************************************************
 *
 * ATMSignalingStructEx Description:
 * This structure is used by the NSATMTestStartEx API call.  It setups the
 * test parameters, assigns ports used, stores the overall system and
 * individual port statistics.
 ****************************************************************************/

typedef struct 	tagATMSignalingStructEx
 {
 short              iDirection; /* specifies direction of the Call */
	/* Setups for this test. Values may be one of the following:    */
	/*   ATM_DIR_FORWARD   Uni-Directional Call Setups from ports   */
	/*                     in iSource[] to ports in iDest[].        */
	/*   ATM_DIR_BACKWARD  Uni-Directional Call Setups from ports   */
	/*                     in iDest[] to ports in iSource[].        */
	/*   ATM_DIR_FWD_BWD   Bi-Directional Call Setups from ports    */
	/*                     in iSource[] to ports in iDest[], and    */
	/*                     also from iDest[] to iSource[].          */

 short              iPattern; /* Specifies the Call Setup "traffic */
	/* pattern" for configuring the test. Values may be one of the  */
	/* following:                                                   */
	/*   TRAFFIC_PATTERN_1_1  Use one to one port pairings for      */
	/*                        Call Setups from each port in         */
	/*                        iSource[index] to the same index      */
	/*                        port at iDest[index].                 */
	/*   TRAFFIC_PATTERN_1_N  Use one to N port matching for Call   */
	/*                        Setups from the first port in         */
	/*                        iSource[] to all N ports in iDest[]   */
	/*   TRAFFIC_PATTERN_N_1  Use N to one port matching for Call   */
	/*                        Setups from all N ports in iSource[]  */
	/*                        to the first port in iDest[].         */
	/*   TRAFFIC_PATTERN_N_N  Use an N to N full mesh pattern of    */
	/*                        Call Setups from all N ports in       */
	/*                        iSource[] to all of the same N ports  */
	/*                        in iSource[]                          */
	/*   TRAFFIC_PATTERN_M_N  Use an M to N port matching for       */
	/*                        Call Setups from the first M ports    */
	/*                        in iSource[] to the first N ports in  */
	/*                        iDest[].                              */
 short              iSource[ATM_320_PORTS];/* Zero terminated list */
	/* of port numbers each of which specifies an ATM Signaling     */
	/* SmartCard which will source Call Setups. The list of ports   */
	/* must end with an iSource[] entry of zero. The iPattern value */
	/* will determine how each port in the iSource[] array is used. */
 short              iDest[ATM_320_PORTS];  /* Zero terminated list */
	/* of port numbers each of which specifies an ATM Signaling     */
	/* SmartCard which will act as a destination port for Call      */
	/* Setups. The list of ports must end with an iSource[] entry   */
	/* of zero. The iPattern value will determine how each port in  */
	/* the iSource[] array is used.                                 */
 ATMSysResults      SysResults; /* The overall system results.     */
 ATMPortResults     PortResults[ATM_320_PORTS];/* Per port results.*/
 unsigned long      ulOptions;  /* Specifies whether to default    */
	/* the DUT configuration, or to use the settings in the         */
	/* ATMConfigureDUT structure. Setting this value to zero will	 */
	/* use defaults for all SSCOP, UNI, ILMI, and Line parameters.  */
	/* This field should only be used if the DUT requires special	 */
	/* values for these interfaces (the SSCOP, UNI, ILMI, and Line  */
	/* parameter structures are defined in atmitems.h). This field  */
	/* is a bit-wise OR of the following values:                    */
	/*   ATM_USE_SSCOP  use the ATMSSCOP settings in ConfigDUT[]    */
	/*   ATM_USE_UNI    use the ATMUNI settings in ConfigDUT[]      */
	/*   ATM_USE_ILMI   use the ATMILMI settings in ConfigDUT[]     */
	/*   ATM_USE_LINE   use the ATMLine settings in ConfigDUT[]     */
	/* To run the test without a Device Under Test (DUT) use        */
	/*   ATM_NO_DUT     runs without ILMI, SSCOP protocol exchanges */
	/*                  Can ONLY run one to one traffic pattern     */
	/*                  with direct cabling between ATM Signaling   */
	/*                  SmartCards.											 */
 }	ATMSignalingStructEx;

/*****************************************************************************/


/* some defines for the options param */
#define	ATM_NO_DUT			0x00000001L
#define	ATM_USE_SSCOP		0x00000002L
#define	ATM_USE_UNI			0x00000004L
#define	ATM_USE_ILMI		0x00000008L
#define	ATM_USE_LINE		0x00000010L

#define	ATM_NO_HW_DEBUG	0x40000000L
#define	ATM_NO_LIB_DEBUG	0x20000000L


#ifdef __cplusplus
extern "C" {
#endif

#if defined WIN16 || defined WIN32
typedef int (WINAPI * ATMStatusCallbackFunc)(TestStatus *pTestStatus, ATMSignalingStruct *pIntSig);
typedef int (WINAPI * ATMErrorCallbackFunc)(char *pError);
typedef int (WINAPI * ATMStatusCallbackFuncEx)(TestStatus *pTestStatus, ATMSignalingStructEx *pIntSigEx);
#else
typedef int (*ATMStatusCallbackFunc)(TestStatus *pTestStatus, ATMSignalingStruct *pIntSig);
typedef int (*ATMErrorCallbackFunc)(char *pError);
typedef int (*ATMStatusCallbackFuncEx)(TestStatus *pTestStatus, ATMSignalingStructEx *pIntSigEx);
#endif

#ifdef __cplusplus
};
#endif


/*****************************************************************************
 *
 * TestTypeStruct Description:
 * This structure is used to setup the type of test to be executed.  It also
 * contains an error code field that is set in the case of test failure, in
 * addition to pointers to the Status and Error Call back functions.
 ****************************************************************************/

typedef struct		tagTestTypeStruct
 {
 short                 iTestType;	/* Specifies the type of ATM  */
	/* Signaling test to execute. Values may be one of the         */
	/* following:                                                  */
	/*   TEST_ATM_MAX_CALL_SETUPS  Selects the Call Capacity test  */
	/*           to be executed to determine the maximum number of */
	/*           Call Setups a DUT can handle.                     */
	/*   TEST_ATM_SUSTAINABLE_CALL_SETUPS  Selects the Peak Call   */
	/*           Rate test is to be executed to determine the      */
	/*           sustainable Call Setup Rate for the DUT.          */
 short                 iErrorReturnCode; /*returns any error code */
	/* for the test being executed. Return values may be one of    */
	/* the following:                                              */
	/*   TEST_ATM_NOT_INITIALIZED       Could not initialize the   */
	/*                                  ATM Line.                  */
	/*   TEST_ATM_DUT_EXCEEDED_LIMITS   The DUT has exceeded the   */
	/*                                  limits of the test.        */
	/*   TEST_ATM_ILMI_NOT_ESTABLISHED  Could not establish a      */
	/*                                  proper ILMI link.          */
	/*   TEST_ATM_ELAN_NOT_ESTABLISHED  Could not join the         */
	/*                                  requested ELAN.            */
	/*   TEST_ATM_STREAM_NOT_CONNECTED  a requested stream failed  */
	/*                                  to configure.              */
	/*   TEST_ATM_SONET_NOT_ESTABLISHED Could not establish a      */
	/*                                  SONET link.                */
	/*   TEST_ATM_SAAL_NOT_ESTABLISHED  Could not establish SAAL.	*/
	/*   TEST_ATM_AVAILABLE4				Reserved for Future use.	*/
	/*	  TEST_ATM_SSCOP_NOT_ESTABLISHED	Could not establish SSCOP.	*/
	/*	  TEST_ATM_UNI_NOT_ESTABLISHED	Could not establish UNI.	*/
	/*	  TEST_ATM_CLIP_ARP_NOT_ESTABLISHED	Could not connect to 	*/
	/*												ARP Server.						*/
	/*   TEST_ATM_DS1_E1_LINE_NOT_ESTABLISHED		DS1/E1 Line 		*/
	/*												statistics error.				*/
	/*	  TEST_ATM_DS3_E3_LINE_NOT_ESTABLISHED		DS3/E3 Line			*/
	/*									  			statistics error.				*/

 ATMStatusCallbackFunc StatusCallBack; /* A pointer to the 			*/
	/* function to be called at lStatusPeriod intervals. This  		*/
	/* function should be used to survey user inputs during        */
	/* execution. A return value of IDABORT will indicate the test */
	/* should abort immediately and return to the calling program  */
	/* as soon as the test is shut down.                           */
 ATMErrorCallbackFunc  ErrorCallBack; /* A pointer to the 			*/
	/* function to be called when an error occurs during the       */
	/* execution of the test. Return values indicate to the test   */
	/* engine what action to take. Valid return values may be one  */
	/* of the following:                                           */
	/*   IDABORT   Abort test, return to calling program.          */
	/*   IDRETRY   Retry the command which gave the error. In the  */
	/*             case of some errors (waiting for ILMI or SAAL)  */
	/*             this is often a desired response to an error.   */
	/*   IDIGNORE  Ignore the error and continue executing the     */
	/*             test. Use of this return value will make all    */
	/*             results suspect.                                */
 ATMStatusCallbackFuncEx StatusCallBackEx; /* A pointer to the		*/
	/* function to be called at lStatusPeriod intervals.				*/
	/* This function should be used to survey user inputs during   */
	/* execution. A return value of IDABORT will indicate the test */
	/* should abort immediately and return to the calling program  */
	/* as soon as the test is shut down (Ex: 320 ports supports)   */

 }	TestTypeStruct;

#ifdef __cplusplus
extern "C" {
#endif

int DLL_EXPORT		NSATMTestStartEx(	short iTestType,
										TestTypeStruct *pTestType,
										ATMSignalingStructEx *pSignalingEx,
										ATMConfigureDUT *pConfig,
										ATMCallSetupParamsEx *pCallSetupParam,
										ATMTestSetup *pTestSetup );
int DLL_EXPORT		NSATMTestStart( short iTestType, TestTypeStruct *pTestType,
							ATMSignalingStruct *pSignaling, ATMTestSetup *pTestSetup );
int DLL_EXPORT		NSATMTestStartVB( short iTestType, TestTypeStruct *pTestType,
							ATMSignalingStruct *pSignaling, ATMTestSetup *pTestSetup );
int DLL_EXPORT  	NSATMTestReset(short iTestType);
int DLL_EXPORT   	NSATMTestStop(short iTestType);
int DLL_EXPORT 	NSATMTestReport(short iTestType, char *pszReport);
int DLL_EXPORT 	NSATMGetReportFilename(char *filename);

#ifdef __cplusplus
};
#endif

#if   defined WIN32
#include <poppack.h>
#endif

#endif

