#ifndef _ATMTMITEMS_H_
#define _ATMTMITEMS_H_



#define AT_BASE_NUM 0x9900



/*****************************************************************************
*	iType Values  
******************************************************************************/
#define AT_PORT_CONFIG           (AT_BASE_NUM + 2) /* Configure the port of an
                                                      ATM Terametrics module */
#define AT_PORT_CONFIG_INFO      (AT_BASE_NUM + 3) /* Retrieve port configuration
                                                      of an ATM Terametrics module */
#define AT_VC_CREATE             (AT_BASE_NUM + 4) /* Configure one VC specified
                                                      by the index, or a 'count'
                                                      of VCs starting at the index 
                                                      on an ATM Terametrics module.
                                                      For multiple VCs, the VCI and 
                                                      VC index are incremented by
                                                      one. */ 
#define AT_VC_DELETE             (AT_BASE_NUM + 5) /* Delete one VC specified by
                                                      the index, or a 'count' of 
                                                      VCs starting at the index
                                                      on an ATM Terametrics module */
#define AT_VC_MODIFY             (AT_BASE_NUM + 6) /* Modify one VC specified by
                                                      the index. Note to do the 
                                                      modify, the same VPI, VCI 
                                                      must be used but change other
                                                      appropriate fields on an
                                                      ATM Terametrics module */
#define AT_VC_COPY               (AT_BASE_NUM + 7) /* Copy the configuration of
                                                      one existing VC specified 
                                                      by index, to create a 'count'
                                                      of VCs starting at the index+1
                                                      on an ATM Terametrics module.
                                                      As the copy is made, the same
                                                      configuration of the existing
                                                      VC is made except that the
                                                      specified uiVPI and uiVCI values
                                                      are added to the previous 
                                                      configuration of the existing VC.*/                                                     
#define AT_VC_INFO               (AT_BASE_NUM + 8) /* Retrieve the information of a
                                                      single VC specified by the index
                                                      on an ATM Terametrics module */
#define AT_VC_COUNTER_INFO       (AT_BASE_NUM + 9) /* Retrieve the transmit and receive
                                                      statistics - the cell/frame 
                                                      counts and cell/frame rates - of a
                                                      particular VC specified by index 
                                                      on an ATM Terametrics module.*/
#define AT_STREAM_TX_COUNTER_INFO (AT_BASE_NUM + 10) /* Retrieve the stream transmit
                                                        statistics - the transmit frame 
                                                        count - on a per-stream basis,
                                                        on an ATM Terametrics module. */
#define AT_PORT_COUNTER_INFO      (AT_BASE_NUM + 11) /* Retrieve transmit and receive 
                                                        statistics - cell/frame counts
                                                        and cell/frame rates on an
                                                        ATM Terametrics port.*/
#define AT_SET_SPEED              (AT_BASE_NUM + 12) /* Set up the port speed on
                                                        an ATM Terametrics module */
#define AT_VC_CLIP_COUNTER_INFO   (AT_BASE_NUM + 13) /* Retrieve CLIP related statistics
                                                        of a particular VC specified by 
                                                        index on an ATM Terametrics module.*/                                                     
#define AT_PORT_CLIP_COUNTER_INFO (AT_BASE_NUM + 14)  /*Retrieve CLIP related statistics
                                                        on an ATM Terametrics card.*/                                                     
#define AT_VC_DELETE_ALL          (AT_BASE_NUM + 15)  /* Delete all VC's on an ATM
                                                         Terametrics module.*/                                                     
#define AT_MOD_VC_ARRAY           (AT_BASE_NUM + 16)  /* Modify certain fields of an
                                                         array of VCs on an ATM
                                                         Terametrics module. */
/******************************************************************************
 Structure:   ATPortConfig
 iType1:      AT_PORT_CONFIG / AT_PORT_CONFIG_INFO
 Function:    HTSetStructure / HTGetStructure
 
 ATPortConfig Description:

 This structure is used to setup / retrieve the ATM Terametrics card port configuration.
******************************************************************************/
typedef struct tagATPortConfig
{
   unsigned char ucInterfaceSpeed;  /* AT_SPEED_OC3 (OC3 - 155) - Default,
                                       AT_SPEED_OC12 (OC12 - 622)*/
   unsigned char ucFramingMode;     /* Physical layer framing 
                                       AT_SONET_FRAMING - SONET (Default),
                                       AT_SDH_FRAMING - SDH */
   unsigned char ucTxClockSource;   /* AT_INTERNAL_CLOCK - Internal Clock (Default),
                                       AT_LOOP_TIMED_CLOCK - Loop Timed
                                    */
   unsigned char	ucCellScramblingMode; /* AT_CELL_SCRAMBLING_OFF - Off
                                           AT_CELL_SCRAMBLING_HEADER - Scramble Header (Not supported)
                                           AT_CELL_SCRAMBLING_PAYLOAD - Scramble Payload (Default),
                                           AT_CELL_SCRAMBLING_BOTH - Scramble Both (Not supported) */
   unsigned char	ucHecCosetEnable; /* 0 - disable HEC Coset usage, 
                                       1 - enable HEC Coset usage (Default)
                                       If enabled, the coset polynomial x^6+x^4+x^2+1 is added
                                          to the received Header Checksum octet prior to 
                                          comparison with the calculated result.
                                       If disabled, the coset polynomial wont be added.
                                    */
   unsigned char	ucLoopbackMode; /* AT_LOOPBACK_DISABLED - Off (Default),
                                     AT_LOOPBACK_LOCAL - Local Loop 
                                  */	

   /* Idle cell definition */
   unsigned char	ucIdleCellHeaderGFC; /* Generic Flow Control in IdleCell/UnassignedCell header
                                          Range: 0-15,    Default:0 */
   unsigned char	ucIdleCellHeaderPTI; /* Payload Type Indicator in IdleCell/UnassignedCell header
                                       AT_USRDATA_NOT_CONGESTED (Default)
                                       AT_USRDATA_CONGESTED */
   unsigned char	ucIdleCellHeaderCLP;    /* Cell Loss Priority in IdleCell/UnassignedCell header
                                             Range: 0-1,
                                             1 - indicates a discardable cell 
                                             Default: 1 */
   unsigned char	ucIdleCellPayloadByte;  /* Payload bytes in IdleCell/UnassignedCell header
                                             Range: 0x00-0xFF
                                             Default: 0x6A */

   unsigned char  ucPathSignalLabel; /* AT_PATH_SIGNAL_LABEL_ATM (Default) */

   unsigned char	ucHecErrorHandlingMode; /*
                                          AT_HEC_ERROR_HANDLING_PASS - Pass,
                                             Neither is single bit HEC error corrected,
                                             nor are multiple HEC errors detected.
                                             The cells are just passed up
                                          AT_HEC_ERROR_HANDLING_DISCARD - Discard,
                                             If any HEC error is detected, the cells are discarded.
                                          AT_HEC_ERROR_HANDLING_CORRECT - Correct (Default),
                                             Single bit HEC error is corrected,
                                             multiple HEC errors are detected,
                                             and the cells are passed up.
                                          */
   unsigned char  ucSONETCountMode;    /* AT_ERROR_COUNT_INDIVIDUAL - Individual (Default) 
                                          AT_ERROR_COUNT_BLOCK - Block */
   unsigned short uiMaxCLIPInARPRate;  /* Maximum rate of Inverse ATM ARP request and unsolicited 
                                          Inverse ATM ARP reply messages, in the unit of 
                                          number of Inverse ATP ARPs per second.
                                          Range: 0 - 200   Default: 10
                                          If 0 is entered, default value 10 will be assigned. 
                                       */

   unsigned long	ulVCInterleaveDepth; /* Maximum number of interleaved VCs. It is the
                                          maximum number of VCs that the scheduler is 
                                          allowed to interleave frames on.
                                          Range: 1-8191
                                          Default: AT_VC_INTERLEAVE_ALL */
   unsigned long	ulMaxRxCutThroughBufferSize; /* Maximum receive Cut Through buffer size
                                                  allocated for the port (bytes)
                                                  Range: 0-12288000 (AT_PORT_RX_CT_BUFFER_SIZE)
                                                  Default: AT_PORT_RX_CT_BUFFER_SIZE
                                                  If 0 is entered, default value
                                                  AT_PORT_RX_CT_BUFFER_SIZE will be assigned.*/
   unsigned long  ulErrorInjection;    /* 0 (for no error) (Default)
                                       AT_SONET_CELL_HEC_ALARM,
                                       AT_SONET_PATH_RDI_ALARM,
                                       AT_SONET_PATH_AIS_ALARM,
                                       AT_SONET_PATH_BIP_ALARM,
                                       AT_SONET_LINE_RDI_ALARM,
                                       AT_SONET_LINE_AIS_ALARM,
                                       AT_SONET_LINE_BIP_ALARM,
                                       AT_SONET_SECTION_LOS_ALARM,	
                                       AT_SONET_SECTION_LOF_ALARM,
                                       AT_SONET_SECTION_BIP_ALARM */
   unsigned long  ulFlags;  /* To set/unset the restriction for bad frame lengths
                               in latency measurement
                               AT_PORT_DEFAULT_FLAGS (Default)
                               AT_PORT_ALLOW_ALL_FRAME_SIZES */

   /* Output */
   unsigned long  ulConfiguredCellRate;   /* Configured cell rate on the port */
   unsigned long  ulVCCount;              /* number of VC's configured on the port */
   unsigned char	ucReserved[64];	      /* Reserved */		 
	
}ATPortConfig;

#define AT_VC_INTERLEAVE_ALL           8191     /* Based on document "Titan ATM USE CASE SCENARIOS" */

#define AT_PORT_RX_CT_BUFFER_SIZE      12288000 /* 1500 * 8192 */

#define AT_SPEED_OC3						0
#define AT_SPEED_OC12					1

#define AT_SONET_FRAMING				0
#define AT_SDH_FRAMING					1

#define AT_INTERNAL_CLOCK				0
#define AT_LOOP_TIMED_CLOCK			1

#define AT_PATH_SIGNAL_LABEL_ATM		0x13
#define AT_PATH_SIGNAL_LABEL_PPP		0x16
#define AT_PATH_SIGNAL_LABEL_HDLC	0xcf

#define AT_SONET_CELL_HEC_ALARM			0x0001
#define AT_SONET_PATH_RDI_ALARM			0x0002
#define AT_SONET_PATH_AIS_ALARM			0x0004
#define AT_SONET_PATH_BIP_ALARM			0x0008
#define AT_SONET_LINE_RDI_ALARM			0x0010
#define AT_SONET_LINE_AIS_ALARM			0x0020
#define AT_SONET_LINE_BIP_ALARM			0x0040
#define AT_SONET_SECTION_LOS_ALARM		0x0080
#define AT_SONET_SECTION_LOF_ALARM		0x0100
#define AT_SONET_SECTION_BIP_ALARM		0x0200

#define AT_CELL_SCRAMBLING_OFF      0x00
#define AT_CELL_SCRAMBLING_HEADER   0x01
#define AT_CELL_SCRAMBLING_PAYLOAD  0x02
#define AT_CELL_SCRAMBLING_BOTH     0x03

#define AT_LOOPBACK_DISABLED        0x00
#define AT_LOOPBACK_LOCAL           0x01

#define AT_HEC_ERROR_HANDLING_PASS     0x00  /* Don't correct or discard HEC errors */
#define AT_HEC_ERROR_HANDLING_DISCARD  0x01  /* Discard HEC errors */
#define AT_HEC_ERROR_HANDLING_CORRECT  0x02  /* Correct HEC errors */

#define AT_ERROR_COUNT_INDIVIDUAL   0x00  /* Each B2, B1 erros in byte count as 1 */
#define AT_ERROR_COUNT_BLOCK        0x01  /* Multiple B2, B1 erros in byte count as 1 */

/* ucIdleCellHeaderPTI in ATPortConfig and ucPTI in ATVC */
#define AT_USRDATA_NOT_CONGESTED    0  /* Generates Uncongested traffic  */
#define AT_USRDATA_CONGESTED        2  /* Generates Congested traffic  */

#define AT_PORT_DEFAULT_FLAGS          0x00000000 /* Default setting -
                                                     Not allowing certain frame lengths,
                                                     which would cause problem in latency
                                                     measurement due to certain limit
                                                     on card */
#define AT_PORT_ALLOW_ALL_FRAME_SIZES	0x00000001 /* Allowing all frame lengths, including
                                                     some frame lengths, which would 
                                                     cause problem in latency measurement
                                                     due to certain limit on card */

/******************************************************************************
 Structure:   ATPortCounterInfo
 iType1:      AT_PORT_COUNTER_INFO
 Function:    HTGetStructure
 
 ATPortCounterInfo Description:

 This structure is used to get the cell/frame counts per ATM Terametrics port.
******************************************************************************/
typedef struct tagATPortCounterInfo
{
   /* Transmitter - Counts */
   U64 u64TxAssignedCells;          /* Transmitted cells */
   U64 u64TxAAL0Cells;              /* Transmitted AAL0 cells */
   U64 u64TxAAL5Frames;             /* Transmitted AAL5 frames */
   U64 u64TxAAL5FrameBytes;         /* Transmitted bytes of AAL5 frames */

   /* Receiver - Counts */
   U64 u64RxCells;                  /* Received cells */
   U64 u64RxTaggedCells;            /* Received cells with CLP bit on (CLP=1) */
   U64 u64RxCongestedCells;         /* Received cells with congestion bit on in PTI field */
   U64 u64RxHecCorrErrorCells;      /* Received HEC error corrected cell */
   U64 u64RxHecUncorrErrorCells;    /* Received HEC error non-corrected cell */
   U64 u64RxAAL0Cells;              /* Received AAL0 cells */
   U64 u64RxAAL5Frames;             /* Received AAL5 frames */
   U64 u64RxAAL5FrameBytes;         /* Received bytes of AAL5 frames */
   U64 u64RxCRCErredAAL5Frames;     /* Received AAL5 frames with CRC error */

   /* Transmitter - Rates */
   unsigned long ulTxCellRate;      /* Transmit cell rate */
	
   /* Receiver - Rates */
   unsigned long ulRxCellRate;            /* Receive cell rate */
   unsigned long ulRxTaggedCellRate;      /* Receive rate of cells with CLP bit on (CLP=1) */
   unsigned long ulRxCongestedCellRate;   /* Receive rate of cells with congestion bit on in PTI field */
   unsigned long ulRxHecCorrErrorRate;    /* Receive rate of cells with HEC error corrected */
   unsigned long ulRxHecUncorrErrorRate;  /* Receive rate of cells with HEC error non-corrected */

   unsigned char ucReserved[64];          /* Reserved */
} ATPortCounterInfo;

/******************************************************************************
 Structure:   ATVC
 iType1:      AT_VC_CREATE
 iType2:      VC Index
 iType2:      VC Count
 Function:    HTSetStructure
 
 iType1:      AT_VC_MODIFY
 iType2:      VC Index
 Function:    HTSetStructure
 
 iType1:      AT_VC_COPY
 iType2:      VC Index
 iType2:      VC Count
 Function:    HTSetStructure
 
 iType1:      AT_VC_INFO
 iType2:      VC Index
 Function:    HTGetStructure
  
 ATVC Description:

 This structure is used to create a single VC or multiple VCs, modify a single VC,
 or copy a previously configured VC of index to a count of VC starting at vc_index+1,
 or retrieve the information of a particular VC specified by the index,
 on an ATM Terametrics module. The valid VC index range is 0-8190. The maximum number
 of VCs which can be configured on the ATM Terametrics modules is 8191.
******************************************************************************/
typedef struct tagATVC
{
   unsigned char ucTxEnable;  /* 0 - disable,  1 - enable VC on transmitter, */
   unsigned char ucRxEnable;  /* 0 - disable , 1 - enable VC on receiver*/

   /* Connection parameters */
   unsigned char ucConnType;  /* Connection type.
                                 AT_STR_CONN_TYPE_PVC */
   unsigned short  uiVPI;      /* Virtual Path Identifier in cell header
                                 Range: 0-255  
                                 NOTE: only up to 63 unique ucVPI in the value range
                                       of 0-255 can be configured on a receiving port. */
   unsigned short uiVCI;      /* Virtual Channel Identifier in cell header
                                 Range: 0-65535 */
   unsigned char  ucGFC;      /* Generic Flow Control Payload
                                 Range: 0-15 */
   unsigned char  ucPTI;      /* Payload Type Indicator in cell header
                                 AT_USRDATA_NOT_CONGESTED
                                 AT_USRDATA_CONGESTED
                               */
	
   unsigned char ucAALType;   /* AAL types
                                 AT_AAL5   */

   unsigned char ucEncapType; /* Encapsulation type
                                 AT_ENCAP_TYPE_NULL   
                                 AT_ENCAP_TYPE_VCMUX_ROUTED     
                                 AT_ENCAP_TYPE_VCMUX_BRIDGED     
                                 AT_ENCAP_TYPE_VCMUX_MPLS     
                                 AT_ENCAP_TYPE_LLC_ROUTED
                                 AT_ENCAP_TYPE_LLC_BRIDGED
                               The encapsulation should be the same on the transmit and receive 
                               sides in order for the card to update the counters properly */   
   unsigned char ucCustomHeaderEnable; /* Custom Header flag
									  0 - disable 1 - enable customized VC encapsulation
									  */
   unsigned char ucCustomHeaderLength; /* Custom Header Length of VC encapsulation,
									  parameter range 1-12*/
   unsigned char ucCustomHeader[12];  /*  Custom Header of VC encapsulation
                                      The ucCustomHeaderLength field determines the length 
                                      of ucCustomHeader[] used.
                                      */

   unsigned char ucReserved1; /* Reserved for AAL0 data integrity check enable */ 
   unsigned char ucCaptureEnable; /* 0 -disable, 1 -enable receive capture on VC */ 

   unsigned char ucRateClass;    /* Rate class of service
                                    AT_RATE_CLASS_CBR,
                                    AT_RATE_CLASS_UBR  */
   unsigned long ulPCR;          /* Peak Cell Rate (cells/sec), 
                                    cannot oversubscribe,
                                    Range: 0 - 353207 (for speed OC3)                                    
                                          0 - 1412830 (for speed 0C12) */ 
   unsigned long ulATCDVT;       /* Cell Delay Variation Tolerance in millisecond unit,
                                    Default: 1 */

   unsigned long  ulRxCutThroughBufferSize;  /* Receive Cut Through buffer size allocated
                                                for the VC (bytes)
                                                Range: 1-65535
                                                Suggest to use 1500 (AT_VC_RX_CT_BUFFER_SIZE).
                                                Sum of all VCs must not exceed total for port. */ 
	  	
   unsigned char  ucRxCutThroughFilter;         /* Reserved, MUST be zero */	  	
   unsigned short uiRxCutThroughNullProtocol;   /* Specify expected receive cut through protocol 
                                                   if encapsulation ucEncapType==AT_ENCAP_TYPE_NULL. 
                                                   Use 0x00 - No cut through null protocol 
                                                */

   unsigned long  ulTxMode;      /* packet transmit mode
                                    CONTINUOUS_PACKET_MODE
                                    SINGLE_BURST_MODE
                                    CONTINUOUS_BURST_MODE
                                    MULTI_BURST_MODE */
   unsigned long  ulBurstCount;  /* the burst number */
   unsigned long  ulMburstCount; /* the multi burst number */
   unsigned long  ulBurstGap;    /* the gap between bursts,
                                    in milliseconds units  */

   //CLIP set up
   unsigned char ucCLIPInARPEnable; /* Applicable only when
                                          ucEncapType = AT_ENCAP_TYPE_LLC_ROUTED, and
                                          ucAALType = AT_AAL5                             
                                       0 - disable, 1 - enable sending
                                       Inverse ATM ARP Requests and Replies. */
   unsigned char ucCLIPUnSolicitedInARPReplyEnable;
                                    /* Applicable only when
                                       ucEncapType = AT_ENCAP_TYPE_LLC_ROUTED, and
                                       ucAALType = AT_AAL5
                                       0 - disable, 1 - enable sending      
                                       unsolicited Inverse ATM ARP Reply packets
                                       at the time of VC configuration */                                             
   unsigned short uiCLIPInARPTimeInterval;   /* Specifies how frequently (in seconds)
                                                Inverse ATM ARP Requests will be sent out.                                            
                                                Applicable only when
                                                   ucCLIPInARPEnable = 1 (enabled). 
                                                Range: 0-65534
                                                0 -send Inverse ATM ARP request once only  
                                                Default: 600 */
   unsigned char  ucCLIPIPAddress[4];  /* Used as the source protocol address
                                          in the Inverse ATM ARP Request. */

   /* Output */
   unsigned long ulConfiguredCellRate;   /* Accumulated sum of stream cell rates */
   unsigned char ucReserved[50];         /* Reserved */
}ATVC;

/* Connection type */
#define AT_STR_CONN_TYPE_PVC					0

/* AAL Type */
#define AT_AAL5                        5

/* Encapsulation Type */
#define AT_ENCAP_TYPE_NULL             0
#define AT_ENCAP_TYPE_VCMUX_ROUTED     1
#define AT_ENCAP_TYPE_VCMUX_MPLS       2
#define AT_ENCAP_TYPE_VCMUX_BRIDGED    4
#define AT_ENCAP_TYPE_LLC_ROUTED       8
#define AT_ENCAP_TYPE_LLC_BRIDGED      9

/*Obsolete*/
#define AT_ENCAP_TYPE_VCM_IPV4         1
#define AT_ENCAP_TYPE_LLC_IPV4         5

/* Rate Class Type */
#define AT_RATE_CLASS_CBR              0
#define AT_RATE_CLASS_UBR              1

/* Default Rx Cut Through buffer size */
#define AT_VC_RX_CT_BUFFER_SIZE     1500 

/* Expected Rx Cut Through Protocol if encapsulation is NULL. */
#define AT_RX_CT_PROTOCOL_IP         0x0100
#define AT_RX_CT_PROTOCOL_PPP        0x0101
#define AT_RX_CT_PROTOCOL_CLIP_ARP   0x0102
#define AT_RX_CT_PROTOCOL_AAL5       0x0103

/******************************************************************************
 Structure:   ATVCCounterInfo
 iType1:      AT_VC_COUNTER_INFO
 iType2:      VC Index
 Function:    HTGetStructure
 
 ATVCCounterInfo Description:

 This structure is used to retrieve the transmit and receive statistics - 
 the cell/frame counts and cell/frame rates - of a particular VC specified
 by vc_index, on an ATM Terametrics port.

******************************************************************************/
typedef struct tagATVCCounterInfo
{
   /* Transmitter - Counts */
   U64 u64TxCells;            /* Transmitted cells */
   U64 u64TxAAL5Frames;       /* Transmitted AAL5 frames */

   /* Receiver - Counts */
   U64 u64RxCells;               /* Received cells */
   U64 u64RxAAL5Frames;          /* Received AAL5 frames */
   U64 u64RxCRCErredAAL5Frames;  /* Received CRC error AAL5 frames */

   unsigned char ucReserved[64];    /* Reserved */
}ATVCCounterInfo;


/******************************************************************************
 Structure:   ATStreamCounterInfo
 iType1:      AT_STREAM_TX_COUNTER_INFO
 iType2:      Stream Index
 Function:    HTGetStructure
 
 ATStreamCounterInfo Description:

 This structure is used to retrieve the stream transmit statistics - the transmit
 frame count - on a per-stream basis, on an ATM Terametrics card.

******************************************************************************/
typedef struct tagATStreamCounterInfo
{
   U64 u64TxFrameCount; 		      /* Transmitted frames */
   unsigned char ucReserved[64];    /* Reserved */
}ATStreamCounterInfo;

/******************************************************************************
 Structure:   ATCardSetSpeed
 iType1:      AT_SET_SPEED
 Function:    HTSetStructure
 
 ATCardSetSpeed Description:

 This structure is used to setup card speed - AT_SPEED_OC3 or AT_SPEED_OC12,
 on an ATM Terametrics port.

******************************************************************************/
typedef struct tagATCardSetSpeed
{
   unsigned short	uiSpeed; /* AT_SPEED_OC3 (Default)
                              AT_SPEED_OC12 */
} ATCardSetSpeed;

/******************************************************************************
 Structure:   ATVCCLIPCounterInfo
 iType1:      AT_VC_CLIP_COUNTER_INFO
 Function:    HTGetStructure
 
 ATVCCLIPCounterInfo Description:

 This structure is used to retrieve CLIP related statistics of a VC on an 
 ATM Terametrics port.

******************************************************************************/
typedef struct tagATVCCLIPCounterInfo
{
  unsigned long ulRxInARPRequest;   /* Received Inverse ATM ARP Requests */
  unsigned long ulTxInARPRequest;   /* Transmitted Inverse ATM ARP Requests */
  unsigned long ulRxInARPReply;     /* Received Inverse ATM ARP Replies */
  unsigned long ulTxInARPReply;     /* Transmitted Inverse ATM ARP Replies */
  unsigned long ulRxARPRequest;     /* Received ATM ARP Requests */
  unsigned long ulRxARPReply;       /* Received ATM ARP Replies */
  unsigned long ulRxARPNAKs;        /* Received ATM ARP NAKs */
  unsigned long ulRxInvalidMessage; /* Received Invalid Messages
                                       Invalid Message includes:
                                       - Any of the message fields length exceed limits
                                         as specified in the RFC 
                                         (i.e. ATM addresses > 20, protocol address > 4.
                                       - If the total length of the message exceeds the
                                         length calculated from each of the fields.
                                       - If the message is not an ATM ARP or Inverse ATM
                                         ARP message.
                                       - If the message protocol type is not IPv4 */
  unsigned char ucReserved[64];     /* Reserved */

} ATVCCLIPCounterInfo;

/******************************************************************************
 Structure:   ATPortCLIPCounterInfo
 iType1:      AT_PORT_CLIP_COUNTER_INFO
 Function:    HTGetStructure
 
 ATPortCLIPCounterInfo Description:

 This structure is used to retrieve CLIP related statistics of the port on
 an ATM Terametrics port.

******************************************************************************/
typedef struct tagATPortCLIPCounterInfo
{
  U64 u64RxInARPRequest;   /* Received Inverse ATM ARP Requests */
  U64 u64TxInARPRequest;   /* Transmitted Inverse ATM ARP Requests */
  U64 u64RxInARPReply;     /* Received Inverse ATM ARP Replies */
  U64 u64TxInARPReply;     /* Transmitted Inverse ATM ARP Replies */
  U64 u64RxARPRequest;     /* Received ATM ARP Requests */
  U64 u64RxARPReply;       /* Received ATM ARP Replies */
  U64 u64RxARPNAKs;        /* Received ATM ARP NAKs */
  U64 u64RxInvalidMessage; /* Received Invalid Messages
                              Invalid Message includes:
                              - Any of the message fields length exceed limits
                              as specified in the RFC 
                              (i.e. ATM addresses > 20, protocol address > 4.
                              - If the total length of the message exceeds the
                                length calculated from each of the fields.
                              - If the message is not an ATM ARP or Inverse ATM
                                ARP message.
                              - If the message protocol type is not IPv4 */
  unsigned char ucReserved[64];  /* Reserved */

} ATPortCLIPCounterInfo;

/******************************************************************************
 Structure:   ATModifyVCArray
 iType1:      AT_MOD_VC_ARRAY
 Function:    HTSetStructure
 
 ATModifyVCArray Description:

 This structure is used to modify certain fields of an array of VCs on ATM Terametrics module.

******************************************************************************/

#define AT_MODIFY_VC_ARRAY_SIZE	8192

typedef struct tagATModifyVCArray
{
  unsigned long ulIndex; 	/* Index of the first VC to modify */
  unsigned long ulCount; 	/* The total number of patterns to use, or
                              the total number of VCs to modify */
  unsigned long ulField; 	/* Field in the ATVC structure to modify
                              ATMV_FIELD_TX_ENABLE
                              ATMV_FIELD_RX_ENABLE
                              ATMV_FIELD_RATE_CLASS
                              ATMV_FIELD_PCR
                              ATMV_FIELD_CDVT
                              ATMV_FIELD_TX_MODE
                              ATMV_FIELD_BURST_COUNT
                              ATMV_FIELD_MBURST_COUNT
                              ATMV_FIELD_BURST_GAP
                              ATMV_FIELD_GFC
                              ATMV_FIELD_PTI
                           */
  unsigned long ulData[AT_MODIFY_VC_ARRAY_SIZE]; 
                           /* Array of 1,2, or 4 byte patterns/elements
                              that will be overlaid (right justified)
                              in the Field
                           */
  unsigned char ucReserved[24];

} ATModifyVCArray;


#define ATMV_FIELD_TX_ENABLE				1	/* 1 byte, for ucTxEnable in ATVC structure */
#define ATMV_FIELD_RX_ENABLE				2	/* 1 byte, for ucRxEnable in ATVC structure */
#define ATMV_FIELD_RATE_CLASS				3	/* 1 byte, for ucRateClass in ATVC structure  */
#define ATMV_FIELD_PCR                 4	/* 4 bytes, for ulPCR in ATVC structure  */
#define ATMV_FIELD_CDVT                5	/* 4 bytes, for ulATCDVT in ATVC structure  */
#define ATMV_FIELD_TX_MODE             6	/* 4 bytes, for ulTxMode in ATVC structure  */
#define ATMV_FIELD_BURST_COUNT         7	/* 4 bytes, for ulBurstCount in ATVC structure  */
#define ATMV_FIELD_MBURST_COUNT        8	/* 4 bytes, for ulMBurstCount in ATVC structure  */
#define ATMV_FIELD_BURST_GAP           9	/* 4 bytes, for ulBurstGap in ATVC structure  */
#define ATMV_FIELD_GFC                 10	/* 4 bits (1/2 byte), for ucGFC in ATVC structure  */
#define ATMV_FIELD_PTI                 11	/* 1 bytes, for ucPTI in ATVC structure  */

#endif




