/****************** Start of ET1000.H ******************/

/* This header file contains all the class definitions,			*/
/* prototypes and error constants needed to run the ET-1000		*/
/* "C" Library functions.										*/
/* Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc. */
/* Copyright (c) 1993-1999, Netcom Systems, Inc.				*/

#ifndef __et1000_h
#define __et1000_h

/*--------------------------------------------------------------------*/
/*------- TCP SmartCard Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "tcpisp.h"


#if   defined WIN32
#include <pshpack4.h>
#endif

#include "ettypes.h"

/*#define bool BOOL
#define false FALSE
#define true TRUE */

#define PORT_A                  1
#define PORT_B                  0

#define MFPORT_A                0
#define MFPORT_B                1

#define LOOP_PORT_A             0
#define LOOP_PORT_B             1

#define CAPTURE_NONE            0X0000
#define CAPTURE_ALL             0XFFFF
#define CAPTURE_ERRS_RXTRIG     0XFFFF
#define CAPTURE_ANY             0X0800
#define CAPTURE_NOT_GOOD        0X0200
#define CAPTURE_GOOD            0X0100
#define CAPTURE_RXTRIG          0X0001
#define CAPTURE_CRC             0X0002
#define CAPTURE_ALIGN           0X0004
#define CAPTURE_OVERSIZE        0X0008
#define CAPTURE_UNDERSIZE       0X0010
#define CAPTURE_COLLISION       0X0020

#define CAPTURE_ENTIRE_PACKET   0
#define CAPTURE_RANGE           1
#define CAPTURE_OFF             2

#define TIME_TAG_ON             1
#define TIME_TAG_OFF            0

#define BUFFER_CONTINUOUS       0
#define BUFFER_ONESHOT          1

#define COLLISION_OFF           0
#define COLLISION_LONG          1
#define COLLISION_ADJ           2
#define CORP_A                  3
#define CORP_B                  4
#define ETCOLLISION_MAX         4

#define SYMBOL_OFF              0
#define SYMBOL_ON               1

#define QUEUE_ENABLE            1
#define QUEUE_DISABLE           0

#define ETCOM1                  0
#define ETCOM2                  1
#define ETCOM3                  2
#define ETCOM4                  3
#define ETCOM5                  4
#define ETCOM6                  5
#define ETCOM7                  6
#define ETCOM8                  7

#define ETMAXCOM                512
#define ETMAXSLOT               5120  // Per Steve and chassis team, curently 11/29/2005
                                      // SMB can support up to 256 chassis although no one did
                                      // 5120 = 256*20, in which 20 is MAX_SLOTS_HD
#define ETSMB600MAXSLOT         2
#define ETSMB6000MAXSLOT        12

#define ET_ON                   1
#define ET_OFF                  0

#define ETBURST_ON              1
#define ETBURST_OFF             0

#define ETGAP_100NS             1
#define ETGAP_1US               0

#define ETLOOPBACK_ON           1
#define ETLOOPBACK_OFF          0

#define ETCRC_OFF               0	/* no CRC errors */
#define ETCRC_ON                1	/* CRC errors */
#define ETCRC_NONE				2	/* omit 4-byte CRC */

#define ETRUN_STOP              0
#define ETRUN_STEP              1
#define ETRUN_RUN               2

#define ETVFD_ENABLE            1
#define ETVFD_DISABLE           0

#define ETLNM_ON                1
#define ETLNM_OFF               0

#define ETBAUD_2400             0
#define ETBAUD_4800             1
#define ETBAUD_9600             2
#define ETBAUD_19200            3
#define ETBAUD_38400            4

#define ETLOCALMODE             0
#define ETREMOTEMODE            1

#define ETRUN                   2
#define ETSTEP                  1
#define ETSTOP                  0
#define HTRUN                   2
#define HTSTEP                  1
#define HTSTOP                  0

#define RUN_NON_BLOCKING_FLAG	0x0100
#define RUN_FIXED_TIME_FLAG     0x0200
#define RUN_NON_BLOCKING_MASK	0x00FF

#define ETSELA                  0
#define ETSELB                  1
#define ETPINGPONG              2

/* constants for ETGetController */
#define CONTROLLER_UNKNOWN      0
#define CONTROLLER_ET1000       1
#define CONTROLLER_SMB1000      2
#define CONTROLLER_SMB2000      3
#define CONTROLLER_SMB6000		4
#define CONTROLLER_SMB200		5
#define CONTROLLER_SMB600		6
#define CONTROLLER_SMB6000C	7
#define CONTROLLER_SMB600C		8    /* There is never such a chassis existing. */
#define CONTROLLER_SMB600B		9
#define CONTROLLER_SMB6000C_NTS5000A		10

/* constants for ETGetProductFamily */
#define FAMILY_UNKNOWN			0
#define FAMILY_ET1000			1
#define FAMILY_SMB2000			2
#define FAMILY_SMB6000			3
#define FAMILY_SMB6000C			4
#define FAMILY_SMB6000C_NTS5000A			5

/* constants for NSSetPortMappingMode */
#define PORT_MAPPING_COMPATIBLE 0
#define PORT_MAPPING_NATIVE		1

/* constants for iReserve parameter to NSSocketLink */
#define RESERVE_NONE			0
#define RESERVE_ALL				1

/* constants for HTSlotOwnership */
#define SLOT_RESERVED_BY_OTHER  0
#define SLOT_RESERVED_BY_USER	1
#define SLOT_AVAILABLE			2

#define ETSTORESETUP            0
#define ETRECALLSETUP           1

#define CT_UNKNOWN				-1
#define CT_NOT_PRESENT          0
#define CT_ACTIVE               1
#define CT_PASSIVE              2
#define CT_FASTX                3
#define CT_TOKENRING            4
#define CT_VG                   5
#define CT_L3                   6
#define CT_ATM                  7
#define CT_GIGABIT              8
#define CT_ATM_SIGNALING        9
#define CT_WAN_FRAME_RELAY      10
#define CT_POS                  11
#define CT_FC                   12
#define CT_MAX_CARD_TYPE		CT_FC

#define	CM_UNKNOWN				-1
#define	CM_NOT_PRESENT			0
#define	CM_SE_6205				1
#define	CM_SC_6305				2
#define	CM_ST_6405				3
#define	CM_ST_6410				4
#define	CM_SX_7205				5
#define	CM_SX_7405				6
#define	CM_SX_7410				7
#define	CM_TR_8405				8
#define	CM_VG_7605				9
#define	CM_L3_6705				10
#define	CM_AT_9025				11
#define	CM_AT_9155				12
#define	CM_AS_9155				13
#define	CM_GX_1405				14
#define	CM_WN_3405				15
#define	CM_AT_9015				16
#define	CM_AT_9020				17
#define	CM_AT_9034				18
#define	CM_AT_9045				19
#define	CM_AT_9622				20
#define	CM_L3_6710				21
#define	CM_SX_7210				22
#define	CM_ML_7710				23
#define	CM_ML_5710A				24
#define	CM_WN_3415				25
#define	CM_WN_3420				26
#define	CM_LAN_3200				27
#define	CM_LAN_3100				28

#define	CM_POS_3500A			30
#define	CM_GX_1420A				31
#define	CM_LAN_3201A			32
#define	CM_AT_9155C				33
#define	CM_WN_3445A				34
#define	CM_POS_3502A			35
#define	CM_POS_3500B			36
#define	CM_GX_1420B				37
#define	CM_LAN_3201B			38
#define	CM_AT_9045B				39

#define	CM_LAN_3101				40
#define	CM_LAN_3101A			40

#define	CM_POS_3505A			41
#define	CM_LAN_3301A			42
#define	CM_WN_3442A				43
#define	CM_WN_3441A				44
#define	CM_LAN_3150A			45
#define	CM_AT_9034B				46
#define	CM_LAN_3311A			47
#define	CM_POS_3504A			48
#define	CM_LAN_3300A			49
#define	CM_LAN_3310A			50

#define	CM_LAN_3710AS			51
#define	CM_LAN_3710AL			52
#define	CM_LAN_3710AE			53

#define	CM_FBC_3601A			54
#define	CM_FBC_3602A			55

#define	CM_POS_3519A			56
#define	CM_POS_3510A			57
#define	CM_POS_3511A			58

#define CM_AT_3450A				59
#define CM_AT_3451A				60
#define CM_AT_3452A				61
#define CM_AT_3453A				62

#define	CM_LAN_3302A			63

#define CM_POS_3550A				64
#define CM_POS_3518A				65

#define CM_XLW_3720A				66
#define CM_XLW_3721A				67

#define CM_LAN_3101B				68

#define CM_LAN_3320A          69
#define CM_LAN_3321A          70
#define CM_LAN_3324A          71
#define CM_LAN_3325A          72
#define CM_LAN_3306A          73
#define CM_LAN_3327A          74

#define CM_XFP_3730A				75
#define CM_XFP_3731A				76

#define	CT_MAX_CARD_MODELS	CM_XFP_3731A

/*****************************************/
/* MII-related definitions */
/*****************************************/

/* register names */
#define MII_REGISTER_CONTROL				0
#define MII_REGISTER_STATUS					1
#define MII_REGISTER_AN_ADVERTISEMENT		4
#define MII_REGISTER_AN_LINK_PARTNER		5
#define MII_REGISTER_AN_EXPANSION			6
#define MII_REGISTER_1000_CONTROL			9
#define MII_REGISTER_1000_STATUS			10

/* register 0 (control register) bits */
#define MII_CTRL_RESET						0x8000
#define MII_CTRL_LOOPBACK					0x4000
#define MII_CTRL_SPEED						0x2000
#define MII_CTRL_AUTONEGOTIATE				0x1000
#define MII_CTRL_POWERDOWN					0x0800
#define MII_CTRL_ISOLATE					0x0400
#define MII_CTRL_RESTARTAUTONEGOTIATE		0x0200
#define MII_CTRL_DUPLEXMODE					0x0100
#define MII_CTRL_COLLISIONTEST				0x0080
#define MII_CTRL_SPEED_MSB					0x0040
#define MII_CTRL_SPEED_LSB					MII_CTRL_SPEED

/* register 1 definitions */
#define MII_STATUS_EXT_CAP					0x0001
#define MII_STATUS_JABBER_DETECT			0x0002
#define MII_STATUS_LINK						0x0004
#define MII_STATUS_AN_ABILITY				0x0008
#define MII_STATUS_REMOTE_FAULT				0x0010
#define MII_STATUS_AN_COMPLETE				0x0020
#define MII_STATUS_MF_PREAMBLE_SUP			0x0040
#define MII_STATUS_EXT_STATUS				0x0100
#define MII_STATUS_100BASE_T2_HALF			0x0200
#define MII_STATUS_100BASE_T2_FULL			0x0400
#define MII_STATUS_10_HALF					0x0800
#define MII_STATUS_10_FULL					0x1000
#define MII_STATUS_100BASE_X_HALF			0x2000
#define MII_STATUS_100BASE_X_FULL			0x4000
#define MII_STATUS_100BASE_T4				0x8000

/* register 4 & 5 definitions */
#define MII_AN_10BASE_T						0x0020
#define MII_AN_10BASE_T_FULL				0x0040
#define MII_AN_100BASE_TX					0x0080
#define MII_AN_100BASE_TX_FULL				0x0100
#define MII_AN_100BASE_T4					0x0200
#define MII_AN_FLOW_CONTROL					0x0400
#define MII_AN_REMOTE_FAULT					0x2000
#define MII_AN_ACKNOWLEDGE					0x4000
#define MII_AN_NEXT_PAGE					0x8000

/* register 6 */		
#define MII_AN_LINK_PARTNER					0x0001

/* register 9 definitions */
#define MII_CONTROL9_1000BASE				0x0100
#define MII_CONTROL9_1000BASE_FULL		0x0200

/* register 10 definitions */
#define MII_STATUS10_1000BASE				0x0080
#define MII_STATUS10_1000BASE_FULL			0x0100


/* Failure Codes */
#define UNSPECIFIED_ERROR					-1
#define PORT_NOT_LINKED						-2
#define UNLINK_FAILED						-3
#define INCORRECT_MODE						-4
#define PARAMETER_RANGE						-5
#define PACKET_NOT_AVAILABLE				-6
#define SERIAL_PORT_DATA					-7
#define ET1000_OUT_OF_SYNC					-8
#define PACKET_NOT_FOUND					-9
#define FUNCTION_ABORT						-10
#define ACTIVE_HUB_NOT_INITIALIZED		-11
#define ACTIVE_HUB_NOT_PRESENT			-12
#define WRONG_HUB_CARD_TYPE				-13
#define MEMORY_ALLOCATION_ERROR			-14
#define UNSUPPORTED_INTERLEAVE			-15
#define PORT_ALREADY_LINKED				-16
#define HUB_SLOT_PORT_UNAVAILABLE		-17
#define GROUP_HUB_SLOT_PORT_ERROR		-18
#define REENTRANT_ERROR						-19
#define DEVICE_NOT_FOUND_ERROR			-20
#define PORT_RELINK_REQUIRED				-21
#define DEVICE_NOT_READY					-22
#define GROUP_NOT_HOMOGENEOUS				-23
#define INVALID_GROUP_COMMAND				-24
#define ERROR_SMARTCARD_INIT_FAILED		-25
#define SOCKET_FAILED						-26
#define SOCKET_TIMEOUT 						-27
#define COMMAND_RESPONSE_ERROR			-28
#define CRC_ERROR 							-29
#define INVALID_LINK_PORT_TYPE			-30
#define INVALID_SYNC_CONFIGURATION		-31
#define HIGH_DENSITY_CONTROLLER_ERROR	-32
#define HIGH_DENSITY_CARD_ERROR	 		-33
#define DATA_NOT_AVAILABLE					-34
#define UNSUPPORTED_PLATFORM				-35
#define FILE_IO_ERROR						-36
#define MULTI_USER_CONFLICT				-37
#define INVALID_STRUCT_SIZE				-38
#define FLUSH_ERROR							-39
#define BANDWIDTH_EXCEEDED_ERROR			-40
#define NOT_MULTI_USER_CHASSIS         -41
#define NON_BLOCKING_RESPONSE_ERROR    -42
#define GPS_NOT_CONNECTED              -43
#define GPS_NOT_READY                  -44
#define GPS_SYNC_RETRY_ERROR			   -45


#define SERIAL_PORT_TIMEOUT				-98

/* Errors occurring in the Tcl interface */
#define NSTCL_PARAMETER_TYPE					-501
#define NSTCL_INVALID_MSG_FUNC				-502
#define NSTCL_PARAMETER_RANGE					-503
#define NSTCL_STRUCT_NOT_DEFINED				-504
#define NSTCL_INVALID_STRUCT_COUNT			-505
#define NSTCL_INVALID_STRUCT_SIZE			-506

/* Non-fatal errors */
#define UNSUPPORTED_COMMAND					-1001
#define UPDATED_FIRMWARE_NEEDED				-1002
#define INVALID_TYPE1  						   -1003
#define SOCKET_RECONNECT_FAIL             -1004
#define SOCKET_RECONNECT_SUCCESS          -1005

/* Non-fatal errors specific to autonegotiation */
#define AN_LINK_NOT_NEGOTIATED				-1100
#define AN_NO_EXTENDED_CAPABILITY			-1101
#define AN_LINK_PARTNER_INCAPABLE			-1102
#define AN_INVALID_MII_ADDRESS				-1103
#define AN_SETTINGS_NOT_VERIFIED				-1104



#define EXPRESS_UNLINK						1
#define NORMAL_UNLINK						0

/*---------------------- SmartCard Objects flags -----------*/
#define  SMARTCARD_STATUS_OK	0

/*--------------------- BNC Configuration ------------------*/
#define ETBNC_1                 1
#define ETBNC_2                 2
#define ETBNC_3                 3

#define ETBNC_INPUT             0
#define ETBNC_RXEA              1
#define ETBNC_RXEB              2
#define ETBNC_RCKA              3
#define ETBNC_RCKB              4
#define ETBNC_RDATA             5
#define ETBNC_RDATB             6
#define ETBNC_TXEA              7
#define ETBNC_TXEB              8
#define ETBNC_TDAT              9
#define ETBNC_COLLISIONA        10
#define ETBNC_COLLISIONB        11
#define ETBNC_CRCA              12
#define ETBNC_CRCB              13
#define ETBNC_UNDRA             14
#define ETBNC_UNDRB             15
#define ETBNC_OVRA              16
#define ETBNC_OVRB              17
#define ETBNC_ALA               18
#define ETBNC_ALB               19
#define ETBNC_TXTRIG            20
#define ETBNC_RXTRIG            21
#define ETBNC_10MHZ             22
#define ETBNC_10MHZINV          23
#define ETBNC_20MHZ             24
#define ETBNC_20MHZINV          25
#define ETBNC_EXTCLK            26
#define ETBNC_EXTCLKINV         27

#define ETBNC_MAX               27
#define ETBNC_JET210            99

/*---------------- Types of ET-1000 Transmit Data Patterns ------------*/
#define ETDP_ALLZERO            0
#define ETDP_ALLONE             1
#define ETDP_RANDOM             2
#define ETDP_AAAA               3
#define ETDP_5555               4
#define ETDP_F0F0               5
#define ETDP_0F0F               6
#define ETDP_00FF               7
#define ETDP_FF00               8
#define ETDP_0000FFFF           9
#define ETDP_FFFF0000           10
#define ETDP_00000000FFFFFFFF   11
#define ETDP_FFFFFFFF00000000   12
#define ETDP_INCR8              13
#define ETDP_INCR16             14
#define ETDP_DECR8              15
#define ETDP_DECR16             16
#define ETDP_FULLCUSTOM         17
#define MAX_DATA_PATTERN        ETDP_FULLCUSTOM

/*----------------- Receive Error and Trigger LED Parameters -----------*/
#define RXLED_ANY               0
#define RXLED_ERRORA            1
#define RXLED_ERRORB            2
#define RXLED_ERRORAB           3
#define RXLED_UNDERSIZEA        4
#define RXLED_UNDERSIZEB        5
#define RXLED_UNDERSIZEAB       6
#define RXLED_OVERSIZEA         7
#define RXLED_OVERSIZEB         8
#define RXLED_OVERSIZEAB        9
#define RXLED_ALIGNA            0x0a
#define RXLED_ALIGNB            0x0b
#define RXLED_ALIGNAB           0x0c
#define RXLED_NONE              0

#define TRIGLED_MISSING         0
#define TRIGLED_TXRX            1
#define TRIGLED_RX              2
#define TRIGLED_TX              3

/*----------------- Preamble Parameters -------------*/
#define ETPREAMBLE_MAX          128
#define ETPREAMBLE_MIN          10

/*----------------- ET-1000 Multifunction Counters ---------------*/
#define ETMF_PACKET_LENGTH      0
#define ETMF_RXTRIG_COUNT       1
#define ETMF_TXTRIG_COUNT       2
#define ETMF_TIME_ROUNDTRIP     3
#define ETMF_TIME_PORT2PORT     4
#define ETMF_RXTRIG_RATE        5
#define ETMF_TXTRIG_RATE        6
#define ETMF_PREAMBLE_COUNT     7
#define ETMF_GAP_TIME           8
#define ETMF_SQE_COUNT          9
#define ETMF_TOTAL_LENGTH       10

#define ETMF_MAX                ETMF_TOTAL_LENGTH

/*----------------------- Hub Tester ----------------------*/
#define MAX_HUBS				4
#define MAX_SLOTS				20
#define MAX_PORTS				4

#define MAX_HUBS_HD				4
#define MAX_SLOTS_HD			32
#define MAX_PORTS_HD			16

#define MAX_HUBS_SMB200			1
#define MAX_SLOTS_SMB200		4

#define MAX_MAX_HUBS			MAX_HUBS_HD
#define MAX_MAX_SLOTS			MAX_SLOTS_HD
#define MAX_MAX_PORTS			MAX_PORTS_HD

#define MAX_SUBSYSTEMS          2

#define PORTS_PER_ACTIVE_CARD   1
#define PORTS_PER_PASSIVE_CARD  2

#define MAX_PORT_IDS            (MAX_MAX_HUBS*MAX_MAX_SLOTS*MAX_MAX_PORTS)
#define MAX_ACTIVE_SLOTS        (MAX_MAX_HUBS*MAX_MAX_SLOTS*PORTS_PER_ACTIVE_CARD)
#define MAX_PASSIVE_SLOTS       (MAX_MAX_HUBS*MAX_MAX_SLOTS*PORTS_PER_PASSIVE_CARD)
#define MAX_TOTAL_PORTS         (MAX_MAX_HUBS*MAX_MAX_SLOTS*MAX_MAX_PORTS)
#define MAX_SLOTLIST_SIZE       255
#define MAX_GROUP_SIZE          450
#define MAX_VFD_SIZE            2048
#define MAX_FILL_PATTERN_SIZE   2044

#define RESET_FULL				1
#define RESET_PARTIAL			2

/* LEDs status indication */
#define HTLED_OFF						0
#define HTLED_RED						1
#define HTLED_GREEN						2
#define HTLED_ORANGE					3

#define HTLED_TXRED						0x00000001L		/* Unconfigured card*/
#define HTLED_TXGREEN					0x00000002L		/* Transmitting*/

#define HTLED_COLLRED					0x00000004L		/* Collision detected */
#define HTLED_COLLGREEN 				0x00000008L		/* Trigger detected */
#define HTLED_LINK_PAUSE				0x0000000CL		/* Link Pause */ 

#define HTLED_RXRED						0x00000010L		/* Receive with errors*/ 
#define HTLED_RXGREEN					0x00000020L		/* Receiving frame */
#define HTLED_RXOFF						0x00000030L		/* Not receiving*/

#define HTLED_100MB						0x00000040L		/* Port speed is 100MB */	
#define HTLED_SYNC_LOCK					0x00000080L		/* Frame lock synchronized and locked*/	
#define HTLED_SYNC						0x000000C0L		/* Frame lock synchronized but not locked */	

#define HTLED_FULL_DUPLEX				0x00000100L		/* Port duplex mode is full*/ 
#define HTLED_LINKED					0x00000200L		/* The link is up*/
#define HTLED_TX_PAUSE					0x00000400L		/* Transmitting Pause frame*/
#define HTLED_FRAME_CAPTURE				0x00000800L		/* Capture frame is ready*/
#define HTLED_CAPTURE_STOP				0x00001000L		/* Capture engine is stopped*/
#define HTLED_LINK_100MHZ				0x00010000L		/* Link is in 100Mhz mode*/
#define HTLED_LINK_10MHZ				0x00020000L		/* Link is in 10Mhz mode*/
#define HTLED_XENPAK_PROFILE_CHANGE		0x00040000L		/* Detected XENPAK profile mismatch*/
#define HTLED_XENPAK_MODULE_CHANGE		0x00080000L		/* Detected XENAPK module*/

/* LEDs status indication -- for ATM Terametrics Cards Only */
#define HTLED_MGMTLOFGREEN          0x00000008L		/* MGMT/LOF green when the port is receiving a management frame*/ 
#define HTLED_MGMTLOFYELLOW         0x0000000CL		/* MGMT/LOF yellow when there is a loss of frame (LOF)*/
#define HTLED_TRIGLOSGREEN          0x00000080L		/* TRIG/LOS green when there is a trigger event*/
#define HTLED_TRIGLOSYELLOW         0x000000C0L		/* TRIG/LOS yellow when there is a loss of signal (LOS)*/

/* Card Properties used with HTPortProperty */
#define CA_SIGNALRATE_10MB				0x00000001L
#define CA_SIGNALRATE_100MB				0x00000002L
#define CA_DUPLEX_FULL					0x00000004L
#define CA_DUPLEX_HALF					0x00000008L
#define CA_CONNECT_MII					0x00000010L
#define CA_CONNECT_TP					0x00000020L
#define CA_CONNECT_BNC					0x00000040L
#define CA_CONNECT_AUI					0x00000080L
#define CA_CAN_ROUTE					0x00000100L
#define CA_VFDRESETCOUNT				0x00000200L
#define CA_SIGNALRATE_4MB				0x00000400L
#define CA_SIGNALRATE_16MB				0x00000800L
#define CA_CAN_COLLIDE					0x00001000L
#define CA_SIGNALRATE_25MB				0x00002000L
#define CA_SIGNALRATE_155MB				0x00004000L
#define CA_BUILT_IN_ADDRESS				0x00008000L
#define CA_HAS_DEBUG_MONITOR			0x00010000L
#define CA_SIGNALRATE_1000MB			0x00020000L
#define CA_CONNECT_FIBER				0x00040000L
#define CA_CAN_CAPTURE					0x00080000L
#define CA_ATM_SIGNALING				0x00100000L
#define CA_CONNECT_V35					0x00200000L
#define CA_SIGNALRATE_8MB				0x00400000L
#define CA_SIGNALRATE_622MB				0x00800000L
#define CA_SIGNALRATE_45MB				0x01000000L
#define CA_SIGNALRATE_34MB				0x02000000L
#define CA_SIGNALRATE_1_544MB			0x04000000L
#define CA_SIGNALRATE_2_048MB			0x08000000L
#define CA_HASVFDREPEATCOUNT			0x10000000L
#define CA_CONNECT_USB					0x20000000L
#define CA_TRANSCEIVER_MULTIMODE		0x40000000L
#define CA_GBIC							0x80000000L

/* Card Attributes to be used with HTPortAttribute */
#define ATTRIB_SPEED_10MB				1
#define ATTRIB_SPEED_100MB				2
#define ATTRIB_DUPLEX_FULL				3
#define ATTRIB_DUPLEX_HALF				4
#define ATTRIB_CONNECT_MII				5
#define ATTRIB_CONNECT_TP				6
#define ATTRIB_CONNECT_BNC				7
#define ATTRIB_CONNECT_AUI				8
#define ATTRIB_CAN_ROUTE				9
#define ATTRIB_VFDRESETCOUNT			10
#define ATTRIB_SPEED_4MB				11
#define ATTRIB_SPEED_16MB				12
#define ATTRIB_CAN_COLLIDE				13
#define ATTRIB_SPEED_25MB				14
#define ATTRIB_SPEED_155MB				15
#define ATTRIB_BUILT_IN_ADDRESS			16
#define ATTRIB_HAS_DEBUG_MONITOR		17
#define ATTRIB_SPEED_1000MB				18
#define ATTRIB_CONNECT_FIBER			19
#define ATTRIB_CAN_CAPTURE				20
#define ATTRIB_ATM_SIGNALING			21
#define ATTRIB_CONNECT_V35				22
#define ATTRIB_SPEED_8MB				23
#define ATTRIB_SPEED_622MB				24
#define ATTRIB_SPEED_45MB				25
#define ATTRIB_SPEED_34MB				26
#define ATTRIB_SPEED_1_544MB			27
#define ATTRIB_SPEED_2_048MB			28
#define ATTRIB_HASVFDREPEATCOUNT		29
#define ATTRIB_CONNECT_USB				30
#define ATTRIB_TRANSCEIVER_MULTIMODE	31
#define ATTRIB_GBIC						32
#define ATTRIB_SPEED_2488MB			33
#define ATTRIB_TERAMETRICS				34
#define ATTRIB_SPEED_9952MB			35
#define ATTRIB_SPEED_10GB				36
#define ATTRIB_CONNECT_XENPAK			37
#define ATTRIB_OAM_CAPABLE  			38
#define ATTRIB_LAN_3201C            39

/* reference bit masks for standard SMB counters in HxGetEnhancedCounters()--use ulMask1 */
#define SMB_STD_MASK					0x000007FFL
#define SMB_STD_TXFRAMES				0x00000001L
#define SMB_STD_TXBYTES					0x00000002L
#define SMB_STD_TXTRIGGER				0x00000004L
#define SMB_STD_RXFRAMES				0x00000008L
#define SMB_STD_RXBYTES					0x00000010L
#define SMB_STD_RXTRIGGER				0x00000020L
#define SMB_STD_ERR_CRC					0x00000040L
#define SMB_STD_ERR_ALIGN				0x00000080L
#define SMB_STD_ERR_UNDERSIZE			0x00000100L
#define SMB_STD_ERR_OVERSIZE			0x00000200L
#define SMB_STD_ERR_COLLISION			0x00000400L

/* indices for referencing standard SMB counters in HxGetEnhancedCounters() */
#define ISMB_STD_TXFRAMES				0
#define ISMB_STD_TXBYTES				1
#define ISMB_STD_TXTRIGGER				2
#define ISMB_STD_RXFRAMES				3
#define ISMB_STD_RXBYTES				4
#define ISMB_STD_RXTRIGGER				5
#define ISMB_STD_ERR_CRC				6
#define ISMB_STD_ERR_ALIGN				7
#define ISMB_STD_ERR_UNDERSIZE			8
#define ISMB_STD_ERR_OVERSIZE			9
#define ISMB_STD_ERR_COLLISION			10

/* reference bit masks for VG/AnyLan enhanced counters in HxGetEnhancedCounters()--use ulMask2 */
#define SMB_VG_INV_PKTMARK				0x00000001
#define SMB_VG_ERR_PKT					0x00000002
#define SMB_VG_TRANSTRAIN_PKT			0x00000004
#define SMB_VG_PRIO_PROM_PKT			0x00000008
#define SMB_VG_MASK						0x0000000F

/* indices for referencing the enhanced counters in HxGetEnhancedCounters() */
#define ISMB_VG_INV_PKTMARK				32
#define ISMB_VG_ERR_PKT					33
#define ISMB_VG_TRANSTRAIN_PKT			34
#define ISMB_VG_PRIO_PROM_PKT			35

/* reference bit masks for Layer 3 enhanced counters in HxGetEnhancedCounters()--use ulMask2 */
#define L3_MASK                       0x00004FFFL
#define L3_FRAMEERROR                 0x00000001L
#define L3_TX_RETRIES                 0x00000002L
#define L3_TX_EXCESSIVE               0x00000004L
#define L3_TX_LATE                    0x00000008L
#define L3_RX_TAGS                    0x00000010L
#define L3_TX_STACK                   0x00000020L
#define L3_RX_STACK                   0x00000040L
#define L3_ARP_REQ                    0x00000080L
#define L3_ARP_SEND                   0x00000100L
#define L3_ARP_REPLIES                0x00000200L
#define L3_PINGREP_SENT               0x00000400L
#define L3_PINGREQ_SENT               0x00000800L
#define L3_PINGREQ_RECV               0x00001000L
#define L3_DATA_INTEGRITY_ERRORS	  0x00002000L
#define L3_IP_CHECKSUM_ERRORS		  0x00004000L


/* indices for referencing the enhanced counters in HxGetEnhancedCounters() */
#define IL3_FRAMEERROR             	  32
#define IL3_TX_RETRIES                33
#define IL3_TX_EXCESSIVE              34
#define IL3_TX_LATE                   35
#define IL3_RX_TAGS                   36
#define IL3_TX_STACK                  37
#define IL3_RX_STACK                  38
#define IL3_ARP_REQ                   39
#define IL3_ARP_SEND                  40
#define IL3_ARP_REPLIES               41
#define IL3_PINGREP_SENT              42
#define IL3_PINGREQ_SENT              43
#define IL3_PINGREQ_RECV              44
#define IL3_DATA_INTEGRITY_ERRORS	  45
#define IL3_IP_CHECKSUM_ERRORS		  46


/* reference bit masks for ATM enhanced counters in HxGetEnhancedCounters()--use ulMask2 */
#define ATM_MASK                      0x0007FFFFL
#define ATM_CELLS                     0x00000001L
#define ATM_CORRECTEDHEADERS          0x00000002L
#define ATM_UNCORRECTABLEHEADERS      0x00000004L
#define ATM_CELLSLOST                 0x00000008L
#define ATM_OUT_OF_SEQUENCE           0x00000010L
#define ATM_MISDELIVERED              0x00000020L
#define ATM_OAM_F4                    0x00000040L
#define ATM_OAM_F5                    0x00000080L
#define ATM_SIGNALING                 0x00000100L
#define ATM_CELL_ERROR_RATIO          0x00000200L
#define ATM_SEVERE_ERROR_CB_RATIO     0x00000400L
#define ATM_CELL_LOSS_RATIO           0x00000800L
#define ATM_MISINSERTION              0x00001000L
#define ATM_CELL_TRANSFER_DELAY       0x00002000L
#define ATM_MEAN_CELL_TRANSFER_DELAY  0x00004000L
#define ATM_CELL_DELAY_VARIATION      0x00008000L
#define ATM_TX_CELLS                  0x00010000L
#define ATM_TX_AAL_PDU                0x00020000L
#define ATM_TIMEOUT                   0x00040000L

/* indices for referencing the enhanced counters in HxGetEnhancedCounters() */
#define IATM_CELLS                     32
#define IATM_CORRECTEDHEADERS          33
#define IATM_UNCORRECTABLEHEADERS      34
#define IATM_CELLSLOST                 35
#define IATM_OUT_OF_SEQUENCE           36
#define IATM_MISDELIVERED              37
#define IATM_OAM_F4                    38
#define IATM_OAM_F5                    39
#define IATM_SIGNALING                 40
#define IATM_CELL_ERROR_RATIO          41
#define IATM_SEVERE_ERROR_CB_RATIO     42
#define IATM_CELL_LOSS_RATIO           43
#define IATM_MISINSERTION              44
#define IATM_CELL_TRANSFER_DELAY       45
#define IATM_MEAN_CELL_TRANSFER_DELAY  46
#define IATM_CELL_DELAY_VARIATION      47
#define IATM_TX_CELLS                  48
#define IATM_TX_AAL_PDU                49
#define IATM_TIMEOUT                   50

/* reference bit masks for Token Ring enhanced counters in HxGetEnhancedCounters()--use ulMask2 */
#define TR_MASK                 0x001FFFFFL
#define TR_RXMAC                0x00000001L
#define TR_RXABORTFRAMES        0x00000002L
#define TR_LINEERRORS           0x00000004L
#define TR_BURSTERRORS          0x00000008L
#define TR_BADTOKEN             0x00000010L
#define TR_PURGEEVENTS          0x00000020L
#define TR_BEACONEVENTS         0x00000040L
#define TR_CLAIMEVENTS          0x00000080L
#define TR_INSERTIONS           0x00000100L
#define TR_MAC_LINEERRORS       0x00000200L
#define TR_MAC_INTERNALERRORS   0x00000400L
#define TR_MAC_BURSTERRORS      0x00000800L
#define TR_MAC_ACERRORS         0x00001000L
#define TR_MAC_ABORTTX          0x00002000L
#define TR_MAC_LOSTFRAME        0x00004000L
#define TR_MAC_RXCONGESTED      0x00008000L
#define TR_MAC_FRAMECOPIED      0x00010000L
#define TR_MAC_FREQUENCYERROR   0x00020000L
#define TR_MAC_TOKENERROR       0x00040000L
#define TR_LATENCY              0x00080000L
#define TR_TOKEN_RT             0x00100000L

/* indices for referencing the extended counters in HxGetEnhancedCounters() */
#define ITR_RXMAC               32
#define ITR_RXABORTFRAMES       33
#define ITR_LINEERRORS          34
#define ITR_BURSTERRORS         35
#define ITR_BADTOKEN            36
#define ITR_PURGEEVENTS         37
#define ITR_BEACONEVENTS        38
#define ITR_CLAIMEVENTS         39
#define ITR_INSERTIONS          40
#define ITR_MAC_LINEERRORS      41
#define ITR_MAC_INTERNALERRORS  42
#define ITR_MAC_BURSTERRORS     43
#define ITR_MAC_ACERRORS        44
#define ITR_MAC_ABORTTX         45
#define ITR_MAC_LOSTFRAME       46
#define ITR_MAC_RXCONGESTED     47
#define ITR_MAC_FRAMECOPIED     48
#define ITR_MAC_FREQUENCYERROR  49
#define ITR_MAC_TOKENERROR      50
#define ITR_LATENCY             51
#define ITR_TOKEN_RT            52

/* ------------------ TokenRing parameter values ------------------- */
#define TR_SPEED_4MBITS         0
#define TR_SPEED_16MBITS        1
#define TR_TOKEN_EARLY_RELEASE  1
#define TR_TOKEN_DEFAULT        0
#define TR_DUPLEX_FULL          1
#define TR_DUPLEX_HALF          0
#define TR_MODE_DEVICE          1
#define TR_MODE_MAU             0
#define TR_PROPERTY_ENTRY       4

/* ------------------ TokenRing Error bits ------------------- */
#define TR_ERR_FCS              0x0001
#define TR_ERR_FRAME_COPY       0x0002
#define TR_ERR_FRAME_BIT        0x0004
#define TR_ERR_FRAME_FS         0x0008
#define TR_ERR_ABORT_DELIMITER  0x0010
#define TR_ERR_BURST            0x0020

/* ------------------ TokenRing FC byte values ------------------- */
#define TRFC_DEFAULT            0x40
#define TRFC_PCFON              0x01
#define TRFC_PCF_BEACON         0x02
#define TRFC_PCF_CLAIMTOKEN     0x03
#define TRFC_PCF_RINGPURGE      0x04
#define TRFC_PCF_AMP            0x05
#define TRFC_PCF_SMP            0x06
#define TRFC_PCF_DAT            0x01
#define TRFC_PCF_RRS            0x01
#define TRFC_PCF_EXPRESSBUFFER  0x01

/* ------------------ VG card parameter values ------------------- */
#define VG_CFG_END_NODE         0
#define VG_CFG_MASTER           1
#define VG_CFG_NO_PRIO_PROMO    0
#define VG_CFG_PRIORITY_PROMO   1
#define VG_CFG_TOKENRING        1
#define VG_CFG_ETHERNET         0
#define VG_PROPERTY_ENTRY       3

/* ------------------ TokenRing Enhanced Status bits ------------------- */
#define TR_STATUS_ACCESSED				0x000100L
#define TR_STATUS_BADSTREAM				0x000200L
#define TR_STATUS_BURST_MODE			0x000400L
#define TR_STATUS_BEACONING				0x000800L
#define TR_STATUS_DEVICE				0x001000L
#define TR_STATUS_EARLY_TOKEN_RELEASE	0x002000L
#define TR_STATUS_FULL_DUPLEX			0x004000L
#define TR_STATUS_16MB					0x008000L
#define TR_STATUS_RING_ALIVE			0x010000L
#define TR_STATUS_LATENCY_STABLE		0x020000L
#define TR_STATUS_TRANSMITTING			0x040000L

/* ------------------ Gigabit Ethernet Enhanced Status bits ------------------- */
#define GIG_STATUS_LINK					0x000200L   /* is link established--note: 
																		this is the only status bit 
																		supported by the LAN-3201 */
#define GIG_STATUS_TX_PAUSE				0x000400L   /* is pause holdoff in process */
#define GIG_STATUS_CAPTURED_FRAMES		0x000800L   /* are there captured frames */
#define GIG_STATUS_CAPTURE_STOPPED		0x001000L   /* is capture stopped */
#define GIG_STATUS_1420					0x002000L	/* is the card a GX-1420 */
#define GIG_STATUS_1420B				0x004000L	/* is the card a GX-1420B */
#define GIG_STATUS_100MHZ				0x010000L	/* is the card at 100MHz speed */
#define GIG_STATUS_10MHZ				0x020000L	/* is the card at 10MHz speed */

/* ------------------ 100 MB SX-7410 Fast Ethernet Enhanced Status bits ------------------- */
#define FAST7410_STATUS_LINK			0x000200L   /* is link established */
#define FAST7410_STATUS_TX_PAUSE		0x000400L   /* is pause holdoff in process */

/* ------------------ 10 MB Ethernet Layer 3 Enhanced Status bits ------------------- */
/* this bit will be set if the 10 MB Layer 3 card is an L3-6710, else it is an L3-6705 */
#define L3_STATUS_6710					0x080000L

/* ------------------ 10 and 10/100 MB Ethernet Layer 3 and Multi-Layer Enhanced Status bits ------------------- */
#define L3_ARPS_NOT_RESOLVED			0x100000		/* if ARPS are not resolved for all streams */
#define L3_ARPS_STILL_TXING				0x200000		/* if ARPS are still transmitting */

/*------------------- USB CARDs ---------------------*/
#define L3_USB_PORT_ENABLED				0x400000    /* if USB Port is enabled.*/
#define L3_USB_PORT_LINKED				0x800000    /* if USB Port is linked to a USB device (enumeration was successful).*/
#define L3_RNDIS_MODE_ENABLED			0x010000	/* If RNDIS mode is enabled */

/* ------------------ VG Enhanced Status bits ------------------- */
/* this bit will be set if the mode is Ethernet, else it will be in Token Ring mode */
#define VG_STATUS_MODE					0x000200L

/* ------------------ WAN Frame Relay Enhanced Status bits ------------------- */
#define FR_STATUS_LINK_OK				0x000200L   /* is link established */
#define FR_STATUS_GROUP_MEMBER			0x000400L   /* set if Card is "grouped" */
#define FR_STATUS_UNI_UP     			0x008000L   /* set if UNI is up */
#define FR_STATUS_EIA_DSR				0x010000L   /* set if DSR line is high */
#define FR_STATUS_EIA_CTS    			0x020000L   /* set if CTS line is high */
#define FR_STATUS_EIA_DCD				0x040000L   /* set if DCD line is high */
#define FR_STATUS_EIA_TM  	   			0x080000L   /* set if TM line is high */
#define FR_STATUS_EIA_DTR	   			0x100000L   /* set if DTR line is high */
#define FR_STATUS_EIA_RTS 				0x200000L   /* set if RTS line is high */
#define FR_STATUS_EIA_RDL	   			0x400000L   /* set if RDL line is high */
#define FR_STATUS_EIA_LLB				0x800000L   /* set if LLB line is high */

/* ------------------ SmartBits chassis (hub) identifiers ----------------- */
#define HTHUBID_1               1
#define HTHUBID_2               2
#define HTHUBID_3               3
#define HTHUBID_4               4
#define HTHUBID_ALL             0

/* ------------------ Data stream Transmission modes ------------------- */
#define CONTINUOUS_PACKET_MODE  0
#define FIRST_TRANSMIT_MODE		CONTINUOUS_PACKET_MODE
#define SINGLE_BURST_MODE       1
#define MULTI_BURST_MODE        2
#define CONTINUOUS_BURST_MODE   3
#define ECHO_MODE               4
#define LAST_TRANSMIT_MODE		ECHO_MODE

/*
	Supported duplex modes of different SmartCards.
	Not all cards support all duplex settings
	See the SmartCard reference for supported settings
*/

#define FULLDUPLEX_MODE         0
#define HALFDUPLEX_MODE         1

/*
#define HTRECEIVE_OFF           0
*/
/* ------------------ ET-1000 Port B transmit modes ------------------- */
#define HTTRANSMIT_OFF          0
#define HTTRANSMIT_STD          1
#define HTTRANSMIT_COL          2

/* ------------------ SmartCard Trigger params ------------------- */
#define HTTRIGGER_OFF           0
#define HTTRIGGER_1             1
#define HTTRIGGER_2             2
#define HTTRIGGER_DEPENDENT     3
#define HTTRIGGER_INDEPENDENT   4
#define HTTRIGGER_ON            4

/* ------------------ SmartCard VFD params ------------------- */
#define HVFD_1                  1
#define HVFD_2                  2
#define HVFD_3                  3

#define HVFD_NONE               0
#define HVFD_RANDOM             1
#define HVFD_INCR               2
#define HVFD_DECR               3
#define HVFD_ENABLED            4
#define HVFD_STATIC             5

/* ------------- SmartCard Echo transmission mode control ------------ */
#define HTECHO_OFF              0
#define HTECHO_ON               1

/* ------------------ SmartCard Latency params ------------------- */
#define HT_RUN_LATENCY          0
#define HT_GET_LATENCY          1

#define HT_LATENCY_OFF          0
#define HT_LATENCY_RX           1
#define HT_LATENCY_TX           2
#define HT_LATENCY_REPORT       3
#define HT_LATENCY_RXTX         4

/* ------------- Collision backoff aggressiveness values ------------- */
#define HT_CBA_DEFAULT          0
#define HT_CBA_1                1
#define HT_CBA_2                2
#define HT_CBA_3                3
#define HT_CBA_4                4
#define HT_CBA_5                5
#define HT_CBA_6                6
#define HT_CBA_7                7
#define HT_CBA_8                8
#define HT_CBA_9                9
#define HT_CBA_10               10

/* ------------- Library command debug and logging values ------------- */
#define ET_SECURE               1
#define ET_NO_SECURE            0

#define ET_CMDLOG_COMMANDS      0x0001L /* Display the input, output,
														 or comment data */
#define ET_CMDLOG_SHOW_IOTYPE   0x0002L /* Display input or output
														 prefix at start of each
														 line */
#define ET_CMDLOG_TIMESTAMP     0x0004L /* Place timestamps at the
														 start of each line
														 indicating when command was
														 sent or received */
#define ET_CMDLOG_APPEND        0x0008L /* Append new log entries to
														 the end of the existing
														 file */
#define ET_CMDLOG_NOREAD        0x0010L /* Exclude entries for reads
														 from the chassis */
#define ET_CMDLOG_NOWRITE       0x0020L /* Exclude entries to writes
														 to the chassis */
#define ET_CMDLOG_NOCOMMENT     0x0040L /* Exclude informative
														 comments */
#define ET_CMDLOG_NOVERSION		0x0080L /* Exclude library version
														 information at link and
														 unlink */
#define ET_CMDLOG_NOLINKINFO	0x0100L /* Exclude link info for
														  multi-link situations */
#define ET_CMDLOG_ALWAYSLINKINFO	0x0200L	/* Include link info even
															for single links
															(overrides NOLINKINFO) */
#define ET_CMDLOG_FIELDNAMES	0x0400L  /* Include message header field names 
															when printing out command */

/* --- Scales used for InterPacketGap (IPG) and InterBurstGap (IBG) --- */
#define PICO_SCALE              4
#define NANO_SCALE              1
#define MICRO_SCALE             2
#define MILLI_SCALE             3

/*
	Supported speeds of different SmartCards.
	Not all cards support all speeds.
	See the SmartCard reference for supported speeds.
*/
#define SPEED_4MHZ					0x0001
#define SPEED_10MHZ					0x0002
#define SPEED_16MHZ					0x0004
#define SPEED_100MHZ					0x0008
#define SPEED_155MHZ					0x0010
#define SPEED_25MHZ					0x0020
#define SPEED_1GHZ					0x0040
#define SPEED_2GHZ					0x0080
#define SPEED_10GHZ					0x0100
#define SPEED_DUPLEX_UNTOUCHED	0x00ff

/* ------------- Library command : NSCalculateGap ------------- */
#define PPS_TO_GAP_BITS					0
#define PERCENT_LOAD_TO_GAP_BITS		1


/* ------------------ MFType Definitions ------------------- */
#define MFTYPEEVENT             0
#define MFTYPERATE              1

/* ---------- HTSeparateHubCommands parameters ------------- */
#define HUB_GROUP_DEFAULT_ACTION			0
#define HUB_GROUP_INDEPENDENT_ACTION  		1
#define HUB_GROUP_UNIT_ACTION				2	/* redundant -- effectively equivalent */
												/* to HUB_GROUP_DEFAULT_ACTION; left in */
												/* for legacy purposes */
#define HUB_GROUP_SYNC_ACTION				3


/* ----------- Firmware Release Type ----------------------- */
#define PRODUCTION_RELEASE             0
#define PATCH_RELEASE                  1
#define ENGINEERING_QA_RELEASE         2
#define ENGINEERING_TEST_RELEASE       3


/* ----- return values for NSGetMultiUserCapability ----- */
#define MULTI_USER_INCAPABLE 			0
#define MULTI_USER_CAPABLE				1

/* return values for NSGetSyncMode command */
#define SYNC_NONE                         0
#define SYNC_GPS_MASTER                   1
#define SYNC_GPS_MASTER_AND_INOUT_SLAVE   2
#define SYNC_INOUT_MASTER                 3
#define SYNC_INOUT_SLAVE                  4

/* return values for NSGetGPSStatus command */
#define GPS_STATUS_UNKNOWN			0
#define GPS_STATUS_OK				1
#define GPS_STATUS_NOT_READY		2
#define GPS_STATUS_NOT_CONNECTED	3

/* Log Command */
#define COMMAND_MODE_LOG_AND_SEND	0	/* send to socket and write to log file */
#define COMMAND_MODE_LOG_ONLY		1		/* only write to log file, don't send to socket */
#define COMMAND_MODE_SEND_ONLY		2	/* only send to socket, don't  write to log file */

/* Defined constants for HGSetGroupBehavior*/
#define ALLOW_LATENCY_COUNTER_RESET       0
#define INHIBIT_LATENCY_COUNTER_RESET     1
 
/* Defined constants for NSSetNonBlockingMode */
#define ENABLE_NON_BLOCKING_MODE    1
#define DISABLE_NON_BLOCKING_MODE   0

enum LINK_PORT_TYPE{
	INVALID_LINK_PORT = 0,
	COMM_PORT,
	SOCK_PORT
};


/*---------------------------------------------------*/
/*----------------- Data Structures -----------------*/
/*---------------------------------------------------*/

typedef struct
	{
	unsigned int Offset;
	unsigned int Range;
	int Filter;
	int Port;
	int BufferMode;
	int TimeTag;
	int Mode;
	} CaptureStructure;

typedef struct tagETCapturePacketInfo
	{
	unsigned long ulPacketNumber;
	unsigned long ulPacketLength;
	unsigned int uiCaptureFlag;
	unsigned char ucReserved[16];
	} ETCapturePacketInfo;

typedef struct
	{
	unsigned int Offset;
	unsigned int Duration;
	unsigned int Count;
	int Mode;
	} CollisionStructure;

typedef struct
	{
	unsigned long ERAEvent;
	unsigned long ERARate;
	unsigned long ERBEvent;
	unsigned long ERBRate;
	unsigned long TXAEvent;
	unsigned long TXARate;
	unsigned long TXBEvent;
	unsigned long TXBRate;
	unsigned long RXAEvent;
	unsigned long RXARate;
	unsigned long RXBEvent;
	unsigned long RXBRate;
	unsigned long CXAEvent;
	unsigned long CXARate;
	unsigned long CXBEvent;
	unsigned long CXBRate;
	unsigned long ALAEvent;
	unsigned long ALARate;
	unsigned long ALBEvent;
	unsigned long ALBRate;
	unsigned long UPAEvent;
	unsigned long UPARate;
	unsigned long UPBEvent;
	unsigned long UPBRate;
	unsigned long OPAEvent;
	unsigned long OPARate;
	unsigned long OPBEvent;
	unsigned long OPBRate;
	unsigned long MFAEvent;
	unsigned long MFARate;
	unsigned long MFBEvent;
	unsigned long MFBRate;
	} CountStructure;

typedef struct
	{
	unsigned long Gap;
	unsigned long Data;
	unsigned int Disp;
	unsigned int Mode;
	int Run;
	int Sel;
	} SwitchStructure;

typedef struct
	{
	unsigned int days;
	unsigned int hours;
	unsigned int minutes;
	unsigned int seconds;
	unsigned int milliseconds;
	unsigned int microseconds;
	} TimeStructure;

typedef struct
	{
	unsigned int Offset;
	int Range;
	int Pattern[12];
	} TriggerStructure;

typedef struct
	{
	unsigned int Offset;
	unsigned int Range;
	int Start[4096];
	int Increment[4096];
	} VFDStructure;

typedef struct
	{
	int Configuration;
	int Range;
	int Offset;
	int* Data;
	int DataCount;       /*VFD 3 sets buffer size; VFD1 or 2, sets cycle count */
	} HTVFDStructure;

typedef struct
	{
	BOOL AlignError;
	int AlignCount;
	BOOL DribbleError;
	int DribbleCount;
	BOOL CRCError;
	} TErrorStructure;

typedef struct
	{
	unsigned long RcvPkt;
	unsigned long TmtPkt;
	unsigned long Collision;
	unsigned long RcvTrig;
	unsigned long RcvByte;
	unsigned long CRC;
	unsigned long Align;
	unsigned long Oversize;
	unsigned long Undersize;
	unsigned long TmtPktRate;
	unsigned long RcvPktRate;
	unsigned long CRCRate;
	unsigned long OversizeRate;
	unsigned long UndersizeRate;
	unsigned long CollisionRate;
	unsigned long AlignRate;
	unsigned long RcvTrigRate;
	unsigned long RcvByteRate;
	} HTCountStructure;

typedef struct
	{
	unsigned int Offset;
	int Range;
	int Pattern[6];
	} HTTriggerStructure;

typedef struct
	{
	unsigned int Bit_Offset;
	int Bit_Range;
	int Trig_Pattern[6];
	int Bit_Mask[6];
	} TriggerMaskStructure;

typedef struct
	{
	int Range;
	int Offset;
	int iData[12];
	unsigned long ulLatency;
	} HTLatencyStructure;

typedef struct
	{
	int iMode;
	int iPortType;
	unsigned long ulMask1;
	unsigned long ulMask2;
	unsigned long ulData[64];
	} EnhancedCounterStructure;

typedef struct
   {
   int ReleaseType;     /* can be one of the constants: xxx_RELEASE  */
   int MajorNumber;     /* range: 1 - 99                             */
   int MinorNumber;     /* range: 1 - 99                             */
   int BuildNumber;     /* range: 1 - 999                            */
   int PatchNumber;     /* range: 1 - 99                             */
   }FirmwareVersionStructure;


typedef struct
   {
   unsigned short uiReleaseType;     /* can be one of the constants: xxx_RELEASE  */
   unsigned short uiMajorNumber;     /* range: 1 - 99                             */
   unsigned short uiMinorNumber;     /* range: 1 - 99                             */
   unsigned short uiBuildNumber;     /* range: 1 - 999                            */
   unsigned char  ucReserved[16];    /* Reserved for future using                 */	
   }CardFWVersionStructure;


/* Card sharing Query */
#define MAX_USER_CONNECTIONS		4
typedef struct tagNSIPAddress
{
	unsigned char	ucIPAddress[4];
} NSIPAddress;

/* Card sharing structure */
typedef struct tagHTSlotSharingStructure
{
	unsigned short	uiNumUsers;						//number of users actively sharing the card, current limited to 0-4
	NSIPAddress		User[MAX_USER_CONNECTIONS];//the IP Address of each card-sharing users
} HTSlotSharingStructure;

/* For use with NSGetFlashData */
typedef struct tagNSFlashData
{
	unsigned short	uiDataCRC;                  /* 16-bit CRC for the next 254 bytes */
	unsigned short	uiDataID;                   /* ID */
	unsigned short	uiDataFormatVersion;        /* Always 0 */
	unsigned char 	ucControllerProperties;     /* Controller property */
	unsigned char	ucMaxUsersAllowed;          /* Maximum number of users allowed to simultaneously log in */
	unsigned short	uiControllerAttributes;     /* Controller Attributed */
	unsigned char	ucNumberOfPhysicalSlots;    /* Set to 6 for an SMB-6000/B. Set to 2 for an SMB-600 */
	unsigned char	ucNumberOfCardsPerSlot;     /* Set to 2 for an SMB-6000/B. Set to 1 for an SMB-600 */
	unsigned long	ulBaseAddressOfFirstCard;   /* Memory-mapped location of first card's data ports */
	unsigned long	ulBaseAddressDelta;         
	unsigned char	ucIPAddress[4];             /* Controller's IP address as a 32-bit number */
	unsigned char	ucMACAddress[6];            /* Controller's MAC address */
	unsigned short	uiTCPListenPortNumber;      /* TCP port number for BIN connections */
	unsigned char	ucProductFamilyID;          /*  */
	unsigned char	ucControllerUniqueID;       /* Set to 1 for an SMB-6000/B. Set to 2 for an SMB-600 */
	unsigned long	ulProductSerialNumber;      /* 32-bit chassis serial number */
	char		    szProductDescription[60];   /* Text string: "SMB-6000 Multiport controller" */
	unsigned long	ulIdleConnectionTimeout;    /* Idle timeout for TCP connections in 100ths of seconds. */
	unsigned char	ucReserved1[8];             /* Encrypted version of super-user password */
	unsigned char	ucProductIDSupported[20];   /*  */
    unsigned long	ulCustomerID;               /* 32-bit customer number */
    char	        szSecurityPassword[8];      /* Security access password. */
    unsigned long	ulSecurityEncryption;       /* Unused */
    unsigned char	ucSecurityLevel;            /* Indication of what security access features are enabled. */
    unsigned char	ucResetCard;                /* unused */
    unsigned char	ucMaxTelnetSession;         /* The maximum number of open Telnet connections. */
    unsigned char   ucNTPConfigure;             /* Bitmap of NTP options */
    unsigned short  uiNTPTimeZone;              /* Time offset (in minutes) of local time zone from UTC. */
    NSIPAddress NTPPeerIPAddress[8];            /* IP addresses of NTP peer servers. */
    unsigned char   ucControllerNetmask[4];     /* Controller's netmask */
    unsigned char   ucDefaultGateway[4];        /* Controller's default gateway */
    unsigned char   ucReservedForGateway[28];   /* Intended to be used for other (non-default gateway IP addresses). Currently unused. */
    unsigned char   ucReserved2[6];             /* Reserved for future use */
    unsigned long   ulManufactureTestVersion;   /* Manufactured test version number */
    char            szDateManufactured[10];     /* Controller's manufacture date in MM/DD/YYYY format */
    char            szSaleOrderNum[16];         /* Text string indicating SmartBits sales order number */
} NSFlashData;



/*--------------------------------------------------------------------*/
/*--------------- TokenRing specific Data Structures -----------------*/
/*--------------------------------------------------------------------*/
typedef struct
	{
	int UseMAC;
	int Stations;
	int MACSrc[6];
	int MACDest[6];
	int FramesPerToken;
	int FrameControl;
	} TokenRingMACStructure;

typedef struct
	{
	int UseLLC;
	int DSAP;
	int SSAP;
	int LLCCommand;
	} TokenRingLLCStructure;

typedef struct
	{
	int SpeedSetting;
	int EarlyTokenRelease;
	int DuplexMode;
	int DeviceOrMAUMode;
	} TokenRingPropertyStructure;

typedef struct
	{
	int UseHoldingGap;
	int GapValue;
	int GapScale;
	int UseIntermediateFrameBits;
	int UseAC;
	int ACdata;
	int AdvancedControl1;
	int AdvancedControl2;
	unsigned long AReserved1;
	unsigned long AReserved2;
	} TokenRingAdvancedStructure;

/*--------------------------------------------------------------------*/
/*------------------- VG specific Data Structures --------------------*/
/*--------------------------------------------------------------------*/
typedef struct
	{
	int EndOrMasterMode;
	int PriorityPromotion;
	int EtherNetOrTokenRing;
	} VGCardPropertyStructure;

/*--------------------------------------------------------------------*/
/*-------- Layer 3 SmartCard Parameters and Data Structures  ---------*/
/*--------------------------------------------------------------------*/

#include "l3items.h"

/*--------------------------------------------------------------------*/
/*----------- ATM SmartCard Parameters and Data Structures  ----------*/
/*--------------------------------------------------------------------*/

#include "atmitems.h"

/*--------------------------------------------------------------------*/
/*--------- GigaBit SmartCard Parameters and Data Structures  --------*/
/*--------------------------------------------------------------------*/

#include "gigitems.h"

/*--------------------------------------------------------------------*/
/*------- Frame Relay SmartCard Parameters and Data Structures  ------*/
/*--------------------------------------------------------------------*/

#include "fritems.h"

/*--------------------------------------------------------------------*/
/*------- Fast Ethernet SmartCard Parameters and Data Structures -----*/
/*--------------------------------------------------------------------*/

#include "fstitems.h"


/*--------------------------------------------------------------------*/
/*------- Ethernet SmartCard Parameters and Data Structures ----------*/
/*--------------------------------------------------------------------*/

#include "ethitems.h"

/*--------------------------------------------------------------------*/
/*-------                          Frame Types              ----------*/
/*--------------------------------------------------------------------*/

#include "frmitems.h"

/*--------------------------------------------------------------------*/
/*------------ POS SmartCard Parameters and Data Structures  ---------*/
/*--------------------------------------------------------------------*/

#include "l2items.h"
#include "positems.h"


/*--------------------------------------------------------------------*/
/*------------ PPP Parameters and Data Structures  -------------------*/
/*--------------------------------------------------------------------*/

#include "pppitems.h"


/*--------------------------------------------------------------------*/
/*------------ Fibre Channel Parameters and Data Structures  ---------*/
/*--------------------------------------------------------------------*/

#include "fcitems.h"


/*--------------------------------------------------------------------*/
/*---------- NS Command Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "nsitems.h"


/*--------------------------------------------------------------------*/
/*---------- MPLS Command Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "mplsitems.h"

/*--------------------------------------------------------------------*/
/*---------- PMC Command Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "pmcitems.h"


/*--------------------------------------------------------------------*/
/*---------- Titan Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "atmtmitems.h"

/*--------------------------------------------------------------------*/
/*---------- NTP Parameters and Data Structures ---------------*/
/*--------------------------------------------------------------------*/

#include "ntpitems.h"

/*-----------------------------------------------------------------------------*/
/*---------- NS stream configuration command Parameters and Data Structures ---*/
/*-----------------------------------------------------------------------------*/

#include "nsstreamitems.h"

/*=======================================================================*/
/*====================== Function Prototypes ============================*/
/*=======================================================================*/

#ifdef __cplusplus
extern "C" {
#endif

int     DLL_EXPORT ETAlignCount(int iCount);
int     DLL_EXPORT ETBNC(int iBNCid, int iConfig);
int     DLL_EXPORT ETBurst(int iMode, long lCount);
int     DLL_EXPORT ETCaptureParams(CaptureStructure* pCStruct);
int     DLL_EXPORT ETCaptureRun(void);
int     DLL_EXPORT ETCollision(CollisionStructure* pCStruct);
int     DLL_EXPORT ETDataLength(long lCount);
int     DLL_EXPORT ETDataPattern(int iPattern);
int     DLL_EXPORT ETDribbleCount(int iCount);
int     DLL_EXPORT ETGap(long lCount);
int     DLL_EXPORT ETGapScale(int iTimeOfGap);
int     DLL_EXPORT ETGetAlignCount(void);
long    DLL_EXPORT ETGetBaud(void);
int     DLL_EXPORT ETGetBNC(int iBNCid);
long    DLL_EXPORT ETGetBurstCount(void);
int     DLL_EXPORT ETGetBurstMode(void);
int     DLL_EXPORT ETGetCapturePacket(long lPI, int* piBuffer, int iBufferSize);
long    DLL_EXPORT ETGetCapturePacketCount(void);
int     DLL_EXPORT ETGetCapturePacketInfo(unsigned long ulPacket, ETCapturePacketInfo* pCPI);
int     DLL_EXPORT ETGetCaptureErrors(void);
int     DLL_EXPORT ETGetCaptureParams(CaptureStructure* pCStruct);
int     DLL_EXPORT ETGetCaptureTime(TimeStructure* pTStruct);
int     DLL_EXPORT ETGetCollision(CollisionStructure* pCStruct);
int     DLL_EXPORT ETGetTotalLinks(void);
int     DLL_EXPORT ETGetLinkFromIndex(int iLink);
int     DLL_EXPORT ETGetCurrentLink(void);
int     DLL_EXPORT ETSetLinksHubAccessMode(int iMode);
int     DLL_EXPORT ETGetController(void);
int		DLL_EXPORT ETGetProductFamily(void);
int     DLL_EXPORT ETGetCounters(CountStructure* pCStruct);
int     DLL_EXPORT ETGetCRCError(void);
long    DLL_EXPORT ETGetDataLength(void);
int     DLL_EXPORT ETGetDataPattern(void);
int     DLL_EXPORT ETGetDribbleCount(void);
int     DLL_EXPORT ETGetErrorStatus(void);
int     DLL_EXPORT ETGetFirmwareVersion(char* pszDump);
int     DLL_EXPORT ETGetFlashVersion(char* pszDump);
long    DLL_EXPORT ETGetGap(void);
int     DLL_EXPORT ETGetGapScale(void);
int     DLL_EXPORT ETGetHardwareVersion(char* pszDump);
int     DLL_EXPORT ETGetJET210Mode(void);
int     DLL_EXPORT ETGetLibVersion(char* pszDescription, char* pszVersion);
int     DLL_EXPORT ETGetLinkStatus(void);
int     DLL_EXPORT ETGetPreamble(void);
int     DLL_EXPORT ETGetReceiveTrigger(TriggerStructure* pRStruct);
int     DLL_EXPORT ETGetRun(void);
int     DLL_EXPORT ETGetSel(void);
int     DLL_EXPORT ETGetSerialNumber(char* pszDump);
int     DLL_EXPORT ETGetSwitch(SwitchStructure* pSStruct);
int     DLL_EXPORT ETGetTransmitTrigger(TriggerStructure* pTStruct);
int     DLL_EXPORT ETGetVFDRun(void);
int     DLL_EXPORT ETLink(int iComPort);
int     DLL_EXPORT ETSocketLink(char* szIPAddr, int iTCPport);
int 	DLL_EXPORT ETSocketLinkRsvNone(char* szIPAddr, int iTCPPort);
int     DLL_EXPORT ETDebugLink(int iComPort,unsigned long ulType,char* pszFile);
int     DLL_EXPORT ETLoopback(int iPort, int iStatus);
int     DLL_EXPORT ETLNM(int);
int     DLL_EXPORT ETGetLNM(void);
int     DLL_EXPORT ETMFCounter(int iPort, int iMode);
int     DLL_EXPORT ETPreamble(int iCount);
int     DLL_EXPORT ETReceiveTrigger(TriggerStructure* pRStruct);
int     DLL_EXPORT ETRemote(int iMode);
int     DLL_EXPORT ETReset(void);
int     DLL_EXPORT ETResume(void);
int     DLL_EXPORT ETRun(int iRunValue);
int     DLL_EXPORT ETSetBaud(int iBaud);
int     DLL_EXPORT ETSetCurrentLink(int ComPort);
int     DLL_EXPORT ETSetCurrentSockLink(char* IPAddr);
int		DLL_EXPORT ETSetCurrentLinkByIndex(int iIndex);
int     DLL_EXPORT ETSetJET210Mode(int iMode);
int     DLL_EXPORT ETSetSel(int iSelValue);
int     DLL_EXPORT ETSetTimeout(unsigned uiTimeOutValue);
int		DLL_EXPORT NSSetIdleMax(unsigned long ulIdleSeconds);
int     DLL_EXPORT ETSetup(int iMode, int iSetupId);
int     DLL_EXPORT ETTransmitCRC(int iActive);
int     DLL_EXPORT ETTransmitTrigger(TriggerStructure* pTStruct);
int     DLL_EXPORT ETUnLink(void);
int     DLL_EXPORT ETUnLinkAll(void);
int     DLL_EXPORT ETVFDParams(VFDStructure* pVFDdata);
int     DLL_EXPORT ETVFDRun(int iStart);
int     DLL_EXPORT NSSetControllerID(int iControllerID);
int     DLL_EXPORT NSClearURLTable();
int     DLL_EXPORT NSClearURITable();
int     DLL_EXPORT NSClearCookieTable();
int     DLL_EXPORT NSClearAgentTable();
int		DLL_EXPORT NSClearURLObjLenTable();
 
/* Card commands for Hub Ports */

int     DLL_EXPORT HTAlign(int iMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTBurstCount(long lVal,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTBurstGap(long lSize, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTBurstGapAndScale(long lSize, int iScale, int iHub, int iSlot, int iPort);
int	  	DLL_EXPORT HTCardModels(int iCardModels[MAX_HUBS][MAX_SLOTS]);
int	  	DLL_EXPORT HTGetCardModel(char* pszCardModel, int iHub, int iSlot, int Port );
int     DLL_EXPORT HTClear(int iHub);
int     DLL_EXPORT HTClearPort(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTCollision(CollisionStructure* pCS, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTCollisionBackoffAggressiveness(unsigned int uiAggressiveness, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTCRC(int iMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTDataLength(int iLength, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTDribble(int iMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTDuplexMode(int iMode,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetSpeed(int iSpeed,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTFillPattern(int iSize, int* piData, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTModifyFillPattern(int iOffset, int iSize, int* piData, int iHub,int iSlot, int iPort);
int     DLL_EXPORT HTFindMIIAddress(unsigned int* puiAddress, unsigned short* puiControlBits, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGap(long lSize, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGapAndScale(long lSize, int iScale, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGapScaleAndMode(long lSize, int iScale, int iGapMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetBuiltInAddress(int* piMACAddress, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetCounters(HTCountStructure* pHStruct, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetEnhancedCounters(EnhancedCounterStructure *pEnCounterStructure , int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetEnhancedStatus(long *piData , int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetHWVersion(unsigned long *pulFirm, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetHubLEDs(int iHub, int* pLEDS);
int     DLL_EXPORT HTGetLEDs(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGroupStart(int iHub);
int     DLL_EXPORT HTGroupStep(int iHub);
int     DLL_EXPORT HTGroupStop(int iHub);
int     DLL_EXPORT HTHubId(char Data[MAX_HUBS][MAX_SLOTS][MAX_PORTS]);
int     DLL_EXPORT HTHubSlotPorts(int PortTypes[MAX_HUBS][MAX_SLOTS][MAX_PORTS]);
int     DLL_EXPORT HTLatency(int Mode, HTLatencyStructure* htLat, int Hub, int Slot, int Port);
int     DLL_EXPORT HTMultiBurstCount(long lVal,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTPortType(int iHub, int iSlot, int iPort);
int		DLL_EXPORT HTPortTypeChar(char* cType, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTPortProperty(unsigned long* pulProperties,int iHub, int iSlot, int iPort);
long	  DLL_EXPORT HTPortAttribute(unsigned long ulAttribute, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTMinAcceptableLength(int Hub, int Slot, int Port);
int     DLL_EXPORT HTMaxAcceptableLength(int Hub, int Slot, int Port);
int     DLL_EXPORT HTMinAllowableLength(int Hub, int Slot, int Port);
int     DLL_EXPORT HTMaxAllowableLength(int Hub, int Slot, int Port);
long    DLL_EXPORT HTMinAcceptableGap(int Hub, int Slot, int Port);
long    DLL_EXPORT HTMaxAcceptableGap(int Hub, int Slot, int Port);
long    DLL_EXPORT HTMinAllowableGap(int Hub, int Slot, int Port);
long    DLL_EXPORT HTMaxAllowableGap(int Hub, int Slot, int Port);
long    DLL_EXPORT HTMinGapIncrement(int Hub, int Slot, int Port);

int     DLL_EXPORT HTReadMII(unsigned int uiAddress, unsigned int uiRegister, unsigned short* puiBits, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTResetPort(int iResetType, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTRun(int iMode, int iHub, int iSlot, int iPort);

int     DLL_EXPORT HTSelectReceive(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSelectTransmit(int Mode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSendCommand(int iState);
int     DLL_EXPORT HTSeparateHubCommands(int iFlag);

int     DLL_EXPORT HTSetStructure(int iType1,int iType2,int iType3,int iType4,void* pData,unsigned int uiLen, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTGetStructure(int iType1,int iType2,int iType3,int iType4,void* pData,unsigned int uiLen, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetCommand(  int iType1,int iType2,int iType3,int iType4,void* pData,int iHub, int iSlot, int iPort);

int     DLL_EXPORT HGSetStructure(int iType1,int iType2,int iType3,int iType4,void* pData,unsigned int uiLen);
int     DLL_EXPORT HGSetCommand(  int iType1,int iType2,int iType3,int iType4,void* pData);

int     DLL_EXPORT HTDefaultStructure(int iType1,void* pData,unsigned int uiLen, int iHub, int iSlot, int iPort);

int		DLL_EXPORT HTGetTypeStrings(int iType1, int iHub, int iSlot, int iPort, char* szType, char* szDataType);

unsigned int DLL_EXPORT HTGetStructureSize(int iType1, int iHub, int iSlot, int iPort);
unsigned int DLL_EXPORT HTGetStructSize(int iType1, int iType2, int iType3, int iType4, int iHub, int iSlot, int iPort);

int     DLL_EXPORT ETIsSyncCapable(void);
int		DLL_EXPORT ETSetGPSActionTime(char* szDate, char* szTime);
int		DLL_EXPORT ETSetGPSActionTimeWithDelay(char* szDate, char* szTime, unsigned long ulDelaySeconds);
int		DLL_EXPORT ETGetGPSTime(char* szDate, char* szTime);
int     DLL_EXPORT HTGetStandardFWVersion(FirmwareVersionStructure* pIn, int iHub, int iSlot, int iPort );
int     DLL_EXPORT HTGetCardFWVersion(CardFWVersionStructure* pIn, int iHub, int iSlot, int iPort );

/* TokenRing Specific */

int     DLL_EXPORT HTSetTokenRingProperty(TokenRingPropertyStructure* pTRPStructure,int iHub,int iSlot,int iPort);
int     DLL_EXPORT HTSetTokenRingErrors(int ErrorTrafficRatio,unsigned int TRErrors, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetTokenRingLLC(TokenRingLLCStructure* pTRLStructure, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetTokenRingMAC(TokenRingMACStructure* pTRMStructure, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetTokenRingSrcRouteAddr(int UseSRA, int* pData, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSetTokenRingAdvancedControl(TokenRingAdvancedStructure *pTRAdvancedStructure,int iHub, int iSlot, int iPort);

/* VG specific */

int     DLL_EXPORT HTSetVGProperty(VGCardPropertyStructure* pVGPStructure,int iHub,int iSlot,int iPort);

int     DLL_EXPORT HTSymbol(int iMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTTransmitMode(int iMode,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTScheduleMode(int iMode,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTTrigger(int iTrigId, int iConfig, HTTriggerStructure* pTStruct, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTTriggerAndMask(int TrigIdNum, int* pTrigIdLst, TriggerMaskStructure* pTMStruct, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTVFD(int iVFDId, HTVFDStructure* pVStruct, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTWriteMII(unsigned int uiAddress, unsigned int uiRegister, unsigned short uiBits, int iHub, int iSlot, int iPort);

/* The Hub Tester Port "Group" commands for PortId assignments */

int     DLL_EXPORT HGStartSetGroup(void);
int     DLL_EXPORT HGSetGroup(char* pszPortIdList);
int     DLL_EXPORT HGClearGroup(void);
int     DLL_EXPORT HGSetGroupType(int SubTypesMode, int * Data);
int     DLL_EXPORT HGAddtoGroup(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HGRemoveFromGroup(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HGRemovePortIdFromGroup(int iPortId);
int     DLL_EXPORT HGEndSetGroup(void);
int     DLL_EXPORT HGIsPortInGroup(int iPortId);
int     DLL_EXPORT HGIsHubSlotPortInGroup(int iHub, int iSlot, int iPort);
int     DLL_EXPORT HGGetGroupCount(void);
int     DLL_EXPORT HGSetCurrentGroupName(char* szGroupName);

int     DLL_EXPORT HGClear(void);
int     DLL_EXPORT HGGetLEDs(int* piLEDS);
int     DLL_EXPORT HGSelectTransmit(int iMode);
int     DLL_EXPORT HGClearPort(void);
int     DLL_EXPORT HGGetCounters(HTCountStructure* pHCountStruct);
int     DLL_EXPORT HGGetEnhancedCounters(EnhancedCounterStructure *pEnCounterStructure);
int     DLL_EXPORT HGFillPattern(int iSize, int* piData);
int     DLL_EXPORT HGModifyFillPattern(int iOffset, int iSize, int* piData);
int     DLL_EXPORT HGGap(long lSize);
int     DLL_EXPORT HGGapAndScale(long lSize, int iScale);
int     DLL_EXPORT HGGapScaleAndMode(long lSize, int iScale, int iGapMode);
int     DLL_EXPORT HGTransmitMode(int iMode);
int     DLL_EXPORT HGScheduleMode(int iMode);
int     DLL_EXPORT HGBurstCount(long lVal);
int     DLL_EXPORT HGMultiBurstCount(long lVal);
int     DLL_EXPORT HGBurstGap(long lSize);
int     DLL_EXPORT HGBurstGapAndScale(long lSize, int iScale);
int     DLL_EXPORT HGDataLength(int iLength);
int     DLL_EXPORT HGDuplexMode(int iMode);
int	  DLL_EXPORT HGResetPort(int iResetType);
int     DLL_EXPORT HGRun(int iMode);
int     DLL_EXPORT HGStart(void);
int     DLL_EXPORT HGStep(void);
int     DLL_EXPORT HGStop(void);
int	  DLL_EXPORT HGRunFixedTime(unsigned long ulSeconds);
int	  DLL_EXPORT HGRunGPSDelay(int iMode, unsigned long ulDelaySeconds);
int     DLL_EXPORT HGSetGroupBehavior(int iMode);
int     DLL_EXPORT HGTrigger(int iTrigId, int iConfig, HTTriggerStructure* pTStruct);
int     DLL_EXPORT HGTriggerAndMask(int TrigIdNum, int* pTrigIdLst,TriggerMaskStructure* pTMStruct);
int     DLL_EXPORT HGVFD(int iVFDId, HTVFDStructure* pVStruct);
int     DLL_EXPORT HGCollisionBackoffAggressiveness(unsigned int uiAggressiveness);
int     DLL_EXPORT HGWriteMII(unsigned int uiAddress, unsigned int uiRegister, unsigned short uiBits);
int	  DLL_EXPORT HGSendCardData(	unsigned short uiFunctionCode, void* pData, unsigned long ulLen,
								unsigned long ulOffset, unsigned long ulTotalLen);

/* TokenRing specific */

int     DLL_EXPORT HGSetTokenRingProperty(TokenRingPropertyStructure* pTRPStructure);
int     DLL_EXPORT HGSetTokenRingErrors(int ErrorTrafficRatio,unsigned int TRErrors);
int     DLL_EXPORT HGSetTokenRingLLC(TokenRingLLCStructure* pTRLStructure);
int     DLL_EXPORT HGSetTokenRingMAC(TokenRingMACStructure* pTRMStructure);
int     DLL_EXPORT HGSetTokenRingSrcRouteAddr(int UseSRA, int* piData);
int     DLL_EXPORT HGSetTokenRingAdvancedControl(TokenRingAdvancedStructure *pTRAdvancedStructure);

/* VG specific */

int     DLL_EXPORT HGSetVGProperty(VGCardPropertyStructure* pVGPStructure);

/* Card error condition commands */

int     DLL_EXPORT HGAlign(int iMode);
int     DLL_EXPORT HGCRC(int iMode);
int     DLL_EXPORT HGDribble(int iMode);
int     DLL_EXPORT HGSymbol(int iMode);
int     DLL_EXPORT HGCollision(CollisionStructure* pCS);


/* Multi-user functions */
int 		DLL_EXPORT HTSlotReserve(int iHub, int iSlot);
int 		DLL_EXPORT HTSlotRelease(int iHub, int iSlot);
int		DLL_EXPORT HTSlotOwnership(int iHub, int iSlot);
int		DLL_EXPORT NSGetMultiUserCapability(void);
int		DLL_EXPORT HTSlotSharingInfo(HTSlotSharingStructure *pSlotSharingStructure, int iHub, int iSlot);

/* Command to reset the card */
int DLL_EXPORT HTSlotReboot(int iHub, int iSlot);

/* Port mapping functions */
int		DLL_EXPORT NSSetPortMappingMode(int iMode);

int		DLL_EXPORT NSGetMaxHubs(void);
int		DLL_EXPORT NSGetMaxSlots(void);
int     DLL_EXPORT NSGetMaxPorts(void);

int     DLL_EXPORT NSGetNumHubs(void);
int     DLL_EXPORT NSGetNumSlots(int iHub);
int     DLL_EXPORT NSGetNumPorts(int iHub, int iSlot);
int		DLL_EXPORT NSGetChannelId(int iLineNo,int iChannelNo);

int 	DLL_EXPORT HTMapUserToNative(int iHubUser, int iSlotUser, int iPortUser, int* piHubNative, int* piSlotNative, int* piPortNative);
int		DLL_EXPORT HTMapNativeToUser(int iHubNative, int iSlotNative, int iPortNative, int* piHubUser, int* piSlotUser, int* piPortUser);

/* NS Frames functions */
long int DLL_EXPORT NSCreateFrame( FrameSpec_Type* framespec );
long int DLL_EXPORT NSSetPayload( long int iFrameID, int iSize, unsigned char* pucPayload );
long int DLL_EXPORT HTFrame( long int iFrameID, int iHub, int iSlot, int iPort,
                                 unsigned short uiStreamIndex);
long int DLL_EXPORT NSDeleteFrame( long int iFrameID );
long int DLL_EXPORT NSCreateFrameAndPayload( FrameSpec_Type* framespec,
               int iPayloadSize, unsigned char* pucPayload );
long int DLL_EXPORT NSModifyFrame( long int lFrameID, int iIdentifier,
                                    unsigned char* pucBytes, int iNumBytes );
int     DLL_EXPORT NSGetControllerFWVersion(char* pszDump);

/* Get last error */
int     DLL_EXPORT NSGetAllLastError(NSErrorList* pErrorList);
int     DLL_EXPORT NSGetLastError(NSErrorEntry* pErrorEntry);

/* GPS/sync-related functions */
int		DLL_EXPORT ETSetGPSDelay(unsigned long ulSeconds);
int		DLL_EXPORT NSGetSyncMode(void);
int		DLL_EXPORT NSGetGPSStatus(void);

/* Other new "system" functions */
int		DLL_EXPORT NSSocketLink(char* szIPAddr, int iTCPPort, int iReserve);
int 		DLL_EXPORT NSUnLink(void);
int		DLL_EXPORT NSUnLinkAll(void);
int		DLL_EXPORT NSSendKeepAlive(void);



/* IP Forward command */
int		DLL_EXPORT NSIPForwardLink(char* IPAddr, int iHub, int iSlot);
int		DLL_EXPORT NSIPForwardUnLink(int iHub, int iSlot);
int		DLL_EXPORT HTIPForwardLink(IPForwardConfig *pIPForward, int iHub, int iSlot);
int		DLL_EXPORT HTIPForwardUnLink(int iHub, int iSlot);

int		DLL_EXPORT NSSetDefaultsFile(char* szFileName);
int		DLL_EXPORT NSDelay(unsigned long ulSeconds);

int		DLL_EXPORT NSGetDetailedLibVersion(NSDetailedLibVersionStructure* pVersion);

int		DLL_EXPORT NSRebootChassis(int iHub);
int		DLL_EXPORT NSLoginSuperUser(char* szPassword);
int		DLL_EXPORT NSLogoutSuperUser(void);

int      DLL_EXPORT HTGetSlotUserInfo(SlotUserInfo* pUserInfo,int iHub,int iSlot);

/* NTP function */
int DLL_EXPORT NSNTPEnterMode(void);
int DLL_EXPORT NSNTPExitMode(void);
int DLL_EXPORT NSNTPSetClientMode(unsigned long ulMode); 
int DLL_EXPORT NSNTPSetFFOMLimit(unsigned long ulFFOMLimit);
int DLL_EXPORT NSNTPSetTFOMLimit(unsigned long ulTFOMLimit);
int DLL_EXPORT NSNTPAddPeer(NSIPAddress* pIPAddress);
int DLL_EXPORT NSNTPDeletePeer(NSIPAddress* pIPAddress);
int DLL_EXPORT NSNTPDeleteAllPeers(void);
int DLL_EXPORT NSNTPGetClientMode(unsigned long* pulMode);
int DLL_EXPORT NSNTPGetFOM(NSNTPFOMInfo* pNTPFOMInfo);
int DLL_EXPORT NSNTPGetPeerList(NSNTPPeerListInfo* pNTPPeerListInfo);
int DLL_EXPORT NSNTPGetClientStatusCount(unsigned long* pulStatusCount);
int DLL_EXPORT NSNTPGetClientStatus(unsigned long ulStatusCount, NSNTPStatusInfo* pStatus);
int DLL_EXPORT NSNTPGetPeerStatusCount(NSIPAddress* pIPAddress, unsigned long* pulStatusCount);
int DLL_EXPORT NSNTPGetPeerStatus(NSIPAddress* pIPAddress, unsigned long ulStatusCount, NSNTPStatusInfo* pStatus);

int DLL_EXPORT NSSaveControllerConfiguration(void);
int DLL_EXPORT NSSetControllerGateway(NSIPAddress* pIPAddress);
int DLL_EXPORT NSSetControllerNetmask(NSIPAddress* pIPAddress);

/* Command for Log File  */
int		DLL_EXPORT NSCommandMode(int iCommandMode);

/* Command for Rate calculator */
int		DLL_EXPORT NSCalculateGap(int iMode, int iSpeed, 
										unsigned long ulPacketLength,
										double dValue,
										unsigned long *pulGap,
										int iHub, int iSlot, int iPort);

/* Command to set the time out value used when establishing a socket connection */
int DLL_EXPORT NSSetSocketLinkTimeOut(unsigned long ulSeconds);

/* Command to debug console*/
int DLL_EXPORT NSDebugConsole(char *szCommand,int iHub,int iSlot,int iPort);

/* CM related commands */
int	DLL_EXPORT NSSetNonBlockingMode(int iMode);
int	DLL_EXPORT NSWaitForResponse(void);
int   DLL_EXPORT NSReportError(NSReportErrorList* pErrorList);
int   DLL_EXPORT NSReportFirstError(NSReportErrorEntry* pErrorEntry);
int	DLL_EXPORT NSSetMaxNonBlockingCallsBeforeErrorCheck(unsigned long ulMaxNBCalls);
int	DLL_EXPORT NSSetKeepAliveInterval(unsigned long ulIntervalInSec);

/* NS stream configuration commands */
int DLL_EXPORT NSCreateStreamConfigObject(void);
int DLL_EXPORT NSDeleteStreamConfigObject(int iStreamConfigID);
int DLL_EXPORT NSCreateStream(NSStreamConfig* pStream);
int DLL_EXPORT NSCopyStream(NSCopyStreamInfo* pCopy);
int DLL_EXPORT NSGetStreamCount(int iStreamConfigID);
int DLL_EXPORT NSCreateProtocolHeader(NSCreateHeaderInfo* pHeaderInfo, void* pHeaderData, unsigned int uiHeaderSize);
int DLL_EXPORT NSUpdateProtocolHeader(NSUpdateHeaderInfo* pUpdate, void* pHeaderData, unsigned int uiHeaderSize);
int DLL_EXPORT NSCopyProtocolHeader(NSCopyHeaderInfo* pCopy, void* pHeaderData);
int DLL_EXPORT NSGetProtocolHeader(NSGetHeaderInfo* pGet, void* pHeaderData, unsigned int uiHeaderSize);
int DLL_EXPORT NSGetProtocolHeaderStackInfo(NSHeaderStackInfo* pProtocolInfo);
int DLL_EXPORT NSUpdateTxConfig(NSUpdateTxConfigInfo* pUpdate, NSTxConfig* pTxConfigData, unsigned int uiTxConfigSize);
int DLL_EXPORT NSCopyTxConfig(NSCopyTxConfigInfo* pCopy, NSTxConfig* pTxConfigData);
int DLL_EXPORT NSGetTxConfig(NSGetTxConfigInfo* pGet, NSTxConfig* pTxConfig, unsigned int uiTxConfigSize);
int DLL_EXPORT NSUpdateVFD(NSUpdateVFDInfo* pUpdate, NSVFDConfig* pVFDConfig, unsigned int uiVFDConfigSize);
int DLL_EXPORT NSGetVFD(NSGetVFDInfo* pGet, NSVFDConfig* pVFDConfig, unsigned int uiVFDConfigSize);
int DLL_EXPORT NSCommitStreamConfigObject(NSCommitStreamConfig* pConfigInfo);
int DLL_EXPORT NSDeleteAllStreams(int iStreamConfigID);

int DLL_EXPORT NSRunTimeHistStatsInfo(NSRunTimeHistStats* pHistStatsInfo, void* pHistData, unsigned int uiHistDataLen,
												  int iHub, int iSlot, int iPort);
/* NSMultiCommandConfig takes 16 arguments, including
   1.  ulCommandArray: an unsigned long array, which contains regular command names to be called
   2.  uiStructSizeArray: an unsigned integer array of the ulCommandArray's corresponding
       structure size
   3.  uiCount: the number of elements to be used from the ulCommandArray and uiStructSizeArray.
       Valid range: 1 - 5 in this release.
   4.  pData1: an void pointer which point to the corresponding structure of ulCommandArray[0] 
   5.  pData2: an void pointer which point to the corresponding structure of ulCommandArray[1]
   6.  pData3: an void pointer which point to the corresponding structure of ulCommandArray[2] 
   7.  pData4: an void pointer which point to the corresponding structure of ulCommandArray[3]
   8.  pData5: an void pointer which point to the corresponding structure of ulCommandArray[4] 
   9.  pData6: an void pointer which point to the corresponding structure of ulCommandArray[5]
       (Reserved)
   10. pData7: an void pointer which point to the corresponding structure of ulCommandArray[6]
       (Reserved)
   11. pData8: an void pointer which point to the corresponding structure of ulCommandArray[7]
      (Reserved)
   12. pData9: an void pointer which point to the corresponding structure of ulCommandArray[8]
      (Reserved)
   13. pData10: an void pointer which point to the corresponding structure of ulCommandArray[9]
      (Reserved)
   14. iHub: Hub number of the port
   15. iSlot: Slot number of the port
   16. iPort: Port number of the port

 NSMultiCommandConfig allows user to send up to 10 different commands/structures with one 
 single library call. In this release, it will only support up to 5 commands/structures
 for the flexible Generic Interface to the Terametrics Receive Engine. The commands can
 only be up to one from each of the 5 groups below (any sequential order is allowed)
 in ulCommandArray. 
     1. NS_HIST_LATENCY_OPTION
     2. NS_ALTERNATE_KEY_CONFIG
     3. NS_ALTERNATE_KEY_HASH_CONFIG
     4. L3_HIST_START
     5. one of any NS_HIST_XX/L3_HIST_XX test configure command with the corresponding
        structures, including

         NS/L3 histogram command name       Structures

         NS_HIST_SEQUENCE_PER_STREAM        N/A
         NS_HIST_COMBO_PER_STREAM	        NSHistLatencyDistPerStream
         NS_HIST_LATENCY_DIST_PER_STREAM	NSHistLatencyDistPerStream
         NS_HIST_RAW_SIGNATURE              N/A
         NS_HIST_LATENCY_OVER_TIME          NSHistLatencyOverTime
         L3_HIST_LATENCY_DISTRIBUTION       Layer3HistDistribution
         L3_HIST_V2_LATENCY_DISTRIBUTION    Layer3V2HistDistribution
         L3_HIST_V2_LATENCY_PER_STREAM      Layer3V2HistDistribution
         L3_HIST_LATENCY                    Layer3HistLatency
         L3_HIST_V2_LATENCY	                Layer3HistLatency
         L3_HIST_SEQUENCE                   N/A
         L3_HIST_RAW_TAGS                   N/A

Note:
   1. uiCount is the number of elements to use from the ulCommandArray and
      uiStructSizeArray. The first zero element in ulCommandArray declares
      the end of valid input from user. Always the first reached criteria
      take the precedence.  
   2. C/C++ interface user should always zero memset the ulCommandArray to
      avoid junk value in the un-used elements of ulCommandArray. 
   3. The configuration of NS_HIST_LATENCY_OPTION/NS_ALTERNATE_KEY_CONFIG/
      NS_ALTERNATE_KEY_HASH_CONFIG won't take effect unless
	  NS_HIST_XX/L3_HIST_XX histogram command is also configured in the
	  same NSMultiCommandConfig command.
*/

int DLL_EXPORT NSMultiCommandConfig(unsigned long ulCommandArray[10],
							 unsigned int uiStructSizeArray[10], unsigned int uiCount,
							 void* pData1, void* pData2, void* pData3, void* pData4,
							 void* pData5, void* pData6, void* pData7, void* pData8,
							 void* pData9, void* pData10,
							 int iHub, int iSlot, int iPort);



int DLL_EXPORT NSDOT1XCreateSubprocess(unsigned long *pulHandle,int iHub, int iSlot);  
int DLL_EXPORT NSDOT1XDestroySubprocess(unsigned long ulHandle,int iHub, int iSlot); 

int DLL_EXPORT NSModStreamArrayConfig(NSModStreamArray *pModStreamArray, unsigned long *ulData,unsigned long ulDataLen,
												   int iHub, int iSlot, int iPort);

int DLL_EXPORT NSFillPattern(unsigned long ulPatternLen, unsigned char *pucPattern,int iHub, int iSlot, int iPort);


int DLL_EXPORT SMBSendCardData(unsigned short uiFunctionCode, void* pData, unsigned long ulLen,
										unsigned long ulOffset, unsigned long ulTotalLen,
										int iHub, int iSlot, int iPort);

int DLL_EXPORT NSStreamMultiConfig(
						NSStreamMultiConfigInfo* pStreamMultiConfigInfo,
						void* pHeaderData1, void* pHeaderData2, void* pHeaderData3, void* pHeaderData4,
						void* pHeaderData5, void* pHeaderData6, void* pHeaderData7, void* pHeaderData8,
						void* pHeaderData9, void* pHeaderData10, void* pHeaderData11, void* pHeaderData12,	
						void* pHeaderData13, void* pHeaderData14, void* pHeaderData15, void* pHeaderData16,
						int iHub, int iSlot, int iPort);

int DLL_EXPORT NSEnhancedRunTimeHistStatsInfo (unsigned long ulCounterType,  unsigned long *pulNumRecords,  
						  NSEnhancedRunTimeHistStats *pEnhancedRunTimeHistStats, unsigned long ulDataLen,
						  int iHub, int iSlot, int iPort);

int DLL_EXPORT NSMultiChassisCardInfo(NSChassisCardInfo* pNSChassisCardInfo,  int iCount);
int DLL_EXPORT NSMultiSlotReserve(NSSlotInfo* pNSSlotInfo, int iCount);
int DLL_EXPORT NSMultiSlotRelease(NSSlotInfo* pNSSlotInfo, int iCount);
int DLL_EXPORT NSMultiSlotOwnership(NSSlotInfo* pNSSlotInfo,  int iCount);
int DLL_EXPORT NSGetMultiCaptureData(NSMultiCaptureDataInfo *pMultiCapInfo, unsigned char *ucData,
									 unsigned long ulDataLenInKB, int iHub, int iSlot, int iPort);

#if defined WIN16 || defined WIN32
typedef short (CALLBACK * NSErrorCallbackFunc)(int iError, char* szDescription);
#else
typedef short (*NSErrorCallbackFunc)(int iError, char* szDescription);
#endif

int		DLL_EXPORT NSSetErrorCallback(NSErrorCallbackFunc ErrorCallback);


#if defined MS_DOS
int     DLL_EXPORT ETGetLSR(void);
int     DLL_EXPORT ETGetLSRIntCount(void);
int     DLL_EXPORT ETGetLSRHistory(void);
#endif

int     DLL_EXPORT ETEraseFlash(int iSecurity);            /* CAUTION!!! */
int     DLL_EXPORT ETLoadHex(char* pszHex, int iSecurity); /* CAUTION!!! */
int     DLL_EXPORT ETDiagReset(void);
int     DLL_EXPORT ETReadChar(void);
int     DLL_EXPORT ETSendRecv(const char* pszOutput,char* pszInput,int iInputSize,char* pszDelimiter);
int     DLL_EXPORT ETSetXonXoff(BOOL);
int     DLL_EXPORT ETGetXonXoff(void);
int     DLL_EXPORT ETIsBackgroundProcessing(void);
int     DLL_EXPORT ETEnableBackgroundProcessing(BOOL bFlag);
int     DLL_EXPORT ETCommandLog(unsigned long ulType,char* pszFile);
int     DLL_EXPORT ETCommandComment(char* szComment);
int	  DLL_EXPORT NSGetFlashData(NSFlashData* pFlash, int iHub);

/* debug commands only, for direct firmware communication */
int DLL_EXPORT ETSendString(char* pszString,char* pszDelimiter);
int DLL_EXPORT SMBFunction(unsigned short uiFunctionCode, int iDest,
									int iHub, int iSlot, int iPort,
									unsigned char* pSendData, unsigned long ulSendLen,
									unsigned char* pRecvData, unsigned long ulRecvLen);
/* Equivalent to SMBFunction */
int DLL_EXPORT NSSendData(unsigned short uiFunctionCode, int iDest,
									int iHub, int iSlot, int iPort,
									unsigned char* pSendData, unsigned long ulSendLen,
									unsigned char* pRecvData, unsigned long ulRecvLen);

#if defined WIN16 || defined WIN32
int     			DLL_EXPORT ETCommandWindow(HWND hwCmdMessage, UINT uiMessage);
unsigned long	DLL_EXPORT ETReturnAddress(void* pVoid);
#endif

int     			DLL_EXPORT ETAuthorization(int iProduct);

#ifdef __APPARENTLY_UNDEFINED__
int     DLL_EXPORT ETRcvLED(int iType);
int     DLL_EXPORT ETTrigLED(int iType);

/* ET1000 built-in tests */

long    DLL_EXPORT ETBridgeTest(int iTestId);
long    DLL_EXPORT ETRepeaterTest(int iTestId);
long    DLL_EXPORT ETTransceiverTest(int iTestId);

#endif

#ifdef __cplusplus
};
#endif

/*
 OBSOLETE functions and structures. The following section is only provided for
 backward compatibility. The items in this section will not be supported in
 future revs of this product. Adjust any programs to make use of the newer
 functions described above.
*/

#define	CM_L3_7505				CM_L3_6705

#define	CM_LAN_6100				CM_LAN_3100

#define	CM_LAN_6101				CM_LAN_3101
#define	CM_LAN_6101A			CM_LAN_3101A
#define	CM_LAN_6101B			CM_LAN_3101B

#define	CM_LAN_6200				CM_LAN_3200
#define	CM_LAN_6201A			CM_LAN_3201A
#define	CM_LAN_6201B			CM_LAN_3201B
#define	CM_LAN_6300A			CM_LAN_3300A
#define	CM_LAN_6301A			CM_LAN_3301A
#define	CM_LAN_6302A			CM_LAN_3302A
#define	CM_LAN_6310A			CM_LAN_3310A
#define	CM_LAN_6311A			CM_LAN_3311A
#define	CM_POS_6500A			CM_POS_3500A
#define	CM_POS_6500B			CM_POS_3500B
#define	CM_POS_6502A			CM_POS_3502A
#define	CM_POS_6504A			CM_POS_3504A
#define	CM_POS_6505A			CM_POS_3505A





/* ------- OLD HTSeparateHubCommands parameters ------------ */
/* Replaced by constants above because these names are misleading. */
#define HUB_DEFAULT_ACTION			0
#define HUB_ACT_AS_LINK_UNIT		1
#define HUB_ACT_INDEPENDENTLY		2
#define HUB_ACT_AS_MASTER			3


typedef struct
	{
	int Hub;
	int TransmitSlot;
	int ReceiveSlot[20];
	int Offset;
	int Range;
	unsigned char Pattern[12];
	} SetLatencyStructure;

#ifdef __cplusplus
extern "C" {
#endif

int     DLL_EXPORT ETSetIdleMax(char* pszString,char* pszDelimiter);
int     DLL_EXPORT HTBurst(long lVal,int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTEcho(int iMode, int iHub, int iSlot, int iPort);
int     DLL_EXPORT HTSelectReceivePort(int iPortId);
int     DLL_EXPORT HTSelectTMTPort(int iPortId, int iMode);
int     DLL_EXPORT HTSetLED(int iPortId, int iColor);
int     DLL_EXPORT HTGroup(int iHub, char* pszGroupString);

int     DLL_EXPORT HGBurst(long lVal);
int     DLL_EXPORT HGEcho(int iMode);
int     DLL_EXPORT HGSelectReceivePort(int PortId);
int     DLL_EXPORT HGSelectTMTPort(int iMode);
int     DLL_EXPORT HGSetLED(int iColor);
int     DLL_EXPORT HGSetSpeed(int iSpeed);

int     DLL_EXPORT HTLatencyTest(SetLatencyStructure* pLS, unsigned long* pulData, int iMode);

int     DLL_EXPORT HTLayer3SetAddress(Layer3Address* pLayer3Address,int iHub,int iSlot,int iPort);
int     DLL_EXPORT HTLayer3GetAddress(Layer3Address* pLayer3Address,int iHub,int iSlot,int iPort);

int	  DLL_EXPORT HTTcpRecordCount(int iType1, int iType2, int iType3, int iType4,	int iHub, int iSlot, int iPort);

#ifdef __cplusplus
};
#endif

#if   defined WIN32
#include <poppack.h>
#endif

#endif


