/************************************************************************
 *	Netcom Systems, Inc.

 *	file: fcitems.h
 *	Fibre Channel SmartCard Configuration definitions

 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (C) 1993-2000. All Rights Reserved.
 ************************************************************************/

#ifndef  _FCITEMS_H_
#define  _FCITEMS_H_

#include "ettypes.h"
#include "l3items.h"

#define FC_CARD_BASE 0x3500 

/****************************************************************************/
/*  iType1 values                                                           */
/****************************************************************************/
#define FC_PORT_CONFIG				(FC_CARD_BASE + 0x01)  /* Configure Fibre Channel Port Parameters */
#define FC_PORT_CONFIG_INFO		(FC_CARD_BASE + 0x02)  /* Get Fibre Channel Port Config Parameters */
#define FC_COUNTER_INFO				(FC_CARD_BASE + 0x05)  /* Get Generic and Fibre Channel Counters */
#define FC_STATUS_INFO				(FC_CARD_BASE + 0x08)  /* Get Port Link Status */
#define FC_LINKUP						(FC_CARD_BASE + 0x09)  /* Command to initiate Linkup Procedure */	
#define FC_WWN_LOGIN					(FC_CARD_BASE + 0x0A)  /* Command to perform fabric login */
#define FC_PUBLIC_DISCOVERY		(FC_CARD_BASE + 0x0B)  /* Command to initiate public login */
#define FC_PRIVATE_DISCOVERY		(FC_CARD_BASE + 0x0C)  /* Command to initiate private discovery */
#define FC_COMMIT						(FC_CARD_BASE + 0x0D)  /* Command to complete init/config phase */
#define FC_WWN_COUNT_INFO			(FC_CARD_BASE + 0x10)  /* Get number of WWNs configured on a port */
#define FC_DEFINE_HEADER			(FC_CARD_BASE + 0x11)  /* Configure Fibre Channel Stream data */
#define FC_DEFINE_HEADER_INFO		(FC_CARD_BASE + 0x13)  /* Retrieve the Fibre Channel header information for one or more streams.  Passing an array of FCConfig structures will allow for retrieval of header information for multiple streams. */
#define FC_WWN_INFO					(FC_CARD_BASE + 0x14)  /* Get Fibre Channel emulated Nodes/Devices info */
#define FC_WWN							(FC_CARD_BASE + 0x15)  /* Configure Fibre Channel emulated Nodes/Devices */ 
#define FC_DEFINE_STREAM			(FC_CARD_BASE + 0x16)  /* Create FC Stream and its header information */

#define FC_SET_TX_MODE				(FC_CARD_BASE + 0x17)  /* Set the transmit mode on the card */
#define FC_SEND_CUSTOM				(FC_CARD_BASE + 0x18)  /* Send a frame on cut-through channel */
#define FC_RECV_CUSTOM				(FC_CARD_BASE + 0x19)  /* Receive a frame on the cut-through channel */
#define FC_DEFINE_STREAM_128		(FC_CARD_BASE + 0x20)  /* Create FC Stream and its header information */
#define FC_GET_TX_MODE				(FC_CARD_BASE + 0x21)  /* Read the transmit mode the card is in */
#define FC_MOD_STREAM				(FC_CARD_BASE + 0x22)  /* Overwrite one Fibre Channel Stream in the list at a given index. */
#define FC_DEFINE_MULTI_STREAM	(FC_CARD_BASE + 0x23)  /* Append similar copies of a Fibre Channel Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */

#define FC_FLOGI						(FC_CARD_BASE + 0x30)  /* Send an FLOGI Frame	*/
#define FC_PLOGI						(FC_CARD_BASE + 0x31)  /* Send a PLOGI Frame		*/
#define FC_PORT_NAME_REQUEST		(FC_CARD_BASE + 0x32)  /* Send a RPN_ID Frame	*/
#define FC_LOGO						(FC_CARD_BASE + 0x33)  /* Send a LOGO Frame		*/
#define FC_NAME_SERVER_QUERY		(FC_CARD_BASE + 0x34)  /* Send a NSQ Frmae		*/
#define FC_PORT_ID_QUERY			(FC_CARD_BASE + 0x35)  /* Send a GID_PN Frame	*/
#define FC_COS_QUERY					(FC_CARD_BASE + 0x36)  /* Send a GCOS_ID Frame	*/
#define FC_STATE_CHNG_REQUEST		(FC_CARD_BASE + 0x37)  /* Send a SCN Frame		*/

#define FC_LINK_DOWN					(FC_CARD_BASE + 0x38)  /* Command to bring the Link Down */	

#define FC_HBA_CONFIG				(FC_CARD_BASE + 0x39)  /* Configure the timer parameters of the HBA simulation */
#define FC_HBA_MODE_START			(FC_CARD_BASE + 0x40)  /* Put the FBC card into the HBA simulation mode */
#define FC_HBA_MODE_STOP			(FC_CARD_BASE + 0x41)  /* Take out the FBC card out of the HBA simulation mode */

/* SRT Application Section */
#define FC_FSPF_CONFIG						(FC_CARD_BASE + 0x50)	/* Configure FSPF parameters	*/
#define FC_FSPF_CONFIG_INFO				(FC_CARD_BASE + 0x51)	/* Read back FSPF parameters	*/
#define FC_MULTI_SWITCH_CONFIG			(FC_CARD_BASE + 0x52)	/* Configure multiple switches*/
#define FC_MULTI_SWITCH_CONFIG_INFO		(FC_CARD_BASE + 0x53)	/* Read back multiple switches*/
#define FC_FABRIC_LINK_CONFIG				(FC_CARD_BASE + 0x54)	/* Configure Fabric links		*/
#define FC_FABRIC_LINK_CONFIG_INFO		(FC_CARD_BASE + 0x55)	/* Read back Fabric links		*/
#define FC_SWITCH_MULTI_LINK_CONFIG		(FC_CARD_BASE + 0x56)	/* Configure multiples links	*/
#define FC_SWITCH_MULTI_LINK_CONFIG_INFO	(FC_CARD_BASE + 0x57)/* Read back multiples links	*/
#define FC_FSPF_STATS_CONFIG				(FC_CARD_BASE + 0x58)	/* Configure what stats to get*/
#define FC_FSPF_STATS_CONFIG_INFO		(FC_CARD_BASE + 0x59)	/* Read back the stats set		*/
#define FC_FSPF_START						(FC_CARD_BASE + 0x60)	/* Start the FSPF stack			*/
#define FC_FSPF_SHUTDOWN					(FC_CARD_BASE + 0x61)	/* Shut down the FSPF stack	*/
#define FC_FSPF_STATS_INFO					(FC_CARD_BASE + 0x62)	/* Get the statistics for FSPF*/
#define FC_FSPF_REAL_TIME_STATS_INFO	(FC_CARD_BASE + 0x63)	/* Get real time stats results*/
#define FC_NODE_CONFIG					(FC_CARD_BASE + 0x64)	/* To configure end nodes for a particular switch. */
#define FC_NODE_CONFIG_INFO				(FC_CARD_BASE + 0x65)	/* To query information for all nodes for a particular switch */
#define FC_NAME_SERVER_EVENT_CONFIG		(FC_CARD_BASE + 0x66)	/* To make the name server component
                                                               send a particular query out to the DUT. */

#define FC_NAME_SERVER_STATS_INFO		(FC_CARD_BASE + 0x67)	/* To collect name server stats.*/
#define FC_EPORT_SETTING_CONFIG			(FC_CARD_BASE + 0x68)	/* To configure the e-port settings. */
#define FC_EPORT_SETTING_CONFIG_INFO	(FC_CARD_BASE + 0x69)	/* To query the e-port settings. */

#define FW_FC_SRT_FSPF_START				0xC940	/* same as FW_FC_FSPF_START		*/
#define FW_FC_SRT_FSPF_SHUTDOWN			0xC941	/* same as FW_FC_FSPF_SHUTDOWN	*/

/* FaST Specific Constants */
#define FW_FC_FS_CONFIG_GROUP			0x7126
#define FW_FC_FS_CONFIG_GROUP_INFO	0x7127
#define FW_FC_FS_RUN_TEST				0x7128
#define FW_FC_FS_QUERY_STATS			0x7129

#define FC_MAX_DEVICES      1000	/* Maximum number of emulated nodes */
#define FC_MAX_NUM_SWITCHES 150	/* Maximum number of switches per port */
#define FC_MAX_NUM_LINKS	 225	/* Maximum number of links per switch */
#define FC_MAX_NUM_DEST_SWITCHES 450 /* Maximum number of destination switches */
#define FC_MAX_NUM_NODES		90  /*Maximum number of nodes can be configured 
                                       with FC_NODE_CONFIG for a particular switch */


/****************************************************************************/
/*  structures to be used with HTSetStructure & HTGetStructure              */
/****************************************************************************/

/******************************************************************************
PORT CONFIG PARAMETERS

 Structure:   FCPortConfig
 iType1:      FC_PORT_CONFIG
 Function:    HTSetStructure
 
FCPortConfig Description:

This structure is used to setup the Fibre Channel card port configuration.
******************************************************************************/
typedef struct tagFCPortConfig
{
	unsigned char  ucTopology;				/* For Point-To-Point use TOPOLOGY_PT_2_PT
														and for LOOP Topology use TOPOLOGY_LOOP */
	unsigned char  ucSpeed;					/* SPEED_1GHZ, SPEED_2GHZ						 */
	unsigned char  ucDisableTimer;		/* (Not Currently Used) enable or disable 
														timeout timer									 */
	unsigned long  ulRRDYGap;				/* (Not Currently Used) up to a 27-bit val */
	unsigned long  ulRRDYGapRandomEnable;/* (Not Currently Used)enable/disable		 */
	unsigned long  ulRRDYGapSeed;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned long  ulRRDYGapMin;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned long  ulRRDYGapMax;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned char  ucAutoNegotiate;		/* (Not Currently Used) enable or disable 
														auto negotiation								 */
	unsigned short uiBBCreditConfigRx;	/* BB_credit this port will advertise		 */
	unsigned char  ucStatsMode;			/* Determines weather or not to retrieve
                                          the extended stats counters, use
                                          STATS_MODE_NORMAL & STATS_MODE_EXTENDED */
	unsigned char  ucReserved[15];		/* Reserved */
} FCPortConfig;

/* Port Level Config Data */
#define TOPOLOGY_PT_2_PT	0
#define TOPOLOGY_LOOP		1
#define TOPOLOGY_E_PORT		2
/* Port Level Config Data */
#define STATS_MODE_NORMAL	0
#define STATS_MODE_EXTENDED 1

/******************************************************************************
PORT CONFIG INFORMATION

 Structure:   FCPortConfigInfo
 iType1:      FC_PORT_CONFIG_INFO
 Function:    HTGetStructure 
 
FCPortConfigInfo Description:

This structure is used to get the Fibre Channel card port configuration information
******************************************************************************/
typedef struct tagFCPortConfigInfo
{
	unsigned char  ucTopology;				/* topology that is set to, pt-2-pt or loop*/
	unsigned char  ucSpeed;					/* speed the card is set to					 */  
	unsigned char  ucDisableTimer;		/* (Not Currently Used) enable or disable 
														timeout timer									 */
	unsigned long  ulRRDYGap;				/* (Not Currently Used) up to a 27-bit val */
	unsigned long  ulRRDYGapRandomEnable;/* (Not Currently Used)enable/disable		 */
	unsigned long  ulRRDYGapSeed;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned long  ulRRDYGapMin;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned long  ulRRDYGapMax;			/* (Not Currently Used) If random set; 
														a 27-bit val									 */
	unsigned char  ucAutoNegotiate;		/* (Not Currently Used) enable or disable 
														auto negotiation								 */
	unsigned short uiBBCreditConfigRx;	/* BB_credit this port will advertise		 */
	unsigned short uiBBCreditConfigTx;	/* advertised BB_credit of attached device */
	unsigned short uiBBCreditCurrentRx;	/* current BB_credit of this port			 */
	unsigned short uiBBCreditCurrentTx;	/* current BB_credit of attached device	 */
	unsigned long  ulRA_TOV;				/* local val or val returned from fabric	 */
	unsigned long  ulED_TOV;				/* local val or val returned from fabric	 */	
	unsigned char  ucGBICType;				/* type of GBIC of port							 */
	unsigned char  ucStatsMode;			/* state that the stats counters was in    */

	unsigned char  ucReserved[15];		/* Reserved */
} FCPortConfigInfo;

/******************************************************************************
FC STATUS INFORMATION

 Structure:   FCStatus
 iType1:      FC_STATUS_INFO 
 Function:    HTGetStructure 
 
FCStatus Description:

 This Structure is used to get FC card Device status
******************************************************************************/

typedef struct tagFCStatus					
{       
	unsigned long ulState;					/* State of port, refer to bitmaps defined		*/
	unsigned long ulError;					/* if port is in error state, the type (bitmap) is 
														reflected here */
	unsigned long ulErrorExtendedInfo;	/* may contain the reason codes for error			*/
	unsigned long ulErrorDetailedInfo;	/* may contain the explanation codes for error	*/
	U64			  u64ErrorWWN;				/* WWN that was being processed when error 
														occurred (if applicable)							*/
	unsigned long ulLinkErrorSeen;		/* a latched status of link errors					*/
	unsigned short uiErrorData;			/* may contain the data associated with the error */
	unsigned char ucReserved[14];			/* Reserved */
} FCStatus;

/* ulState use: the following bitmaps */
/* Port states */
#define PORT_LINK_DOWN						0x001
#define PORT_LINK_INITIALIZING			0x002
#define PORT_LINK_UP							0x004
/* Fabric specific states */
#define PORT_DEVICE_LOGIN					0x008
#define PORT_DEVICE_LOGIN_COMPLETE		0x010
#define PORT_PUBLIC_DISCOVERY				0x020
#define PORT_PUBLIC_DISCOVERY_COMPLETE	0x040
#define PORT_PRIVATE_DISCOVERY			0x080
#define PORT_PRIVATE_DISCOVERY_COMPLETE 0x100
#define PORT_READY_TO_TEST					0x200

/* ulError: use the following bitmaps */
/* Link specific errors */
#define PORT_LOSS_OF_SYNC					0x01
#define PORT_LOSS_OF_SIGNAL				0x02
#define PORT_LINK_RESET						0x04
#define PORT_TX_FAULT						0x08
/* Fabric specific errors */
#define PORT_FABRIC_LOGIN_ERROR			0x10
#define PORT_PORT_LOGIN_ERROR				0x20
#define PORT_NAME_SERVER_ERROR			0x40
#define PORT_INVALID_STATE_ERROR			0x80

/* ulErrorExtendedInfo: use the following single values (not bitmaps) */
/* Error reason codes */
#define NO_REASON_CODE				0
#define INVALID_LS_CMD				1		
#define LOGICAL_ERROR 				2
#define LOGICAL_INVALID_IU_SIZE	3
#define LOGICAL_BUSY					4
#define PROTOCOL_ERROR				5
#define UNABLE_TO_PERFORM_CMD		6
#define CMD_NOT_SUPPORTED			7
#define TIMEOUT						8
#define COS2_UNSUPPORTED			9
#define COS3_UNSUPPORTED			10

/* ulErrorDetailedInfo use the following single values (not bitmaps) */
/* Error explanation code */
#define NO_ADDITIONAL_EXPLANATION					0
#define SERVICE_PARM_OPTIONS							1
#define SERVICE_PARM_INIT_CTRL						2
#define SERVICE_PARM_RECP_CTRL						3
#define SERVICE_PARM_RCV_SIZE							4
#define SERVICE_PARM_CONCURRENT_SEQS				5
#define SERVICE_PARM_CREDIT							6
#define INVALID_PORT_NAME								7
#define INVALID_NODE_OR_FABRIC_NAME					8
#define INVALID_COMMON_SERVICE_PARMS				9
#define CMD_ALREADY_IN_PROGRESS						10
#define OUT_OF_RESOURCES								11
#define PORT_IDENTIFIER_NOT_REGISTERED				12
#define PORT_NAME_NOT_REGISTERED						13
#define NODE_NAME_NOT_REGISTERED						14
#define COS_NOT_REGISTERED								15
#define IP_ADDRESS_NOT_REGISTERED					16
#define INITIAL_PROCESS_ASSOCIATOR_NOT_REGISTERED	17
#define FC_4_TYPES_NOT_REGISTERED					18
#define SYMBOLIC_PORT_NAME_NOT_REGISTERED			19
#define SYBOLIC_NODE_NAME_NOT_REGISTERED			20
#define PORT_TYPE_NOT_REGISTERED						21
#define PORT_IP_ADDRESS_NOT_REGISTERED				22
#define FABRIC_PORT_NAME_NOT_REGISTERED			23
#define HARD_ADDRESS_NOT_REGISTERED					24
#define ACCESS_DENIED									25
#define UNACCEPTABLE_PORT_IDENTIFIER				26
#define DATA_BASE_EMPTY									27
#define NO_OBJECT_REGISTERED_IN_SCOPE				28
#define RPN_ID_FAILED_LOGIN                         29
#define GID_PN_FAILED_DISCOVERY                     30

/******************************************************************************
FC COUNTER STATISTICS

 Structure:   FCCounterInfo
 iType1:      FC_COUNTER_INFO 
 Function:    HTGetStructure 
 
 FCCounterInfo Description:

 This Structure is used to get FC card counter statistics.
******************************************************************************/

typedef struct tagFCCounterInfo {
	/* common counters */
	unsigned long		ulRcvPkt;			/* Number of packets received						*/
	unsigned long		ulTmtPkt;			/* Number of packets transmitted					*/
	unsigned long		ulCollision;		/* Number of collisions								*/
	unsigned long		ulRcvTrig;			/* Number of Triggers received					*/
	unsigned long		ulRcvByte;			/* Number of Bytes received						*/
	unsigned long		ulCRC;				/* Number of CRC errors received					*/
	unsigned long		ulAlign;				/* Number of Alignment errors detected			*/
	unsigned long		ulOversize;			/* Number of Oversize  errors detected			*/
	unsigned long		ulUndersize;		/* Number of Undersize erorrs detected			*/
	unsigned long		ulRcvPktRate;		/* Number of received pakcets per second		*/
	unsigned long		ulTmtPktRate;		/* Number of transmitted packets per second	*/
	unsigned long		ulCRCRate;			/* Number of CRC errors received per second	*/
	unsigned long		ulOversizeRate;	/* Number of Oversize errors received per second	*/
	unsigned long		ulUndersizeRate;	/* Number of Undersize errors received per second	*/
	unsigned long		ulCollisionRate;	/* Number of Collisions detected per second	*/
	unsigned long		ulAlignRate;		/* Number of Alignment errors received per second	*/
	unsigned long		ulRcvTrigRate;		/* Number of Triggers received per second		*/
	unsigned long		ulRcvByteRate;		/* Number of bytes received per second			*/
   U64					u64TxSigPkt;		/* Count of signature field frames tx			*/
   U64					u64RxSigPkt;		/* Count of signature field frames rx			*/

	/* FC Error Counters */
	U64			  u64LinkTxWordErr;	/* Tx word error count	*/
	unsigned long ulLinkInit;			/* Link init count		*/
	unsigned long ulLinkFailure;		/* Link fail count		*/
	unsigned long ulLinkLossOfSync;	/* Loss of sync count	*/
	unsigned long ulLinkLossOfSig;	/* Loss of signal count */
	unsigned long ulLinkReset;			/* LRR  error count		*/
	unsigned long ulLinkPrimSeqErr;	/* Primitive sequence error count */
	
	/*FC General Counters */
	U64 u64TxBytes;					/* Transmitted Bytes count			*/
	U64 u64TxClass2Frames;			/* Count of Class 2 frames Tx'd	*/
	U64 u64TxClass3Frames;			/* Count of Class 3 frames Tx'd	*/
	U64 u64TxClassFFrames;			/* Count of Class F frames Tx'd	*/
	U64 u64TxOtherFrames;			/* Count of other frames Tx'd		*/
	U64 u64TxClass2Bytes;			/* Count of Class 2 frames Tx'd	*/
	U64 u64TxClass3Bytes;			/* Count of Class 3 Bytes Tx'd	*/
	U64 u64TxClassFBytes;			/* Count of Class F Bytes Tx'd	*/
	U64 u64TxOtherBytes;				/* Count of other Bytes Tx'd		*/
	U64 u64RxClass2Frames;			/* Count of Class 2 frames Rx'd	*/
	U64 u64RxClass3Frames;			/* Count of Class 3 frames Rx'd	*/
	U64 u64RxClassFFrames;			/* Count of Class F frames Rx'd	*/
	U64 u64RxOtherFrames;			/* Count of other frames Rx'd		*/
	U64 u64RxClass2Bytes;			/* Count of Class 2 frames Rx'd	*/
	U64 u64RxClass3Bytes;			/* Count of Class 3 Bytes Rx'd	*/
	U64 u64RxClassFBytes;			/* Count of Class F Bytes Rx'd	*/
	U64 u64RxOtherBytes;				/* Count of other Bytes Rx'd		*/
	unsigned long ulTxByteRate;	/* Rate/sec of all bytes Tx'd		*/
	unsigned long ulTxClass2FrameRate;	/* Rate/sec of Class 2 frames Tx'd */
	unsigned long ulTxClass3FrameRate;	/* Rate/sec of Class 3 frames Tx'd */
	unsigned long ulTxClassFFrameRate;	/* Rate/sec of Class F frames Tx'd */
	unsigned long ulTxOtherFrameRate;	/* Rate/sec of other frames Tx'd	  */
	unsigned long ulTxClass2ByteRate;	/* Rate/sec of Class 2 frames Tx'd */
	unsigned long ulTxClass3ByteRate;	/* Rate/sec of Class 3 Bytes Tx'd  */
	unsigned long ulTxClassFByteRate;	/* Rate/sec of Class F Bytes Tx'd  */
	unsigned long ulTxOtherByteRate;		/* Rate/sec of other Bytes Tx'd    */
	unsigned long ulRxClass2FrameRate;	/* Rate/sec of Class 2 frames Rx'd */
	unsigned long ulRxClass3FrameRate;	/* Rate/sec of Class 3 frames Rx'd */
	unsigned long ulRxClassFFrameRate;	/* Rate/sec of Class F frames Rx'd */
	unsigned long ulRxOtherFrameRate;	/* Rate/sec of other frames Rx'd   */
	unsigned long ulRxClass2ByteRate;	/* Rate/sec of Class 2 frames Rx'd */
	unsigned long ulRxClass3ByteRate;	/* Rate/sec of Class 3 Bytes Rx'd  */
	unsigned long ulRxClassFByteRate;	/* Rate/sec of Class F Bytes Rx'd  */
	unsigned long ulRxOtherByteRate;		/* Rate/sec of other Bytes Rx'd    */
   unsigned long ulPLOGIsSent;	   	/* Count of PLOGIs sent				  */
   unsigned long ulPLOGIsRx;				/* Count of PLOGIs rx				  */
   unsigned long ulPLOGIAcceptsSent;	/* Count of PLOGI-Accept sent		  */
   unsigned long ulPLOGIAccepts; 		/* Count of PLOGI-Accept received  */
	unsigned long ulPLOGIsReturned;		/* Count of PLOGIs returned		  */
	unsigned long ulFLOGIsSent;			/* Count of FLOGIs sent				  */
	unsigned long ulFLOGIAccepts;			/* Count of FLOGIs Accepted		  */
	unsigned long ulFLOGIRejects;			/* Count of FLOGIs Rejected		  */
	unsigned long ulFLOGITimeouts;		/* Count of FLOGIs Timedout		  */
	unsigned long ulFrameDiscarded;		/* Frames discarded by the driver  */
	unsigned long ulTxCutThroughFrames;	/* Count of Cut Through Frames Transmitted */
	unsigned long ulRxCutThroughFrames;	/* Count of Cut Through Frames Received	 */
	unsigned long ulTxCutThroughBytes;	/* Count of Cut Through Bytes Transmitted	 */
	unsigned long ulRxCutThroughBytes;	/* Count of Cut Through Bytes Received		 */
	// begin extended counters section
	U64 u64TxCreditUnavailable;			/* Count of the number of times that
                                          Tx bb_credit went to 0          */
	U64 u64RxCreditUnavailable;			/* Count of the number of times that
                                          Rx bb_credit went to 0          */
	U64 u64ThrottledCount;					/* Number of times that a frame 
                                          transmission was delayed because
                                          no Tx bb_credit was available   */
	unsigned long ulCurrentTxBBCredit;	/* Current number of Tx buffers 
													   available in this FC port       */
	unsigned long ulCurrentRxBBCredit;	/* Current number of Rx buffers 
													   available in the attached FC port*/
	unsigned char ucReserved[96];			/* to support several future counters */
} FCCounterInfo;

/******************************************************************************
FC CONFIG INFO PARAMETERS

 Structure:   FCConfig
 iType1:      FC_DEFINE_HEADER_INFO
 Function:    HTGetStructure
 
FCConfig Description:

This structure is used to get Fibre Channel Stream Header Data.
******************************************************************************/
typedef struct tagFCConfig
{
	unsigned char ucEnableSeqCnt;		/* 0=disabled; 1=enabled						
													If this has been enabled then the ulSOF & 
													ulEOF fileds are are automatically set */
	unsigned char ucCOS;					/* Class Of Service: FC_STREAM_COS_NONE, 
													FC_STREAM_COS_2, FC_STREAM_COS_3			*/
	unsigned char ucHalfDuplex;		/* 0=Full duplex mode; 
													1=Half duplex mode							*/
	unsigned char ucVerifyAL_PD;		/* Verify the ALPA destination
													0=don't verify; 1=verify					*/
	unsigned char ucVerifyAL_PS;		/* Verify the ALPA source
													0=don't verify; 1=verify					*/
	/* end of TxDESC */
	unsigned long  ulSOF;				/* FC Start Of Frame								*/
	unsigned char	ucR_CTL;				/* FC header R_CTL field						*/
	U64				u64SourceWWN;		/* Source WWN address							*/
	U64				u64DestWWN;			/* Destination WWN address						*/
	unsigned short uiCS_CTL;			/* FC header CS_CTL field						*/
	unsigned char	ucFCType;			/* FC header Type field							*/
	unsigned long	ulF_CTL;				/* FC header FCTL field							*/
	unsigned char	ucSeqID;				/* FC header SeqID field						*/
	unsigned char	ucDF_CTL;			/* FC header DF_CTL field						*/
	unsigned short uiSeqCnt;			/* FC header SEQ_CNT  field					*/
	unsigned short uiOX_ID;				/* FC header OX_ID field						*/
	unsigned short uiRX_ID;				/* FC header RX_ID field						*/
	unsigned long	ulParameter;		/* FC header Parameter field					*/
	unsigned long	ulEOF;				/* FC end of frame								*/
	unsigned char	ucReserved[19];	/* Reserved */
} FCConfig;

#define FC_STREAM_COS_NONE	0x0
#define FC_STREAM_COS_2		0x2
#define FC_STREAM_COS_3   	0x3

/******************************************************************************
WWN COUNT STATISTICS

 Structure:   FCWWNCount
 iType1:      FC_WWN_COUNT_INFO 
 Function:    HTGetStructure 
 
FCWWNCount Description:

 This Structure is used to get FC card Device status.
******************************************************************************/
typedef struct tagFCWWNCount			
{    
	unsigned long ulWWNCount;
} FCWWNCount;

/******************************************************************************
 WWN CONFIG

 Structure:   FCWWN
 iType1:      FC_WWN / INFO 
 Function:    HTSetStructure & HTGetStructure
 
 FCWWN Description:

 This Structure is used to configure and read FC card Device WWNs.
******************************************************************************/
typedef struct tagFCWWN
{
	U64			  u64WWN;			/* WWN of emulated device									*/
	unsigned char ucSupportedCOS;	/* Supported Classes of Service for this WWN use:
												CLASS_OF_SERVICE_3, CLASS_OF_SERVICE_2				*/
	unsigned char ucResponseCOS;	/* Supported Classes of Service for Fabric or 
												private device.  
												This is a read-only value (FC_WWW_INFO) which is 
												received from the connected fabric switch			*/
	unsigned char ucPublic;			/* Use PUBLIC_MODE for Public, and
												PRIVATE_MODE for Private								*/
	unsigned char ucRemote;			/* Use REMOTE_MODE for "Remote from port", and
												LOCAL_MODE for "Local to port"						*/
	unsigned long ulAddressID;		/* 24-bit Address ID of this WWN.  This can only be 
												obtained after Public and Private discovery are
												completed.  If this is a loop port, the ALPA for
												this WWN will be in the least significant 8-bits*/
	unsigned char ucReserved[4];	/* Reserved */
} FCWWN;

/********************************************************************
 Device Config Data
 class_of_service_modes											   */
#define CLASS_OF_SERVICE_NOT_VALID	0
#define CLASS_OF_SERVICE_3				0x1
#define CLASS_OF_SERVICE_2				0x2

#define PUBLIC_MODE						1
#define PRIVATE_MODE						0

#define REMOTE_MODE						1
#define LOCAL_MODE						0

/******************************************************************************
 FIBRE CHANNEL STREAM

 Structure:   StreamFC
 iType1:      FC_DEFINE_STREAM
 Function:    HTSetStructure
 
 StreamFC Description:

 This structure is used to configure a stream with the Fibre Channel header in
 the first 24 bytes of the header.  The 40 bytes remaining are filled in with the
 background pattern.
******************************************************************************/
typedef struct tagStreamFC
{
	/* General Stream Configuration options */
	unsigned char   ucActive;					/* 1=Enable Stream, 0=Disable Stream	*/
	unsigned char   ucProtocolType;			/* use STREAM_PROTOCOL_FC					*/

	unsigned char   ucRandomLength;			/* Enable Random Frame Length				*/
	unsigned char   ucRandomData;			

	unsigned short  uiFrameLength;			/* frame length not counting CRC			*/
														/* 0 - 2144 for Fibre Channel				*/
														/* NOTE:  The Fibre Channel frame 
															length includes the SOF & SOF; 
															however once captured in the receive 
															engine, the length nor the packet 
															will include the SOF & EOF.  So the 
															expected length would be 4 bytes 
															less than the one set.					*/

	unsigned char   ucTagField;				/* 0 = off, 1 = insert Signature			*/
														/* field into each frame					*/

	/* Fibre Channel specific stream config */
	unsigned char  ucEnableSeqCnt;			/* 0=disabled; 1=enabled				
															If this has been enabled then the 
															ulSOF & ulEOF fileds are 
															automatically set by the card			*/
	unsigned char  ucCOS;						/* class of service possible values:
															FC_STREAM_COS_NONE, 
															FC_STREAM_COS_2, and
															FC_STREAM_COS_3							*/
	unsigned char  ucDuplexMode;				/* desired duplex mode of link:
															FULLDUPLEX_MODE, HALFDUPLEX_MODE		*/

														/* NOTE: It is recommended that the verify
															bits are enabled so that the verification
															is done by the card, unless the user
															specifically wants to disable it.	*/
	unsigned char ucVerifyAL_PD;				/* Verify the ALPA destination
															0=don't verify; 
															1=verify(recommended)					*/
	unsigned char ucVerifyAL_PS;				/* Verify the ALPA source
															0=don't verify; 
															1=verify(recommended)					*/

	unsigned long  ulSOF;						/* FC Start Of Frame							*/
	unsigned char	ucR_CTL;						/* FC header R_CTL field					*/

	U64				u64SourceWWN;				/* Source WWN address						*/
	U64				u64DestWWN;					/* Destination WWN address					*/

	unsigned short uiCS_CTL;					/* FC header CS_CTL field					*/
	unsigned char	ucFCType;					/* FC header Type field						*/
	unsigned long	ulF_CTL;						/* FC header FCTL field 					*/
	unsigned char	ucSeqID;						/* FC header SeqID field 					*/
	unsigned char	ucDF_CTL;					/* FC header DF_CTL field 					*/
	unsigned short uiSeqCnt;					/* FC header SEQ_CNT  field				*/
	unsigned short uiOX_ID;						/* FC header OX_ID field 					*/
	unsigned short uiRX_ID;						/* FC header RX_ID field 					*/
	unsigned long	ulParameter;				/* FC header Parameter field 				*/
	unsigned long	ulEOF;						/* FC End Of Frame 							*/
	unsigned short uiPayLoadLength;			/* If 0 then use the Backgroun, 
															otherwise, will use this length to
															set the payload	Max = 28				*/

	unsigned char  ProtocolHeader[28];		/* Fibre Channel requires 36 bytes for	
                                             the FC header and so out of the usual
                                             64 bytes only 28 bytes are available
                                             to be used for custom payload*/
	unsigned char	ucReserved[74];			/* Reserved */
											
} StreamFC;

/******************************************************************************
 FIBRE CHANNEL STREAM

 Structure:   StreamFC128
 iType1:      FC_DEFINE_STREAM_128
 Function:    HTSetStructure
 
 StreamFC128 Description:

 This structure is used to configure a stream with the Fibre Channel header in
 the first 24 bytes of the header.  The 92 bytes remaining are filled in with the
 background pattern.
******************************************************************************/

typedef struct tagStreamFC128
{
	/* General Stream Configuration options */
	unsigned char   ucActive;					/* 1=Enable Stream, 0=Disable Stream	*/
	unsigned char   ucProtocolType;			/* use STREAM_PROTOCOL_FC					*/

	unsigned char   ucRandomLength;			/* Enable Random Frame Length				*/
	unsigned char   ucRandomData;			

	unsigned short  uiFrameLength;			/* frame length not counting CRC			*/
														/* 0 - 2144 for Fibre Channel				*/

	unsigned char   ucTagField;				/* 0 = off, 1 = insert Signature			*/
														/* field into each frame					*/

	/* Fibre Channel specific stream config */
	unsigned char  ucEnableSeqCnt;			/* 0=disabled; 1=enabled				
															If this has been enabled then the 
															ulSOF & ulEOF fileds are 
															automatically set by the card			*/
	unsigned char  ucCOS;						/* class of service possible values:
															FC_STREAM_COS_NONE, 
															FC_STREAM_COS_2, and
															FC_STREAM_COS_3							*/
	unsigned char  ucDuplexMode;				/* desired duplex mode of link:
															FULLDUPLEX_MODE, HALFDUPLEX_MODE		*/

														/* NOTE: It is recommended that the verify
															bits are enabled so that the verification
															is done by the card, unless the user
															specifically wants to disable it.	*/
	unsigned char ucVerifyAL_PD;				/* Verify the ALPA destination
															0=don't verify; 
															1=verify(recommended)					*/
	unsigned char ucVerifyAL_PS;				/* Verify the ALPA source
															0=don't verify; 
															1=verify(recommended)					*/

	unsigned long  ulSOF;						/* FC Start Of Frame							*/
	unsigned char	ucR_CTL;						/* FC header R_CTL field					*/

	U64				u64SourceWWN;				/* Source WWN address						*/
	U64				u64DestWWN;					/* Destination WWN address					*/

	unsigned short uiCS_CTL;					/* FC header CS_CTL field					*/
	unsigned char	ucFCType;					/* FC header Type field						*/
	unsigned long	ulF_CTL;						/* FC header FCTL field 					*/
	unsigned char	ucSeqID;						/* FC header SeqID field 					*/
	unsigned char	ucDF_CTL;					/* FC header DF_CTL field 					*/
	unsigned short uiSeqCnt;					/* FC header SEQ_CNT  field				*/
	unsigned short uiOX_ID;						/* FC header OX_ID field 					*/
	unsigned short uiRX_ID;						/* FC header RX_ID field 					*/
	unsigned long	ulParameter;				/* FC header Parameter field 				*/
	unsigned long	ulEOF;						/* FC End Of Frame 							*/
	unsigned short uiPayLoadLength;			/* If 0 then use the Background, 
															otherwise, will use this length to
															set the payload Max = 92				*/

	unsigned char  ProtocolHeader[92];		/* Fibre Channel requires 36 bytes for	
                                             the FC header and so out of the usual
                                             128 bytes only 92 bytes are available
                                             to be used for custom payload*/
	unsigned char	ucReserved[74];			/* Reserved */
											
} StreamFC128;

/******************************************************************************
 SET FIBRE CHANNEL 

 Structure:   FCLinkDown
 iType1:      FC_LINK_DOWN
 Function:    HTSetStructure
 
 FCLinkDown	  Description:
 Will bring the link down on a Fibre Channel port.  Will keep the link down for
 the specified amount of time.  This command works the exact opposite of the 
 FC_LINK_UP command and can be executed at any state of the card to bring its 
 ports down.

******************************************************************************/
typedef struct tagFCLinkDown {

	unsigned long	ulDuration;					/* This value in miliseconds determines 
															how long the port(link) stays down.*/
	unsigned char	ucReserved[40];
} FCLinkDown;

/******************************************************************************
 SET FIBRE CHANNEL TRANSMISION MODE

 Structure:   FCTransmitMode
 iType1:      FC_SET_TX_MODE / FC_GET_TX_MODE
 Function:    HTSetStructure
 
 FCTransmitMode Description:
 This structure allows the user to change the mode on the FBC card to either the
 regular transmit engine mode, the cut through channel mode or HBA mode.

******************************************************************************/
typedef struct tagFCTransmitMode {

	unsigned char	ucTxMode;					/* TRANSMIT_ENGINE_MODE is used
															when send data out on the 
															regular transmit plane. 
															CUT_THROUGH_MODE allows the
															user to transmit a frame from
															the cut through channel of the
															card. This way allows the user
															to send any pre-defined frame
															by calling FC_SEND_CUSTOM.		
                                             HBA_EMULATION_MODE is used to 
															set the FBC module in the HBA
															mode. */
	unsigned char	ucState;						/* This is optional if the user	*/
														/* wants to change the state of	*/
														/* the card, they have the ability*/
														/* to do so.  Use the following	*/
														/* defined state constants			*/
	unsigned char	ucEnablePublicDiscMode;	/* Public Discovery Mode Enable
															A value of 1 means its enabled
																		  0 means disabled	*/
	unsigned char	ucReserved[5];
} FCTransmitMode;

#define TRANSMIT_ENGINE_MODE			0
#define CUT_THROUGH_MODE				1
#define HBA_EMULATION_MODE				2
/* use the following for the ucState field of FCTransmitMode */
#define FC_FABRIC_DOWN_STATE							0
#define FC_FABRIC_INIT_STATE							1
#define FC_DEVICE_LOGIN_STATE							2
#define FC_DEVICE_LOGIN_COMPLETE_STATE				3
#define FC_PUBLIC_DISCOVERY_STATE					4
#define FC_PUBLIC_DISCOVERY_COMPLETE_STATE		5
#define FC_PRIVATE_DISCOVERY_STATE					6
#define FC_PRIVATE_DISCOVERY_COMPLETE_STATE		7
#define FC_READY_TO_TEST_STATE						8

/******************************************************************************
 SET FIBRE CHANNEL HBA CONFIGURATION

 Structure:   FCHBAConfig
 iType1:      FC_HBA_CONFIG
 Function:    HTSetStructure
 
 FCHBAConfig Description:
 This structure allows the user to configure all the necessary timers involved
 in the Fibre Channel module acting like a Host Bus Adapter.
 
 Note:  All timers are measured in units of milliseconds

******************************************************************************/
typedef struct tagFCHBAConfig {

	unsigned long	ulState;						/* State of port, refer to bitmaps defined */
	unsigned long	ulInterStateTimer;		/* Amount of time to wait between each state:
                                             Linkup -> Login -> Disc -> Ready To Test */
	unsigned long	ulErrorRetryCount;		/* On error status for each state, how many
                                             times to retry until successful */
	unsigned long	ulErrorRetryTimer;		/* On error status for each state, how long 
                                             to wait before trying again */
	unsigned long	ulPollRetryCount;			/*	On no change in status for each state 
                                             how many times to poll the module */
	unsigned long	ulPollRetryTimer;			/*	On no change in status for each state
                                             how long to wait before polling again */

	unsigned char	ucReserved[32];
} FCHBAConfig;

/* Possible values to be used in setting the state */
#define HBA_LINK_UP							0x01
#define HBA_DEVICE_LOGIN					0x02
#define HBA_DISCOVERY						0x04
#define HBA_READY_TO_TEST					0x08

/******************************************************************************
 SEND/RECV FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:   FCCustomFrame
 iType1:      FC_SEND_CUSTOM / FC_RECV_CUSTOM
 Function:    HTSetStructure / HTGetStructure
 
 FCCustomFrame Description:  Use this structure to transmit frames from the
										cut-through channel.

******************************************************************************/
typedef struct tagFCCustomFrame {

	unsigned long	ulLength;					/* The total length of the packet		*/
														/* Min = 0, Max = 256		(0-256)		*/
	unsigned long	ulTimeToWait;				/* Time out value for the response		*/
														/*	packet to the one we are sending.	*/
														/*	in milliseconds							*/
	unsigned long	ulResponseTime;			/* The time it took for the response	*/
														/* to get back to the port from the fab*/
	unsigned char	ucMessageType;				/* Response from the fabric				*/
	unsigned char	ucErrorCodeReturned;		/* If an error occurred, returned code	*/
	unsigned char	ucPayLoad[256];			/* User defined packet 
															(in Network byte order)					*/
	unsigned char	ucReserved[28];
} FCCustomFrame;

/******************************************************************************
SRT

 Structure:   FCFSPFConfig
 iType1:      FC_FSPF_CONFIG 
 Function:    HTSetStructure
 
FCFSPFConfig Description:


******************************************************************************/
typedef struct tagFCFSPFConfig {
	unsigned char	ucTopology;						/* For Point-To-Point use TOPOLOGY_PT_2_PT
																 and for LOOP Topology use TOPOLOGY_LOOP
																 and for E-PORT use TOPOLOGY_E_PORT		 */
	unsigned char	ucSpeed;							/* SPEED_1GHZ, SPEED_2GHZ						 */
	unsigned short	uiBBCreditTx;					/* BB_credit this port will advertise		 */
	unsigned short	uiBBCreditRx;					/* BB_credit this port will advertise		 */
	unsigned short	uiRCFCapable;					/* To turn off ability to send RCF			 */
	unsigned long	ulOUI;							/* For Future Use */
															/*  In case we want to overwrite OUI 
																 in all WWNs									 */
	unsigned char   ucDomainManagerLogLevel;	/* possible values: 
																	FC_LOG_LEVEL_OFF, 
																	FC_LOG_LEVEL_RECURSION, 
																	FC_LOG_LEVEL_FATAL, 
																	FC_LOG_LEVEL_ERROR, 
																	FC_LOG_LEVEL_CRITICAL,
																	FC_LOG_LEVEL_WARNING, 
																	FC_LOG_LEVEL_MESSAGE, 
																	FC_LOG_LEVEL_INFO, 
																	FC_LOG_LEVEL_DEBUG */
	unsigned char  ucPortManagerLogLevel;     /* See previous constants above				 */
	unsigned char  ucTopologyManagerLogLevel; /* See previous constants above				 */
	unsigned char  ucZoneManagerLogLevel;     /* See previous constants above				 */
	unsigned char  ucFSPFLogLevel;            /* See previous constants above				 */ 
	unsigned char  ucNameServerLogLevel;      /* See previous constants above				 */
	unsigned char  ucFabricConfigServerLogLevel; /* See previous constants above			 */
   unsigned char  ucInterOpMode;             /* Possible modes:
                                                INTEROP_NORMAL (max. emulated switches is 30)
                                                INTEROP_NO_ESC (Exchange Switch Capabilities) */

   /* FLOGI response parameters (global for all emulated devices on port)					 */
	unsigned long ulResourceAllocTimeOut;
	unsigned long ulErrorDetectTimeOut;
   unsigned char ucMasterOrNot;              /* Border switch priority (1,2 or 255) */
	unsigned char ucRoundTripTimeOut;			/* Round trip timeout value (constants used are
															 0 1 2 3, thery are mapped to values)
															 The values are 100, 250, 500 and 1000 ms*/
   unsigned char  ucReserved[62];				/* Reserved for future use						 */
} FCFSPFConfig;

/* Log levels */
#define FC_LOG_LEVEL_OFF			0
#define FC_LOG_LEVEL_RECURSION	1
#define FC_LOG_LEVEL_FATAL			2
#define FC_LOG_LEVEL_ERROR			3
#define FC_LOG_LEVEL_CRITICAL		4
#define FC_LOG_LEVEL_WARNING		5
#define FC_LOG_LEVEL_MESSAGE		6
#define FC_LOG_LEVEL_INFO			7
#define FC_LOG_LEVEL_DEBUG			8

/*InterOp modes */
#define    INTEROP_NORMAL        0
#define    INTEROP_NO_ESC        1

/******************************************************************************
SRT

 Structure:   FCMultiSwitchConfig 
 iType1:      FC_MULTI_SWITCH_CONFIG 
 Function:    HTSetStructure
 
FCMultiSwitchConfig  Description:


******************************************************************************/
typedef struct tagFCSwitchConfig {
    U64   			u64SwitchName;
    unsigned char	ucRequestedDomainID;
    unsigned char	ucIndexOnPort;		/* index of  this switch  on port pointed in next field */
    unsigned char	ucPort;				/* Which port is this switch on ? */
	 unsigned char ucReserved;
} FCSwitchConfig;

typedef struct tagFCMultiSwitchConfig {
    unsigned char	ucCount;				/* Number of switches being configured  */
    unsigned char ucIndex; 			/* Starting switch number */
    unsigned char ucTopology;			/* Use the provided constants below */
    unsigned char	ucCommitFlag;		/* Are all switches configured yet ? Possible values:  
                                         FC_CONFIG_IN_PROGRESS
                                         FC_CONFIG_COMMIT */
    unsigned char	ucTopologySpecificParam;	/* Only one defined is for core -edge */
    unsigned char ucDefaultLinkCost;         /* Default ISL cost for all links in this topology.
                                                Possible values:
                                                  FC_LINK_SPEED_1GIG
                                                  FC_LINK_SPEED_2GIG
                                                  FC_LINK_SPEED_10GIG */
    unsigned char ucDefaultLinkSpeed;        /* Default ISL speed for all links in this topology.
                                                Possible values:
                                                  FC_LINK_SPEED_1GIG
                                                  FC_LINK_SPEED_2GIG
                                                  FC_LINK_SPEED_10GIG */
    FCSwitchConfig	Switches[FC_MAX_NUM_SWITCHES];	/* Switch Name and domain id */
 
    unsigned char	ucReserved[65];

} FCMultiSwitchConfig;

/*  Constants for topology */
#define FC_SWITCH_TOPOLOGY_CUSTOM 		0
#define FC_SWITCH_TOPOLOGY_GRID			1
#define FC_SWITCH_TOPOLOGY_RING			2
#define FC_SWITCH_TOPOLOGY_FULL_MESH	3
#define FC_SWITCH_TOPOLOGY_CORE_EDGE	4
#define FC_SWITCH_TOPOLOGY_CASCADE		5
#define FC_SWITCH_TOPOLOGY_BINARY_TREE 6

/* Constants for commit flag */
#define FC_CONFIG_IN_PROGRESS			0
#define FC_CONFIG_COMMIT            1

/*constants for link speed/cost */
#define FC_LINK_SPEED_1GIG          0
#define FC_LINK_SPEED_2GIG          1
#define FC_LINK_SPEED_10GIG         2
#define FC_LINK_COST_100            FC_LINK_SPEED_10GIG
#define FC_LINK_COST_200            3
#define FC_LINK_COST_500            FC_LINK_SPEED_2GIG
#define FC_LINK_COST_1000           FC_LINK_SPEED_1GIG
#define FC_LINK_COST_2000           4
#define FC_LINK_COST_5000           5
#define FC_LINK_COST_10000          6

/*Constant for ucDestSwitchIndex */
#define	FC_DEST_DUT                 255 /* It will be used to bring border link
                                           up and down using all the link
                                           configuration messages. */

/******************************************************************************
SRT

 Structure:   FCFabricLinkConfig  
 iType1:      FC_FABRIC_LINK_CONFIG 
 Function:    HTSetStructure
 
FCFabricLinkConfig  Description:


******************************************************************************/
typedef struct tagFCLinkConfig {

	unsigned char		ucSourceSwitchIndex;		/* Index of source switch */
	unsigned char		ucSourceSwitchPort;		/* The port that the source switch is on */
	unsigned char		ucDestSwitchIndex;		/* Index of destination switch
	                                               FC_DEST_DUT - bring border link up and down using
	                                                             all the link configuration messages */
	unsigned char		ucDestSwitchPort;			/* The port that the destination switch is on */
	unsigned char		ucLinkCost;					/* Cost of the Link between the 2 switches.
                                                Possible values:
                                                FC_LINK_SPEED_1GIG
                                                 FC_LINK_SPEED_2GIG
                                                 FC_LINK_SPEED_10GIG
	                                              FC_LINK_COST_100
	                                              FC_LINK_COST_200
	                                              FC_LINK_COST_500
	                                              FC_LINK_COST_1000
	                                              FC_LINK_COST_2000
	                                              FC_LINK_COST_5000
	                                              FC_LINK_COST_10000 */
	unsigned char		ucLinkSpeed;				/* Speed of the Link between the 2 switches.
                                                   Possible values:
                                                 FC_LINK_SPEED_1GIG
                                                 FC_LINK_SPEED_2GIG
                                                 FC_LINK_SPEED_10GIG
	                                              FC_LINK_COST_100
	                                              FC_LINK_COST_200
	                                              FC_LINK_COST_500
	                                              FC_LINK_COST_1000
	                                              FC_LINK_COST_2000
	                                              FC_LINK_COST_5000
	                                              FC_LINK_COST_10000 */
    unsigned char		ucReserved[2];	
} FCLinkConfig;

typedef struct tagFCFabricLinkConfig {

	unsigned short		uiCount;				/* Number of links being configured */
	unsigned char		ucOperation;		/* Are links being added or removed? 
															Use FC_ADD_LINK for add, and
                                             FC_REMOVE_LINK for remove */
	FCLinkConfig   	Link[FC_MAX_NUM_LINKS]; 			/* Array of links with source & dest switches */

	unsigned char		ucReserved[65];
} FCFabricLinkConfig;

#define FC_ADD_LINK			1
#define FC_REMOVE_LINK		0

/******************************************************************************
SRT

 Structure:   FCFabricLinkConfig  
 iType1:      FC_SWITCH_MULTI_LINK_CONFIG 
 Function:    HTSetStructure
 
FCFabricLinkConfig  Description:


******************************************************************************/
typedef struct tagFCSwitchDestConfig
{
    unsigned char		ucDestSwitchIndex;	/* Index of destination switch */
    unsigned char		ucDestSwitchPort; 	/* Which port is dest switch on */
    unsigned char		ucLinkCost;	
    unsigned char		ucLinkSpeed;
	
} FCSwitchDestConfig;

typedef struct tagFCSwitchMultiLinkConfig
{
    unsigned short   uiCount;					/* Number of entries in structure */
    unsigned char		ucOperation;			/* Are links being added or removed?
															Use FC_ADD_LINK for add, and
                                                 FC_REMOVE_LINK for remove */
    unsigned char		ucSourceSwitchIndex;	/* Index of source switch */
    unsigned char		ucSourceSwitchPort; 	/* Which port is source switch on */
    FCSwitchDestConfig  SwitchLinks[FC_MAX_NUM_DEST_SWITCHES]; 
								/* Contains the Dest switch port and link cost&speed */

    unsigned char 	ucReserved[67];
} FCSwitchMultiLinkConfig;

/******************************************************************************
SRT

 Structure:   FCFSPFStatsConfig  
 iType1:      FC_FSPF_STATS_CONFIG 
 Function:    HTSetStructure
 
FCFSPFStatsConfig  Description:


******************************************************************************/
typedef struct tagFCFSPFStatsConfig
{
    unsigned short	uiPollingInterval;		/* in milliseconds or seconds? */
    unsigned short	uiStatsType;				/* ex. 0 - collect only port counts, 
						         								 1 - collect FSPF stats etc.. */
    unsigned char		ucReserved[64];

}FCFSPFStatsConfig;

#define FC_STATS_TYPE_PORT_COUNTS		0
#define FC_STATS_TYPE_FSPF					1

/******************************************************************************
SRT

 Structure:   FCFSPFRealTimeStatsInfo  
 iType1:      FC_FSPF_REAL_TIME_STATS_INFO 
 Function:    HTGetStructure
 
FCFSPFRealTimeStatsInfo  Description:


******************************************************************************/
/* FCFSPFRealTimeStats Description:
*/
typedef struct tagFCFSPFRealTimeStats
{
    unsigned long ulTimeStamp; /* in milliseconds */
    unsigned long ulRate;
} FCFSPFRealTimeStats;

typedef struct tagFCFSPFRealTimeStatsInfo
{
    unsigned long 		ulType;		      /* Reserved */
    unsigned long 		ulCount;		      /* Number of elements returned in the following field. */
    FCFSPFRealTimeStats	Stats[255];			/* array of timestamp,data structure */
}FCFSPFRealTimeStatsInfo;
 

/******************************************************************************
SRT

 Structure:   FCFSPFStatsInfo
 iType1:      FC_FSPF_STATS_INFO
 Function:    HTGetStructure
 
FCFSPFStatsInfo  Description:


******************************************************************************/
typedef struct tagFCFSPFStatsInfo
{
    /* FSPF specific stats */
    U64     u64TxELPS;
    U64     u64RxELPS;
    U64     u64TxESC;
    U64     u64RxESC;
    U64     u64TxEFPS;
    U64     u64RxEFPS;
    U64     u64RxDIAS;
    U64     u64TxRDI;
    U64     u64TxMR;
    U64     u64RxMR;
    U64     u64TxHLOS;
    U64     u64RxHLOS;
    U64     u64TxLSUS;
    U64     u64RxLSUS;
    U64     u64TxLSAS;
    U64     u64RxLSAS;

    /* FSPF FSM state */
    unsigned short  uiLNEDomainManagerState;
    unsigned short  uiLNEPortManagerState;
    unsigned short  uiLNEToplogyManagerState;
    unsigned short  uiLNEFSPFState;

    /* FSPF Errors  Coming */
    unsigned char   ucReserved[128];
} FCFSPFStatsInfo; 




/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  FCFlogi
 iType1:      FC_FLOGI
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCFlogi {
	
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/
	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/
	/* FC-CT */
	unsigned long	CommandCode;	/* 32 bits	*/

	unsigned	char	HighVersion;	/* 8 bits	*/
	unsigned	char	LowVersion;		/* 8 bits	*/
	unsigned	short	BBCredit;		/* 16 bits	*/

	unsigned	char	Name;				/* 8 bits	*/
	unsigned	char	BBM;				/* 8 bits	*/
	unsigned	short	MaxRxSize;		/* 16 bits	*/

	unsigned long	Reserved1;		/* 32 bits	*/
	unsigned long	Reserved2;		/* 32 bits	*/
	
	unsigned long	WWNhigh;			/* 32 bits	*/
	unsigned long	WWNlow;			/* 32 bits	*/
	unsigned long	Reserved3;		/* 32 bits	*/
	unsigned long	Reserved4;		/* 32 bits	*/

	unsigned char	Reserved5[32];	/* 32*8 bits*/

	unsigned long	C_3Val;			/* 32 bits	*/

	unsigned char	Reserved6[44];	/* 44*8 bits*/
	
	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCFlogi;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  FCPlogi
 iType1:      FC_PLOGI
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCPlogi {
	
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/
	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/
	/* FC-CT */
	unsigned long	CommandCode;	/* 32 bits	*/

	unsigned	char	HighVersion;	/* 8 bits	*/
	unsigned	char	LowVersion;		/* 8 bits	*/
	unsigned	short	BBCredit;		/* 16 bits	*/

	unsigned	char	Name;				/* 8 bits	*/
	unsigned	char	BBM;				/* 8 bits	*/
	unsigned	short	MaxRxSize;		/* 16 bits	*/

	unsigned short	NPTCS;			/* 16 bits	*/
	unsigned short	ROIC;				/* 16 bits	*/
	
	unsigned long	EDTOV;			/* 32 bits	*/

	unsigned long	WWNhigh;			/* 32 bits	*/
	unsigned long	WWNlow;			/* 32 bits	*/
	unsigned long	Reserved3;		/* 32 bits	*/
	unsigned long	Reserved4;		/* 32 bits	*/

	unsigned char	Reserved5[32];	/* 32*8 bits*/

	unsigned long	C_3Val;			/* 32 bits	*/

	unsigned short Reserved6;		/* 16 bits	*/
	unsigned short	C_3RxSize;		/* 16 bits	*/

	unsigned short	C_3ConSeq;		/* 16 bits	*/
	unsigned short	Reserved7;		/* 16 bits	*/

	unsigned short	C_3OSPE;			/* 32 bits	*/
	unsigned short	Reserved8;		/* 16 bits	*/


	unsigned char	Reserved9[32];	/* 32*8 bits*/
	
	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCPlogi;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  FCGetRPN_ID
 iType1:      FC_PORT_NAME_REQUEST
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCGetRPN_ID {
	
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned	char	Revision;		/* 8 bits	*/
	unsigned	long	IN_ID;			/* 24 bits	*/

	unsigned char	GS_Type;			/* 8 bits	*/
	unsigned	char	GS_Subtype;		/* 8 bits	*/
	unsigned	char	Options;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/

	unsigned	short	Command_Code;	/* 16 bits	*/
	unsigned	short	MaximumSize;	/* 16 bits	*/

	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	ReasonCode;		/* 8 bits	*/
	unsigned	char	Explanation;	/* 8 bits	*/
	unsigned	char	VendorUnique;	/* 8 bits	*/

	unsigned	char	Reserved3;		/* 8 bits	*/
	unsigned long	PortID;			/* 24 bits	*/

	U64				PortName;		/* 64 bits	*/
	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCGetRPN_ID;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  FCLOG_Out
 iType1:      FC_LOGO
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCLOG_Out {
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/
	/* Rest */
	unsigned	long	Command_Code;	/* 32 bits	*/

	unsigned	char	Reserved1;		/* 8 bits	*/
	unsigned long	PortID;			/* 24 bits	*/

	U64				PortName;		/* 64 bits	*/
	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/
} FCLOG_Out;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  FCNameServer
 iType1:      FC_NAME_SERVER_QUERY
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCNameServer {
	
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned	char	Revision;		/* 8 bits	*/
	unsigned	long	IN_ID;			/* 24 bits	*/

	unsigned char	GS_Type;			/* 8 bits	*/
	unsigned	char	GS_Subtype;		/* 8 bits	*/
	unsigned	char	Options;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/

	unsigned	short	Command_Code;	/* 16 bits	*/
	unsigned	short	MaximumSize;	/* 16 bits	*/

	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	ReasonCode;		/* 8 bits	*/
	unsigned	char	Explanation;	/* 8 bits	*/
	unsigned	char	VendorUnique;	/* 8 bits	*/

	unsigned long	TimeToWait;
	unsigned short	PayLoadLenght;
	unsigned	char	PayLoad[208];	/* Rest of the 208 available space for user to set */

	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCNameServer;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  
 iType1:      FC_GET_ALL_NEXT
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCGetNext {
	
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned	char	Revision;		/* 8 bits	*/
	unsigned	long	IN_ID;			/* 24 bits	*/

	unsigned char	GS_Type;			/* 8 bits	*/
	unsigned	char	GS_Subtype;		/* 8 bits	*/
	unsigned	char	Options;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/

	unsigned	short	Command_Code;	/* 16 bits	*//* Default 0x0100 */
	unsigned	short	MaximumSize;	/* 16 bits	*/

	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	ReasonCode;		/* 8 bits	*/
	unsigned	char	Explanation;	/* 8 bits	*/
	unsigned	char	VendorUnique;	/* 8 bits	*/

	unsigned	char	Reserved3;		/* 8 bits	*/
	unsigned long	PortID;			/* 24 bits	*/

	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCGetNext;

/******************************************************************************
 SEND FIBRE CHANNEL FRAMES BY CUT THROUGH

 Structure:	  
 iType1:      FC_COS_QUERY
 Function:    HTSetStructure
 
 Description:  Use this structure while in manual mode

******************************************************************************/
typedef struct tagFCGetCOS_ID
 {
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned	char	Revision;		/* 8 bits	*/
	unsigned	long	IN_ID;			/* 24 bits	*/

	unsigned char	GS_Type;			/* 8 bits	*/
	unsigned	char	GS_Subtype;		/* 8 bits	*/
	unsigned	char	Options;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/

	unsigned	short	Command_Code;	/* 16 bits	*//* Default 0x0100 */
	unsigned	short	MaximumSize;	/* 16 bits	*/

	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	ReasonCode;		/* 8 bits	*/
	unsigned	char	Explanation;	/* 8 bits	*/
	unsigned	char	VendorUnique;	/* 8 bits	*/

	unsigned	char	Reserved3;		/* 8 bits	*/
	unsigned long	PortID;			/* 24 bits	*/

	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCGetCOS_ID;

typedef struct tagFCGetGID_PN {
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned	char	Revision;		/* 8 bits	*/
	unsigned	long	IN_ID;			/* 24 bits	*/

	unsigned char	GS_Type;			/* 8 bits	*/
	unsigned	char	GS_Subtype;		/* 8 bits	*/
	unsigned	char	Options;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/

	unsigned	short	Command_Code;	/* 16 bits	*/
	unsigned	short	MaximumSize;	/* 16 bits	*/

	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	ReasonCode;		/* 8 bits	*/
	unsigned	char	Explanation;	/* 8 bits	*/
	unsigned	char	VendorUnique;	/* 8 bits	*/

	unsigned	long	WWNhigh;			/* 32 bits	*/
	unsigned long	WWNlow;			/* 32 bits	*/

	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCGetGID_PN;

typedef struct tagFCSCReg {
	/* Start of Frame */
	unsigned long	StartOfFrame;	/* 32 bits	*/

	/* FC Header */
	unsigned char	R_CTL;			/* 8 bits	*/
	unsigned	long	D_ID;				/* 24 bits	*/	

	unsigned	char	CS_CTL;			/* 8 bits	*/
	unsigned long	S_ID;				/* 24 bits	*/

	unsigned	char	Type;				/* 8 bits	*/
	unsigned	long	F_CTL;			/* 24 bits	*/

	unsigned char	SEQ_ID;			/* 8 bits	*/
	unsigned	char	DF_CTL;			/* 8 bits	*/
	unsigned	short	SEQ_CNT;			/* 16 bits	*/

	unsigned	short	OX_ID;			/* 16 bits	*/
	unsigned short	RX_ID;			/* 16 bits	*/

	unsigned long	Parameter;		/* 32 bits	*/

	/* FC-CT */
	unsigned char	Command;			/* 8 bits	*/
	unsigned	char	Reserved1;		/* 8 bits	*/
	unsigned	char	Reserved2;		/* 8 bits	*/
	unsigned	char	Reserved3;		/* 8 bits	*/

	unsigned	char	Reserved4;		/* 8 bits	*/
	unsigned	char	Reserved5;		/* 8 bits	*/
	unsigned	char	Reserved6;		/* 8 bits	*/
	unsigned	char	RegFunc;			/* 8 bits	*/

	/* End Of Frame */
	unsigned long	EndOfFrame;		/* 32 bits	*/

} FCSCReg;


/*constants for port type*/
#define FC_NODE_N_PORT				1
#define FC_NODE_NL_PORT				2

/******************************************************************************
SRT

 Structure:   FCNodeConfig  
 iType1:      FC_NODE_CONFIG/FC_NODE_CONFIG_INFO  
 Function:    HTSetStructure/HTGetStructure
 
FCNodeConfig  Description:
 This structure is used to configure the end nodes for a particular switch.
 It is also used to query information for all nodes for a particular switch. When
 used for the query, fields ucOwnerSwitchIndex and ucOwnerSwitchPort are
 required as input for the query. And in the output, ucNodeNumber is always
 the total number, and ucStartNodeID is the first node index is being returned.
 If there are more than 100 nodes, ucStartNodeID field will be used to indicate
 the start index of the next 100 nodes that are requested in the query message.

******************************************************************************/
   

typedef struct tagFCNode {
	unsigned char		ucPortType;	/*  possible values:
	                                    FC_NODE_N_PORT,  FC_NODE_NL_PORT */
	unsigned char		ucClassofService; /* Class Of Service: Class 2 or Class 3 */
	unsigned char		ucIndex;	/* Index of this node on this switch */
	U64		   u64NodeName;
	unsigned long	    ulAddressID;
	unsigned char      ucIPAddress[4];
	unsigned char      ucReserved;
} FCNode;

typedef struct tagFCNodeConfig {
	unsigned char    ucOwnerSwitchIndex;	 /* Index of owner switch */
	unsigned char    ucOwnerSwitchPort;       /* the port which the owner switch is on */
	unsigned char    ucNodeCount;	/* number of nodes to be configured */
	unsigned char    ucStartNodeID;	/* starting node id in this message */
	FCNode           NodeArray[FC_MAX_NUM_NODES];    /* Array of the node*/
	unsigned char    ucReserved[64];
} FCNodeConfig;


/******************************************************************************
SRT

 Structure:   FCNameServerEventConfig  
 iType1:      FC_NAME_SERVER_EVENT_CONFIG 
 Function:    HTSetStructure
 
 FCNameServerEventConfig description:
 This structure is used to configure the name server component to send
 a particular query out to the DUT.

******************************************************************************/

typedef struct tagFCNameServerEventConfig {
	unsigned char    ucDomainID;	 /* Domain id of switch to use to generate request */
	unsigned char    ucAreaID;     /* Area id of address to be used to generate request */
	unsigned char    ucNodeID;      /* Node id of address to be used to generate request */
	unsigned long    ulType;  /* Type of query's stats, possible value
	                                        FC_GET_ENTRY_GIVEN_PORT_TYPE_RX */
	unsigned long    ulParameter1;	/* used for both the currently defined event type  */
	U64              u64Parameter2;	       /* reserved for future use*/
	unsigned char    ucReserved[256];
} FCNameServerEventConfig;

/******************************************************************************
SRT

 Structure:   FCNameServerStatsInfo  
 iType1:      FC_NAME_SERVER_STATS_INFO  
 Function:    HTGetStructure
 
 FCNameServerStatsInfo description:
 This structure is used to collect name server stats. The fields ulDomainID and
 ulType are required as input for the query.

******************************************************************************/
 

typedef struct tagFCDomainStats {
	unsigned long    ulDomainID;  /* Domain id of switch - input */
	U64              u64Count;    /* Number of queries of the specified query of ulType
	                                      sent or received */
	U64              u64AcceptCount;   /* number of queries resulted in an Accept being sent/received*/
	U64              u64RejectCount;   /* number of queries resulted in a Reject being sent/received */
	unsigned long    ulEntryCount;     /* number of entries returned in response to query */
	unsigned char    ucReserved[256];
} FCDomainStats;



typedef struct tagFCNameServerStatsInfo {
	unsigned long    ulType;      /* Type of query stats - input, possible value
	                                      FC_GET_ENTRY_GIVEN_PORT_TYPE_RX 
													  FC_GET_ENTRY_GIVEN_PORT_TYPE_TX
													  FC_GET_ENTRY_GIVEN_IP_ADDRESS_RX
													  FC_GET_ENTRY_GIVEN_IP_ADDRESS_TX
													  - it is a name server query which is used to exchange
	                                      name server entries in the switch's name server
	                                    table */
	FCDomainStats DomainStatsArray[40];
	unsigned char    ucReserved[256];
}FCNameServerStatsInfo;

/*constants for port type*/
#define FC_GET_ENTRY_GIVEN_PORT_TYPE_RX		0
#define FC_GET_ENTRY_GIVEN_PORT_TYPE_TX		1
#define FC_GET_ENTRY_GIVEN_IP_ADDRESS_RX		2
#define FC_GET_ENTRY_GIVEN_IP_ADDRESS_TX		3

/******************************************************************************
SRT

 Structure:   FCEPortSettingConfig  
 iType1:      FC_EPORT_SETTING_CONFIG/FC_EPORT_SETTING_CONFIG_INFO  
 Function:    HTSetStructure/HTGetStructure
 
 FCEPortSettingConfig description:
 This structure is used to configure or query the e-port settings.
 Fields ulr_a_tov and ule_d_tov are included in this message.

******************************************************************************/
  
typedef struct tagFCEPortSettingConfig {
	unsigned long    ulr_a_tov;	 /* Resource allocation time out value,
	                                reserved, set on command line currently.
	                                This field will no longer be set using
	                                FC_FSPF_CONFIG command. unit of time: ms
	                                Minimum value: 100 ms  Maximum Value: 100000 ms. */
	unsigned long    ule_d_tov;  /* Error detetecton time out value,
	                                reserved, set on command line currently.
	                                This field will no longer be set using
	                                FC_FSPF_CONFIG command. Unit of time: ms
	                                Minimum value: 100 ms  Maximum Value: 20000 ms. */
	unsigned char    ucClassofService2Supported;       /* 0 - false, 1 - true  */
	unsigned char    ucClassofService3Supported;       /* 0 - false, 1 - true  */
	unsigned char    ucLRSupported;       /* 0 - false, 1 - true  */
	unsigned char    ucESCSupported;       /* 0 - false, 1 - true  */
	unsigned long    ulClassofService2FrameSize; /* Minimum: 256, Maximum: 2112 */
	unsigned long    ulClassofService3FrameSize; /* Minimum: 256, Maximum: 2112 */
	unsigned long    ulMaxClassofServiceFFrameSize; /* Minimum: 256, Maximum: 2112 */
	unsigned long	  ulTimer1;			/* Programmable Timer 1 value in milliseconds */
	unsigned long	  ulTimer2;			/* Programmable Timer 2 value in milliseconds */
	unsigned long	  ulTimer3;			/* Programmable Timer 3 value in milliseconds */
	unsigned long	  ulTimer4;			/* Programmable Timer 4 value in milliseconds */
	unsigned long	  ulTimer5;			/* Programmable Timer 5 value in milliseconds */
	unsigned char	  ucDMThreshold;
	unsigned char	  ucFSPFTHreshold;
	unsigned char	  ucNSThreshold;
	unsigned char	  ucTestType;

	unsigned char    ucReserved[252];
}FCEPortSettingConfig;

#endif

