/*
	Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
	Netcom Systems, Inc.
	Copyright (C) 1993-1999. All Rights Reserved.
*/

/* file: frame.h */

#ifndef  _FRAME_H
#define  _FRAME_H

#include "frmitems.h"

/* ------------- Begin of CONSTANT_H -------------------------------------- */

#define	SIZE_ENCAP_ETHERNET		            12
#define  SIZE_ENCAP_ATM_SVC_SNAP             6           /* LLC + SNAP */
#define  SIZE_ENCAP_ATM_SVC_LANE802_3        14
#define  SIZE_ENCAP_ATM_SVC_LANE802_5        22
#define  SIZE_ENCAP_ATM_SVC_CLASSICAL_IP     6
#define	SIZE_ENCAP_TOKEN_RING               14
#define	SIZE_ENCAP_BRIDGE_FR                12
#define	SIZE_ENCAP_ROUTE_FR                 0

#define	SIZE_PROTOCOL_IP		               20          /* = IP (Header) */
#define	SIZE_PROTOCOL_UDP		               28          /* = IP + UDP (Headers) */
#define	SIZE_PROTOCOL_TCP		               40          /* = IP + TCP (Headers) */
#define	SIZE_PROTOCOL_ARP		               28          /* = ARP (Header) */
#define	SIZE_PROTOCOL_RARP		            28
#define	SIZE_PROTOCOL_IPX		               30          /* = IPX (Header) */
#define	SIZE_PROTOCOL_ICMP                  28          /* = IP + ICMP (Headers) */


/*
 use these specifiers to reference to:
	( notice that to reduce number of specifiers, we have some of the specifiers
	referencing to common members of different frame structures. please address
	them carefully.
	Implementation details: (ignore this part if you don't want to know)
		 since any frame structure has 3 distinct parts ( 4 if including the payload)
		 which are type, encap, and protocol, we map identifiers into 3 different
		 range of values.  This mapping method will help us to identify the group
		 to which the modifiers belong quickly and avoid unneccessary function calls.

		 So, to add or to remove any specifier will have to update the range and its
		 supporting functions.

	  * specifiers reference to members of encaps will be in range starting from
			 ENCAP_SPECIFIER_MIN to ENCAP_SPECIFIER_MAX
	  * specifiers reference to members of protocols will be in range starting from
			 PROTOCOL_SPECIFIER_MIN to PROTOCOL_SPECIFIER_MAX
	  * specifier references to the frame type is set to zero ( since there is only one member)
 )
*/
#define  ENCAP_SPECIFIER_MIN        1
#define  ENCAP_SPECIFIER_MAX        12
#define  PROTOCOL_SPECIFIER_MIN     50
#define  PROTOCOL_SPECIFIER_MAX     94



/**************************************
	Sizes:
	~~~~~

	 MAC Address = 6 BYTES
	 IP Address = 4 BYTES
	 IP Header = 5 [unit of 4-BYTE]
	 UDP Header = 8 BYTES
	 Ethernet Header = 14 bytes
	 TCP Header = 5 [unit of 4-BYTE]
	 ARP Header = 28 bytes
	 ICMP Header = 8 bytes
**************************************/
#define SIZE_MAC_ADDR         6
#define SIZE_IP_ADDR          4

#define SIZE_IP_HEADER        5
#define SIZE_UDP_HEADER       8
#define SIZE_ETHERNET_HEADER  14
#define SIZE_TCP_HEADER       5
#define SIZE_ARP_HEADER       28
#define SIZE_ICMP_HEADER      8
#define SIZE_IPX_HEADER       30

/**************************************
 Default Values:
 ~~~~~~~~~~~~~~

	 MAC Source Address = 0.0.0.0.0.0
	 MAC Destination Address = 0.0.0.0.0.0.0
	 Ethernet Type = 0x0800  (IP Protocol)
	 IP Version = 4
	 IP type of service = 0
	 UDP source port number = 0xC020
	 UDP destination port number = 7
	 TCP source port number = 0
	 TCP destination port number = 0
	 TCP sequence number = 0
	 TCP acknowledge number = 0
	 TCP window size = 0
	 TCP urgent pointer = 0
**************************************/
#define  DEFAULT_MAC_SRC_ADDR             0
#define  DEFAULT_MAC_DEST_ADDR            0
#define  DEFAULT_ETHERNET_TYPE            0x0800
#define  DEFAULT_IP_VERSION               4
#define  DEFAULT_IP_HEADER_LENGTH         5
#define  DEFAULT_IP_TYPE_OF_SERVICE       0

#define  DEFAULT_UDP_SRC_PORT_NUMBER      0xC020
#define  DEFAULT_UDP_DST_PORT_NUMBER      0x0007
#define  DEFAULT_UDP_CHECKSUM_OPTION      AUTO_CALCULATED_CRC

#define  DEFAULT_TCP_SRC_PORT_NUMBER      0x0000
#define  DEFAULT_TCP_DST_PORT_NUMBER      0x0000
#define  DEFAULT_TCP_SEQ_NUMBER           0
#define  DEFAULT_TCP_ACK_NUMBER           0
#define  DEFAULT_TCP_WINDOW_SIZE          0
#define  DEFAULT_TCP_URGENT               0

#define  DEFAULT_ARP_HARDWARE_TYPE        1
#define  DEFAULT_ARP_PROTOCOL_TYPE        0x0800
#define  DEFAULT_ARP_OP                   ARP_REQUEST

#define  DEFAULT_RARP_HARDWARE_TYPE        1
#define  DEFAULT_RARP_PROTOCOL_TYPE        0x0800
#define  DEFAULT_RARP_OP                   RARP_REQUEST

#define  DEFAULT_ICMP_TYPE                8     /* Echo Request (ping request) */
#define  DEFAULT_ICMP_CODE                0
#define  DEFAULT_ICMP_IDENTIFIER          0
#define  DEFAULT_ICMP_SEQ_NUMBER          0

#define  DEFAULT_IPX_CHECKSUM             0xFFFF
#define  DEFAULT_IPX_LENGTH               SIZE_IPX_HEADER
#define  DEFAULT_IPX_HOP                  0
#define  DEFAULT_IPX_TYPE                 4
#define  DEFAULT_IPX_DST_SOCKET           0
#define  DEFAULT_IPX_SRC_SOCKET           0


/**************************************
 Other values:
 ~~~~~~~~~~~~
**************************************/
#define  USER_SPECIFIED_CRC      0
#define  AUTO_CALCULATED_CRC     1
#define  ARP_REQUEST             1
#define  ARP_REPLY               2
#define  RARP_REQUEST            3
#define  RARP_REPLY              4


#define IP_FRAME        1
#define TCP_FRAME       2
#define UDP_FRAME       3
#define ARP_FRAME       4
#define IPX_FRAME       5


typedef  unsigned char  BYTE;    /*  8-bit byte */
typedef  unsigned short WORD;    /* 16-bit word */
typedef  unsigned long  DWORD;   /* 32-bit double word */

#define HIGHBYTE(s)        ((BYTE)(((s) & 0xFF00) >> 8))
#define LOWBYTE(s)         ((BYTE)((s) & 0x00FF))
#define HIGHWORD(dword)    ((WORD)(((dword) & 0xFFFF0000L) >> 16))
#define LOWWORD(dword)     ((WORD)(((dword) & 0x0000FFFFL)))

#define BYTES2WORD(h,l)    ((WORD)((((WORD)(h)) << 8) | ((WORD)(l))))
#define  BYTES2DWORD( b1, b2, b3, b4 ) \
( (DWORD)(((DWORD)(b1) << 24) | ((DWORD)(b2) << 16) | ((DWORD)(b3) << 8) | (b4)) )
#define WORD2BYTES(w, b)   { (*b)=HIGHBYTE((w)); (*(b+1)) = LOWBYTE((w)); }
#define DWORD2BYTES(dw, b) { (*b)=HIGHBYTE(HIGHWORD(dw));      \
                             (*(b+1)) = LOWBYTE(HIGHWORD(dw)); \
                             (*(b+2)) = HIGHBYTE(LOWWORD(dw)); \
                             (*(b+3)) = LOWBYTE(LOWWORD(dw)); }





/*
   Generic Frame format:
   +-----------------+---------+------------------------+---------\----------+
   |    Encap        |  Type   |       Protocol         |    payload         |
   +-----------------+---------+------------------------+---------\----------+
*/
typedef struct tagFrame
{
	void*          pEncap;
	unsigned short uiType;
	void*          pProtocol;
	unsigned char* pucPayload;

	/* the following is used for frame management purposes */
	int            iSize;
   int            iPayloadSize;  
}Frame_Type;

/*
  Ethernet Header:
    0                                                                31
    +================================================================+
    |           D   E   S   T   I   A   T   I   O   N                |
    +===============================+================================+
    |  M   A    C                   |       S  O   U   R   C   E     |
    +===============================+================================+
    |         M   A   C     S   O   U   R   C   E      M   A   C     |
    +===============================+================================+
*/

typedef struct tagMACAddress
{
	unsigned char  pucDestinationMAC[SIZE_MAC_ADDR];
   unsigned char  pucSourceMAC[SIZE_MAC_ADDR];
}MACAddress_Type;

typedef struct tagEthernetHeader
{
   MACAddress_Type   MACAddrs;
}EthernetHeader_Type;

/*
   IP Header:
   0                                                                 31
 ^  +------+------+-----------------+--------------------------------+
 |  |4-bit |4-bit | 8-bit type of   |  16-bit total length in bytes  |
 H  |ver.  |length|   service       |                                |
 E  +------+------+-----------------+------+-------------------------+
 A  | 16-bit identification         |3-bit |  13-bit fragment offset |
 D  |       (sequence number)       |flags |                         |
 E  +-------------+-----------------+------+-------------------------+
 R  | 8-bit time  | 8-bit protocol  | 16-bit header checksum         |
 |  |  to live    |                 |                                |
 |  +----------------------------------------------------------------+
 |  |               32-bit source IP address                         |
 |  +----------------------------------------------------------------+
 |  |               32-bit destination IP address                    |
 -  +----------------------------------------------------------------+
*/
typedef struct tagIPHeader
{
	 unsigned char   ucVersion;            /* version                      */
    unsigned char   ucHeaderLength;       /* Length of Header,unit:4-byte */
    unsigned char   ucTypeOfService;      /* Type of Service              */
    unsigned short  uiTotalLength;        /* Length of entired Frame      */
    unsigned short  uiSequenceNumber;     /* Sequence Number              */
    unsigned char   ucFlags;              /* 3-bit flags, reversed        */
    unsigned short  uiFragment;           /* Fragment offset              */
    unsigned char   ucTimeToLive;         /* Time to Live                 */
    unsigned char   ucProtocol;           /* Protocol                     */
    unsigned short  uiHeaderCRC;          /* Header CRC                   */
    unsigned char   pucSourceIP[SIZE_IP_ADDR];     /* Source IP Address      */
    unsigned char   pucDestinationIP[SIZE_IP_ADDR];/* Destination IP Address */
}IPHeader_Type;


/*
   UDP Header:
   0                                                                31
   +--------------------------------+-------------------------------+
   |         source port number     |    destination port number    |
   +--------------------------------+-------------------------------+
   |          UDP Length            |        UDP checksum           |
   +--------------------------------+-------------------------------+
   |                                                                |
   /                            data (if any)                       /
   |                                                                |
   +--------------------------------+-------------------------------+
*/
typedef struct tagUDPHeader
{
   unsigned short uiSourcePort;
   unsigned short uiDestinationPort;
   unsigned short uiLength;
   unsigned short uiCheckSum;
}UDPHeader_Type;

/*
   TCP Header:
   0                                                                31
   +--------------------------------+-------------------------------+
   |         source port number     |    destination port number    |
   +----------------------------------------------------------------+
   |                       Sequence Number                          |
   +----------------------------------------------------------------+
   |                       Acknowledgment Number                    |
   +--------+-----------+-+-+-+-+-+-+-------------------------------+
   | header | reserved  |U|A|P|R|S|F|                               |
   | length |           |R|C|S|S|Y|I|        window size            |
   |(4 bits)| (6 bits)  |G|K|H|T|N|N|        (16 bits)              |
   +--------+-----------+-+-+-+-+-+-+-------------------------------+
   |          Checksum              |        urgent pointer         |
   +--------------------------------+-------------------------------+
   |                                                                |
   /                            data (if any)                       /
   |                                                                |
   +--------------------------------+-------------------------------+
*/
typedef struct tagTCPHeader
{
   unsigned short uiSourcePort;
   unsigned short uiDestinationPort;
   unsigned long  ulSequenceNumber;
   unsigned long  ulAcknowledgeNumber;
   unsigned char  ucHeaderLength;
   unsigned char  ucReserved1;            /* use only least sig. 4 bits */
   unsigned char  ucReserved2;            /* use only least sig. 2 bits */
   unsigned char  ucCodes;                /* use only least sig. 6 bits */
   unsigned short uiWindowSize;
   unsigned short uiCheckSum;
   unsigned short uiUrgent;
}TCPHeader_Type;

/*
   ARP Header:
   +------+------+------+------+----+----------+---------+----------+----------+
   | h/w  | prot | h/w  | prot | op | sender   | sender  | receiver | receiver |
   | type | type | size | size |    | MAC addr | IP addr | MAC addr | IP addr  |
   +--2---+--2---+--1---+--1---+-2--+---6------+---4-----+----6-----+----4-----+
   <-------------- 28 bytes ARP request/reply --------------------------------->
*/
typedef struct tagARPHeader
{
   unsigned short uiHardwareType;
   unsigned short uiProtocolType;
   unsigned char  ucHardwareSize;
   unsigned char  ucProtocolSize;
   unsigned short uiOp;
	unsigned char  pucSenderMAC[SIZE_MAC_ADDR];
   unsigned char  pucSenderIP[SIZE_IP_ADDR];
   unsigned char  pucReceiverMAC[SIZE_MAC_ADDR];
   unsigned char  pucReceiverIP[SIZE_IP_ADDR];
}ARPHeader_Type;

/*
   RARP Header: same as ARP except the default values:
*/
typedef ARPHeader_Type RARPHeader_Type;

/*
   ICMP Header:
   0             8              16                                 31
   +-------------+---------------+----------------------------------+
   |     Type    |     Code      |            Checksum              |
   +-----------------------------+----------------------------------+
   |         Identifier          |         Sequence number          |
   +----------------------------------------------------------------+
*/
typedef struct tagICMPHeader
{
   unsigned char  ucType;
   unsigned char  ucCode;
   unsigned short uiCheckSum;
   unsigned short uiIdentifier;
   unsigned short uiSequenceNumber;
}ICMPHeader_Type;

/*
   IPX Header:

   +----+----+-+-+-------+------------+----+---------+------------+----+
   |  2 |  2 |1|1|   4   |     6      |  2 |     4   |     6      |  2 |
   +----+----+-+-+-------+------------+----+---------+------------+----+
      |    |  | |    |         |         |       |         |         |
      |    |  | |    |         |         |       |         |         +-- source socket
      |    |  | |    |         |         |       |         +----- source MAC
      |    |  | |    |         |         |       +----- source IP
      |    |  | |    |         |         +---- destination socket
      |    |  | |    |         +---- destination MAC
      |    |  | |    +---- destination IP
      |    |  | +--- packet type
      |    |  +-- transport control
      |    +-- packet length
      +-- checksum
*/
typedef struct tagIPXHeader
{
   unsigned short uiCheckSum;
   unsigned short uiLength;
   unsigned char  ucHop;
   unsigned char  ucType;
   unsigned char  pucDestinationIP[SIZE_IP_ADDR];
   unsigned char  pucDestinationMAC[SIZE_MAC_ADDR];
   unsigned short uiDestinationSocket;
   unsigned char  pucSourceIP[SIZE_IP_ADDR];
   unsigned char  pucSourceMAC[SIZE_MAC_ADDR];
   unsigned short uiSourceSocket;
}IPXHeader_Type;

/*
   Logic Link Control (LLC) Header:
   +------+------+------+
   | DSAP | SSAP | Crtl |
   +------+------+------+
   |<-1-->|<-1-->|<-1-->|
*/
typedef struct tagLLCHeader
{
   unsigned char  ucDSAP;
   unsigned char  ucSSAP;
   unsigned char  ucControl;
}LLCHeader_Type;

/*
   SubNetwork Attachment Point (SNAP) Header:
   +-----------------------+
   |       OUI             |
   +-----------------------+
   |<--------- 3 --------->|
*/
typedef struct tagSNAPHeader
{
   unsigned char  pucOUI[3];
}SNAPHeader_Type;

/*
   Asynchronous Transfer Mode (ATM)
   Switched Virtual Circuits (SVC)
   Permanent Virtual Circuits (PVC)
   ATM SVC CLASSIC IP Header:
   +------+------+------+------------------+
   | DSAP | SSAP | Crtl |       OUI        |
   +------+------+------+------------------+
   |<-1-->|<-1-->|<-1-->|<------ 3 ------->|
*/
typedef struct tagATMClassicIPHeader
{
   LLCHeader_Type LLCHeader;
   unsigned char  pucOUI[3];
}ATMClassicIPHeader_Type;


/*
   SubNetwork Attachment Point (SNAP)
   Organizationally Unique Identifier (OUI)
   ATM SVC SNAP Header:
   |<------ LLC ------->|<-- SNAP -------->|
   +------+------+------+------------------+
   | DSAP | SSAP | Crtl |       OUI        |
   +------+------+------+------------------+
   |<-1-->|<-1-->|<-1-->|<------ 3 ------->|
*/
typedef struct tagATMSNAPHeader
{
   LLCHeader_Type    LLCHeader;
   SNAPHeader_Type   SNAPHeader;
}ATMSNAPHeader_Type;

/*
   ATM SVC LANE 802.3 Header:
   +----------+-------------------------------------------------+
   |  LEC ID  |                     MAC                         |
   +----------+-------------------------------------------------+
   |<-- 2 --->|<---------------- 12 --------------------------->|
*/
typedef struct tagATMLANE802_3
{
   unsigned short    uiLECID;
   MACAddress_Type   MACAddrs;
}ATMLANE802_3Header_Type;

/*
	ATM SVC LANE 802.5 Header:
   +-----------+--------+-------+---- - - - ---+------+------+------+------------------+
   |  LEC ID   | AC pad |  FC   |      MAC     | DSAP | SSAP | Crtl |       OUI        |
   +-----------+--------+-------+---- - - - ---+------+------+------+------------------+
   |<--- 2 --->|<-- 1-->|<--1-->|<---- 12 ---->|<-1-->|<-1-->|<-1-->|<------ 3 ------->|
*/
typedef struct tagATMLANE802_5
{
   unsigned short    uiLECID;
   unsigned char     ucACPad;
   unsigned char     ucFC;
   MACAddress_Type   MACAddrs;
   LLCHeader_Type    LLCHeader;
   unsigned char     pucOUI[3];
}ATMLANE802_5Header_Type;


typedef struct tagTokenRingHeader
{
   unsigned char  ucAC;
   unsigned char  ucFC;
   MACAddress_Type   MACAddrs;
}TokenRingHeader_Type;

typedef struct tagFrameRelayBridgedHeader
{
   MACAddress_Type   MACAddrs;
}FrameRelayBridgedHeader_Type;

/*----------------- Protocol ----------------------------------------*/

typedef struct tagProtocolIP
{
	IPHeader_Type  IPHeader;
}ProtocolIP_Type;

typedef struct tagProtocolUDP
{
   IPHeader_Type  IPHeader;
   UDPHeader_Type UDPHeader;
}ProtocolUDP_Type;

typedef struct tagProtocolTCP
{
   IPHeader_Type  IPHeader;
   TCPHeader_Type TCPHeader;
}ProtocolTCP_Type;

typedef struct tagProtocolARP
{
   ARPHeader_Type ARPHeader;
}ProtocolARP_Type;

typedef struct tagProtocolRARP
{
   RARPHeader_Type RARPHeader;
}ProtocolRARP_Type;

typedef struct tagProtocolIPX
{
   IPXHeader_Type IPXHeader;
}ProtocolIPX_Type;

typedef struct tagProtocolICMP
{
   IPHeader_Type  IPHeader;
   ICMPHeader_Type   ICMPHeader;
}ProtocolICMP_Type;

long int NSCreateFrame_Internal( FrameSpec_Type* framespec );
long int NSSetPayload_Internal( long int lFrameID, int iSize, unsigned char* pucPayload );
long int NSModifyFrame_Internal( long int lFrameID, int iSpecifier,
                  unsigned char* pucBytes, int iNumBytes );

#endif
 
