/*
	Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
	Netcom Systems, Inc.
	Copyright (C) 1993-1999. All Rights Reserved.
*/

/* file: frmitems.h */

#ifndef  _FRAME_ITEMS_H
#define  _FRAME_ITEMS_H

/*
FrameSpec_Type Description:
   Use this structure to specify the content of a frame.
 */
typedef struct tagFrameSpec
{
   int   iEncap;                 /* Specifying the encapsulator               */
   int   iSize;                  /* Specifying size of the frame              */
   int   iProtocol;              /* Specifying the protocol of the frame      */
	int	iPattern;               /* Specifying the payload pattern            */
}FrameSpec_Type;


#define	ENCAP_ETHERNET	               0
#define	ENCAP_ATM_PVC                 1
#define  ENCAP_ATM_SVC_SNAP            2
#define  ENCAP_ATM_SVC_LANE802_3       3
#define  ENCAP_ATM_SVC_LANE802_5       4
#define  ENCAP_ATM_SVC_CLASSICAL_IP    5
#define	ENCAP_TOKEN_RING	            6
#define	ENCAP_BRIDGE_FR	            7
#define	ENCAP_ROUTE_FR	               8
#define	ENCAP_ATM_PVC_SNAP            9

#define  FRAME_PROTOCOL_NULL           0
#define	FRAME_PROTOCOL_IP		         1
#define	FRAME_PROTOCOL_UDP		      2
#define	FRAME_PROTOCOL_TCP		      3
#define	FRAME_PROTOCOL_ARP		      4
#define	FRAME_PROTOCOL_RARP		      5
#define	FRAME_PROTOCOL_IPX		      6
#define	FRAME_PROTOCOL_ICMP		      7

#define  PAT_0000	0  	/* 00 00 00 00 00 ...                       */
#define  PAT_1111	1  	/* 11 11 11 11 11 ...                       */
#define  PAT_AAAA  2  	/* AA AA AA AA AA ...                       */
#define  PAT_5555  3  	/* 55 55 55 55 55 ...                       */
#define  PAT_F0F0  4  	/* F0 F0 F0 F0 F0 ...                       */
#define  PAT_0F0F  5  	/* 0F 0F 0F 0F 0F ...                       */
#define  PAT_FF00  6  	/* FF OO FF OO FF ...                       */
#define  PAT_00FF  7  	/* 00 FF 00 FF 00 ...                       */
#define  PAT_FFFF  8  	/* FF FF FF FF FF ...                       */
#define  PAT_INCB  9  	/* increase in byte                         */
#define  PAT_INCW	10 	/* increase in word                         */
#define  PAT_DECB  11 	/* decrease in byte                         */
#define  PAT_DECW  12 	/* decrease in word                         */
#define  PAT_CUST  13 	/* custome ... user-define pattern          */
#define  PAT_RAND  14	/* randomly generated patterns              */

#define  FRAME_TYPE                 0  /*    --> "ANY" frame type. */

                                       /* ENCAP_SPECIFIER_MIN = 1 */
#define  FRAME_DST_MAC_ADDR         1  /*    --> "ANY" frame destination MAC address. */
#define  FRAME_SRC_MAC_ADDR         2  /*    --> "ANY" frame source MAC address. */
#define  FRAME_LLC_DSAP             3  /*    --> "ONLY" LLC DSAP. */
#define  FRAME_LLC_SSAP             4  /*    --> "ONLY" LLC DSAP. */
#define  FRAME_LLC_CONTROL          5  /*    --> "ONLY" LLC CONTROL */
#define  FRAME_SNAP_OUI             6  /*    --> "ALL FOLLOWED:" SNAP OUI, classical IP OUI. */
#define  FRAME_SNAP_PROTOCOL_ID     7  /*    --> "ONLY" SNAP Protocol ID. */
#define  FRAME_LEC_ID               8  /*    --> "ALL FOLLOWED:" ATM_LANE802.3, ATM_LANE802.5 LECid */
#define  FRAME_AC_PAD               9  /*    --> "ONLY" ATM_LAND802.5 AC pad. */
#define  FRAME_FC                   10 /*    --> "ALL FOLLOWED:" ATM_LANE802.5 FC, Token Ring FC. */
#define  FRAME_AC                   11 /*    --> "ONLY" Token Ring AC. */
#define  FRAME_PAD                  12 /*    --> "ONLY" ATM SNAP Header pad. */
                                       /* ENCAP_SPECIFIER_MAX = 12 */

                                       /* PROTOCOL_SPECIFIER_MIN = 50 */
#define  FRAME_VERSION              50 /*    --> "ONLY" IP version. */
#define  FRAME_HEADER_LENGTH        51 /*    --> "ALL FOLLOWED:" IP length, IPX length. */
#define  FRAME_UDP_HEADER_LENGTH    52 /*    --> "ONLY" UDP length. */
#define  FRAME_TCP_HEADER_LENGTH    53 /*    --> "ONLY" TCP length. */
#define  FRAME_TYPE_SERVICE         54 /*    --> "ONLY" IP type of service. */
#define  FRAME_TOTAL_LENGTH         55 /*    --> "ONLY" IP total length. */
#define  FRAME_SEQUENCE             56 /*    --> "ALL FOLLOWED:" IP sequence, ICMP sequence. */
#define  FRAME_UDP_SEQUENCE         57 /*    --> "ONLY" UDP sequence. */
#define  FRAME_TCP_SEQUENCE         58 /*    --> "ONLY" TCP sequence. */
#define  FRAME_FLAGS                59 /*    --> "ONLY" IP flags. */
#define  FRAME_FRAGMENTS_OFFSET     60 /*    --> "ONLY" IP fragment and offset. */
#define  FRAME_TIME_TO_LIVE         61 /*    --> "ONLY" IP time to live. */
#define  FRAME_PROTOCOL             62 /*    --> "ONLY" IP protocol. */
#define  FRAME_HEADER_CRC           63 /*    --> "ALL FOLLOWED:" IP checksum, IPX checksum. */
#define  FRAME_UDP_HEADER_CRC       64 /*    --> "ONLY" UDP checksum. */
#define  FRAME_TCP_HEADER_CRC       65 /*    --> "ONLY" TCP checksum. */
#define  FRAME_DST_IP_ADDR          66 /*    --> "ANY" frame Destination IP Address. */
#define  FRAME_SRC_IP_ADDR          67 /*    --> "ANY" frame Source IP Address. */
#define  FRAME_SRC_PORT             68 /*    --> "ANY" frame Source Port number */
#define  FRAME_DST_PORT             69 /*    --> "ANY" frame Destination Port number. */
#define  FRAME_ACKNOWLEDGE          70 /*    --> "ONLY" TCP Acknowledge number. */
#define  FRAME_RESERVED             71 /*    --> "ONLY" TCP reserved bits. */
#define  FRAME_URG_BIT              72 /*    --> "ONLY" TCP URG bit. */
#define  FRAME_ACK_BIT              73 /*    --> "ONLY" TCP ACK bit. */
#define  FRAME_PSH_BIT              74 /*    --> "ONLY" TCP PSH bit. */
#define  FRAME_RST_BIT              75 /*    --> "ONLY" TCP RST bit. */
#define  FRAME_SYN_BIT              76 /*    --> "ONLY" TCP SYN bit. */
#define  FRAME_FIN_BIT              78 /*    --> "ONLY" TCP FIN bit. */
#define  FRAME_WINDOW_SIZE          79 /*    --> "ONLY" TCP window size. */
#define  FRAME_URGENT_POINTER       80 /*    --> "ONLY" TCP urgent pointer. */
#define  FRAME_HARDWARE_TYPE        81 /*    --> "ALL FOLLOWED:" ARP, RARP hardware type. */
#define  FRAME_HEADER_TYPE          82 /*    --> "ALL FOLLOWED:" ICMP Header type, IPX Header Type. */
#define  FRAME_HARDWARE_SIZE        83 /*    --> "ALL FOLLOWED:" ARP, RARP hardware size. */
#define  FRAME_PROTOCOL_TYPE        84 /*    --> "ALL FOLLOWED:" ARP, RARP protocol type. */
#define  FRAME_PROTOCOL_SIZE        85 /*    --> "ALL FOLLOWED:" ARP, RARP protocol size. */
#define  FRAME_OPERATION            86 /*    --> "ALL FOLLOWED:" ARP, RARP operations. */
#define  FRAME_HEADER_CODE          87 /*    --> "ONLY" ICMP Header codes. */
#define  FRAME_IDENTIFIER           88 /*    --> "ONLY" ICMP Identifier. */
#define  FRAME_SEN_MAC_ADDR         89 /*    --> "ANY" protocol MAC sender address. */
#define  FRAME_REC_MAC_ADDR         90 /*    --> "ANY" protocol MAC receiver address. */
#define  FRAME_HOP                  91 /*    --> "ONLY" IPX Hop */
#define  FRAME_DST_SOCKET           92 /*    --> "ONLY" IPX destination socket. */
#define  FRAME_SRC_SOCKET           93 /*    --> "ONLY" IPX source socket. */
#define  FRAME_ICMP_HEADER_CRC      94 /*    --> "ONLY" ICMP Header checksum. */
													/* PROTOCOL_SPECIFIER_MAX = 94 */

#endif
