/*****************************************************************************
 * gigitems.h
 * Gigabit Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

/****************************************************************************/
#ifndef _GIGITEMS_H_
#define _GIGITEMS_H_

#include "ettypes.h"

#define	GIG_BASE_NUM					0x9000

/* Gigabit direction defines */
#define	GIG_RECEIVE						1
#define	GIG_TRANSMIT					2

/****************************************************************************
 *  iType1 values
 ****************************************************************************/
#define GIG_STRUC_CAP_INFO  				(GIG_BASE_NUM + 2)	/* Get info about captured frames.  Note that "index" is the index of first frame and "count" is the index of the frame following the last frame. */
#define GIG_STRUC_CAP_COUNT_INFO			(GIG_BASE_NUM + 3)	/* Get number of frames captured. */
#define GIG_STRUC_CAP_DATA_INFO				(GIG_BASE_NUM + 4)	/* Get a frame's captured data. */
#define GIG_STRUC_CAPTURE_SETUP				(GIG_BASE_NUM + 5)	/* Set up capture. */
#define GIG_STRUC_TX						(GIG_BASE_NUM + 6)	/* Set up transmit. */
#define GIG_STRUC_ALT_TX					(GIG_BASE_NUM + 7)	/* Set up alternate transmit. */
#define GIG_STRUC_AUTO_FIBER_NEGOTIATE		(GIG_BASE_NUM + 8)	/* Set up AutoFiber Negotiation. */
#define GIG_STRUC_TRIGGER					(GIG_BASE_NUM + 9) 	/* Set up triggers. */
#define GIG_STRUC_CARD_INFO					(GIG_BASE_NUM + 10)	/* Get card information. */
#define GIG_STRUC_COUNTER_INFO				(GIG_BASE_NUM + 11)	/* Get counter information. */
#define GIG_STRUC_RATE_INFO					(GIG_BASE_NUM + 12)	/* Get rate information. */
#define GIG_STRUC_VFD3						(GIG_BASE_NUM + 13)	/* Set VFD3 data, using an array of unsigned chars.  
																					To specify VFD3 offset and range, use GIG_STRUC_TX. */
#define GIG_STRUC_FILL_PATTERN				(GIG_BASE_NUM + 14)	/* Set main background pattern, using an array of unsigned chars. */
#define GIG_STRUC_BG1						(GIG_BASE_NUM + 15)	/* Set background pattern for alternate frame, using an array of unsigned chars. */
#define GIG_STRUC_BG2						(GIG_BASE_NUM + 16)	/* Set background pattern for periodic frame, using an array of unsigned chars. */
#define GIG_STRUC_SS1						(GIG_BASE_NUM + 17)
#define GIG_STRUC_SS2						(GIG_BASE_NUM + 18)
#define GIG_CMD_CLEAR_STATS					(GIG_BASE_NUM + 19)
#define GIG_STRUC_IMAGE_VERSIONS			(GIG_BASE_NUM + 20)	/* Gets version information about the hardware and firmware. */
#define GIG_STRUC_DEBUG_DISPLAY				(GIG_BASE_NUM + 21)
#define GIG_STRUC_LED						(GIG_BASE_NUM + 22)
#define GIG_STRUC_CAPTURE_DESCRIPTION		(GIG_BASE_NUM + 23)
#define GIG_STRUC_CAPTURE_SETUP_READBACK	(GIG_BASE_NUM + 24)
#define GIG_STRUC_TX_READBACK				(GIG_BASE_NUM + 25)
#define GIG_STRUC_ALT_TX_READBACK			(GIG_BASE_NUM + 26)
#define GIG_STRUC_TRIGGER_READBACK			(GIG_BASE_NUM + 27)
#define GIG_STRUC_AUTO_NEGO_READBACK		(GIG_BASE_NUM + 28)
#define GIG_STRUC_FILL_PATTERN_READBACK		(GIG_BASE_NUM + 29)
#define GIG_STRUC_BG1_READBACK				(GIG_BASE_NUM + 30)
#define GIG_STRUC_BG2_READBACK				(GIG_BASE_NUM + 31)
#define GIG_STRUC_SS1_READBACK				(GIG_BASE_NUM + 32)
#define GIG_STRUC_SS2_READBACK				(GIG_BASE_NUM + 33)
#define GIG_STRUC_VFD3_READBACK				(GIG_BASE_NUM + 34)
#define GIG_STRUC_TX_READ_WRITE				(GIG_BASE_NUM + 35)
#define GIG_STRUC_TRIGGER_READ_WRITE		(GIG_BASE_NUM + 36)
#define GIG_STRUC_RESET						(GIG_BASE_NUM + 37)
#define GIG_STRUC_INIT						(GIG_BASE_NUM + 38)
#define GIG_STRUC_IMAGE_DOWNLOAD			(GIG_BASE_NUM + 39)
#define GIG_STRUC_STOP						(GIG_BASE_NUM + 40)
#define GIG_STRUC_RESTART					(GIG_BASE_NUM + 41)
#define GIG_STRUC_STEP						(GIG_BASE_NUM + 42)
#define GIG_STRUC_SET_PORT_INTO_GROUP		(GIG_BASE_NUM + 43)
#define GIG_STRUC_GET_PORT_GROUP_INFO		(GIG_BASE_NUM + 44)
#define GIG_STRUC_MEMORY_WRITE				(GIG_BASE_NUM + 45)
#define GIG_STRUC_MEMORY_READ				(GIG_BASE_NUM + 46)
#define GIG_STRUC_TEST_RAM					(GIG_BASE_NUM + 47)
#define GIG_STRUC_TEST_CAPTURE_MEMORY		(GIG_BASE_NUM + 48)
#define GIG_STRUC_TEST_TX_LOOPBACK			(GIG_BASE_NUM + 49)
#define GIG_STRUC_TEST_RX_LOOPBACK			(GIG_BASE_NUM + 50)
#define GIG_STRUC_TEST_FLASH_CRC			(GIG_BASE_NUM + 51)
#define GIG_STRUC_LOAD_FPGA					(GIG_BASE_NUM + 52)
#define GIG_STRUC_UPLOAD_ERROR_LOG			(GIG_BASE_NUM + 53)

/* New  gig struct autofibernegotiate & gig mac configure */
#define GIG_STRUC_AFN_CONFIG				(GIG_BASE_NUM + 61) /* Set up AutoFiber Negotiation. */
#define GIG_STRUC_MAC_CONFIG				(GIG_BASE_NUM + 62) /* Set up Mac configure. */
#define GIG_STRUC_MAC_CONFIG_INFO			(GIG_BASE_NUM + 63) /* Get Mac configure. */

/* XenPak command */
#define XENPAK_PHY_CONFIG					(GIG_BASE_NUM + 64) /* Set layer 2 protocol mode of operation. */
#define XENPAK_PHY_CONFIG_INFO				(GIG_BASE_NUM + 65) /* Get layer 2 protocol mode of operation. */
#define XENPAK_NVR_CONFIG					(GIG_BASE_NUM + 66) /* Write to a specific NVR.*/ 
#define XENPAK_NVR_CONFIG_INFO				(GIG_BASE_NUM + 67) /* Read from a specific NVR.*/
#define XENPAK_ALARM_CONFIG					(GIG_BASE_NUM + 68) /* Set the configure specific alarm.*/
#define XENPAK_ALARM_CONFIG_INFO			(GIG_BASE_NUM + 69) /* Get the configure specific alarm.*/
#define XENPAK_ALARM_STATUS_INFO			(GIG_BASE_NUM + 70) /* Get the transmit, receive and link status alarm. */
#define XENPAK_PROFILE_INFO					(GIG_BASE_NUM + 71) /* Get the current XENPAK profile. */

/* XAUI command */
#define XAUI_PRBS_CONFIG					(GIG_BASE_NUM + 72) /* Enable or disable the PRBS on channel A, B, C or D.*/
#define XAUI_PRBS_CONFIG_INFO				(GIG_BASE_NUM + 73) /* Read the PRBS configuration. */
#define XAUI_PRBS_STATUS_INFO				(GIG_BASE_NUM + 74) /* Read the PRBS running status and per channel error counter.*/ 

#define GIG_STRUC_AUTO_FIBER_NEGOTIATE_INFO			(GIG_BASE_NUM + 75) /* Read the AutoFiber Negotiation.*/ 

/*XFP Commmands */
#define XFP_PROFILE_INFO					(GIG_BASE_NUM + 76) /* Get the current XFP profile. */

/****************************************************************************/

#define GIG_FILL_SELECTED   0
#define GIG_FILL_RANDOM    1

#define GIG_MAX_CAPTURE_FRAMES 96 /* max number of frames to get info about */


/****************************************************************************
 *  structures to be used with HTSetStructure
 ****************************************************************************/

/******************************************************************************
CAPTURE SETUP PARAMETERS

Structure:   GIGCaptureSetup
iType1:      GIG_STRUC_CAPTURE_SETUP
Function:    HTSetStructure

GIGCaptureSetup Description:

This structure sets the capture parameters.  If ucFilterMode is
enabled, the card will only capture frames with CRC errors, Rx
triggers, Tx triggers, or RC errors, as determined by the
ucCRCErrors, ucRxTriggers, ucTxTriggers, and ucRCErrors fields,
respectively.  If ucStartStopOnConditionMode is enabled, the card
will START capturing upon receiving a frame meeting the conditions
determined by the first four parameters (ucCRCErrors, etc).  If
it is disabled, the card will STOP capturing upon receiving a frame
meeting those conditions.  If ucFilterMode is disabled, the card
will capture all frames (up to a maximum of 2048). Use the
ucStartStop field to start or stop capturing frames. Capture must
be stopped before examining any captured data.

*******************************************************************/
typedef struct tagGIGCaptureSetup
{
 unsigned char ucCRCErrors;  /* 1 = enable, 0 = disable: 0=default*/
 unsigned char ucRxTrigger;  /* 1 = enable, 0 = disable: 0=default*/
 unsigned char ucTxTrigger;  /* 1 = enable, 0 = disable: 0=default*/
 unsigned char ucRCErrors;   /* 1 = enable, 0 = disable: 0=default*/
 unsigned char ucFilterMode; /* 1 = capture filtered frames, 
										  0 = capture all frames: 0=default; 
										  setting to 1 will cause 64-byte-only 
										  capture */
 unsigned char ucStartStopOnConditionMode; /* 1 = start on condition 
															 0 = stop on condition 
															 (0 = default); setting 
															 to 1 will cause 64-byte-
															 only capture */
 unsigned char uc64BytesOnly;/* 1 = enable, 0 = disable: 0=default*/
 unsigned char ucLast64Bytes;/* 1=last 64 bytes, 0 = first 64 bytes
										 (0=default)                        */
 unsigned char ucStartStop;  /* 1=start capture, 0 = stop capture
										 (0=default)                        */
} GIGCaptureSetup;
/******************************************************************************
 * GIGCaptureSetup Comment:

The gigabit card hardware imposes a limitation on capturing trigger
frames.  When capturing trigger frames only (ucFilterMode = 1, and
ucRxTrigger = 1 or ucTxTrigger = 1) the interframe gap must be at
least 128ns.  If the gap is set to the gigabit card minimum of 96ns,
the card will capture the frame following the trigger frame instead.
Also, enabling ucFilterMode and/or ucStartStopOnConditionMode will
cause the gigabit card to only capture 64 bytes, even if uc64BytesOnly
is disabled.

******************************************************************************/


/******************************************************************************
 * TRANSMIT PARAMETERS
 *
 * Structure:   GIGTransmit
 * iType1:      GIG_STRUC_TX
 * Function:    HTSetStructure
 * GIGTransmit Description:

This structure sets all the basic transmit parameters for the
gigabit card, including the VFDs.  

References to "Main" frame
refer to the standard frame (as determined by the transmit
parameters); references to the "BG1" frame refer to the alternate
frame; and references to the "BG2" frame refer to the periodic
frame.  

Background data must be set using GIG_STRUC_FILL_PATTERN,
GIG_STRUC_BG1, and GIG_STRUC_BG2, all with arrays of unsigned
chars, for the main frame, alternate frame, and periodic frame,
respectively.  

Also, while the VFD3 parameters are set in the
GIGTransmit structure, the VFD3 data itself is set using
GIG_STRUC_VFD3 with an array of unsigned chars.

The ucControlBits element is supported only for the GX-1420B SmartCard. 
Possible logical OR values are:
   GIG_CONTROL_IP_FLOW_GENERATE     0x01
   GIG_CONTROL_IP_CHECKSUM_INHIBIT  0x02
   GIG_CONTROL_VLAN_GENERATE        0x04

The ucError element is supported only for the GX-1420B SmartCard.
Possible logical OR values are:
   GIG_TRANSMIT_ERROR_GENERATE      0x01
   GIG_IP_CHECKSUM_ERROR_GENERATE   0x02

Possible values for ucTransmitMode are:
   GIG_CONTINUOUS_MODE              0
   GIG_SINGLE_BURST_MODE            1
   GIG_MULTIBURST_MODE              3
   GIG_CONTINUOUS_MULTIBURST_MODE   2

LAN-332xA modules do not support the Next Page bit (0x8000) or Acknowledge 
bit (0x4000).

LAN-3710AE/AL/AS:
These modules support the following fields:
uiMainLength, ulGap, ucMainCRCError, uiVFD1Offset, iVFD1Range, ucVFD1Mode,
ulVFD1CycleCount, ucVFD1Data[8], uiVFD2Offset, iVFD2Range, ucVFD2Mode, 
ulVFD2CycleCount, ucVFD2Data[8], uiVFD3Offset uiVFD3Range, ulVFD3Count, 
ucVFD3Mode, ulBurstCount, ulMultiburstCount, ulInterBurstGap, ucTransmitMode,
uiVFD1BlockCount, uiVFD2BlockCount, uiVFD3BlockCount. 

********************************************************************/
typedef struct tagGIGTransmit
{
 unsigned short uiMainLength;    /* length of main packet (bytes)
                                          (60 = default) */
 unsigned char  ucPreambleByteLength;   /* preamble length (bytes)
																 (8 = default) */
 unsigned char  ucFramesPerCarrier;     /* reserved, forced to 1
																 (1 = default) */
 unsigned long  ulGap;                  /* interframe gap (ns)
																 (96 = default) */

 unsigned char  ucMainRandomBackground; /* 1 = enable, 0 = disable
																 (0 = default) */
 unsigned char  ucBG1RandomBackground;  /* 1 = enable, 0 = disable
																 (0 = default) */
 unsigned char  ucBG2RandomBackground;  /* 1 = enable, 0 = disable
																 (0 = default) */
 unsigned char  ucSS1RandomBackground;  /* 1 = enable, 0 = disable
																 (0 = default) */
 unsigned char  ucSS2RandomBackground;  /* 1 = enable, 0 = disable
																 (0 = default) */

 unsigned char  ucMainCRCError;/*1 = enable, 0 = disable:0=default*/
 unsigned char  ucBG1CRCError;/*1 = enable, 0 = disable: 0=default*/
 unsigned char  ucBG2CRCError;/*1 = enable, 0 = disable: 0=default*/
 unsigned char  ucSS1CRCError;/*1 = enable, 0 = disable: 0=default*/
 unsigned char  ucSS2CRCError;/*1 = enable, 0 = disable: 0=default*/

 unsigned char  ucJabberCount;  /* for each unit, add 8K bytes to
											   each frame to simulate jabber 
											   (0 = default) */
 unsigned char  ucLoopback;     /* 1 = enable, 0 = disable
														 (0 = default) */

 unsigned long  ulBG1Frequency; /* no. of main frames between each
                                    alternate frame (0 = default) */
 unsigned long  ulBG2Frequency; /* gap between periodic frames, in
												units of 32ns (0 = default) */

 unsigned short uiBG1Length;    /* length of alternate frame (bytes)
													  (0 = default) */
 unsigned short uiBG2Length;    /* length of periodic frame (bytes)
													  (0 = default) */
 unsigned short uiSS1Length;    /* reserved -- not currently in use
													  (0 = default) */
 unsigned short uiSS2Length;    /* reserved -- not currently in use
													  (0 = default) */

 unsigned short uiLinkConfiguration; /* use GIG_AFN_XXX values
															 (0x20 = default)*/

 unsigned short uiVFD1Offset;   /* bit offset of VFD1: 0=default */
 short          iVFD1Range;     /* range of VFD1 (no. of bytes)
															 (0 = default) */
 unsigned char  ucVFD1Mode;     /* GIG_VFD_OFF, GIG_VFD_STATIC,
                                   GIG_VFD_INCREMENT,
                                   GIG_VFD_DECREMENT, or
                                   GIG_VFD_RANDOM 
											  (GIG_VFD_OFF = default) */
 unsigned long  ulVFD1CycleCount;/* no. of blocks before resetting
                                to initial VFD1 pattern: 0=default*/
 unsigned char  ucVFD1Data[8]; /* initial VFD1 data (0 = default) */

 unsigned short uiVFD2Offset;  /* bit offset of VFD2: 0 = default */
 short          iVFD2Range;    /* range of VFD2 (number of bytes)
															 (0 = default) */
 unsigned char  ucVFD2Mode;    /*  GIG_VFD_OFF, GIG_VFD_STATIC,
                                   GIG_VFD_INCREMENT,
                                   GIG_VFD_DECREMENT, or
                                   GIG_VFD_RANDOM 
											  (GIG_VFD_OFF = default) */
 unsigned long  ulVFD2CycleCount; /* no. of blocks before resetting
										 to initial VFD2 pattern: 0=default*/
 unsigned char  ucVFD2Data[8]; /* initial VFD2 data: 0=default */

 unsigned short uiVFD3Offset;  /* bit offset of VFD3: 0 = default */
 unsigned short uiVFD3Range;   /* range of VFD3 (number of bytes of
										 VFD3 data per frame) (0 = default).  
                               NOTE:  For the LAN-3200A, GX-1405 
                               and GX-1420 cards, if uiVFD3BlockCount
                               is used (>=2), then the max VFD3 range
                               is limited to 4. */
 unsigned long  ulVFD3Count;   /* no. of frames worth of VFD3 data (0 = default).
                                  NOTE:  This field does not apply to the LAN TeraMetrics modules. */
 unsigned char  ucVFD3Mode;    /* GIG_VFD3_OFF or GIG_VFD3_ON
												(GIG_VFD3_OFF = default) */

 unsigned char  ucMainBG1Mode; /* reserved -- not currently in use
															 (0 = default) */

 unsigned long  ulBurstCount;      /* number of frames per burst;
												  when ucTransmitMode is set to
												  GIG_CONTINUOUS_MODE,
												  ulBurstCount must be greater
												  than 0  (1 = default) */
 unsigned long  ulMultiburstCount; /* no. of bursts per multi-burst
															 (1 = default) */
 unsigned long  ulInterBurstGap;   /* gap between multi-bursts
												 (nanoseconds) (0 = default)  */
 unsigned char  ucTransmitMode;    /* see GIG_xxx_MODE definitions
											  (GIG_CONTINUOUS_MODE = default)*/
 unsigned char  ucEchoMode;        /* 1 = enable, 0 = disable
															(0 = default) */
 unsigned char  ucPeriodicGap;     /* gap between main frame and
												  periodic frame, in increments
												  of 32ns; valid values from 0 to
												  7 (0 to 224ns), but less than 3
												  defaults to 3 (96ns)
												  (0 = default) */
 unsigned char  ucCountRcverrOrOvrsz;/* 0 = count oversized pkt errs
													 1 = count receive errors
													 (0 = default) */
 unsigned char  ucGapByBitTimesOrByRate;	/* 0 = set ulGap parameter
														as the number of ns between
														the end of one packet and
														the start of the next;
														1 = set ulGap parameter as
														the number of ns between 
														the start of one packet and
														the start of the next.
														(0 = default) */
 unsigned char  ucRandomLengthEnable;/* 1 = enable random pkt length
													 0 = disable (0 = default) */

 unsigned short  uiVFD1BlockCount; /* no. of VFD1 pattern repeats
												before next pattern: 1=default*/
 unsigned short  uiVFD2BlockCount; /* no. of VFD2 pattern repeats
												before next pattern: 1=default*/
 unsigned short  uiVFD3BlockCount; /* no. of VFD3 pattern repeats
												before next pattern: 1=default.
                                    */
 unsigned char	  ucControlBits;	  /* GIG_CONTROL_IP_FLOW_GENERATE,
                                    GIG_CONTROL_IP_CHECKSUM_INHIBIT,
                                    GIG_CONTROL_VLAN_GENERATE,
												(0 = default) */
 unsigned char   ucError;          /* 0 = no errors are generated,
                                      GIG_TRANSMIT_ERROR_GENERATE         
                                      GIG_IP_CHECKSUM_ERROR_GENERATE */
} GIGTransmit;

/******************************************************************************
 * GIGTransmit Comment:

The ulBurstCount field should be set to a value greater than 0 when
ucTransmit mode is set to GIG_CONTINUOUS_MODE.  Otherwise, the ulGap
value will not take effect, and frames will be transmitted with a
minimum gap.  Also, to ensure correct card behavior, the
ucFramesPerCarrier field should be set to 1.

For the uiLinkConfiguration field, use the GIG_AFN_XXX definitions:

GIG_AFN_RESERVED0     0x0001
GIG_AFN_RESERVED1     0x0002
GIG_AFN_RESERVED2     0x0004
GIG_AFN_RESERVED3     0x0008
GIG_AFN_RESERVED4     0x0010
GIG_AFN_FULL_DUPLEX   0x0020
GIG_AFN_HALF_DUPLEX   0x0040
GIG_AFN_PAUSE1        0x0080
GIG_AFN_PAUSE2        0x0100
GIG_AFN_RESERVED9     0x0200
GIG_AFN_RESERVED10    0x0400
GIG_AFN_RESERVED11    0x0800
GIG_AFN_REMOTE_FAULT1 0x1000
GIG_AFN_REMOTE_FAULT2 0x2000
GIG_AFN_ACKNOWLEDGE   0x4000
GIG_AFN_NEXT_PAGE     0x8000

Some GIG_AFN_XXX bits can be combined:

PAUSE2			PAUSE1		  	Pause Flow Control
0				  	0					None
0					1					Symmetric
1					0					Asymmetric->Link Partner
1					1					Asymmetric->Local Device

REMOTE_FAULT2	REMOTE_FAULT1	Remote Fault
0				  	0					Link OK
0					1					Link Failure
1					0					Offline
1					1					Link Configuration Error

******************************************************************************/

/* VFD patterns */
#define GIG_VFD_OFF          4
#define GIG_VFD_STATIC       0
#define GIG_VFD_INCREMENT    1
#define GIG_VFD_DECREMENT    2
#define GIG_VFD_RANDOM       3

#define GIG_VFD3_OFF         0
#define GIG_VFD3_ON          1

/* Transmit modes */
#define GIG_CONTINUOUS_MODE   0
#define GIG_SINGLE_BURST_MODE 1
#define GIG_MULTIBURST_MODE   3
#define GIG_CONTINUOUS_MULTIBURST_MODE 2

/* AutoFiber Negotiation values */
#define GIG_AFN_RESERVED0     0x0001
#define GIG_AFN_RESERVED1     0x0002
#define GIG_AFN_RESERVED2     0x0004
#define GIG_AFN_RESERVED3     0x0008
#define GIG_AFN_RESERVED4     0x0010
#define GIG_AFN_FULL_DUPLEX   0x0020
#define GIG_AFN_HALF_DUPLEX   0x0040
#define GIG_AFN_PAUSE1        0x0080
#define GIG_AFN_PAUSE2        0x0100
#define GIG_AFN_RESERVED9     0x0200
#define GIG_AFN_RESERVED10    0x0400
#define GIG_AFN_RESERVED11    0x0800
#define GIG_AFN_REMOTE_FAULT1 0x1000
#define GIG_AFN_REMOTE_FAULT2 0x2000
#define GIG_AFN_ACKNOWLEDGE   0x4000
#define GIG_AFN_NEXT_PAGE     0x8000

/* additional control bit values */
#define GIG_CONTROL_IP_FLOW_GENERATE		0x01
#define GIG_CONTROL_IP_CHECKSUM_INHIBIT	0x02
#define GIG_CONTROL_VLAN_GENERATE			0x04

/* define ucError constants */
#define GIG_TRANSMIT_ERROR_GENERATE       0x01
#define GIG_IP_CHECKSUM_ERROR_GENERATE    0x02

/******************************************************************************
 * ALTERNATE TRANSMIT PARAMETERS
 *
 * Structure:   GIGAltTransmit
 * iType1:      GIG_STRUC_ALT_TX
 * Function:    HTSetStructure
 * GIGAltTransmit Description:

This structure sets some additional transmit parameters,
specifically to enable the alternate and periodic frames and to
enable PAUSE frame recognition.  Note that the periodic frame will
begin transmitting as soon as this structure is sent with ucEnableBG2
set to 1.  It will continue transmitting with the periodic rate set
by the GIGTransmit structure (ulBG2Frequency field) until the
GIGAltTransmit structure is sent again with ucEnableBG2 set to 0.

Note: Since this command is only valid in traditional mode, please use the
ucEnableHoldoff field in the GIGAutoFiberNegotiate(GIG_STRUC_AUTO_FIBER_NEGOTIATE)
structure to configure PAUSE frame recognition when SmartMetrics streams are
defined.  If the card(i.e. LAN-3300A/3301A) does not support the
GIG_STRUC_AUTO_FIBER_NEGOTIATE command, then please call GIG_STRUC_ALT_TX before
defining streams in order for PAUSE frame recognition to work correctly.

*****************************************************************************/
typedef struct tagGIGAltTransmit
{
 unsigned char   ucEnableSS1;     /* reserved: 0 = default  */
 unsigned char   ucEnableSS2;     /* reserved: 0 = default  */
 unsigned char   ucEnableBG1;     /* enable alternate frame
															 (0 = default) */
 unsigned char   ucEnableBG2;     /* enable periodic frame
															 (0 = default) */
 unsigned char   ucEnableHoldoff; /* Enable PAUSE frame
												 recognition. (0 = default)
												 NOTE: Please read the comments above
												 regarding the use of this field */
 unsigned char   ucReserved[3];   /* reserved: 0 = default  */
} GIGAltTransmit;

/******************************************************************************
 * AUTO NEGOTIATION PARAMETERS
 *
 * Structure:   GIGAutoFiberNegotiate
 * iType1:      GIG_STRUC_AUTO_FIBER_NEGOTIATE
                /GIG_STRUC_AUTO_FIBER_NEGOTIATE_INFO
 * Function:    HTSetStructure/HTGetStructure
 * GIGAutoFiberNegotiate Description:

This structure sets the parameters for AutoFiber Negotiation.
Please note that the uiLinkConfiguration field of this structure
is currently unused. Instead, use the uiLinkConfiguration in the
GIGTransmit structure.

NOTE: 

ucInfiniteRetryMode:
GIG_RETRY_16	      0  Retry 16
GIG_RETRY_INFINITE   1  Retry infinite 
GIG_RETRY_16_RX      2  Retry 16 and wait for receive packet to retry again

These fields currently only apply for the LAN-3320A, LAN-3321A, LAN-3324A, 
LAN-3325A and LAN-3327A cards:
 ucMode, ucRestart and uiLinkConfiguration(fiber mode ONLY)
 ucPreambleLen, ucEnableJumboFrame, ucCollisionBackoffAggressiveness and
ucInfiniteRetryMode(copper mode ONLY)

These fields currently only apply for the LAN-3301A/3300A cards:
	ucPreambleLen
	ucEnableJumboFrame
	ucCollisionBackoffAggressiveness
	ucInfiniteRetryMode

uiLinkConfiguration:
   -- use the uiLinkConfiguration field
			in GIGTransmit (0 = default) 

The ucEnableHoldoff field does not apply for the LAN-6200A/3200A cards.  To enable
PAUSE frame recognition on these cards, please use the ucEnableHoldoff field for the
GIG_STRUC_ALT_TX command instead. 

LAN-332xA modules do not support the Next Page bit (0x8000) or Acknowledge 
bit (0x4000).
******************************************************************************/
typedef struct tagGIGAutoFiberNegotiate
{
 unsigned char   ucMode;        /* 1 = enable auto-negotiation,
								   0 = disable (0 = default) */
 unsigned char   ucRestart;     /* 1 = restart auto-negotiation,
								   0 = do not restart (0 = default) */
 unsigned short  uiLinkConfiguration; /* reserved
									     -- use the uiLinkConfiguration field
									     in GIGTransmit (0 = default) */
 unsigned char  ucEnableCCode;	 /* 1 = Use C Code (uiLinkConfiguration)
                                    for negotiation, 0 = or not
                                    (0 = default) */
 unsigned char  ucEnableHoldoff; /* enable PAUSE frame recognition
                                    (0 = default) */
 unsigned char	ucIgnoreLink;	 /* 1 = enable transmitting to continue even though 
								    Autonegotiation is not complete. For LAN-3200 cards only.
								    0 = Normal behaviour */
 unsigned char ucPreambleLen;    /* Preamble length: Valid lengths are 4,8,12 and 16. */
 unsigned char ucEnableJumboFrame;	/* Enable/disable jumbo frames */
 unsigned char	ucCollisionBackoffAggressiveness;	/* Valid values are from
                                                       1 to 10 */
 unsigned char ucInfiniteRetryMode; /* Retry mode after a collision occurs.
                                       Use GIG_RETRY_INFINITE, GIG_RETRY_16 or GIG_RETRY_16_RX */
 unsigned char ucReserved[2];       /* reserved -- not currently in use
                                       (0 = default) */
} GIGAutoFiberNegotiate;

/* Infinite retry modes */
#define GIG_RETRY_16	      0  /* Retry 16 */
#define GIG_RETRY_INFINITE 1  /* Retry infinite */
#define GIG_RETRY_16_RX    2  /* Retry 16 and wait for receive packet to retry again */


/******************************************************************************
 * AUTO NEGOTIATION CONFIG
 *
 * Structure:   GIGAfnConfig
 * iType1:      GIG_STRUC_AFN_CONFIG
 * Function:    HTSetStructure
 * GIGAfnConfig Description:

This structure sets the parameters for AutoFiber Negotiation.
Please note that the uiLinkConfiguration field of this structure
is currently unused. Instead, use the uiLinkConfiguration in the
GIGTransmit structure.

******************************************************************************/
typedef struct tagGIGAfnConfig
{
 unsigned char ucMode;					/* 1 = enable auto-negotiation,
												0 = disable (0 = default) */
 unsigned char ucRestart;				/* 1 = restart auto-negotiation,
												0 = do not restart (0 = default) */
 unsigned short uiLinkConfiguration;	/* reserved
											-- use the uiLinkConfiguration field
												in GIGTransmit (0 = default) */
 unsigned char ucEnableCCode;			/* 1 = Use C Code (uiLinkConfiguration)
												for negotiation, 0 = or not
												(0 = default) */
 unsigned char ucEnableHoldoff;			/* enable PAUSE frame recognition
												(0 = default) */
 unsigned char ucIgnoreLink;			/* 1 = enable transmitting to continue even though 
											Autonegotiation is not complete. For LAN-3200 cards only.
											0 = Normal behaviour */
 unsigned char ucReserved[32];			/* reserved -- not currently in use
											(0 = default) */
} GIGAfnConfig;


/******************************************************************************
 * GIG MAC CONFIG
 *
 * Structure:   GIGMacConfig
 * iType1:      GIG_STRUC_MAC_CONFIG/GIG_STRUC_MAC_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * GIGMacConfig Description:

This structure sets and read back the parameters for MAC configure.

NOTE:

The following table contains information about field/card compatibility.

	                              LAN-3310/3311	LAN-330x    LAN-332x          XLW-3720/3721
ucPreambleLen	                  Y	            Y	         Y	               Y
ucEnableJumboFrame	            Y	            Y	         Y	               Y
ucCollisionBackoffAggressiveness	N	            Y	         Y (Copper ONLY)	N
ucInfiniteRetryMode	            N	            Y	         Y (Copper ONLY)	N
ucEnableObeyPause	               Y	            Y	         Y	               Y
ucLoopBackMode	                  Y	            Y	         Y	               Y
uiJumboFrameSize	               Y	            Y	         Y	               Y
uiVLANTPID	                     Y	            Y	         Y	               Y
ucMode	                        Y	            N	         Y (Fiber ONLY)	   Y
ucRestart	                     Y	            N	         Y (Fiber ONLY)	   Y
  
For ucPreambleLen, use direct numbers such as 4,8,12,16,20,24,28,32

The LAN-33xx modules supports the following loopback modes:
	GIG_PHY_LOOP_DOWN           	
	GIG_PHY_LOOP_PBUS
	GIG_PHY_LOOP_LOCAL_PHY
	GIG_PHY_LOOP_REMOTE_PHY
	GIG_PHY_LOOP_LOCAL_XCVR
	GIG_PHY_LOOP_REMOTE_XCVR
	GIG_PHY_LOOP_MONITOR_PHY

The XLW-372x modules supports the following loopback modes:

   GIG_PHY_LOOP_LOCAL_XGMII    	 						
 	GIG_PHY_LOOP_LOCAL_DTE_XS   	 						
	GIG_PHY_LOOP_REMOTE_PHY_XS  						
 	GIG_PHY_LOOP_LOCAL_PCS                                                               

uiJumboFrameSize - Used to set jumbo frame size limit on the LAN-33xx and XLW-372x
cards. The maximum limit for jumbo frame is 10K. If its set to a value lower
than 1518 the legal frame size will be set to 1518 (non-vlan),1522(1 vlan), 
1526(2 vlans)... and the jumbo frame limit will be 9018 (non-vlan), 9022 (1 vlan)
9026 (2 vlan) ...  These values are also the default.
******************************************************************************/
typedef struct tagGIGMacConfig
{
 unsigned char ucPreambleLen;						/* Preamble length */
 unsigned char ucEnableJumboFrame;			   /* Enable/disable jumbo frames 
                                               1 = enable, 0 = disable (default) */

 unsigned char ucCollisionBackoffAggressiveness; /* Valid values are from
														         1 to 10 */
 unsigned char ucInfiniteRetryMode;					/* Retry mode after a collision occurs.
														         Use GIG_RETRY_INFINITE or GIG_RETRY_16 */

 unsigned char ucEnableObeyPause;					/* Obey PAUSE */

 unsigned char ucLoopBackMode;						/* Loopback modes:

                                                   For the LAN-33xx modules:
															         GIG_PHY_LOOP_DOWN           	
															         GIG_PHY_LOOP_PBUS
															         GIG_PHY_LOOP_LOCAL_PHY 
															         GIG_PHY_LOOP_REMOTE_PHY
															         GIG_PHY_LOOP_LOCAL_XCVR
															         GIG_PHY_LOOP_REMOTE_XCVR
															         GIG_PHY_LOOP_MONITOR_PHY

                                                   For the XLW-372x modules:
                                                      GIG_PHY_LOOP_LOCAL_XGMII    	 						
 															         GIG_PHY_LOOP_LOCAL_DTE_XS   	 						
															         GIG_PHY_LOOP_REMOTE_PHY_XS  						
 															         GIG_PHY_LOOP_LOCAL_PCS                                                               
                                                */
  unsigned short uiJumboFrameSize;     /* Selectable jumbo frame size limit */
  unsigned short uiVLANTPID;           /* Specifies the VLAN TPID to use in the detection of VLAN
                                          frames on the receive side.  0 indicates to use the 
                                          default value of 0x8100.
                                          NOTE:  When receiving frames with multiple VLAN tags, the
                                          last VLAN tag's TPID must be set to 0x8100 for the port
                                          to detect these frames as VLAN frames. For example,
                                             9100 8100 (VLAN frame will be detected)
                                             9100 9100 (VLAN frame will not be detected)
                                       */
  unsigned char ucMode;                /* 1 = enable auto-negotiation, 0 = disable */
  unsigned char ucRestart;             /* 1 = restart auto-negotiation, 0 = do not restart */
  unsigned char ucEnableDeficitIdleCount;  /* For only XLW_3720/21 and XFP3730/31 cards 
                                              0 disable (default)
                                              1 enable */ 	
  unsigned short uiLinkConfiguration;  /* For only Terametrics LAN XD cards.
														If uiLinkConfiguration  field is used either in
														GIG_STRUC_TX or GIG_STRUC_AUTO_FIBER_NEGOTIATE use 
														the same value for this field */
  unsigned char ucReserved[27];        /* reserved */
} GIGMacConfig;
/******************************************************************************
 * GIGMacConfig Comment:

ucLoopBackMode:
1. The Local XGMII is a loopback that closes the loop at one of our 
   internal FPGA's before the data reaches the XGMII interface.
2. The Local DTE XS  is a loopback in the XGXS DTE which is an XGMII
   to XAUI interface chip located in the XLW-3720A/3721A card.
3. The Remote PHY XS is a loopback in the XGXS PHY which is a XAUI 
   to XGMII device located in the local XLW-3720A/3721A module.
4. The Local PCS is a loopback in the PCS (Physical Coding Sublayer) 
   located in the local XLW-3720A/3721A module.
******************************************************************************/
 /* preamble len values */
#define GIG_PREAMB_LEN_4_BYTES      0
#define GIG_PREAMB_LEN_8_BYTES      1  
#define GIG_PREAMB_LEN_12_BYTES     2
#define GIG_PREAMB_LEN_16_BYTES     3
#define GIG_PREAMB_LEN_20_BYTES     4 /* Etherphy2 */
#define GIG_PREAMB_LEN_24_BYTES     5 /* Etherphy2 */
#define GIG_PREAMB_LEN_28_BYTES     6 /* Etherphy2 */
#define GIG_PREAMB_LEN_32_BYTES     7 /* Etherphy2 */

/* Infinite retry modes */
#define GIG_RETRY_16			0  /* Retry 16 */
#define GIG_RETRY_INFINITE		1  /* Retry infinite */
#define GIG_RETRY_16_RX			2  /* Retry 16 and wait for receive packet to retry again */

/* The following loopback modes are supported: */
#define GIG_PHY_LOOP_DOWN           	0
#define GIG_PHY_LOOP_PBUS           	1
#define GIG_PHY_LOOP_LOCAL_PHY      	2
#define GIG_PHY_LOOP_REMOTE_PHY     	3
#define GIG_PHY_LOOP_LOCAL_XCVR     	4
#define GIG_PHY_LOOP_REMOTE_XCVR    	5
#define GIG_PHY_LOOP_MONITOR_PHY    	PHY_LOOP_REMOTE_XCVR

/*The following loopback modes are supported for XENPAK/XAUI card:*/
#define GIG_PHY_LOOP_LOCAL_XGMII    	 6 
#define GIG_PHY_LOOP_LOCAL_DTE_XS   	 7 
#define GIG_PHY_LOOP_REMOTE_PHY_XS		 8 
#define GIG_PHY_LOOP_LOCAL_PCS      	 9


/******************************************************************************
 * TRIGGER PARAMETERS
 *
 * Structure: GIGTrigger
 * iType1:  GIG_STRUC_TRIGGER
 * Function: HTSetStructure
 * GIGTrigger Description:

This structure sets up the triggers for a gigabit card.  This
structure is similar to the HTTrigger function.  The ucTriggerMode
field can be set to specify what combination of triggers must occur to
create a trigger event.

NOTES:

The LAN-3201A and LAN-3201B modules do not support triggers in Layer 3 mode (that is,
when streams are defined for a port).

******************************************************************************/
typedef struct tagGIGTrigger
{
 unsigned char ucTrigger1Mode;    /* reserved - not currently in use
												 (0 = default) */
 unsigned char ucTrigger1Range;   /* range of trigger 1 (in bytes)
												 (0 = default) */
 unsigned short uiTrigger1Offset; /* offset of trigger 1 (in bits)
												 (0 = default) */
 unsigned char ucTrigger1Data[8]; /* trigger 1 data (0 = default) 
									  Note:  Only the first 6 bytes,
									  array elements 0 to 5, are used */
 unsigned char ucTrigger1Mask[8]; /* trigger 1 mask
												 (0xFF = defaults) */

 unsigned char ucTrigger2Mode;    /* reserved - not currently in use
												 (0 = default) */
 unsigned char ucTrigger2Range;   /* range of trigger 2 (in bytes)
												 (0 = default) */
 unsigned short uiTrigger2Offset; /* offset of trigger 2 (in bits)
												 (0 = default) */
 unsigned char ucTrigger2Data[8]; /* trigger 2 data (0 = default) 
									  Note:  Only the first 6 bytes,
									  array elements 0 to 5, are used */
 unsigned char ucTrigger2Mask[8]; /* trigger 2 mask
												 (0xFF = default) */

 unsigned char ucTriggerMode;     /* use trigger combination defines
												   (GIG_TRIGGER1_ONLY = default)
													GIG_TRIGGER2_ONLY
													GIG_TRIGGER1_OR_TRIGGER2
													GIG_TRIGGER1_AND_TRIGGER2
													GIG_TRIGGER_OFF
													GIG_QOS_TRIGGER */
 unsigned char ucReserved;        /* reserved - not currently in use
												 (0 = default) */
} GIGTrigger;

/* Trigger combination */
#define GIG_TRIGGER1_ONLY                 1
#define GIG_TRIGGER2_ONLY                 0
#define GIG_TRIGGER1_OR_TRIGGER2          3
#define GIG_TRIGGER1_AND_TRIGGER2         2
#define GIG_TRIGGER_OFF                   4
#define GIG_QOS_TRIGGER							8	/* reserved for future use */


/****************************************************************************
 * structures to be used with HTGetStructure
 ****************************************************************************/
/*not for use as an individual structure*/
/* -- use GIGCaptureInfo below */
typedef struct tagGIGCaptureFrameInfo
{
 unsigned long  ulFrame;       /* index of this frame */
 unsigned long  reserved1;     /* reserved - not currently in use */
 U64            ullTimestamp;  /* time stamp in units of 32ns */
 unsigned short uiStatus;      /* use GIG_CAP_STATUS_xxx defines  */
 unsigned short uiLength;      /* data length in bytes */
} GIGCaptureFrameInfo;

/* Capture bit masks */
#define GIG_CAP_UNDERSIZE       0x0001     /* undersize packet  */
#define GIG_CAP_OVERSIZE        0x0002     /* oversize packet   */
#define GIG_CAP_TRIGGER         0x0004     /* receive trigger   */
#define GIG_CAP_CRC             0x0008     /* CRC error         */
#define GIG_CAP_RUN_DISPARITY   0x0010     /* run disparity     */
														 /* (alignment) error */

/******************************************************************************
 * CAPTURED FRAMES INFORMATION
 *
 * Structure: GIGCaptureInfo
 * iType1:  GIG_STRUC_CAP_INFO
 * iType2:  index of 1st frame to get info about
 * iType3:  index of frame after last frame to get info about
 * Function: HTGetStructure
 * GIGCaptureInfo Description:

This structure receives information about captured frames. The
GIGCaptureInfo structure consists of an array of GIGCaptureFrameInfo
structures.  This allows you to receive information about
GIG_MAX_CAPTURE_FRAMES (currently 96) frames.

To use this structure, use HTGetStructure with an iType1 of
GIG_STRUC_CAP_INFO and a pData of a pointer to a
GIGCaptureInfo structure.  Also, iType2 must contain the index of
the first captured frame to get information about, and iType3 must
contain the index of the frame after the last captured frame to get
information about.  The structure will then return with the
FrameInfo array filled with structures describing all the captured
frames within the boundaries specified by iType2 and iType3.  The
FrameInfo structures will give the frame index (relative to all
captured frames), a timestamp, a status indicator, and the length
of the captured frame.  The status field (uiStatus) indicates the
status of the frame based on certain bits being set, as specified
by the GIG_CAP_XXX definitions.  If you perform a bit-wise "AND" (&)
on uiStatus with the status characteristic bit to check, you can
determine whether or not that characteristic applies to that frame.

typedef struct tagGIGCaptureFrameInfo
{
unsigned long  ulFrame;       // index of this frame
unsigned long  reserved1;     // reserved - not currently in use
U64            ullTimestamp;  // time stamp in units of 32ns
unsigned short uiStatus;      // use GIG_CAP_STATUS_xxx defines
unsigned short uiLength;      // data length in bytes
} GIGCaptureFrameInfo;

******************************************************************************/
typedef struct tagGIGCaptureInfo
{                         /* GIGCaptureFrameInfo is defined above */
 GIGCaptureFrameInfo FrameInfo[GIG_MAX_CAPTURE_FRAMES];
} GIGCaptureInfo;

/******************************************************************************
 * CAPTURED FRAMES COUNT
 *
 * Structure: GIGCaptureCountInfo
 * iType1:  GIG_STRUC_CAP_COUNT_INFO
 * Function: HTGetStructure
 * GIGCaptureCountInfo Description:

This structure returns the total number of frames captured.  Capture
must be stopped before retrieving the number of captured packets.

 ******************************************************************************/
typedef struct tagGIGCaptureCountInfo
{
 unsigned long ulCount; /* no. of captured packets (0 to 2048) */
} GIGCaptureCountInfo;

/******************************************************************************
 * CATURED FRAMES DATA
 *
 * Structure: GIGCaptureDataInfo
 * iType1:  GIG_CAP_DATA_INFO
 * Function: HTGetStructure
 * GIGCaptureDataInfo Description:

This structure returns the data of a captured frame.  Only one
frame's data is retrieved by each call.

Set the frame index relative to all captured frames in the ulFrame
field BEFORE calling HTGetStructure.  Then the data for that frame
will be returned in ucData.

******************************************************************************/
typedef struct tagGIGCaptureDataInfo
{
 unsigned long ulFrame;       /* frame number (input) */
 unsigned char  ucData[2048]; /* captured frame data  */
} GIGCaptureDataInfo;


/******************************************************************************
 * CARD INFORMATION
 *
 * Structure: GIGCardInfo
 * iType1:  GIG_STRUC_CARD_INFO
 * Function: HTGetStructure
 * GIGCardInfo Description:

This structure returns information about the current state
of the gigabit card.

******************************************************************************/
typedef struct tagGIGCardInfo
{
		unsigned short uiLinkConfiguration;/* current link
                                            configuration, use the
                                            GIG_AFN_XXX values below */
		unsigned long ulLinkStateChanges;  /* number of times link has
                                            been re-established */
} GIGCardInfo;

/******************************************************************************
 * GIGCardInfo Comment:

The uiLinkConfiguration field will be set with the GIG_AFN_XXX
definitions:

#define GIG_AFN_RESERVED0     0x0001
#define GIG_AFN_RESERVED1     0x0002
#define GIG_AFN_RESERVED2     0x0004
#define GIG_AFN_RESERVED3     0x0008
#define GIG_AFN_RESERVED4     0x0010
#define GIG_AFN_FULL_DUPLEX   0x0020
#define GIG_AFN_HALF_DUPLEX   0x0040
#define GIG_AFN_PAUSE1        0x0080
#define GIG_AFN_PAUSE2        0x0100
#define GIG_AFN_RESERVED9     0x0200
#define GIG_AFN_RESERVED10    0x0400
#define GIG_AFN_RESERVED11    0x0800
#define GIG_AFN_REMOTE_FAULT1 0x1000
#define GIG_AFN_REMOTE_FAULT2 0x2000
#define GIG_AFN_ACKNOWLEDGE   0x4000
#define GIG_AFN_NEXT_PAGE     0x8000

Some GIG_AFN_XXX bits can be combined:

PAUSE2			PAUSE1		  	Pause Flow Control
0				  	0					None
0					1					Symmetric
1					0					Asymmetric->Link Partner
1					1					Asymmetric->Local Device

REMOTE_FAULT2	REMOTE_FAULT1	Remote Fault
0				  	0					Link OK
0					1					Link Failure
1					0					Offline
1					1					Link Configuration Error

LAN-332xA modules do not support the Next Page bit (0x8000) or Acknowledge 
bit (0x4000).
******************************************************************************/


/******************************************************************************
 * COUNTER STATISTICS
 *
 * Structure: GIGCounterInfo
 * iType1:  GIG_STRUC_COUNTER_INFO
 * Function: HTGetStructure
 * GIGCounterInfo Description:
 * This structure returns counter information about the gigabit card.
 *
 ******************************************************************************/
typedef struct tagGIGCounterInfo
{
 U64           ullTxFrames;   /* no. of transmitted frames        */
 U64           ullTxBytes;    /* reserved -- not currently in use */
 U64           ullTxTriggers; /* reserved -- not currently in use */
 unsigned long ulTxLatency;   /* Tx latency counter (100ns units) */
 U64           ullRxFrames;   /* no. of received frames           */
 U64           ullRxBytes;    /* no. of received bytes            */
 U64           ullRxTriggers; /* no. of receive triggers          */
 unsigned long ulRxLatency;   /* Rx latency counter (100ns units) */ 
 U64           ullCRCErrors;  /* no. of frames with CRC errors    */
 U64           ullOverSize;   /* no. of oversized frames          */
 U64           ullUnderSize;  /* no. of undersized frames         */
} GIGCounterInfo;

/******************************************************************************
 * RATE STATISTICS
 *
 * Structure: GIGRateInfo
 * iType1:  GIG_STRUC_RATE_INFO
 * Function: HTGetStructure
 * GIGRateInfo Description:

This structure returns rate counter information about the gigabit card.

 ******************************************************************************/
typedef struct tagGIGRateInfo
{
 unsigned long ulTxFrames;   /* transmitted frames per second     */
 unsigned long ulTxBytes;    /* reserved -- not currently in use  */
 unsigned long ulTxTriggers; /* reserved -- not currently in use  */
 unsigned long ulRxFrames;   /* received frames per second        */
 unsigned long ulRxBytes;    /* received bytes per second         */
 unsigned long ulRxTriggers; /* receive triggers per second       */
 unsigned long ulCRCErrors;  /* frames with CRC errors per second */
 unsigned long ulOverSize;   /* oversized frames per second       */
 unsigned long ulUnderSize;  /* undersized frames per second      */
} GIGRateInfo;

/******************************************************************************
 * VERSION INFORMATION
 *
 * Structure: GIGVersions
 * iType1:  GIG_STRUC_IMAGE_VERSIONS
 * Function: HTGetStructure
 * GIGVersionsDescription:

This structure returns version information about the equipment being used.

Note:  The only field supported by the LAN TeraMetrics modules is "uiFirmwareVersion".

 ******************************************************************************/
typedef struct tagGIGVersions
{
 unsigned short  uiFirmwareVersion;
 unsigned short  uiTransmitDataVersion;
 unsigned short  uiTransmitControlVersion;
 unsigned short  uiTransmitLowlevelVersion;
 unsigned short  uiReceiveDataVersion;
 unsigned short  uiReceiveControlVersion;
 unsigned short  uiReceiveLowlevelVersion;
 unsigned short  uiBackplaneControlVersion;
 unsigned short  uiLinkControlVersion;
 unsigned char   ucFirmwareCheck;
 unsigned char   ucTransmitDataCheck;
 unsigned char   ucTransmitControlCheck;
 unsigned char   ucTransmitLowlevelCheck;
 unsigned char   ucReceiveDataCheck;
 unsigned char   ucReceiveControlCheck;
 unsigned char   ucReceiveLowlevelCheck;
 unsigned char   ucBackplaneControlCheck;
 unsigned char   ucLinkControlCheck;
 unsigned char   ucBootVersion;
 unsigned char   ucReserved[16];
} GIGVersions;


/**********OBSOLETE********************************OBSOLETE******************/
/* OBSOLETE Gigabit SmartCard Parameters and Data Structures                */
/* -- provided for backward compatibility                                   */
/**********OBSOLETE********************************OBSOLETE******************/

#define GIG_STRUC_CAP_INFO_REQUEST      116
#define GIG_STRUC_CAP_DATA              GIG_STRUC_CAP_DATA_INFO


typedef struct tagGIGCaptureInfoRequest
{
 unsigned long   ulStartIndex;
 unsigned long   ulEndIndex;
} GIGCaptureInfoRequest;

typedef struct tagGIGCaptureData
{
 unsigned long ulFrame; /* frame number (input) */
 unsigned char  ucData[2048];
} GIGCaptureData;



/*********************************************************************************
					XENPARK SECTION
 **********************************************************************************/

/*********************************************************************************
 * Structure:   XENPAKPhyConfig
 * iType1:      XENPAK_PHY_CONFIG/XENPAK_PHY_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * XENPAKPhyConfig Description:

	This command is used to switch between WAN and LAN PHY for modules that are dual
	PHY capable.  Its also used to read the media present for Xenpak CX4 (Fiber or Copper).

	XENPAK_PHY_CONFIG/XENPAK_PHY_CONFIG_INFO configures/queries the layer 2 protocol mode
	of operation for XLW-3720A/3721A and and XFP 3730A/3731A test modules.
	
	* PHY_MODE_LAN       1
	* PHY_MODE_WAN       2

 **********************************************************************************/

typedef struct tagXENPAKPhyConfig {
	unsigned long ulMode;	/* PHY mode, possible values are
					                PHY_MODE_LAN
					                PHY_MODE_WAN
                            */

	unsigned char ucActiveMedia;  /* Output, only for XENPAK_MODULE_10GBASE_CX4 module
					                Media Present, possible values are
					                  FIBER_MODE
					                  COPPER_MODE
	                              */
	unsigned char ucReserved[123];
} XENPAKPhyConfig;

/********************************************************/
/* Oblolete */
#define 	XENPAK_PHY_MODE_POS     	0 /* Reserved */
#define 	XENPAK_PHY_MODE_LAN     	1
#define 	XENPAK_PHY_MODE_WAN     	2
/* End of Obsolete */
/********************************************************/

//#define XENPAK_ACTIVE_MEDIA_FIBER   0
//#define XENPAK_ACTIVE_MEDIA_COPPER  1

/****************************************************************************
 * Structure:   XENPAKNVRConfig
 * iType1:      XENPAK_NVR_CONFIG/XENPAK_NVR_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * XENPAKNVRConfig Description: 
 
   NVR is an abbreviation for Non-Volatile Register.
   The two commands are for XLW-3720A/3721A card only.
   The max number of non-volatile register entries is 512, please refer to 
   the MSA standard version 2.1.
   The writable nvr offset will be 119 and max writable length is 48.

    For XENPAK_NVR_CONFIG:
        This command is used to write to a specific non-volatile register on 
        the XLW-3720A/3721A module. If write to the non-volatile register is 
        not allowed, an error is returned. The command field is use to 
        indicate to the card that this is any specific field or all fields 
        operation.

        In the case of all fields operation, length field must be 
        XENPAK_MAX_NVR_CUSTOMER_SIZE and nvr_addr offset will be at 
        XENPAK_NVR_CUSTOMER_AREA 

    For XENPAK_NVR_CONFIG_INFO
        This command is used to query specific non-volatile register on the 
        XLW-3720A/3721A module. The command field is use to indicate to the 
        card that this is any specific field or all fields operation.In the 
        case of all fields operation, nvr offset must set to 0 and length 
        field must set to the max number of non-volatile register entries 512.
 **********************************************************************************/

typedef struct tagXENPAKNVRConfig {
    unsigned short  uiDeviceAddress;    /* 30 or 31 depends on the non-volatile register pointer*/
    unsigned short  uiMDIOAddress;      /* Reserved for now 
                                           Management Data Input/Out, or MDIO, is a standard driven,
                                           dedicated-bus approach that's specific in IEEE FPC802.3 */
    unsigned short  uiNVROffset;        /* Non-volatile register offset value 
                                           valid from 0 to 511. 

                                           For XENPAK_NVR_CONFIG: 
                                              - uiNVROffset must set in range from XENPAK_NVR_CUSTOMER_AREA 
                                              to XENPAK_NVR_CUSTOMER_AREA + XENPAK_MAX_NVR_CUSTOMER_SIZE

                                              - when uiCommand is XENPAK_ALL_FIELD, the uiNVROffset set to XENPAK_NVR_CUSTOMER_AREA,
                                              and uiLength must set to XENPAK_MAX_NVR_CUSTOMER_SIZE

                                              - when uiCommand is XENPAK_ANY_SPECIFIC_FIELD, 
                                              uiLength must be sastify this [offset  - uiLength <= XENPAK_MAX_NVR_CUSTOMER_SIZE], and
                                              uiNVROffset = offset[0-XENPAK_MAX_NVR_CUSTOMER_SIZE] + XENPAK_NVR_CUSTOMER_AREA.

                                           For XENPAK_NVR_CONFIG_INFO: 
                                           - read to some NVR fields: uiCommand is XENPAK_ANY_SPECIFIC_FIELD,
                                           the uiNVROffset could be varied from 0 to 511 
                                           and uiLength from 1 to 512
                                           - read all NVR fields: uiCommand is XENPAK_ALL_FIELD,
                                           the uiNVROffset is default to 0 and uiLength to 512. */
    unsigned short  uiCommand;          /* XENPAK_ANY_SPECIFIC_FIELD = 0 -- read or write to some specific fields; 
                                           XENPAK_ALL_FIELD          = 1 -- read or write to all fields. */
    unsigned short  uiLength;           /* Non-volatile register adress and length total 
                                           has to be less than 512. */
    unsigned char   ucData[512];        /* Non-volatile register data to be written	*/
    unsigned char   ucReserved[66];     /* Reserve field */
} XENPAKNVRConfig;
/*************************************************************
XENPAKNVRConfig Comment:

Write command
* XENPAK_ANY_SPECIFIC_FIELD                           0
* XENPAK_ALL_FIELD                                    1

Writable non-volatile register customer size
* XENPAK_MAX_NVR_CUSTOMER_SIZE                        48

Readable non-volatile register Offset
* XENPAK_NVR_VERSION_NUMBER                           0
* XENPAK_NVR_SIZE                                     1
* XENPAK_NVR_MEMORY_USED                              3
* XENPAK_NVR_BASIC_FIELD_ADDRESS                      5
* XENPAK_NVR_CUSTOMER_FIELD_ADDRESS                   6
* XENPAK_NVR_VENDOR_FIELD_ADDRESS                     7
* XENPAK_NVR_EXT_VENDOR_FIELD_ADDRESS                 8

* XENPAK_NVR_TRANSCEIVER_TYPE                         11
* XENPAK_NVR_OPTICAL_CONNECTOR                        12
* XENPAK_NVR_ENCODING                                 13
* XENPAK_NVR_BIT_RATE                                 14
* XENPAK_NVR_PROTOCOL                                 16
* XENPAK_NVR_STANDARDS_COMPLIANCE_CODES               17
* XENPAK_NVR_FIBER_TYPE                               29

* XENPAK_NVR_WAVELENGTH_CHANNEL0                      31
* XENPAK_NVR_WAVELENGTH_CHANNEL1                      34
* XENPAK_NVR_WAVELENGTH_CHANNEL2                      37
* XENPAK_NVR_WAVELENGTH_CHANNEL3                      40

* XENPAK_NVR_PACKAGE_OUI                              43
* XENPAK_NVR_VENDOR_OUI                               47

* XENPAK_NVR_VENDOR_NAME                              51
* XENPAK_NVR_VENDOR_PART_NUMBER                       67
* XENPAK_NVR_VENDOR_REVISION                          83
* XENPAK_NVR_VENDOR_SERIAL_NUMBER                     85
* XENPAK_NVR_VENDOR_YEAR_CODE                         101
* XENPAK_NVR_VENDOR_MONTH_CODE                        105
* XENPAK_NVR_VENDOR_DAY_CODE                          107
* XENPAK_NVR_VENDOR_LOT_CODE                          109

Writable non-volatile register offset
* XENPAK_NVR_CUSTOMER_AREA                            119

Readable non-volatile register offset
of vendor specific start at the offset 167 with length 89
* XENPAK_NVR_VENDOR_SPECIFIC                          167
************************************************************/

/* Write command  */
#define XENPAK_ANY_SPECIFIC_FIELD                           0
#define XENPAK_ALL_FIELD                                    1

/* Writable non-volatile register customer size */
#define XENPAK_MAX_NVR_CUSTOMER_SIZE                        48

/* Readable non-volatile register offset*/
#define XENPAK_NVR_VERSION_NUMBER                           0
#define XENPAK_NVR_SIZE                                     1
#define XENPAK_NVR_MEMORY_USED                              3
#define XENPAK_NVR_BASIC_FIELD_ADDRESS                      5
#define XENPAK_NVR_CUSTOMER_FIELD_ADDRESS                   6
#define XENPAK_NVR_VENDOR_FIELD_ADDRESS                     7
#define XENPAK_NVR_EXT_VENDOR_FIELD_ADDRESS                 8

#define XENPAK_NVR_TRANSCEIVER_TYPE                         11
#define XENPAK_NVR_OPTICAL_CONNECTOR                        12
#define XENPAK_NVR_ENCODING                                 13
#define XENPAK_NVR_BIT_RATE                                 14
#define XENPAK_NVR_PROTOCOL                                 16
#define XENPAK_NVR_STANDARDS_COMPLIANCE_CODES               17
#define XENPAK_NVR_FIBER_TYPE                               29

#define XENPAK_NVR_WAVELENGTH_CHANNEL0                      31
#define XENPAK_NVR_WAVELENGTH_CHANNEL1                      34
#define XENPAK_NVR_WAVELENGTH_CHANNEL2                      37
#define XENPAK_NVR_WAVELENGTH_CHANNEL3                      40

#define XENPAK_NVR_PACKAGE_OUI                              43
#define XENPAK_NVR_VENDOR_OUI                               47

#define XENPAK_NVR_VENDOR_NAME                              51
#define XENPAK_NVR_VENDOR_PART_NUMBER                       67
#define XENPAK_NVR_VENDOR_REVISION                          83
#define XENPAK_NVR_VENDOR_SERIAL_NUMBER                     85
#define XENPAK_NVR_VENDOR_YEAR_CODE                         101
#define XENPAK_NVR_VENDOR_MONTH_CODE                        105
#define XENPAK_NVR_VENDOR_DAY_CODE                          107
#define XENPAK_NVR_VENDOR_LOT_CODE                          109

/*  Writable non-volatile register offset*/
#define XENPAK_NVR_CUSTOMER_AREA                            119

/* Readable non-volatile register offset 
of vendor specific start at the offset 167 with length 89*/
#define XENPAK_NVR_VENDOR_SPECIFIC                          167


/*********************************************************************************
 * Structure:   XENPAKAlarmConfig
 * iType1:      XENPAK_ALARM_CONFIG/XENPAK_ALARM_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * XENPAKAlarmConfig Description: 

	This function allows user to set and get the configure specific alarm on the transmit, 
	receive and also enable/disable transmit alarm, receive alarm and link status alarm.

	Note: The two command are for XLW-3720A/3721A card only.
 **********************************************************************************/

typedef struct tagXENPAKAlarmConfig{
	unsigned short  uiTransmitAlarmControl;				/* Transmit alarm control */
	unsigned short  uiReceiveAlarmControl;				/* Receive alarm control */
	unsigned short  uiLinkAlarmStatusInterruptControl;  /* LASI Control  */
	unsigned char   ucReserved[122];
} XENPAKAlarmConfig;


/*********************************************************************************
 * Structure:   XENPAKAlarmStatusStructure
 * iType1:      XENPAK_ALARM_STATUS_INFO
 * Function:    HTGetStructure
 * XENPAKAlarmStatusStructure Description: 

		This command allow user to query the transmit, receive and link status alarm.

	Note: This command are for XLW-3720A/3721A card only.

        LASI Control Register(0x09002) & Status Register (0x9005) bits
		* XENPAK_LASI_LS_ALARM_ENABLE                               0x0000
		* XENPAK_LASI_TX_ALARM_ENABLE                               0x0001
		* XENPAK_LASI_RX_ALARM_ENABLE                               0x0002

        TX Alarm Control Register(0x09001) & Status Register (0x9004)bits
		* XENPAK_TX_ALARM_PHY_XS_TRANSMIT_LOCAL_FAULT_ENABLE        0x0000  : Read & Write
		* XENPAK_TX_ALARM_PCS_TRANSMIT_LOCAL_FAULT_ENABLE           0x0003  : Read & Write
		* XENPAK_TX_ALARM_PMA_PMD_TRANSMITTER_LOCAL_FAULT_ENABLE    0x0004  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 
		* XENPAK_TX_ALARM_TRASMITTER_FAULT_ENABLE                   0x0006  : Read & Write 
		* XENPAK_TX_ALARM_LASER_OUTPUT_POWER_FAULT_ENABLE           0x0007  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 
		* XENPAK_TX_ALARM_LASER_TEMPERATURE_FAULT_ENABLE            0x0008  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 
		* XENPAK_TX_ALARM_LASER_BIAS_CURRENT_FAULT_ENABLE           0x0009  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 

        RX Alarm Control Register(0x09000) & Status Register(0x9005) bits
		* XENPAK_RX_ALARM_PHY_XS_RECEIVE_LOCAL_FAULT_ENABLE         0x0000  : Read & Write
		* XENPAK_RX_ALARM_PMA_PCS_RECEIVE_LOCAL_FAULT_ENABLE        0x0003  : Read & Write
		* XENPAK_RX_ALARM_PMA_PMD_RECEIVER_LOCAL_FAULT_ENABLE       0x0004  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 
		* XENPAK_RX_ALARM_RECEIVE_OPTICAL_POWER_LOCAL_FAULT_ENABLE  0x0005  : Optional features that are unsupported 
                                                                              should have their enable bit forced to zero 
		* XENPAK_RX_ALARM_WIS_LOCAL_FAULT_ENABLE					0x0009	: Optional features that are unsupported
                                                                              should have their enable bit forced to zero 
 **********************************************************************************/

typedef struct tagXENPAKAlarmStatus {
	unsigned short  uiTransmitAlarmStatus;				/* Transmit alarm status */
	unsigned short  uiReceiveAlarmStatus;				/* Received alarm status */
	unsigned short  uiLinkAlarmStatusInterruptStatus;	/* LASI Status */
	unsigned char   ucReserved[122];
} XENPAKAlarmStatus;


/* LASI Control Register(0x09002) & Status Register(0x9005) bits  */
#define XENPAK_LASI_LS_ALARM_ENABLE								0x0000
#define XENPAK_LASI_TX_ALARM_ENABLE								0x0001
#define XENPAK_LASI_RX_ALARM_ENABLE								0x0002

/* TX Alarm Control Register(0x09001) & Status Register(0x9004)bits  */
#define XENPAK_TX_ALARM_PHY_XS_TRANSMIT_LOCAL_FAULT_ENABLE		0x0000  /* Read & Write */
#define XENPAK_TX_ALARM_PCS_TRANSMIT_LOCAL_FAULT_ENABLE			0x0003  /* Read & Write */
#define XENPAK_TX_ALARM_PMA_PMD_TRANSMITTER_LOCAL_FAULT_ENABLE	0x0004  /* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/
#define XENPAK_TX_ALARM_TRASMITTER_FAULT_ENABLE					0x0006  /* Read & Write */
#define XENPAK_TX_ALARM_LASER_OUTPUT_POWER_FAULT_ENABLE			0x0007  /* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/
#define XENPAK_TX_ALARM_LASER_TEMPERATURE_FAULT_ENABLE			0x0008  /* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/
#define XENPAK_TX_ALARM_LASER_BIAS_CURRENT_FAULT_ENABLE			0x0009  /* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/

/* RX Alarm Control Register(0x09000) & Status Register(0x9005) bits  */
#define XENPAK_RX_ALARM_PHY_XS_RECEIVE_LOCAL_FAULT_ENABLE		0x0000	/* Read & Write */
#define XENPAK_RX_ALARM_PMA_PCS_RECEIVE_LOCAL_FAULT_ENABLE		0x0003	/* Read & Write */
#define XENPAK_RX_ALARM_PMA_PMD_RECEIVER_LOCAL_FAULT_ENABLE		0x0004	/* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/
#define XENPAK_RX_ALARM_RECEIVE_OPTICAL_POWER_LOCAL_FAULT_ENABLE 0x0005 /* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/
#define XENPAK_RX_ALARM_WIS_LOCAL_FAULT_ENABLE					0x0009	/* Optional features that are unsupported 
																		   should have their enable bit forced to zero 
																		*/



/*********************************************************************************
 * Structure:   XENPAKProfile
 * iType1:      XENPAK_PROFILE_INFO
 * Function:    HTGetStructure
 * XENPAKProfile Description: 

	This command is used to query the current XENPAK profile on the card.  
	The XENPAK profile module structure is valid only when the 'module_detected' field is set.


	Define constant for field ucProtocolType of XENPAKProfile
		*  XENPAK_10GBE                 0x01
		*  XENPAK_10GFC                 0x02
		*  XENPAK_WIS                   0x04
		*  XENPAK_LSS                   0x08
		*  XENPAK_SONET_SDH             0x10

		Define constant for field ucStdComplianceCode of XENPAKProfile
        - Byte 0: 10GbE Code
		*  XENPAK_10GBASE_SR            0x01
		*  XENPAK_10GBASE_LR            0x02
		*  XENPAK_10GBASE_ER            0x04
		*  XENPAK_10GBASE_LX4           0x08
		*  XENPAK_10GBASE_SW            0x10
		*  XENPAK_10GBASE_LW4           0x20
		*  XENPAK_10GBASE_LW            0x40
		*  XENPAK_10GBASE_EW            0x80
        - Byte 1: Reserved
        - Byte 2: SONET/SDH
		*  XENPAK_S_64_1                0x01
		*  XENPAK_S_64_2A               0x02
		*  XENPAK_S_64_2B               0x04
		*  XENPAK_S_64_3A               0x08
		*  XENPAK_S_64_3B               0x10
		*  XENPAK_S_64_5A               0x20
		*  XENPAK_S_64_5B               0x40
        - Byte 3:SONET/SDH
		*  XENPAK_I_64_1R               0x01
		*  XENPAK_I_64_1                0x02
		*  XENPAK_I_64_2R               0x04
		*  XENPAK_I_64_2                0x08
		*  XENPAK_I_64_3                0x10
		*  XENPAK_I_64_5                0x20
        - Byte 4:SONET/SDH
		*  XENPAK_L_64_1                0x01
		*  XENPAK_L_64_2A               0x02
		*  XENPAK_L_64_2B               0x04
		*  XENPAK_L_64_2C               0x08
		*  XENPAK_L_64_3                0x10
        - Byte 5:SONET/SDH
		*  XENPAK_V_64_2A               0x01
		*  XENPAK_V_64_2B               0x02
		*  XENPAK_V_64_3                0x04

	Define constant for field ucModuleDetected of XENPAKProfile
	When a Xenpak is installed, ucModuleDetected field will report the following:

		* XENPAK_MODULE_10GBASE_SR			0x73	 
		* XENPAK_MODULE_10GBASE_LR		   0x63
		* XENPAK_MODULE_10GBASE_ER			0x53
		* XENPAK_MODULE_10GBASE_LX4		0x43	 
		* XENPAK_MODULE_10GBASE_SW			0x33	
		* XENPAK_MODULE_10GBASE_LW			0x23
		* XENPAK_MODULE_10GBASE_EW			0x13	
		* XENPAK_MODULE_10GBASE_CX4		0x03

  When a Spirent CX4 is installed ucModuleDetected field will report:
		* CX4_MODULE_10GBASE							0x05

  When the XAUI Extender or an unknown device is installed, ucModuleDetected field will report:
		* XAUI_MODULE_10GBASE						0x01
 **********************************************************************************/

typedef struct tagXENPAKProfile {
	unsigned char	ucModuleDetected;	     /* Announces the type of Xenpak PHY active, 
															possible values are
															XENPAK_MODULE_10GBASE_SR
															XENPAK_MODULE_10GBASE_LR
															XENPAK_MODULE_10GBASE_ER
															XENPAK_MODULE_10GBASE_LX4
															XENPAK_MODULE_10GBASE_SW
															XENPAK_MODULE_10GBASE_LW  
															XENPAK_MODULE_10GBASE_EW
															XENPAK_MODULE_10GBASE_CX4
															CX4_MODULE_10GBASE
															XAUI_MODULE_10GBASE	 */		
	unsigned char	ucNVRVersion;				/* Non-volatile register version */
	unsigned short	uiNVRSize;					/* Non-volatile register size in bytes */
	unsigned char	ucTransceiverType;			/* Transceiver type 
												- XENPAK_UNSPECIFIED_TYPE	= 0
	                    						- XENPAK_TYPE	 	        = 1

												*/
	unsigned char	ucConnectorType;			/* Optical Connector type 
                                                    - XENPAK_UNSPECIFIED_TYPE
                                                    - XENPAK_OPTICAL_SC_TYPE
                                                    - XENPAK_OPTICAL_LC_TYPE
                                                    - XENPAK_OPTICAL_MT_RJ_TYPE
                                                    - XENPAK_OPTICAL_MU_TYPE
                                                    - XENPAK_OPTICAL_FC_PC_TYPE
                                                    - XENPAK_OPTICAL_PIGTAIL_TYPE
												*/
	unsigned char	ucProtocolType;				/* Protocol type 
													-XENPAK_10GBE
													-XENPAK_10GFC
													-XENPAK_WIS
													-XENPAK_LSS
													-XENPAK_SONET_SDH
												*/
	unsigned char	ucStdComplianceCode[10];	/* Standards Compliance Codes: 
													- Byte 0: 10GbE Code 
														+ XENPAK_10GBASE_SR
														+ XENPAK_10GBASE_LR
														+ XENPAK_10GBASE_ER
														+ XENPAK_10GBASE_LX4
														+ XENPAK_10GBASE_SW
														+ XENPAK_10GBASE_LW4
														+ XENPAK_10GBASE_LW
														+ XENPAK_10GBASE_EW
													- Byte 1: Reserved
													- Byte 2: SONET/SDH
														+ XENPAK_S_64_1
														+ XENPAK_S_64_2A
														+ XENPAK_S_64_2B
														+ XENPAK_S_64_3A
														+ XENPAK_S_64_3B
														+ XENPAK_S_64_5A
														+ XENPAK_S_64_5B
													- Byte 3:SONET/SDH
														+ XENPAK_I_64_1R
														+ XENPAK_I_64_1
														+ XENPAK_I_64_2R
														+ XENPAK_I_64_2
														+ XENPAK_I_64_3
														+ XENPAK_I_64_5
													- Byte 4:SONET/SDH
														+ XENPAK_L_64_1
														+ XENPAK_L_64_2A
														+ XENPAK_L_64_2B
														+ XENPAK_L_64_2C
														+ XENPAK_L_64_3
													- Byte 5:SONET/SDH
														+ XENPAK_V_64_2A
														+ XENPAK_V_64_2B
														+ XENPAK_V_64_3
													- Byte 6 - 9: Reserved
												*/

	unsigned short	uiTransmissionRange;		/* Tranmission Range in meters */
	unsigned char	ucFiberType[2];				/* Fiber Type :
													- Byte 0:
														Description		Value
														+ Unspecified	  0
														+ M M, generic	  1
														+ 50/125 only	  2
														+ 62.5/125 only	  4
														+ POF			  8
														+ HPCF			 10
														+ SM, generic	 20
														+ NDSF only		 40
														+.NZDSF only	 80
													- Byte 1:
														Description		Value
														+ Unspecified	  0
														+ Large core only 1
														+. PM F only	  2
												*/
	unsigned long	ulPackageOUI;				/* Package of company ID. 
												An OUI, "company ID" is a 24 bit globally unique 
												assigned number referenced by various standards. 
												OUI is used in the family of 802 LAN standards, e.g., 
												Ethernet, Token Ring, etc.
												*/ 
	unsigned long	ulTransceiverVendorOUI;		/* Transeiver vendor compnay ID */
	unsigned char	ucName[16];					/* Transeiver vendor name in ASCII */
	unsigned char	ucPartNumber[16];			/* Part number provided by transceiver vendor */
	unsigned char	ucRevision[2];				/* Revision level for part number */
	unsigned char	ucSerialNumber[16];			/* Vendor serial number */

	unsigned char	ucDateCodeYear[4];			/* Vendor manufacturing date code in ASCII*/
	unsigned char	ucDateCodeMonth[2];
	unsigned char	ucDateCodeDay[2];

	unsigned char	ucDateCodeLotNumber[2];		/* Manufacturing Lot */
	unsigned char	ucReserved[96];
} XENPAKProfile;

/***************************************************************************
	Define constant for field ucTransceiverType of XENPAKProfile
***************************************************************************/
#define XENPAK_UNSPECIFIED_TYPE		0
#define XENPAK_TYPE					1

/***************************************************************************
	Define constant for field ucConnectorType of XENPAKProfile
***************************************************************************/
#define XENPAK_OPTICAL_SC_TYPE					1
#define XENPAK_OPTICAL_LC_TYPE					2
#define XENPAK_OPTICAL_MT_RJ_TYPE				3
#define XENPAK_OPTICAL_MU_TYPE					4
#define XENPAK_OPTICAL_FC_PC_TYPE				5
#define XENPAK_OPTICAL_PIGTAIL_TYPE				6

/***************************************************************************
			Define constant for field ucProtocolType of XENPAKProfile
***************************************************************************/
#define XENPAK_10GBE				0x01
#define XENPAK_10GFC				0x02
#define XENPAK_WIS					0x04
#define XENPAK_LSS					0x08
#define XENPAK_SONET_SDH			0x10

/***************************************************************************
			Define constant for field ucStdComplianceCode of XENPAKProfile
 ***************************************************************************/
/*- Byte 0: 10GbE Code */
#define XENPAK_10GBASE_SR			0x01
#define XENPAK_10GBASE_LR			0x02
#define XENPAK_10GBASE_ER			0x04
#define XENPAK_10GBASE_LX4			0x08
#define XENPAK_10GBASE_SW			0x10
#define XENPAK_10GBASE_LW			0x20
#define XENPAK_10GBASE_EW			0x40
#define XENPAK_10GBASE_LW4			0x80
/*- Byte 1: Reserved */
/*- Byte 2: SONET/SDH */
#define XENPAK_S_64_1				0x01
#define XENPAK_S_64_2A				0x02
#define XENPAK_S_64_2B				0x04
#define XENPAK_S_64_3A				0x08
#define XENPAK_S_64_3B				0x10
#define XENPAK_S_64_5A				0x20
#define XENPAK_S_64_5B				0x40
/*- Byte 3:SONET/SDH */
#define XENPAK_I_64_1R				0x01
#define XENPAK_I_64_1				0x02
#define XENPAK_I_64_2R				0x04
#define XENPAK_I_64_2				0x08
#define XENPAK_I_64_3				0x10
#define XENPAK_I_64_5				0x20
/*- Byte 4:SONET/SDH */
#define XENPAK_L_64_1				0x01
#define XENPAK_L_64_2A				0x02
#define XENPAK_L_64_2B				0x04
#define XENPAK_L_64_2C				0x08
#define XENPAK_L_64_3				0x10
/*- Byte 5:SONET/SDH */
#define XENPAK_V_64_2A				0x01
#define XENPAK_V_64_2B				0x02
#define XENPAK_V_64_3				0x04
/***************************************************************************
			Define constant for field ucModuleDetected of XENPAKProfile
 ***************************************************************************/

#define XENPAK_MODULE_10GBASE_SR		0x73
#define XENPAK_MODULE_10GBASE_LR		0x63
#define XENPAK_MODULE_10GBASE_ER		0x53
#define XENPAK_MODULE_10GBASE_LX4	0x43	 
#define XENPAK_MODULE_10GBASE_SW		0x33	 
#define XENPAK_MODULE_10GBASE_LW		0x23	 
#define XENPAK_MODULE_10GBASE_EW		0x13	 
#define XENPAK_MODULE_10GBASE_CX4	0x03	 
#define CX4_MODULE_10GBASE	         0x05
#define XAUI_MODULE_10GBASE         0x01
/*********************************************************************************
					XAUI SECTION
 **********************************************************************************/

/*********************************************************************************
 * Structure:   XAUIPRBSConfig
 * iType1:      XAUI_PRBS_CONFIG/XAUI_PRBS_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * XAUIPRBSConfig Description:

    XAUI is an abbreviation for 10-Gigabit Attachment Unit Interface.
    PRBS is an abbreviation for Pseudo Random Bit Stream.
        
    XAUI interfaces will provide interconnections between switch blades and switch backplanes. 

    The XAUI card provides 127 built-in Pseudo Random Bit Stream self test function, for 
    4 channels A, B, C, and D. The Pseudo Random Bit Stream data pattern represents the worst
    case data recovery compare to 8B/10B data pattern.
    Therefor, the Pseudo Random Bit Stream is used to test link and clock jitter tolerance.

	This command XAUI_PRBS_CONFIG is used to enable or disable the Pseudo Random Bit Stream
    on channel A, B, C or D.

    This command XAUI_PRBS_CONFIG_INFO is used to read the previously Pseudo Random Bit 
    Stream configuration.
 **********************************************************************************/

typedef struct tagXAUIPRBSConfig {
	unsigned char ucPRBSEnable;		  /* 1 = enable, 0 = disable */
    U64           u64DurationCount;   /* in micro second unit. Max duration is 32,985,348,833 microseconds*/
    unsigned char ucPreEmphasisEnable;/* In order to compensate for the loss of the high frequency signal 
                                         component through PCB or cable, four levels of programmable pre-emphasis 
                                         have been added to all serial transmit channels. 
                                         This maximizes the data eye opening at the receiver inputs and 
                                         enhances the bit error rate performance of the system.

                                         1 = enable, 0 = disable  */
    unsigned char ucLaneSkewEnable ;  /* 1 = enable, 0 = disable */
	unsigned char ucReserved[21];
} XAUIPRBSConfig;
/******************************************************************************
 * XAUIPRBSConfig Comment:

ucLaneSkewEnable:

Per IEEE802.3ae/D.5 Clause 48, the following rules should be followed: 
1. The Align or ||A||  ordered-set consists of an /A/ code-group on each lane.
2. All /A/ characters must be generated simultaneously by the transmitter.
3. The maximum allowable skew on the receive side is 41UI (1 UI = 320 ps).

Therefore, to create data lane skew the following events must occur:
1. The Bitblitz unit must have the XGMII IDLE pattern to XAUI /A/, /K/, /R/ 
   and vice-versa converters disabled (character transparent mode).

   This is accomplished with the following settings: 
   CONTROL REGISTER 2
   XAUI_EN = 0'b
   TRANS_EN = 0'b
   AKR_EN = 0'b

   and

   CONTROL REGISTER 1
   DSKW_SM_EN = 0'b
   IDLE_D_EN = 0'b
2. Instead of XGMII IDLE (07'h) characters, our Reconciliation Sub-Layer (RS) 
   located in the XGMII FPGA must generate its own /A/, /K/, and /R/ characters. 
   In this manner, by modifying the /A/ character generation on each lane 
   we can control the lane skew distance.
3. The RS needs to count the /A/ character skew between lanes to measure 
   DUT lane skew generation.
******************************************************************************/


/*********************************************************************************
 * Structure:   XAUIPRBSStatusInfo
 * iType1:      XAUI_PRBS_STATUS_INFO
 * Function:    HTGetStructure
 * XAUIPRBSStatusInfo Description:

	This command XAUI_PRBS_STATUS_INFO is used to read  the pseudo random bit stream  
    running status and per channel error counter

    When the user enables the pseudo random bit stream test, the hardware FPGA will 
    monitor each of the XAUI transceiver PRBS status line at 30 nsec and update a 30 nsec
    free running counter for each channel. The individual PRBS counter will stop immediately 
    after that PRBS status for that channel indicates error. There are four 40 bits PRBS 
    counters for 4 channels. The maximum PRBS test duration is 32,985,348,833 micro seconds.

    Define constant for field ucPRBSStatus of XAUIPRBSStatusInfo : 
	* XAUI_PRBS_TEST_DISABLE       0
	* XAUI_PRBS_TEST_RUNNING       1
	* XAUI_PRBS_TEST_COMPLETED     2
 **********************************************************************************/

typedef struct tagXAUIPRBSStatusInfo {
	unsigned char ucPRBSStatus;		    /*  - XAUI_PRBS_TEST_DISABLE
                                            - XAUI_PRBS_TEST_RUNNING
                                            - XAUI_PRBS_TEST_COMPLETED
    								    */
    unsigned long ulPRBSChannelAError;  /* PRBS error counter for channel A */
    unsigned long ulPRBSChannelBError;  /* PRBS error counter for channel B */
    unsigned long ulPRBSChannelCError;  /* PRBS error counter for channel C */
    unsigned long ulPRBSChannelDError;  /* PRBS error counter for channel D */
    unsigned char ucReserved[15];      /* reserved: 0 = default  */
} XAUIPRBSStatusInfo;

/***************************************************************************
	Define constant for field ucPRBSStatus of XAUIPRBSStatusInfo
***************************************************************************/

#define XAUI_PRBS_TEST_DISABLE		0
#define XAUI_PRBS_TEST_RUNNING		1
#define XAUI_PRBS_TEST_COMPLETED	2



/*********************************************************************************
 * Structure:   XFPProfile
 * iType1:      XFP_PROFILE_INFO
 * Function:    HTGetStructure
 * XFPProfile Description: 

	This command is used to query the current XFP profile on the card.  
	The XFP profile module structure is valid only when the 'module_detected' field is set.
 **********************************************************************************
 XFPProfile Description:

Defined constants for field ucModuleIdentifier of XFPProfile

	XFP_IDENTIFIER_UNKNOWN				0x00
   XFP_IDENTIFIER_GBIC					0x01
   XFP_IDENTIFIER_MODULE_SOLDERED	0x02
   XFP_IDENTIFIER_SFP					0x03
   XFP_IDENTIFIER_300_PIN_XBI			0x04
   XFP_IDENTIFIER_XENPAK				0x05
   XFP_IDENTIFIER_XFP					0x06 
   XFP_IDENTIFIER_XFF					0x07 
   XFP_IDENTIFIER_XFP_E					0x08 
   XFP_IDENTIFIER_XPAK					0x09
   XFP_IDENTIFIER_X2						0x0A

Defined constants for field ucConnectorType of XFPProfile

  XFP_CONNECTOR_UNKNOWN					0x00
  XFP_CONNECTOR_SC						0x01
  XFP_CONNECTOR_FC_STYLE_1				0x02
  XFP_CONNECTOR_FC_STYLE_2				0x03
  XFP_CONNECTOR_BNC_TNC					0x04
  XFP_CONNECTOR_FC_COAXIAL_HEADERS	0x05
  XFP_CONNECTOR_FIBERJACK				0x06
  XFP_CONNECTOR_LC						0x07
  XFP_CONNECTOR_MT_RJ					0x08
  XFP_CONNECTOR_MU						0x09
  XFP_CONNECTOR_SG						0x0A
  XFP_CONNECTOR_OPTICAL_PIGTAIL		0x0B
  XFP_CONNECTOR_HSSDC_II				0x20
  XFP_CONNECTOR_COPPER _PIGTAIL		0x21

Defined constants for field ucTransceiverType of XFPProfile

  Byte 0:  Addr 131, 10 Gigabit Ethernet Compliance
  XFP_TRANSCEIVER_10GBASE_EW			0x02
  XFP_TRANSCEIVER_10GBASE_LW			0x04
  XFP_TRANSCEIVER_10GBASE_SW			0x08
  XFP_TRANSCEIVER_10GBASE_ER			0x20
  XFP_TRANSCEIVER_10GBASE_LR			0x40
  XFP_TRANSCEIVER_10GBASE_SR			0x80
                                         
  Byte 1:  Addr 132, 10 Gigabit Fibre Channel Compliance
  XFP_TRANSCEIVER_1NT_REACH_1300_NM_FP		0x10
  XFP_TRANSCEIVER_EXT_REACH_1550_NM_FP		0x20
  XFP_TRANSCEIVER_1200_SM_LL_L				0x40
  XFP_TRANSCEIVER_1200_MX_SN_L				0x80
                                         
  Byte 2:  Addr 133, 10 Gigabit Copper Links -Reserved
                                         
  Byte 3:  Addr 134, Lower Speed Links
  XFP_TRANSCEIVER_OC_48_LR			0x02
  XFP_TRANSCEIVER_OC_48_IR			0x04
  XFP_TRANSCEIVER_OC_48_SR			0x08
  XFP_TRANSCEIVER_2xFC_SMF			0x10
  XFP_TRANSCEIVER_2xFC_MMF			0x20
  XFP_TRANSCEIVER_1000BASE_LX_1xFC_SMF    0x40

  Byte 4:  Addr 135, SONET/SDH codes - Interconnect
  XFP_TRANSCEIVER_I_64_5    0x04
  XFP_TRANSCEIVER_I_64_3    0x08
  XFP_TRANSCEIVER_I_64_2    0x10
  XFP_TRANSCEIVER_I_64_2r   0x20
  XFP_TRANSCEIVER_I_64_1    0x40
  XFP_TRANSCEIVER_I_64_1r   0x80

  Byte 5:  Addr 136, SONET/SDH Codes - Short Haul
  XFP_TRANSCEIVER_S_64_5b   0x02
  XFP_TRANSCEIVER_S_64_5a   0x04
  XFP_TRANSCEIVER_S_64_3b   0x08
  XFP_TRANSCEIVER_S_64_3a   0x10
  XFP_TRANSCEIVER_S_64_2b   0x20
  XFP_TRANSCEIVER_S_64_2a   0x40
  XFP_TRANSCEIVER_S_64_1    0x80

  Byte 6:    Addr 137	 SONET/SDH Codes - Long Haul
  XFP_TRANSCEIVER_L_64_3    0x08
  XFP_TRANSCEIVER_L_64_2c   0x10
  XFP_TRANSCEIVERL_64_2b    0x20
  XFP_TRANSCEIVER_64_2a     0x40
  XFP_TRANSCEIVER_L_64_1    0x80

  Byte 7:    Addr 138, SONET/SDH Codes - Very Long Haul
  XFP_TRANSCEIVER_V_64_3    0x20
  XFP_TRANSCEIVER_V_64_2b   0x40
  XFP_TRANSCEIVER_V_64_2a   0x80 
    
Defined constants for field ucSerialEncodingAlgorithm of XFPProfile
  XFP_ENCODING_64B_66B		0x80
  XFP_ENCODING_8B10B			0x40
  XFP_ENCODING_SONET_SCRAMBLED	0x20
  XFP_ENCODING_NRZ				0x10
  XFP_ENCODING_RZ				0x08

Defined constants for field ucCDRSupport of XFPProfile
  XFP_CDR_LOOPBACK_MODE_SUPPORTED		0x01
  XFP_CDR_LINESIDE_LOOPBACK_MODE_SUPPORTED	0x02
  XFP_CDR_SUPPORT_FOR_11_1_GBS		0x08
  XFP_CDR_SUPPORT_FOR_10_7_GBS    0x10
  XFP_CDR_SUPPORT_FOR_10_5_GBS    0x20
  XFP_CDR_SUPPORT_FOR_10_3_GBS    0x40
  XFP_CDR_SUPPORT_FOR_9_95_GBS    0x80

Defined constants for field ucEnhancedOptions of XFPProfile
  XFP_OPTIONAL_SMU_SUPPORT_MODE			0x01
  XFP_OPTIONAL_WAVELENGTH_TUNABILITY   0x02
  XFP_OPTIONAL_ACTIVE_FEC_CONTROLS		0x04
  XFP_OPTIONAL_VPS_BYPASS_REG_MODE		0x08
  XFP_OPTIONAL_VPS_LV_REG_MODE			0x10
  XFP_OPTIONAL_SOFT_P_DOWN					0x20
  XFP_OPTIONAL_TX_DISABLE					0x40
  XFP_OPTIONAL_VPS							0x80

Defined constants for field ucAuxMonitoring
  XFP_AUX_MONITORING_NOT_IMPLEMENTED			0x00
  XFP_AUX_MONITORING_APD_BIAS_VOLTAGE			0x01
  XFP_AUX_MONITORING_TEC_CURRENT					0x03
  XFP_AUX_MONITORING_LASER_TEMPERATURE       0x04
  XFP_AUX_MONITORING_LASER_WAVELENGTH			0x05
  XFP_AUX_MONITORING_PLUS_5V_SUPPLY_VOLTAGE		0x06
  XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_VOLTAGE	0x07
  XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_VOLTAGE   0x08
  XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_VOLTAGE  0x09
  XFP_AUX_MONITORING_PLUS_5V_SUPPLY_CURRENT     0x0A
  XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_CURRENT   0x0D
  XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_CURRENT   0x0E
  XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_CURRENT  0x0F

*/
typedef struct tagXFPProfile
{
  
  unsigned char ucModuleDetected;     /* 1 - XFP module detected , 0 no XFP module detected */

  unsigned char ucModuleIdentifier;  /* Type of serial transceiver
													XFP_IDENTIFIER_UNKNOWN   
                                       XFP_IDENTIFIER_GBIC      
                                       XFP_IDENTIFIER_MODULE_SOLDERED   
                                       XFP_IDENTIFIER_SFP  
                                       XFP_IDENTIFIER_300_PIN_XBI   
                                       XFP_IDENTIFIER_XENPAK   
                                       XFP_IDENTIFIER_XFP   
                                       XFP_IDENTIFIER_XFF   
                                       XFP_IDENTIFIER_XFP_E   
                                       XFP_IDENTIFIER_XPAK   
                                       XFP_IDENTIFIER_X2     
                                       */
	 
  unsigned char ucExtendedModuleID;	/* Extended identifier of type of serial transceiver - bimap
												  Bit 0 - 3 
												  Reserved 

												  Bit 4:
												  0: TX Ref Clock Input Required
                                      1: TX Ref Clock Input Not Required
                                       
												  Bit 5:
												  0: Module with CDR function
                                      1: Non-CDR version of XFP
     
		                                Bit 6 - 7:
												  00: Power Level 1 Module (1.5 W max. power dissipation.)
                                      01: Power Level 2 Module (2.5W Max)
                                      10: Power Level 3 Module (3.5W max. power dissipation.)
                                      11: Power Level 4 Module (>3.5W max. power dissipation.)

                                    */
	 
  unsigned char ucConnectorType;	   /* Code for connector type 
												XFP_CONNECTOR_UNKNOWN   
                                    XFP_CONNECTOR_SC  1
                                    XFP_CONNECTOR_FC_STYLE_1   
                                    XFP_CONNECTOR_FC_STYLE_2    
                                    XFP_CONNECTOR_BNC_TNC    
                                    XFP_CONNECTOR_FC_COAXIAL_HEADERS  
                                    XFP_CONNECTOR_FIBERJACK   
                                    XFP_CONNECTOR_LC   
                                    XFP_CONNECTOR_MT_RJ   
                                    XFP_CONNECTOR_MU   
                                    XFP_CONNECTOR_SG   
                                    XFP_CONNECTOR_OPTICAL_PIGTAIL  
												XFP_CONNECTOR_HSSDC_II   
                                    XFP_CONNECTOR_COPPER _PIGTAIL   
												0x000C - 0x01FH : Reserved
												0x0080 - 0x0FFH : Vendor Specific
                                    */ 
 unsigned char	ucTransceiverType[8];	/* Code for electronic compatibility or optical compatibility 
													 Byte 0:  Addr 131, 10 Gigabit Ethernet Compliance
                                        XFP_TRANSCEIVER_10GBASE_EW    
                                        XFP_TRANSCEIVER_10GBASE_LW     
                                        XFP_TRANSCEIVER_10GBASE_SW     
                                        XFP_TRANSCEIVER_10GBASE_ER     
                                        XFP_TRANSCEIVER_10GBASE_LR     
                                        XFP_TRANSCEIVER_10GBASE_SR     
                                         
													 Byte 1:  Addr 132, 10 Gigabit Fibre Channel Compliance
                                        XFP_TRANSCEIVER_1NT_REACH_1300_NM_FP    
                                        XFP_TRANSCEIVER_EXT_REACH_1550_NM_FP   
                                        XFP_TRANSCEIVER_1200_SM_LL_L    
                                        XFP_TRANSCEIVER_1200_MX_SN_L    
                                         
													 Byte 2:  Addr 133, 10 Gigabit Copper Links -Reserved
                                         
													 Byte 3:  Addr 134, Lower Speed Links
                                        XFP_TRANSCEIVER_OC_48_LR     
                                        XFP_TRANSCEIVER_OC_48_IR      
                                        XFP_TRANSCEIVER_OC_48_SR     
                                        XFP_TRANSCEIVER_2xFC_SMF     
                                        XFP_TRANSCEIVER_2xFC_MMF     
                                        XFP_TRANSCEIVER_1000BASE_LX_1xFC_SMF     

                                        Byte 4:  Addr 135, SONET/SDH codes - Interconnect
                                        XFP_TRANSCEIVER_I_64_5     
                                        XFP_TRANSCEIVER_I_64_3     
                                        XFP_TRANSCEIVER_I_64_2     
                                        XFP_TRANSCEIVER_I_64_2r     
                                        XFP_TRANSCEIVER_I_64_1     
                                        XFP_TRANSCEIVER_I_64_1r     

                                        Byte 5:  Addr 136, SONET/SDH Codes - Short Haul
                                        XFP_TRANSCEIVER_S_64_5b     
                                        XFP_TRANSCEIVER_S_64_5a     
                                        XFP_TRANSCEIVER_S_64_3b     
                                        XFP_TRANSCEIVER_S_64_3a     
                                        XFP_TRANSCEIVER_S_64_2b     
                                        XFP_TRANSCEIVER_S_64_2a     
                                        XFP_TRANSCEIVER_S_64_1    

                                        Byte 6:    Addr 137	 SONET/SDH Codes - Long Haul
                                        XFP_TRANSCEIVER_L_64_3     
                                        XFP_TRANSCEIVER_L_64_2c     
                                        XFP_TRANSCEIVERL_64_2b     
                                        XFP_TRANSCEIVER_64_2a     
                                        XFP_TRANSCEIVER_L_64_1     

                                        Byte 7:    Addr 138, SONET/SDH Codes - Very Long Haul
                                        XFP_TRANSCEIVER_V_64_3     
                                        XFP_TRANSCEIVER_V_64_2b     
                                        XFP_TRANSCEIVER_V_64_2a      
                                        */

 unsigned char	ucSerialEncodingAlgorithm;	 /* Code for serial encoding algorithm
                                          XFP_ENCODING_64B_66B     
                                          XFP_ENCODING_8B10B      
                                          XFP_ENCODING_SONET_SCRAMBLED     
                                          XFP_ENCODING_NRZ     
                                          XFP_ENCODING_RZ     

                                          */
  unsigned char ucMinBitRate;  /* Minimum bit rate, units of 100 Mbits/s  */

  unsigned char ucMaxBitRate;  /* Maximum bit rate, units of 100 Mbits/s  */	
		 
  unsigned char ucLinkLength[5];	/* Byte 0 - Link length supported for SMF fiber in km 	 
                                    Byte 1 - Link length supported for EBW 50/125 m fiber, units of 2 m
                                    Byte 2 - Link length supported for 50/125 m fiber, units of 1 m
                                    Byte 3 - Link length supported for 62.5/125 m fiber, units of 1 m
                                    Byte 4 - Link length supported for copper, units of 1m
                                 */

  unsigned char ucDeviceTechnology;	/* Device Technology
                                       Bit 0:
												   0: Transmitter not Tunable
                                       1: Transmitter Tunable
                                       
												   Bit 1:
												   0: PIN detector
                                       1: APD detector
     
													Bit 2:
												   0: Uncooled transmitter device
                                       1: Cooled transmitter

													Bit 3:
												   0: No wavelength control
                                       1: Active wavelength control

		                                 Bit 4 - 7:
												   0000b: 850 nm VCSEL
                                       0001b: 1310 nm VCSEL
                                       0010b: 1550 nm VCSEL
                                       0011b: 1310 nm FP
													0100b: 1310 nm DFB
                                       0101b: 1550 nm DFB
                                       0110b: 1310 nm EML
                                       0011b: 1550 nm EML
													1000b: Copper or others
													
                                     */
  	 
  unsigned char ucVendorName[16];  /*  XFP Vendor Name */		
	                                                                 
                                                                                           
  unsigned char ucCDRSupport;	/* CDR Rate Support 
										XFP_CDR_LOOPBACK_MODE_SUPPORTED     
                              XFP_CDR_LINESIDE_LOOPBACK_MODE_SUPPORTED     
                              XFP_CDR_SUPPORT_FOR_11_1_GBS    
                              XFP_CDR_SUPPORT_FOR_10_7_GBS        
                              XFP_CDR_SUPPORT_FOR_10_5_GBS        
                              XFP_CDR_SUPPORT_FOR_10_3_GBS        
                              XFP_CDR_SUPPORT_FOR_9_95_GBS        
                               */		 
  unsigned char ucVendorOUI[3]; /* XFP vendor IEEE company ID */
		 
  unsigned char ucVendorPartNumber[16];	/* Part number provided by XFP vendor */
	 
  unsigned char ucVendorRevision[2];   /*  Revision level for part number provided by vendor */
		 
  unsigned char ucLaserWavelength[2]; /* Nominal laser wavelength (Wavelength = value / 20 in nm) */

  unsigned char ucLaserWavelengthTolerance[2]; /* Guaranteed range of laser wavelength (+/- value) 
																 from Nominal wavelength. (Wavelength Tol. = value/200 in nm)
                                              */

  unsigned char ucMaxCaseTemp;	/* Maximum Case Temperature in Degrees C */
 
  unsigned char ucCCBase;	/* Check code for Base ID Fields (addresses 120-190) */
 
			 
/* Extended ID fields */
  unsigned char ucPowerSupplyFields[4];  /* Byte 0 , Bits 7- 0 (Address 192)
                                            Maximum Power Dissipation, Max power is 8 bit value * 20 mW.
                                                                                     
                                            Byte 1 , Bits 7- 0 (Address 193)
                                            Maximum Total Power Dissipation in Power Down Mode,
                                            Max Power is 8 bit value * 10 mW.

                                            Byte 2 , Bits 7- 4 (Address 194)
                                            Maximum current required by +5V Supply.
                                            Max current is 4 bit value * 50 mA. [500 mA max].

                                            Byte 2 , Bits 3- 0 (Address 194)
                                            Maximum current required by +3.3V Supply.
                                            Max current is 4 bit value * 100 mA.

                                            Byte 3 , Bits 7- 4 (Address 195)
                                            Maximum current required by +1.8V Supply.
                                            Max current is 4 bit value * 100 mA.

                                            Byte 3 , Bits 3- 0 (Address 195)
                                            Maximum current required by -5.2V Supply.
                                            Max current is 4 bit value * 50 mA                                                                               
                                           */
		 
  unsigned char ucVendorSerialNumber[16];	 /* Serial number provided by vendor */

  unsigned char ucVendorDateCode[8];	/* Vendor's manufacturing date code
                                          Byte 0 and 1 (Data address 212 and 213)
                                          ASCII code, two low order digits of year. (00 = 2000).

                                          Byte 2 and 3 (Data address 214 and 215)
                                          ASCII code, digits of month (01 = Jan. through 12 = Dec.)

                                          Byte 4 and 5 (Data address 216 and 217)
                                          ASCII code, day of month (01 - 31)

                                          Byte 6 and 7 (Data address 2128and 219)
                                          ASCII code, vendor specific lot code, may be blank
                                       */
	 
  unsigned char ucDiagMonitoringType;	 /* Indicates which type of diagnostic monitoring is implemented (if any)
                                           in the transceiver,
                                           
														 Bit 3:
														 Received power measurement type
														 0 = OMA, 1 = Average Power

														 Bit :4
														 Module Respond to FEC BER
                                           0= No BER Support, 1=BER Support
                                        */

  unsigned char ucEnhancedOptions;	/* Indicates which optional enhanced features are implemented (if any) in
                                       the transceiver
		                                 XFP_OPTIONAL_SMU_SUPPORT_MODE     
                                       XFP_OPTIONAL_WAVELENGTH_TUNABILITY    
                                       XFP_OPTIONAL_ACTIVE_FEC_CONTROLS     
                                       XFP_OPTIONAL_VPS_BYPASS_REG_MODE     
                                       XFP_OPTIONAL_VPS_LV_REG_MODE     
                                       XFP_OPTIONAL_SOFT_P_DOWN     
                                       XFP_OPTIONAL_TX_DISABLE     
                                       XFP_OPTIONAL_VPS     
                                       */

  unsigned char ucAuxMonitoring;	    /* Defines quantities reported by Aux. A/D channels
		                                  XFP_AUX_MONITORING_NOT_IMPLEMENTED     
                                        XFP_AUX_MONITORING_APD_BIAS_VOLTAGE    
                                        XFP_AUX_MONITORING_TEC_CURRENT     
                                        XFP_AUX_MONITORING_LASER_TEMPERATURE     
                                        XFP_AUX_MONITORING_LASER_WAVELENGTH     
                                        XFP_AUX_MONITORING_PLUS_5V_SUPPLY_VOLTAGE     
                                        XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_VOLTAGE     
                                        XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_VOLTAGE     
                                        XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_VOLTAGE     
                                        XFP_AUX_MONITORING_PLUS_5V_SUPPLY_CURRENT     
                                        XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_CURRENT     
                                        XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_CURRENT     
                                        XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_CURRENT     
                                        */       
  unsigned char	ucCCExt;		/* Check code for the Extended ID Fields */
		 
  unsigned char	ucReserved[256];     /*Reserved */

}XFPProfile;



/* Defined constants for ucModuleIdentifier */
#define	XFP_IDENTIFIER_UNKNOWN				0x00
#define  XFP_IDENTIFIER_GBIC					0x01
#define  XFP_IDENTIFIER_MODULE_SOLDERED	0x02
#define  XFP_IDENTIFIER_SFP					0x03
#define  XFP_IDENTIFIER_300_PIN_XBI			0x04
#define  XFP_IDENTIFIER_XENPAK				0x05
#define  XFP_IDENTIFIER_XFP					0x06 
#define  XFP_IDENTIFIER_XFF					0x07 
#define  XFP_IDENTIFIER_XFP_E					0x08 
#define  XFP_IDENTIFIER_XPAK					0x09
#define  XFP_IDENTIFIER_X2						0x0A

/* Define constants for ucConnectorType */
#define  XFP_CONNECTOR_UNKNOWN				0x00
#define  XFP_CONNECTOR_SC						0x01
#define  XFP_CONNECTOR_FC_STYLE_1			0x02
#define  XFP_CONNECTOR_FC_STYLE_2			0x03
#define  XFP_CONNECTOR_BNC_TNC				0x04
#define  XFP_CONNECTOR_FC_COAXIAL_HEADERS	0x05
#define  XFP_CONNECTOR_FIBERJACK			   0x06
#define  XFP_CONNECTOR_LC						0x07
#define  XFP_CONNECTOR_MT_RJ					0x08
#define  XFP_CONNECTOR_MU						0x09
#define  XFP_CONNECTOR_SG						0x0A
#define  XFP_CONNECTOR_OPTICAL_PIGTAIL		0x0B
#define  XFP_CONNECTOR_HSSDC_II				0x20
#define  XFP_CONNECTOR_COPPER_PIGTAIL		0x21

/* Define constants for field ucTransceiverType */
  //Byte 0:  Addr 131, 10 Gigabit Ethernet Compliance
#define  XFP_TRANSCEIVER_10GBASE_EW			0x02
#define  XFP_TRANSCEIVER_10GBASE_LW			0x04
#define  XFP_TRANSCEIVER_10GBASE_SW			0x08
#define  XFP_TRANSCEIVER_10GBASE_ER			0x20
#define  XFP_TRANSCEIVER_10GBASE_LR			0x40
#define  XFP_TRANSCEIVER_10GBASE_SR			0x80
                                         
  //Byte 1:  Addr 132, 10 Gigabit Fibre Channel Compliance
#define  XFP_TRANSCEIVER_1NT_REACH_1300_NM_FP	0x10
#define  XFP_TRANSCEIVER_EXT_REACH_1550_NM_FP	0x20
#define  XFP_TRANSCEIVER_1200_SM_LL_L				0x40
#define  XFP_TRANSCEIVER_1200_MX_SN_L				0x80
                                         
 //Byte 3:  Addr 134, Lower Speed Links
#define  XFP_TRANSCEIVER_OC_48_LR			0x02
#define  XFP_TRANSCEIVER_OC_48_IR			0x04
#define  XFP_TRANSCEIVER_OC_48_SR			0x08
#define  XFP_TRANSCEIVER_2xFC_SMF			0x10
#define  XFP_TRANSCEIVER_2xFC_MMF			0x20
#define  XFP_TRANSCEIVER_1000BASE_LX_1xFC_SMF    0x40

  //Byte 4:  Addr 135, SONET/SDH codes - Interconnect
#define  XFP_TRANSCEIVER_I_64_5    0x04
#define  XFP_TRANSCEIVER_I_64_3    0x08
#define  XFP_TRANSCEIVER_I_64_2    0x10
#define  XFP_TRANSCEIVER_I_64_2r   0x20
#define  XFP_TRANSCEIVER_I_64_1    0x40
#define  XFP_TRANSCEIVER_I_64_1r   0x80

  //Byte 5:  Addr 136, SONET/SDH Codes - Short Haul
#define XFP_TRANSCEIVER_S_64_5b   0x02
#define XFP_TRANSCEIVER_S_64_5a   0x04
#define XFP_TRANSCEIVER_S_64_3b   0x08
#define XFP_TRANSCEIVER_S_64_3a   0x10
#define XFP_TRANSCEIVER_S_64_2b   0x20
#define XFP_TRANSCEIVER_S_64_2a   0x40
#define XFP_TRANSCEIVER_S_64_1    0x80

  //Byte 6:    Addr 137	 SONET/SDH Codes - Long Haul
#define XFP_TRANSCEIVER_L_64_3    0x08
#define XFP_TRANSCEIVER_L_64_2c   0x10
#define XFP_TRANSCEIVERL_64_2b    0x20
#define XFP_TRANSCEIVER_64_2a     0x40
#define XFP_TRANSCEIVER_L_64_1    0x80

  //Byte 7:    Addr 138, SONET/SDH Codes - Very Long Haul
#define XFP_TRANSCEIVER_V_64_3    0x20
#define XFP_TRANSCEIVER_V_64_2b   0x40
#define XFP_TRANSCEIVER_V_64_2a   0x80 

/* Defined constants for field ucSerialEncodingAlgorithm */
#define XFP_ENCODING_64B_66B		0x80
#define XFP_ENCODING_8B10B			0x40
#define XFP_ENCODING_SONET_SCRAMBLED	0x20
#define XFP_ENCODING_NRZ			0x10
#define XFP_ENCODING_RZ				0x08

/* Defined constants for field ucCDRSupport */
#define XFP_CDR_LOOPBACK_MODE_SUPPORTED	0x01
#define XFP_CDR_LINESIDE_LOOPBACK_MODE_SUPPORTED	0x02
#define XFP_CDR_SUPPORT_FOR_11_1_GBS	0x08
#define XFP_CDR_SUPPORT_FOR_10_7_GBS   0x10
#define XFP_CDR_SUPPORT_FOR_10_5_GBS   0x20
#define XFP_CDR_SUPPORT_FOR_10_3_GBS   0x40
#define XFP_CDR_SUPPORT_FOR_9_95_GBS   0x80


/* Defined constants for field ucEnhancedOptions of XFPProfile */
#define XFP_OPTIONAL_SMU_SUPPORT_MODE				0x01
#define XFP_OPTIONAL_WAVELENGTH_TUNABILITY		0x02
#define XFP_OPTIONAL_ACTIVE_FEC_CONTROLS			0x04
#define XFP_OPTIONAL_VPS_BYPASS_REG_MODE			0x08
#define XFP_OPTIONAL_VPS_LV_REG_MODE				0x10
#define XFP_OPTIONAL_SOFT_P_DOWN						0x20
#define XFP_OPTIONAL_TX_DISABLE						0x40
#define XFP_OPTIONAL_VPS								0x80

/* Defined constants for field ucAuxMonitoring of XFPProfile */
#define XFP_AUX_MONITORING_NOT_IMPLEMENTED				0x00
#define XFP_AUX_MONITORING_APD_BIAS_VOLTAGE				0x01
#define XFP_AUX_MONITORING_TEC_CURRENT						0x03
#define XFP_AUX_MONITORING_LASER_TEMPERATURE				0x04
#define XFP_AUX_MONITORING_LASER_WAVELENGTH				0x05
#define XFP_AUX_MONITORING_PLUS_5V_SUPPLY_VOLTAGE     0x06
#define XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_VOLTAGE	0x07
#define XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_VOLTAGE   0x08
#define XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_VOLTAGE  0x09
#define XFP_AUX_MONITORING_PLUS_5V_SUPPLY_CURRENT     0x0A
#define XFP_AUX_MONITORING_PLUS_3_3V_SUPPLY_CURRENT   0x0D
#define XFP_AUX_MONITORING_PLUS_1_8V_SUPPLY_CURRENT   0x0E
#define XFP_AUX_MONITORING_MINUS_5_2V_SUPPLY_CURRENT  0x0F
		
#endif
