/*****************************************************************************
 * l3items.h
 * Layer 3 SmartCard Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

/****************************************************************************/

#ifndef _L3_ITEMS_H_
#define _L3_ITEMS_H_

#include "stmitems.h"
#include "ettypes.h"


/* start block of common redefines */

/*----------------------- HTSetStructure ----------------------*/

/*------------ iType1 values for HTSetStructure ---------------*/

/* This set of constants will cause streams
 * to be defined on the specified board. A stream structure
 * is used as a blueprint for creating frames.
 * The specified SmartCard appends the streams to the
 * list of streams already defined on the card (unless
 * you are modifying a stream).
 *
 * NOTE: Streams cannot be added or modified while the card
 * is sending traffic.
 */

/* This set refers to an array of 0, 1, or more Stream
 * structures.
 */
#define L3_DEFINE_SMARTBITS_STREAM			NS_DEFINE_SMARTBITS_STREAM			/* Create a list with one or more customizable Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_SMARTBITS_128_STREAM		NS_DEFINE_SMARTBITS_128_STREAM	/* Create a list with one or more customizable Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_802_3_STREAM				NS_DEFINE_802_3_STREAM				/* Create a list with one or more IEEE 802.3 Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_IP_STREAM					NS_DEFINE_IP_STREAM					/* Create a list with one or more IP compliant Tx Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_IPV6_STREAM					NS_DEFINE_IPV6_STREAM

#define L3_DEFINE_IPX_STREAM					NS_DEFINE_IPX_STREAM					/* Create a list with one or more IPX compliant Tx Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_UDP_STREAM					NS_DEFINE_UDP_STREAM					/* Create a list with one or more UDP compliant Tx Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_UDP_IPV6_STREAM				NS_DEFINE_UDP_IPV6_STREAM

#define L3_DEFINE_TCP_STREAM					NS_DEFINE_TCP_STREAM					/* Create a list with one or more TCP compliant Tx Streams. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_TCP_IPV6_STREAM				NS_DEFINE_TCP_IPV6_STREAM

#define L3_DEFINE_IP_STREAM_VLAN				NS_DEFINE_IP_STREAM_VLAN			/* Create a list with one or more IP compliant Tx Streams with VLAN. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_IPV6_STREAM_VLAN				NS_DEFINE_IPV6_STREAM_VLAN

#define L3_DEFINE_UDP_STREAM_VLAN  			NS_DEFINE_UDP_STREAM_VLAN			/* Create a list with one or more UDP compliant Tx Streams with VLAN. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_UDP_IPV6_STREAM_VLAN		NS_DEFINE_UDP_IPV6_STREAM_VLAN

#define L3_DEFINE_TCP_STREAM_VLAN  			NS_DEFINE_TCP_STREAM_VLAN			/* Create a list with one or more TCP compliant Tx Streams with VLAN. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_SMART_TCP_STREAM_VLAN 	NS_DEFINE_SMART_TCP_STREAM_VLAN			/* Create a list with one or more TCP compliant Tx Streams with VLAN. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_TCP_IPV6_STREAM_VLAN		NS_DEFINE_TCP_IPV6_STREAM_VLAN

#define L3_DEFINE_SMART_TCP_STREAM 			NS_DEFINE_SMART_TCP_STREAM			/* Create a list with one or more TCP compliant Tx Streams for the SmartTCP tests. */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/

#define L3_DEFINE_ICMP_STREAM 				NS_DEFINE_ICMP_STREAM				/* Create a list with one or more ICMP compliant Tx Streams */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_STREAM_EXTENSION			NS_DEFINE_STREAM_EXTENSION			/* Create a list with one or more Stream Extensions */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_RTP_STREAM					NS_DEFINE_RTP_STREAM					/* Create a list with one or more RTP compliant Tx Streams */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_RTP_STREAM_VLAN			NS_DEFINE_RTP_STREAM_VLAN			/* Create a list with one or more RTP compliant Tx Streams with VLAN */
																									/* Clears previous streams, disables first stream (at index zero "0.")*/

#define L3_DEFINE_STREAM_MPLS					NS_DEFINE_STREAM_MPLS

#define L3_DEFINE_VFD							NS_DEFINE_VFD					/* Create a list of per-stream VFDs. */

#define L3_DEFINE_MPLS							NS_DEFINE_MPLS					/* Create a single MPLS Stream with stream index */

#define L3_MOD_MPLS								NS_MOD_MPLS						/* Create a single MPLS Stream with stream index */


#define L3_DEFINE_MULTI_SMARTBITS_STREAM		NS_DEFINE_MULTI_SMARTBITS_STREAM	/* Append similar copies of a SmartBits Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_SMARTBITS_128_STREAM NS_DEFINE_MULTI_SMARTBITS_128_STREAM	/* Append similar copies of a SmartBits 128 bytes payloaded Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_802_3_STREAM			NS_DEFINE_MULTI_802_3_STREAM		/* Append similar copies of an IEEE 802.3 Stream */
#define L3_DEFINE_MULTI_IP_STREAM				NS_DEFINE_MULTI_IP_STREAM			/* Append similar copies of an IP Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_IPV6_STREAM				NS_DEFINE_MULTI_IPV6_STREAM
#define L3_DEFINE_MULTI_IPX_STREAM				NS_DEFINE_MULTI_IPX_STREAM			/* Append similar copies of an IPX Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_UDP_STREAM				NS_DEFINE_MULTI_UDP_STREAM			/* Append similar copies of a UDP Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_UDP_IPV6_STREAM			NS_DEFINE_MULTI_UDP_IPV6_STREAM
#define L3_DEFINE_MULTI_TCP_STREAM				NS_DEFINE_MULTI_TCP_STREAM			/* Append similar copies of a TCP Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_TCP_IPV6_STREAM			NS_DEFINE_MULTI_TCP_IPV6_STREAM
#define L3_DEFINE_MULTI_IP_STREAM_VLAN			NS_DEFINE_MULTI_IP_STREAM_VLAN	/* Append similar copies of an IP Stream with VLAN.  Note that "index" is the stream to copy and "count" is the number of streams to create.*/
#define L3_DEFINE_MULTI_IPV6_STREAM_VLAN		NS_DEFINE_MULTI_IPV6_STREAM_VLAN
#define L3_DEFINE_MULTI_UDP_STREAM_VLAN		NS_DEFINE_MULTI_UDP_STREAM_VLAN	/* Append similar copies of a UDP Stream with VLAN.  Note that "index" is the stream to copy and "count" is the number of streams to create.*/
#define L3_DEFINE_MULTI_UDP_IPV6_STREAM_VLAN	NS_DEFINE_MULTI_UDP_IPV6_STREAM_VLAN
#define L3_DEFINE_MULTI_TCP_STREAM_VLAN		NS_DEFINE_MULTI_TCP_STREAM_VLAN	/* Append similar copies of a TCP Stream with VLAN.  Note that "index" is the stream to copy and "count" is the number of streams to create.*/
#define L3_DEFINE_MULTI_TCP_IPV6_STREAM_VLAN	NS_DEFINE_MULTI_TCP_IPV6_STREAM_VLAN
#define L3_DEFINE_MULTI_SMART_TCP_STREAM		NS_DEFINE_MULTI_SMART_TCP_STREAM	/* Append similar copies of a TCP Stream for the SmartTCP tests.  Note that "index" is the stream to copy and "count" is the number of streams to create.*/
#define L3_DEFINE_MULTI_ICMP_STREAM				NS_DEFINE_MULTI_ICMP_STREAM		/* Append similar copies of a ICMP Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_STREAM_EXTENSION		NS_DEFINE_MULTI_STREAM_EXTENSION	/* Append similar copies of a Stream Extension.  Note that "index" is the stream extension to copy and "count" is the number of stream extensions to create. */
#define L3_DEFINE_MULTI_RTP_STREAM				NS_DEFINE_MULTI_RTP_STREAM			/* Append similar copies of a RTP Stream.  Note that "index" is the stream to copy and "count" is the number of streams to create. */
#define L3_DEFINE_MULTI_RTP_STREAM_VLAN		NS_DEFINE_MULTI_RTP_STREAM_VLAN	/* Append similar copies of a RTP Stream with VLAN.  Note that "index" is the stream to copy and "count" is the number of streams to create. */

#define L3_DEFINE_MULTI_VFD						NS_DEFINE_MULTI_VFD					/* Append similar copies of per-stream VFDs.  Note that "index" is the VFD to copy and "count" is the number of VFDs to create. */


/* This set refers to a single Stream structure which
 * overwrites a Stream structure at a given index.
 */

#define L3_MOD_SMARTBITS_STREAM				NS_MOD_SMARTBITS_STREAM		/* Overwrite one SmartBits Stream in the list at a given index("index"). */
#define L3_MOD_SMARTBITS_128_STREAM			NS_MOD_SMARTBITS_128_STREAM	/* Overwrite one SmartBits 128 bytes payloaded Stream in the list at a given index("index"). */
#define L3_MOD_802_3_STREAM					NS_MOD_802_3_STREAM			/* Overwrite one IEEE 802.3 Stream in the list at a given index("index"). */
#define L3_MOD_IP_STREAM						NS_MOD_IP_STREAM				/* Overwrite one IP Stream in the list at a given index("index"). */
#define L3_MOD_IPV6_STREAM						NS_MOD_IPV6_STREAM
#define L3_MOD_IPX_STREAM						NS_MOD_IPX_STREAM				/* Overwrite one IPX Stream in the list at a given index("index"). */
#define L3_MOD_UDP_STREAM						NS_MOD_UDP_STREAM				/* Overwrite one UDP Stream in the list at a given index("index"). */
#define L3_MOD_UDP_IPV6_STREAM					NS_MOD_UDP_IPV6_STREAM
#define L3_MOD_TCP_STREAM						NS_MOD_TCP_STREAM				/* Overwrite one TCP Stream in the list at a given index("index"). */
#define L3_MOD_TCP_IPV6_STREAM					NS_MOD_TCP_IPV6_STREAM
#define L3_MOD_IP_STREAM_VLAN					NS_MOD_IP_STREAM_VLAN		/* Overwrite one IP Stream with VLAN in the list at a given index("index"). */
#define L3_MOD_IPV6_STREAM_VLAN					NS_MOD_IPV6_STREAM_VLAN
#define L3_MOD_UDP_STREAM_VLAN				NS_MOD_UDP_STREAM_VLAN		/* Overwrite one UDP Stream with VLAN in the list at a given index("index"). */
#define L3_MOD_UDP_IPV6_STREAM_VLAN			NS_MOD_UDP_IPV6_STREAM_VLAN
#define L3_MOD_TCP_STREAM_VLAN				NS_MOD_TCP_STREAM_VLAN		/* Overwrite one TCP Stream with VLAN in the list at a given index("index"). */

#define L3_MOD_TCP_IPV6_STREAM_VLAN			NS_MOD_TCP_IPV6_STREAM_VLAN
#define L3_MOD_SMART_TCP_STREAM				NS_MOD_SMART_TCP_STREAM		/* Overwrite one TCP Stream for the SmrtTCP tests in the list at a given index("index"). */
#define L3_MOD_SMART_TCP_STREAM_VLAN        NS_MOD_SMART_TCP_STREAM_VLAN  /* Overwrite one TCP Stream for the SmartTCPVLAN tests in the list at a given index("index"). */
#define L3_MOD_ICMP_STREAM						NS_MOD_ICMP_STREAM			/* Overwrite one ICMP Stream in the list at a given index("index"). */
#define L3_MOD_STREAM_EXTENSION				NS_MOD_STREAM_EXTENSION		/* Overwrite one Stream Extension in the list at a given index("index"). */
#define L3_MOD_RTP_STREAM						NS_MOD_RTP_STREAM				/* Overwrite one RTP Stream in the list at a given index("index"). */
#define L3_MOD_RTP_STREAM_VLAN				NS_MOD_RTP_STREAM_VLAN		/* Overwrite one RTP Stream in the list at a given index("index"). */

#define L3_MOD_VFD								NS_MOD_VFD				 	/* Overwrite one per-stream VFD in the list at a given index("index"). */

#define L3_MOD_STREAMS_DELTA					NS_MOD_STREAMS_DELTA		/* Increment a field in a block of streams by incrementing a base value */
#define L3_MOD_STREAMS_ARRAY					NS_MOD_STREAMS_ARRAY		/* Modify a field in a block of streams by overlaying an element from an array */
#define L3_MOD_V2_STREAMS_ARRAY				NS_MOD_V2_STREAMS_ARRAY	/* Modify a field in a block of streams by overlaying an element from an array for Terametrics LAN XD cards*/

#define L3_MOD_SMARTBITS_STREAMS				NS_MOD_SMARTBITS_STREAMS/* Modify a block of streams by overlaying an array of streams*/
#define L3_MOD_802_3_STREAMS					NS_MOD_802_3_STREAMS
#define L3_MOD_IP_STREAMS						NS_MOD_IP_STREAMS
#define L3_MOD_IPX_STREAMS						NS_MOD_IPX_STREAMS
#define L3_MOD_UDP_STREAMS						NS_MOD_UDP_STREAMS
#define L3_MOD_TCP_STREAMS						NS_MOD_TCP_STREAMS
#define L3_MOD_SMART_TCP_STREAMS				NS_MOD_SMART_TCP_STREAMS
#define L3_MOD_ICMP_STREAMS					NS_MOD_ICMP_STREAMS
#define L3_MOD_RTP_STREAMS						NS_MOD_RTP_STREAMS
#define L3_MOD_UDPDHCP_STREAMS				NS_MOD_UDPDHCP_STREAMS
#define L3_MOD_IP_STREAMS_VLAN				NS_MOD_IP_STREAMS_VLAN
#define L3_MOD_UDP_STREAMS_VLAN				NS_MOD_UDP_STREAMS_VLAN
#define L3_MOD_TCP_STREAMS_VLAN				NS_MOD_TCP_STREAMS_VLAN
#define L3_MOD_RTP_STREAMS_VLAN				NS_MOD_RTP_STREAMS_VLAN

//ICMP streams
#define L3_DEFINE_ICMP_STREAM_VLAN              NS_DEFINE_ICMP_STREAM_VLAN           
#define L3_DEFINE_MULTI_ICMP_STREAM_VLAN        NS_DEFINE_MULTI_ICMP_STREAM_VLAN     
#define L3_MOD_ICMP_STREAM_VLAN                 NS_MOD_ICMP_STREAM_VLAN 
#define L3_DEFINE_ICMP_IPV6_STREAM              NS_DEFINE_ICMP_IPV6_STREAM              
#define L3_DEFINE_MULTI_ICMP_IPV6_STREAM        NS_DEFINE_MULTI_ICMP_IPV6_STREAM        
#define L3_MOD_ICMP_IPV6_STREAM                 NS_MOD_ICMP_IPV6_STREAM                 
#define L3_DEFINE_ICMP_IPV6_STREAM_VLAN         NS_DEFINE_ICMP_IPV6_STREAM_VLAN         
#define L3_DEFINE_MULTI_ICMP_IPV6_STREAM_VLAN   NS_DEFINE_MULTI_ICMP_IPV6_STREAM_VLAN  
#define L3_MOD_ICMP_IPV6_STREAM_VLAN            NS_MOD_ICMP_IPV6_STREAM_VLAN


#define L3_CAPTURE_SETUP						0x1057					/* configure layer 3 capture on a port    */

#define L3_VOICE_TEST_SETUP					NS_VOICE_TEST_SETUP	/* configure the voice test */

#define L3_TX_ADDRESS							NS_TX_ADDRESS			/* set SmartCard device address information */
#define L3_TX_IPV6_ADDRESS						NS_TX_IPV6_ADDRESS      /* Set IPv6 related address information. */
#define L3_TX_IPV6_PROTOCOL						NS_TX_IPV6_PROTOCOL     /* Configure IPv6 Ping settings. */
#define L3_DEFINE_STREAM_BINDING				NS_DEFINE_STREAM_BINDING /* Bind stream(s) to ATM VC(s), and update
                                                                      the stream ATM CLP setting for a ATM Terametrics
                                                                      module. Use an array of L3StreamBinding when
                                                                      bind multiple streams. The starting
                                                                      stream index is always one. The array size
                                                                      is the number of streams to be set */
#define L3_MOD_STREAM_BINDING					NS_MOD_STREAM_BINDING /* Bind one stream to one ATM VC, and update
                                                                   the stream ATM CLP setting for a ATM Terametrics module.
                                                                   The stream is of <index> as given by iType2 */
#define L3_DEFINE_MULTI_STREAM_BINDING		NS_DEFINE_MULTI_STREAM_BINDING /* Copy the stream binding of one stream
                                                                            to multiple streams. The base stream
                                                                            is of <index> as given by iType2.
                                                                            The newly set stream is  of <index+1>,
                                                                            <index+2>, ..., <index+count>. The <count>
                                                                            is given by iType3. The uiBindIndex in
                                                                            L3StreamBinding is the delta value, and
                                                                            the uiATMFlags is ignored. */

#define L3_STREAM_BINDING_INFO				NS_STREAM_BINDING_INFO /* Retrieve stream binding information including
                                                                    VC index and CLP setting for the stream at
                                                                    the index given by iType2. */
/*----------------------- HTGetStructure ----------------------*/
/*----------- iType1 ---------------*/
#define L3_DEFINED_STREAM_COUNT_INFO		NS_STREAM_COUNT_INFO		/* retrieve the count of Streams in the list */
/* L3_STREAM_INFO Description:
	 Used with the HTGetStructure() command
      where
         iType1 = L3_STREAM_INFO
         iType2 = <index>
         pData is one of the Stream structure types of
               StreamSmartBits
               StreamIP
               StreamUDP
               StreamIPX


	Retrieve streams setup information in the streams list, at the index
	given by iType2.  Unless you are already using this command, it is 
	recommended to use the L3_STREAM_128_INFO instead.  L3_STREAM_128_INFO
	accomodates larger stream types and retrieves the stream information in
	the natural byte order
*/
#define L3_STREAM_INFO							0x1510						/* retrieve Streams setup information in the Streams list.  Note than "index" is the stream to retrieve information for. */
#define L3_STREAM_128_INFO						0x1075						/* retrieve Streams setup information in the Streams list.  Note than "index" is the stream to retrieve information for. */

#define L3_V2_STREAM_INFO						NS_V2_STREAM_INFO			/* for internal use only */
#define L3_VFD_INFO								NS_VFD_INFO					/* retrive the VFD data for a given stream specified by "index".  Note that the "ucType" field is an input that needs to be specified. */

#define L3_TX_ADDRESS_INFO						NS_TX_ADDRESS_INFO		    /* retrieve SmartCard device address information */
#define L3_TX_IPV6_ADDRESS_INFO					NS_TX_IPV6_ADDRESS_INFO     /* Retrieve IPv6 related address information. */

#define L3_ARP_TIMES_INFO						NS_ARP_TIMES_INFO			/* Retrieve ARP times for each stream in the list. */

/*----------------------Get Histogram records-----------------*/
#define L3_HIST_ACTIVE_TEST_INFO					NS_HIST_ACTIVE_TEST_INFO				/* Get the number of histogram records, and active histogram */
#define L3_HIST_SEQUENCE_INFO						NS_HIST_SEQUENCE_INFO					/* Get Sequence Tracking histogram results.  Note that "index" is the stream to get these results for. */
#define L3_HIST_LATENCY_INFO						NS_HIST_LATENCY_INFO						/* Get 16-bit Latency over Time histogram results */
#define L3_HIST_LATENCY_PER_STREAM_INFO		NS_HIST_LATENCY_PER_STREAM_INFO		/* Get 16-bit Latency per Stream histogram results */
#define L3_HIST_V1_LATENCY_PER_STREAM_INFO	NS_HIST_V1_LATENCY_PER_STREAM_INFO	/* Get 32-bit Latency per Stream histogram results */
#define L3_HIST_LATENCY_DISTRIBUTION_INFO		NS_HIST_LATENCY_DISTRIBUTION_INFO	/* Get Latency Distribution histogram results.  Note that "index" is the stream to get these results for. */
#define L3_HIST_RAW_TAGS_INFO						NS_HIST_RAW_TAGS_INFO					/* Get Raw Tags histogram records.  Note that "index" is the stream to get these records for. */
#define L3_HIST_V2_LATENCY_INFO					NS_HIST_V2_LATENCY_INFO					/* Get Latency over Time histogram results.  Note that "index" is the time interval to get these results for. */
#define L3_HIST_V2_LATENCY_PER_STREAM_INFO	NS_HIST_V2_LATENCY_PER_STREAM_INFO  /* Get combination histogram results - Latency Dist, Lat. Per Stream, Sequence.  Note that "index" is the stream to get these results for.*/
#define L3_HIST_MC_LATENCY_PER_STREAM_INFO	NS_HIST_MC_LATENCY_PER_STREAM_INFO  /* Get MulticastIP Latency Dist hist with 1st and last Rx timestamp.  Note that "index" is the stream to get these results for. */
#define L3_MULTICAST_COUNTER_INFO				NS_MULTICAST_COUNTER_INFO           /*Multicast counters on 7710 5710A*/
#define L3_HIST_JITTER_COMBO_INFO				NS_HIST_JITTER_COMBO_INFO           /* Get 32-bit latency histogram test */
/*------- 64-bit-Histograms -------*/
/* &&&& 
#define L3_HIST_RAW_SIGNATURE_INFO				NS_HIST_RAW_SIGNATURE_INFO
#define L3_HIST_COMBO_PER_STREAM_INFO			NS_HIST_COMBO_PER_STREAM_INFO
#define L3_HIST_LATENCY_OVER_TIME_INFO			NS_HIST_LATENCY_OVER_TIME_INFO
#define L3_HIST_SEQUENCE_PER_STREAM_INFO		NS_HIST_SEQUENCE_PER_STREAM_INFO
#define L3_HIST_LATENCY_DIST_PER_STREAM_INFO	NS_HIST_LATENCY_DIST_PER_STREAM_INFO
*/

#define L3_HIST_ACTIVE_TEST_EXPRESS_INFO		NS_HIST_ACTIVE_TEST_EXPRESS_INFO
#define L3_HIST_SEQUENCE_EXPRESS_INFO			NS_HIST_SEQUENCE_EXPRESS_INFO

/*----------------------Get Histogram summary-----------------*/
#define L3_HIST_SUMMARY_INFO					NS_HIST_SUMMARY_INFO				/* Get summary results of active test */
#define L3_AGGREGATE_INFO  					NS_AGGREGATE_INFO					/* Get summary results of active test */
#define L3_AGGR_SEQUENCE_INFO					NS_AGGR_SEQUENCE_INFO			/* Get summary of Sequence Tracking histogram results */
#define L3_AGGR_LATENCY_INFO					NS_AGGR_LATENCY_INFO				/* Get summary of 16-bit Latency over Time histogram results */
#define L3_AGGR_LATENCY_PER_STREAM_INFO	NS_AGGR_LATENCY_PER_STREAM_INFO	/* Get summary of 16-bit Latency per Stream histogram results */
#define L3_AGGR_LATENCY_DISTRIBUTION_INFO	NS_AGGR_LATENCY_DISTRIBUTION_INFO/* Get summary of Full Latency Distribution histogram results */
#define L3_AGGR_RAW_TAGS_INFO					NS_AGGR_RAW_TAGS_INFO			/* Get summary of Raw Tags information */
#define L3_AGGR_V2_LATENCY_INFO				NS_AGGR_V2_LATENCY_INFO			/* Get summary of Latency over Time histogram results */
#define L3_AGGR_V2_LATENCY_PER_STREAM_INFO	NS_AGGR_V2_LATENCY_PER_STREAM_INFO	/* Get summary of both Latency Distribution and Per Stream histogram results */
#define L3_AGGR_MC_LATENCY_PER_STREAM_INFO	NS_AGGR_MC_LATENCY_PER_STREAM_INFO  /* Get summary of MulticastIP Latency Dist hist with 1st and last Rx timestamp */

#define L3_CAPTURE_COUNT_INFO				(NS_BASE_NUM + 8)						/* Get the count of captured frames */
#define L3_CAPTURE_PACKET_DATA_INFO			NS_CAPTURE_PACKET_DATA_INFO	/* Get the captured frame.  Note that "index" is the frame to get information for. */
#define L3_CAPTURE_PACKET_DATA_INFO_MT		0x01									/* Fw value for LinkPort::EULTypeCodeL3 detection*/
#define L3_CAPTURE_DETAIL_INFO	   		NS_CAPTURE_DETAIL_INFO			/* Get details of the frame.  Note that "index" is the frame to retrieve information for. */
#define L3_RTP_COUNTER_INFO					NS_RTP_COUNTER_INFO				/* Get RTP counter info */

/*----------------------- HTSetCommand ----------------------*/
/*----------- iType1 ---------------*/

/*--------  Histogram setup commands  ---------*/
#define L3_HIST_START							NS_HIST_START							/* Clear Histogram records/Histogram remains in Receive state.*/
#define L3_HIST_SEQUENCE						NS_HIST_SEQUENCE						/* Specify/Activate Sequence Tracking histogram for Rx port */
#define L3_HIST_LATENCY							NS_HIST_LATENCY						/* Specify/Activate 16-bit Latency over time histogram for Rx port */
#define L3_HIST_LATENCY_PER_STREAM			NS_HIST_LATENCY_PER_STREAM			/* Specify/Activate 16-bit Latency per Stream histogram for Rx port */
#define L3_HIST_V1_LATENCY_PER_STREAM		NS_HIST_V1_LATENCY_PER_STREAM		/* Specify/Activate 32-bit Latency per Stream histogram for Rx port */
#define L3_HIST_LATENCY_DISTRIBUTION		NS_HIST_LATENCY_DISTRIBUTION		/* Specify/Activate 16-bit Latency Distribution histogram for Rx port */
#define L3_HIST_V2_LATENCY_DISTRIBUTION	NS_HIST_V2_LATENCY_DISTRIBUTION	/* Specify/Activate 32-bit Latency Distribution histogram for Rx port */
#define L3_HIST_RAW_TAGS						NS_HIST_RAW_TAGS						/* Specify/Activate Raw Tag histogram for Rx port */
#define L3_HIST_V2_LATENCY						NS_HIST_V2_LATENCY					/* Specify/Activate Latency Over Time histogram for Rx port */
#define L3_HIST_V2_LATENCY_PER_STREAM		NS_HIST_V2_LATENCY_PER_STREAM		/* Specify/Activate combiniation histogram (Latency Dist., Latency Per Strm, and Sequence) for Rx port */
#define L3_HIST_LATENCY_PRECISION			NS_HIST_LATENCY_PRECISION			/* Specify/Activate Sequence Tracking histogram for Rx port */
#define L3_HIST_MULTICAST_LATENCY			NS_HIST_MULTICAST_LATENCY			/* Specify/Activate MulticastIP Latency Dist hist with 1st and last Rx timestamp */
#define L3_HIST_JITTER_COMBO					NS_HIST_JITTER_COMBO					/* Specify/Activate Jitter Combo Test */
#define L3_HIST_TCP_CONNECTION				NS_HIST_TCP_CONNECTION
/*------- 64-bit-Histograms -------*/
/* &&&& NOTE TO SELF: USE THE NS IN CODE
#define L3_HIST_RAW_SIGNATURE					NS_HIST_RAW_SIGNATURE
#define L3_HIST_COMBO_PER_STREAM				NS_HIST_COMBO_PER_STREAM
#define L3_HIST_LATENCY_OVER_TIME			NS_HIST_LATENCY_OVER_TIME
#define L3_HIST_SEQUENCE_PER_STREAM			NS_HIST_SEQUENCE_PER_STREAM
#define L3_HIST_LATENCY_DIST_PER_STREAM	NS_HIST_LATENCY_DIST_PER_STREAM
*/
#define L3_HIST_ACTIVE_TEST_PREP				NS_HIST_ACTIVE_TEST_PREP
#define L3_HIST_SEQUENCE_PREP					NS_HIST_SEQUENCE_PREP	

/*--------  Start ARPs command  ---------*/
#define L3_START_ARPS							NS_START_ARPS					/* Begin ARP exchange on all defined streams. */
#define L3_STOP_ARPS							   NS_STOP_ARPS					/* Stop ARP exchange on all defined streams. */

/*-------- IGMP commands and HTGetStructure values ----------------*/
#define L3_IGMP_RESET 							0x7024							/* Reset IGMP protocol stack */
#define L3_IGMP_INIT 							0x7025							/* Initialize IGMP protocol stack */
#define L3_IGMP_JOIN 							0x7026							/* Join multicast group */
#define L3_IGMP_LEAVE 							0x7027							/* Leave multicast group */
#define L3_IGMP_JOIN_LEAVE_TIMESTAMP_INFO       0x7028	 				        /* Get multicast group Join and Leave timestamps */

#define L3_CAPTURE_OFF_TYPE					NS_CAPTURE_OFF_TYPE				/* Turn Capture off */
#define L3_CAPTURE_ALL_TYPE					NS_CAPTURE_ALL_TYPE				/* Capture all frames received */
#define L3_CAPTURE_BAD_TYPE					NS_CAPTURE_BAD_TYPE				/* Capture errors frames only */
#define L3_CAPTURE_SPECIAL_TYPE				NS_CAPTURE_SPECIAL_TYPE			/* reserved */
#define L3_CAPTURE_TRIGGERS_TYPE				NS_CAPTURE_TRIGGERS_TYPE		/* Capture Trigger frames only */
#define L3_CAPTURE_STOP						   0x2015				            /* turn off capture */
#define L3_CAPTURE_START						0x2016					         /* turn on capture */

/*------------Special L3 Commands--------------*/
#define L3_DELETE_STREAM						NS_DELETE_STREAM				/* Delete one stream */
#define L3_SET_STREAM_STATE					NS_SET_STREAM_STATE				/* Disable Stream=0 Enable Stream=1 Note that this indexes from 1 as the first stream on the card, unlike other commands that index from 0*/
#define L3_ARP_UNRESOLVED						NS_ARP_UNRESOLVED				/* Re ARP for streams whose initial ARPs did not get resolved. */
#define L3_ARP_ONE_STREAM						NS_ARP_ONE_STREAM				/* Send an ARP from the stream specified by "index".*/
#define L3_SET_START_STREAM					NS_SET_START_STREAM				/* Start transmitting from this stream */
#define L3_SET_ARP_GAP							NS_SET_ARP_GAP					/* Sets ARP Gap on all streams */
#define L3_ENABLE_TAGS_ALL_STREAMS			NS_ENABLE_TAGS_ALL_STREAMS		/* Enable tag fields on all streams */
#define L3_DISABLE_TAGS_ALL_STREAMS			NS_DISABLE_TAGS_ALL_STREAMS		/* Disable tag fields on all streams */
#define L3_ENABLE_TAG							NS_ENABLE_TAG					/* Enable tag fields on a stream */
#define L3_DISABLE_TAG							NS_DISABLE_TAG					/* Disable tag fields on a stream */

/*-----------USB Commands and CONSTANTS--------------------*/
#define L3_USB_MODE_ON							NS_USB_MODE_ON			/*Toggle USB mode on, disabling the Ethernet port*/
#define L3_USB_MODE_OFF							NS_USB_MODE_OFF			/*Toggle USB port off, enabling the Ethernet port*/
#define L3_ETHERNET_MODE_ON					NS_ETHERNET_MODE_ON		    /*Enables the Ethernet port*/

#define L3_USB_MODE_CMD							0x00
#define L3_USB_ON									0x00
#define L3_USB_OFF								0x01
#define L3_ETHERNET_ON							0x01
#define L3_USB_INFO_CMD							0x01
#define L3_USB_GET_USB_INFO					NS_USB_GET_USB_INFO         /* Retrieve MAC address information from the attached USB device. */
#define L3_USB_SET_POWER						NS_USB_SET_POWER

#define L3_RNDIS_MODE_ON						NS_RNDIS_MODE_ON		/* Enables RNDIS mode */
#define L3_RNDIS_MODE_CMD						0x00
#define L3_RNDIS_ON								0x02



/*---------- DHCP Commands ------------*/
#define L3_DHCP_GET_ADDRESS        		NS_DHCP_GET_ADDRESS       	/* Start DHCP exchange for one or more streams.  Note that "index" is the first stream to start the exchange for and "count" is the total number of streams to exchange for. */
#define L3_DHCP_GET_ADDRESS_ALL    		NS_DHCP_GET_ADDRESS_ALL  	/* Start DHCP exchange for all streams */
#define L3_DHCP_RELEASE_ADDRESS   		NS_DHCP_RELEASE_ADDRESS		/* Perform DHCP release for one or more.  Note taht "index" is the first stream to perform release for and "count" is the total number of streams to perform release for. */
#define L3_DHCP_RELEASE_ADDRESS_ALL 	NS_DHCP_RELEASE_ADDRESS_ALL /* Perform DHCP release for all streams */
#define L3_DHCP_STATS_INFO          	NS_DHCP_STATS_INFO			/* Get DHCP stats from a particular card.  Note that "index" is the first stream to get info for and "count" is the total number of streams to get info for. */
#define L3_DHCP_HOST_INFO      			NS_DHCP_HOST_INFO      		/* Get DHCP host information from a card.  Note that "index" is the first stream to get info for and "count" is the total number of streams to get info for. */
#define L3_DHCP_EXTENDED_HOST_INFO 		NS_DHCP_EXTENDED_HOST_INFO	/* Get DHCP host extended information from a card.  Note that "index" is the first stream to get info for and "count" is the total number of streams to get info for. */
#define L3_DHCP_ACTION						NS_DHCP_ACTION				/* Set DHCP action, use L3_DHCP_ACTION_XXX defines */
#define L3_DHCP_STATE						NS_DHCP_STATE				/* Set DHCP state, use L3_DHCP_STATE_XXX defines */
#define L3_DHCP_STREAM_COUNT_INFO		NS_DHCP_STREAM_COUNT_INFO	/* Get the number of active DHCP-capable streams */
#define L3_DHCP_CONFIG						NS_DHCP_CONFIG				   /* Config certain parameters for DHCP */
#define L3_DHCP_CONFIG_INFO				NS_DHCP_CONFIG_INFO			/* Retrieve the DHCP configuration. */
#define L3_DHCP_RENEW				      NS_DHCP_RENEW			      /* Transmit a DHCP renew/request message for one or more streams. */
#define L3_DHCP_PORT_COUNTER_INFO		NS_DHCP_PORT_COUNTER_INFO	/* Retrieve DHCP summary information for a port */
#define L3_DHCP_PORT_SESSION_INFO		NS_DHCP_PORT_SESSION_INFO  /* Retrieves DHCP port session counters information for a port */

#define L3_DHCP_RESTART						NS_DHCP_RESTART					/* Re-initiates the DHCP process for one or more DHCP capable active streams that are not in DHCP Bound State */
#define L3_DHCP_RESTART_ALL				NS_DHCP_RESTART_ALL				/* Re-initiates the DHCP process for all DHCP capable active streams that are not in DHCP Bound State */
#define L3_DHCP_V2_HOST_INFO				NS_DHCP_V2_HOST_INFO			/* Get DHCP host information from a specified port */
#define L3_DHCP_V2_EXTENDED_HOST_INFO	NS_DHCP_V2_EXTENDED_HOST_INFO	/* Get extended DHCP host information from a specified card */	

#define L3_DHCP_ACTION_DISCOVER         0
#define L3_DHCP_ACTION_REBOOT           1
#define L3_DHCP_ACTION_RENEW            2
#define L3_DHCP_ACTION_RELEASE          3
#define L3_DHCP_ACTION_DECLINE          4
#define L3_DHCP_ACTION_DONE             5

#define L3_DHCP_STATE_UNDEFINED         0
#define L3_DHCP_STATE_INIT              1
#define L3_DHCP_STATE_SELECTING         2
#define L3_DHCP_STATE_REBOOT            3
#define L3_DHCP_STATE_REBOOTING         4
#define L3_DHCP_STATE_REQUESTING        5
#define L3_DHCP_STATE_RENEW             6
#define L3_DHCP_STATE_RENEWING          7
#define L3_DHCP_STATE_BOUND             8
#define L3_DHCP_STATE_REBINDING         9
#define L3_DHCP_STATE_RELEASING         10


/* end block of common redefines */


/*--------------------------------------------------------------------*/
/*-------- Layer 3 SmartCard Parameters and Data Structures  ---------*/
/*--------------------------------------------------------------------*/
/*-------- Layer 3 protocol types (from stmitems.h) ---------*/
 /*-------- Stream protocol types  ---------*/
 /* these are the Protocol fields to be used in the
  * ucProtocol field of the Stream structures below
  */
#define L3_STREAM_SMARTBITS        STREAM_PROTOCOL_SMARTBITS	/* a user defined Stream type */
#define L3_STREAM_8023             STREAM_PROTOCOL_8023			/* an IEEE 802.3 Stream type */
#define L3_STREAM_IP               STREAM_PROTOCOL_IP			/* an IP Stream type */
#define L3_STREAM_IP_VLAN          STREAM_PROTOCOL_IP_VLAN		/* an IP Stream with VLAN tagging type */
#define L3_STREAM_IPX              STREAM_PROTOCOL_IPX			/* an IPX Stream type */
#define L3_STREAM_UDP              STREAM_PROTOCOL_UDP			/* a UDP Stream type */
#define L3_STREAM_UDP_VLAN         STREAM_PROTOCOL_UDP_VLAN  	/* a UDP Stream with VLAN tagging type */
#define L3_STREAM_TCP              STREAM_PROTOCOL_TCP			/* an TCP Stream type */
#define L3_STREAM_TCP_VLAN         STREAM_PROTOCOL_TCP_VLAN		/* a TCP Stream type with VLAN Tagging */
#define L3_STREAM_SMART_TCP        STREAM_PROTOCOL_SMART_TCP	/* a TCP Stream type used for the SmartTCP tests */
#define L3_STREAM_ICMP             STREAM_PROTOCOL_ICMP			/* an ICMP Stream type */
#define L3_STREAM_PPP              STREAM_PROTOCOL_PPP         
#define L3_STREAM_RTP              STREAM_PROTOCOL_RTP			/* a RTP Stream type */
#define L3_STREAM_RTP_VLAN         STREAM_PROTOCOL_RTP_VLAN		/* a RTP Stream with VLAN type */
#define L3_STREAM_ICMP_VLAN        STREAM_PROTOCOL_ICMP_VLAN	/* an ICMP Stream with VLAN */


#define L3_MODIFY_STREAM_ARRAY_SIZE			8192		/* a reference size for allocation and looping */




/*
Layer3DHCPStatsInfo Description:

This structure returns the DHCP Host statistics.
*/
typedef struct tagLayer3DHCPStatsInfo
{
   unsigned long   ulStreamNumber;		/* Stream index number */
   unsigned short  uiFailure;				/* Number of failure(s) */
   unsigned short  uiTimeout;				/* Timeout value */
   unsigned short  uiDiscoverSent;		/* Number of DISCOVER packets sent */
   unsigned short  uiOfferRcvd;			/* Number of OFFER packets received */
   unsigned short  uiReqSent;				/* Number of REQUEST packets sent */
   unsigned short  uiAckRcvd;				/* Number of ACK pakcets received */
   unsigned short  uiNakRcvd;				/* Number of NACK packets Received */
   unsigned short  uiReleaseSent;		/* Number of RELEASE packets sent */
   unsigned short  uiDeclineSent;		/* Number of DECLINE packets sent */
   unsigned short  uiReserved;			/* Reserved, currently unused */
} Layer3DHCPStatsInfo; 

/*
Layer3DHCPHostInfo Description:
This structure returns the DHCP Host results.

Possible values for the uiState are as follows:
L3_DHCP_STATE_UNDEFINED
L3_DHCP_STATE_INIT
L3_DHCP_STATE_SELECTING
L3_DHCP_STATE_REBOOT
L3_DHCP_STATE_REBOOTING
L3_DHCP_STATE_REQUESTING
L3_DHCP_STATE_RENEW
L3_DHCP_STATE_RENEWING
L3_DHCP_STATE_BOUND
L3_DHCP_STATE_REBINDING
L3_DHCP_STATE_RELEASING

*/
typedef struct tagLayer3DHCPHostInfo
{
   unsigned long  ulStreamNumber;		/* Stream index number */
   unsigned char  ucHostIP[4];			/* Host IP address */
   unsigned char  ucServerIP[4];		/* Server IP address */
   unsigned char  ucServerMAC[6];		/* Server MAC address */
   unsigned char  ucReserved[2];		/* Reserved, currently unused */
   unsigned char  ucGateway[4];			/* Gateway address */
   unsigned char  ucSubnet[4];			/* Subnet address */
   unsigned short uiState;				/* The DHCP State of the stream */
   unsigned short uiReserved;			/* Reserved, currently unused */
   unsigned long  ulTime;				/* DHCP Time in 1/10 microseconds */
} Layer3DHCPHostInfo; 


/*
Layer3DHCPExtendedHostInfo Description:
This structure returns the DHCP Host extended results.

Possible values for the State are as follows:
L3_DHCP_STATE_UNDEFINED
L3_DHCP_STATE_INIT
L3_DHCP_STATE_SELECTING
L3_DHCP_STATE_REBOOT
L3_DHCP_STATE_REBOOTING
L3_DHCP_STATE_REQUESTING
L3_DHCP_STATE_RENEW
L3_DHCP_STATE_RENEWING
L3_DHCP_STATE_BOUND
L3_DHCP_STATE_REBINDING
L3_DHCP_STATE_RELEASING

*/

typedef struct tagLayer3DHCPExtendedHostInfo
{
   unsigned long  ulStreamNumber;		/* Stream index number */
   unsigned char  ucHostIP[4];			/* Host IP address */
   unsigned char  ucServerIP[4];		/* Server IP address */
   unsigned char  ucServerMAC[6];		/* Server MAC address */
   unsigned char  ucReserved[2];		/* Reserved, currently unused */
   unsigned char  ucGateway[4];			/* Currently reserved */
   unsigned char  ucSubnet[4];			/* Currently reserved */
   unsigned short uiState;				/* The DHCP State of the stream */
   unsigned char  ucReserved2[2];		/* Reserved, currently unused */
   unsigned long  ulTime;				/* DHCP Time in 1/10 microseconds */
   unsigned char  szServerName[64];		/* Server Name */
   unsigned char  szFileName[128];		/* File Name */
   unsigned char  ucOption[312];		/* DHCP Option */
} Layer3DHCPExtendedHostInfo;

/*
Layer3DHCPConfig

This command sets DHCP configuration parameters on a per-port basis.
ulRate is the rate, in frames per second, at which DHCP DISCOVER/RELEASE message will be 
transmitted if multiple DHCP-capable streams are initiated
*/

typedef struct tagLayer3DHCPConfig
{
   unsigned long ulRate;				/* In frames per second */
   unsigned char ucBroadcastEnable; /* Enable(1) or disable(0) the use of the broadcast flag in 
                                       DHCP discover and request messages. (LAN-3101A/B modules ONLY) */
   unsigned char ucReserved1[3];    /* Reserved */
   unsigned long ulReserved[5];		/* Reserved, currently unused */
} Layer3DHCPConfig; 


/*
Layer3DHCPRenew Description:
The DHCP client(stream) must be in the "Bound" state before a request message will be sent in 
the "Renewing" state.  This capability will be user-controlled.  The module does not support the
timers necessary to dynamically send a request message in the "Renewing" state when the lease 
time expires or is about to expire. Furthermore, once the request message is sent out, the 
module does not handle timeouts. The user will need to re-send the control message to have the 
module re-send the request message.

Once the "Renewing" state is finished, the user needs to poll the module to check if the IP 
address obtained is different from that of the original DHCP exchange.  This IP address can be 
obtained from the L3_DHCP_HOST_INFO or L3_DHCP_EXTENDED_HOST_INFO commands.
*/
typedef struct tagLayer3DHCPRenew
{
   unsigned long ulIndex;           /* The index for the first stream */
   unsigned long ulCount;				/* The number of streams to send a DHCP request message for */
   unsigned char ucReserved[8];		/* Reserved */
} Layer3DHCPRenew; 


/*
Layer3DHCPPortCounterInfo Description:

This command retrieves DHCP summary information for a port
One structure is returned for each stream.

*/
typedef struct tagLayer3DHCPPortCounterInfo
{
	unsigned short uiFailure; 
   unsigned short uiTimeout;   
	unsigned short uiDiscoverSent;    
	unsigned short uiOfferReceived;    
	unsigned short uiRequestSent;   
	unsigned short uiAckReceived;   
	unsigned short uiNakReceived;   
	unsigned short uiReleaseSent;    
	unsigned short uiDeclineSent;   
	unsigned char ucReserved[128];		/* Reserved */
} Layer3DHCPPortCounterInfo; 

/*
Layer3DHCPPortSessionInfo Description:

This command retrieves DHCP port session counters information for a port.

*/
typedef struct tagLayer3DHCPPortSessionInfo
{    
	unsigned long ulStreams;		/* Number of DHCP-enabled streams that are active */  
	unsigned long ulAttempting;   /* Number of DHCP-enabled streams attempting DHCP protocol 
												exchanges (not in DHCP INIT or DHCP UNDEFINED state).*/ 
   unsigned long ulTotalFailure;  /* Number of DHCP NAK received that resulted in returning the state to DHCP 
 												INIT from  another state. It is the total number of failures */   
	unsigned long ulTotalSuccess;   /* Number of DHCP ACK received that resulted in transiting to DHCP BOUND 
 												state.   This includes DHCP renewal. In essence, this is the total number 
 												of successful DHCP exchanges resulting in updating of IP addresses */
	unsigned long ulTotalAttempt;  /* Total number of attempts that does is not from DHCP renew */ 
	
	unsigned long ulTotalRenewAttempt; /* Number of DHCP enabled streams attempting DHCP renew from
														user renew command */
	unsigned long ulTotalRenewFailure; /* Number of DHCP renew failure as a result of receiving DHCP ACK or
													an DHCP OFFER in DHCP RENEWING state */

	unsigned long ulTotalRenewSuccess;    /* Total number of DHCP renew */
	U64 u64MinTime;		/* The minimum amount of time for this port, in 100ns units, between the DHCP Discover 
 								being sent out for that stream, and the DHCP ACK being returned by the server. */
	U64 u64MaxTime;		/* is the maximum amount of time for this port, in 100ns units, between the DHCP Discover
 								being sent out for that stream, and the DHCP ACK being returned by the server. */   
	U64 u64AccTime;	/* The accumulative amount of time that this port, in 100 ns units for all the DHCP 
 							session between the DHCP Discover being sent out for that stream, and the DHCP ACK 
 							being returned by the server */ 

	unsigned long ulBound;			/* Number of DHCP-enabled streams in DHCP BOUND state */     
	unsigned long ulSelecting;    /* Number of DHCP-enabled streams in DHCP SELECTING state */   
	unsigned long ulRequesting;   /* Number of DHCP-enabled streams in DHCP REQUESTING state */     
	unsigned long ulInit;		   /* Number of DHCP-enabled streams in DHCP INIT state */     
	unsigned long ulRenewing;	   /* Number of DHCP-enabled streams in DHCP RENEWING state */ 
	
	unsigned long ulBoundFromRenew;  /* Reserved - Number of DHCP-enabled streams in DHCP BOUND state transited from DHCP
 	                                   RENEWING state. */ 
	unsigned long ulUndefined;	/* Reserved -Number of DHCP-enabled streams in DHCP UNDEFINED state */ 	    
	U64 u64StartTime; /* Reserved - Time that the first DHCP DISCOVER is sent out. */    
	U64 u64LastSuccess;   /* Reserved -Time that the last stream transited to DHCP BOUND state */ 
	U64 u64RetrievalTime;   /* Reserved - Time that this message is read in firmware */    
	unsigned char ucReserved[128]; 
}Layer3DHCPPortSessionInfo; 




/*
Layer3DHCPV2HostInfo Description:

Get DHCP host information from a specified port. Note that "index" is the first stream to get info
for and "count" is the total number of streams to get info for

Possible values for the uiState are as follows:
L3_DHCP_STATE_UNDEFINED
L3_DHCP_STATE_INIT
L3_DHCP_STATE_SELECTING
L3_DHCP_STATE_REBOOT
L3_DHCP_STATE_REBOOTING
L3_DHCP_STATE_REQUESTING
L3_DHCP_STATE_RENEW
L3_DHCP_STATE_RENEWING
L3_DHCP_STATE_BOUND
L3_DHCP_STATE_REBINDING
L3_DHCP_STATE_RELEASING

*/
typedef struct tagLayer3DHCPV2HostInfo
{   
	unsigned long ulStreamNumber;	/* Stream index number */  
	unsigned char ucHostIP[4];		/* Host IP address */  
	unsigned char ucServerIP[4];	/* Server IP address */  
	unsigned char ucServerMAC[6];	/* Server MAC address */  
	unsigned char ucGateway[4];		/* Gateway address */  
	unsigned char ucSubnet[4];		/* Subnet address */  
	unsigned short uiState;			/* The DHCP State of the stream */  
	unsigned long ulTime;			/* DHCP Time in 1/10 microseconds */  
	unsigned long ulLeaseTime;		/* Lease Time in microseconds offered from the DHCP server */  
	unsigned char ucReserved[128];	/* Reserved */
} Layer3DHCPV2HostInfo;


/*
Layer3DHCPV2ExtendedHostInfo Description:

Get extended DHCP host information from a specified card. 
Note that "index" is the first stream toget info for and "count" is the 
total number of streams to get info for.

Possible values for the State are as follows:
L3_DHCP_STATE_UNDEFINED
L3_DHCP_STATE_INIT
L3_DHCP_STATE_SELECTING
L3_DHCP_STATE_REBOOT
L3_DHCP_STATE_REBOOTING
L3_DHCP_STATE_REQUESTING
L3_DHCP_STATE_RENEW
L3_DHCP_STATE_RENEWING
L3_DHCP_STATE_BOUND
L3_DHCP_STATE_REBINDING
L3_DHCP_STATE_RELEASING
*/
typedef struct tagLayer3DHCPV2ExtendedHostInfo
{    
	unsigned long ulStreamNumber;	/* Stream index number */   
	unsigned char ucHostIP[4];		/* Host IP address */   
	unsigned char ucServerIP[4];	/* Server IP address */   
	unsigned char ucServerMAC[6];	/* Server MAC address */   
	unsigned char ucGateway[4];		/* Gateway address */   
	unsigned char ucSubnet[4];		/* Subnet address  */   
	unsigned short uiState;			/* The DHCP State of the stream */   
	unsigned long ulTime;			/* DHCP Time in 1/10 microseconds */   
	unsigned char szServerName[64]; /* Server Name */   
	unsigned char szFileName[128];	/* File Name */   
	unsigned char ucOption[312];	/* DHCP option */
	unsigned long ulLeaseTime;		/* Lease Time in microseconds offered from the DHCP server  */   
	unsigned char ucReserved[128];	/* Reserved */
} Layer3DHCPV2ExtendedHostInfo;

/*
USBInfo Description:

A simple structure which returns the MAC address of the USB.
Future releases will include other pertinent USB information.

*/
typedef struct tagUSBInfo
 {
 unsigned char szUSBMAC[6];    /* MAC Address of  */
 } USBInfo;

/*
USBPower Description
A simple structure which controls the Protocol and Power On/Off at 5710 card
*/
typedef struct tagUSBProtocolPower
{
 unsigned char ucProtocol;     /*1 = Turn on Protocol, 0 = Turn Off Protocl */
 unsigned char ucPower;        /*1 = Turn on Power, 0 = Turn Off Power*/
}USBProtocolPower;

/*
L3GroupInfo

This structure is used to set a Layer 3 group.
*/
/*--------------------L3 Group Commands and Constants--------------------*/
#define L3_GROUP_DELETE_GROUP			NS_GROUP_DELETE_GROUP
#define L3_GROUP_SET_GROUP				NS_GROUP_SET_GROUP
#define L3_MAX_GROUP_SIZE				100	/* maximum number of members per group */

typedef struct tagLayer3GroupInfo
{
	unsigned long  ulReserved;
	unsigned char  ucGroupId;
	unsigned long  ulFrameLength;
	unsigned long  ulFrameGap;
	unsigned short uiNumberOfStreams;
	unsigned short uiNumberOfFrames;
	unsigned short uiMembers[L3_MAX_GROUP_SIZE];
} Layer3GroupInfo; 



#define L3_STREAM_GROUP_DEFINE	NS_STREAM_GROUP_DEFINE	/* Add a stream group.  Use iType2 for group index. */
#define L3_STREAM_GROUP_DELETE	NS_STREAM_GROUP_DELETE	/* Remove a stream group.  Use iType2 for group index. */

/*************************************************************
Layer3StreamGroup Description: 

Used to specify members and attributes of a group of streams.  Refer
to the SmartLib Command Reference manual for specifics.
*************************************************************/
typedef struct tagLayer3StreamGroup
{
	unsigned long  ulFrameLength;		/* frame length for all streams in
										the group */
	unsigned long  ulFrameGap;			/* gap between frames and between
										this group and the next group */
	unsigned short uiNumberOfStreams;	/* number of streams in the group */
	unsigned short uiMembers[L3_MAX_GROUP_SIZE];	/* group members(set to the actual
                                                       stream index) */
} Layer3StreamGroup;
		
#define L3_STREAM_TRANSMIT_MODE			NS_STREAM_TRANSMIT_MODE	/* Get the mode of transmit (Group or not). */
#define L3_STREAM_TRANSMIT_MODE_INFO	NS_STREAM_TRANSMIT_MODE_INFO/* Determine the transmit mode. */

/*************************************************************
Layer3StreamTransmit Description: 

Used to specify the mode in which the streams are transmitted.  
Either Group mode or single (regular) mode.
(Note: Only on the 3101 card as of 11-3-00)
*************************************************************/
typedef struct tagLayer3StreamTransmitMode
{
	unsigned long  ulMode;					/* For the Transmit Mode field use:				 			    */
													/*	L3_STREAM_TRANSMIT_STREAM_MODE to indicate Group mode  */
													/*	L3_STREAM_TRANSMIT_GROUP_MODE  to indicate Stream mode */
	unsigned long  ulReserved[3];			/* Reserved fields */

} Layer3StreamTransmitMode;
		
#define L3_STREAM_TRANSMIT_STREAM_MODE		0
#define L3_STREAM_TRANSMIT_GROUP_MODE		1

/*
Layer3ModifyStreamDelta Description:

  For use with IP and UDP streams only.

This structure is used to INCREMENT one particular field in a block of
Streams already defined on the SmartCard. The first field is used as
base and is not incremented. The following fields are incremented based
on the first field.

* Identify the stream to use as base. (ulIndex). 
* The total number of streams to be modified is calculated by the 
  number incremented values, multiplied by the number of times
  in a row each value is repeated: (ulCount * ulFieldRepeat).
  The base is included in this number as a delta of 0.
* The amount to increment each field is defined by ulDelta. 
* The field to be modified is specified by ulField. The legal
  field values are listed below.


L3MS_FIELD_DMAC				0	Dest MAC address 
L3MS_FIELD_SMAC				1	Source MAC address
L3MS_FIELD_TTL	  			2   Time to Live field
L3MS_FIELD_ISEQNUM			3	Initial Sequence Number field
L3MS_FIELD_DIP				4	Dest IP address
L3MS_FIELD_SIP				5	Source IP address
L3MS_FIELD_NETMASK			6	The Netmask field
L3MS_FIELD_GATEWAY			7	Gateway address in the stream structure
L3MS_FIELD_SPRT				8	Source port number
L3MS_FIELD_DPRT				9	Dest port number
L3MS_FIELD_FRAMELEN			10
L3MS_FIELD_DIPA				11	First octet in dest IP address in the stream structure
L3MS_FIELD_DIPB				12	Second octet in dest IP address in the stream structure
L3MS_FIELD_DIPC				13	Third octet in dest IP address in the stream structure 
L3MS_FIELD_DIPD				14	Fourth octet in dest IP address in the stream structure
L3MS_FIELD_SIPA				15	First octet in source IP address in the stream structure
L3MS_FIELD_SIPB				16	Second octet in source IP address in the stream structure
L3MS_FIELD_SIPC				17	Third octet in source IP address in the stream structure 
L3MS_FIELD_SIPD				18	Fourth octet in source IP address in the stream structure
L3MS_FIELD_GATEWAYA			19	First octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYB			20	Second octet in Gateway address in the stream structure
L3MS_FIELD_GATEWAYC			21  Third octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYD			22  Fourth octet in Gateway address in the stream structure
L4MS_FIELD_VLANID			   23  Vlan ID (2 bytes) in the packet
L3MS_FIELD_VLANTAG 			23  Vlan Tag (2 bytes) in the packet
L4MS_FIELD_TCP_SEQUENCE		24  TCP Sequence in the Stream struc
L4MS_FIELD_TCP_WINDOW		25  TCP Window size in the Stream struc
L4MS_FIELD_TCP_FLAGS		26  TCP Flags in the Stream struc
L4MS_FIELD_TCP_LENGTH		27  TCP Length in the Stream struc
L3MS_FIELD_STREAM_ACTIVE	28  Modify the stream active bit      
L4MS_FIELD_STARTING_OFFSET	29  Starting time in transmit cycle
L3MS_FIELD_RTP_SSRC			30  Modify RTP Synchronization Source ID 
L3MS_FIELD_RTP_PT			31  Modify RTP Payload Type 

	Example 1:

	ulIndex = 2 (base stream )
	ulCount = 3 (total number of incremented values to use)
	ulField = L3MS_FIELD_TTL/TimeToLive (field in structure to increment)
	ulFieldRepeat = 2 (number of times to repeat an incremented value)
	ulDelta = 3 (amount to increment the field)
     
	(Total fields changed ulCount * ulFieldRepeat = 6)
	  
		  Before			         After
	 Index TTL-Value     Index    TTL-Value
		1      1             1       1
		2      1             2       1 (base value)
		3      1             3       1 (repeat base twice)
		4      1             4       4 (increment base by 3)
		5      1             5       4 (repeat)
		6      1             6       7 (increment previous no by 3)
		7      1             7       7 (repeat)
		8      1             8       1
		9      1             9       1
	   10      1            10       1

Example 2:

      ulIndex = 2 (base stream )
	  ulCount = 3 (total number of incremented values to use)
	  ulField = L3MS_FIELD_TTL/TimeToLive (field in structure to increment)
	  ulFieldRepeat = 2 (number of times to repeat an incremented value)
	  ulDelta = 3 (amount to increment the field)
     
	 (Total fields changed ulCount * ulFieldRepeat = 6)
	 (Difference between example 1 and 2 - initial field Values)

  
		  Before			         After
	 Index TTL-Value     Index    TTL-Value
		1      1             1       1
		2      2             2       2 (base value)
		3      2             3       2 (repeat base twice)
		4      2             4       5 (increment base by 3)
		5      10            5       5 (repeat)
		6      10            6       8 (increment previous no by 3)
		7      10            7       8 (repeat)
		8      10            8       10
		9      10            9       10
	   10      10            10      10

 */
typedef struct tagLayer3ModifyStreamDelta
 {
 unsigned long ulIndex; /* The stream to use as a base.          */
                        /* This stream is not incremented.       */  
								/* The next one is incremented, unless    */
                        /* ulFieldRepeat is greater then 1       */

 unsigned long ulCount; /* The number of different increment     */
                        /* values to use.                        */

 unsigned long ulField; /* Field in the stream structure to mod  */
                        /* See L3MS_FIELD_n defines              */
 
 unsigned long ulFieldRepeat;	
                        /* Number of times each value will be    */
                        /* repeated in a row.                    */
                        /* ulFieldRepeat = 1 does the same thing */
                        /* as ulFieldRepeat = 0                  */

 
 unsigned long ulDelta; /* The amount to increment the field     */

 } Layer3ModifyStreamDelta;


/* Layer3ModifyStreamDelta Comment:
This command/iType1 is supported by the ML-7710 SmartCard, firmware 
version 1.06 and later only.

For related commands and instructions about
working with Streams, see Chapter 18
"How to Setup SmartMetrics / TeraMetrics Test" of the 
"SmartLib Overview and Procedures" manual.
*/


/*
Layer3ModifyStreamArray Description:

For use with IP, UDP, and TCP streams, as well as the
L3StreamExtension.

This structure is used to OVERWRITE four bytes of a specified field
in a block of Streams already defined on the SmartCard.

* Identify the first stream to be modified (ulIndex). 
* The total number of streams to be modified is calculated by the 
  number of array elements to use, multiplied by the number of times
  in a row each element will be repeated: (ulCount * ulFieldRepeat).
* The byte patterns are defined in the elements of ulData[] array.
  Each pattern is four bytes long. One full pattern per stream is
  written into the specified field from the least significant bit.
* The field to be modified is specified by ulField. The accepted
  field values are listed below. If the field is smaller than four
  bytes, fewer than four bytes will be overwritten. 

  NOTE:  
  
  For MAC addresses, the least significant four bytes are
  overwritten. Since the count starts with 0, that would mean bytes
  2,3,4, and 5 are overwritten.

  For the L3MS_FIELD_DIPV6, L3MS_FIELD_SIPV6 and L3MS_FIELD_ROUTER_ADDR constants, each
  stream modified will use a total of 8 elements of ulData[].  The first 4 elements will
  be the IPv6 address to replace, and the last 4 elements will be the bit mask value
  indicating which bits of the address to change.

  The ulFieldCount and ulFieldRepeat fields cannot be used with the following:
    LAN-3201A, LAN-3201B, LAN-3300A, LAN-3301A, LAN-3310A, LAN-3311A, 
    LAN-3710AL, LAN-3710AS, LAN-3710AL
    POS-3500A, POS-3500B, POS-3505As, POS-3504As

  Currently these constants are not applicable for the ML-7710 and ML-5710A cards:
    L3MS_FIELD_DIPV6
    L3MS_FIELD_SIPV6
    L3MS_FIELD_ROUTER_ADDR
    L3MS_FIELD_TRAFFIC_CLASS
    L3MS_FIELD_FLOW_LABEL
    L3MS_FIELD_HOP_LIMIT
    L3MS_FIELD_NEXT_HEADER


L3MS_FIELD_DMAC     0    Dest MAC address bytes 2, 3, 4 and 5
L3MS_FIELD_SMAC     1    Source MAC address bytes 2, 3, 4 and 5
L3MS_FIELD_TTL      2    Time to Live field
L3MS_FIELD_ISEQNUM  3    Initial Sequence Number field
L3MS_FIELD_DIP      4    Dest IP address
L3MS_FIELD_SIP      5    Source IP address 
L3MS_FIELD_NETMASK  6    The Netmask field
L3MS_FIELD_GATEWAY  7    Gateway address in the stream structure
L3MS_FIELD_SPRT     8    Source port number
L3MS_FIELD_DPRT     9    Dest port number
L3MS_FIELD_FRAMELEN 10
L3MS_FIELD_DIPA     11   First octet in dest IP address in the stream structure
L3MS_FIELD_DIPB     12    Second octet in dest IP address in the stream structure
L3MS_FIELD_DIPC     13   Third octet in dest IP address in the stream structure 
L3MS_FIELD_DIPD     14   Fourth octet in dest IP address in the stream structure
L3MS_FIELD_SIPA     15   First octet in source IP address in the stream structure
L3MS_FIELD_SIPB     16   Second octet in source IP address in the stream structure
L3MS_FIELD_SIPC     17   Third octet in source IP address in the stream structure 
L3MS_FIELD_SIPD     18   Fourth octet in source IP address in the stream structure
L3MS_FIELD_GATEWAYA 19   First octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYB 20   Second octet in Gateway address in the stream structure
L3MS_FIELD_GATEWAYC 21   Third octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYD 22   Fourth octet in Gateway address in the stream structure
L4MS_FIELD_VLANID			   23  Vlan ID (2 bytes) in the packet
L3MS_FIELD_VLANTAG         23  Vlan Tag (2 bytes) in the packet
L4MS_FIELD_TCP_SEQUENCE    24  TCP Sequence in the Stream struc
L4MS_FIELD_TCP_WINDOW      25  TCP Window size in the Stream struc
L4MS_FIELD_TCP_FLAGS       26  TCP Flags in the Stream struc
L4MS_FIELD_TCP_LENGTH      27  TCP Length in the Stream struc
L3MS_FIELD_STREAM_ACTIVE   28  Modify the stream active bit      
L4MS_FIELD_STARTING_OFFSET 29  Starting time in transmit cycle
L3MS_FIELD_RTP_SSRC        30  Modify RTP Synchronization Source ID 
L3MS_FIELD_RTP_PT          31  Modify RTP Payload Type 
L3MS_FIELD_STREAM_SIGNATURE 32  ucTagField in the stream struct
L3MS_FIELD_STREAM_START     33  start or stop active and configured stream(s)
L3MS_FIELD_IP_MAN_MODE      34  ucIPManipulateMode in L3StreamExtension
L3MS_FIELD_IP_BITS_OFFSET   35  ucIPBitsOffset in L3StreamExtension
L3MS_FIELD_IP_LIMIT_COUNT   36  ucIPLimitCount in L3StreamExtension
L3MS_FIELD_DMAC_BYTE01      37  Dest MAC address bytes 0 and 1
L3MS_FIELD_SMAC_BYTE01      38  Source MAC address bytes 0 and 1
L3MS_FIELD_FRAME_RATE       39  ulFrameRate in WNStreamExtCfg
L3MS_FIELD_DIPV6            40  Destination IPv6 address
L3MS_FIELD_SIPV6            41  Source IPv6 address
L3MS_FIELD_ROUTER_ADDR      42  IPv6 router address
L3MS_FIELD_TRAFFIC_CLASS    43  IPv6 traffic class
L3MS_FIELD_FLOW_LABEL       44  IPv6 flow label
L3MS_FIELD_HOP_LIMIT        45  IPv6 hop limit
L3MS_FIELD_NEXT_HEADER      46  IPv6 next header
L3MS_FIELD_VC_INDEX         47  VC index of ATM (Titan) 
L3MS_FIELD_ATM_FLAGS        48  ATM flag (Titan)
L3MS_FIELD_SIG_SEQ_ID 		           49	Initial Signature sequence number
L3MS_FIELD_STREAM_FRAME_RATE		   50	stream frame rate
L3MS_FIELD_CUSTOM_STREAM_ID     	   51	custom stream id
L3MS_FIELD_BG_INDEX			           52	background index
L3MS_FIELD_IP_CHECKSUM_ERROR_ENABLE	   53	enable IP header checksum error
L3MS_FIELD_DATA_CHECK_ENABLE		   54	enable data integrity
L3MS_FIELD_DATA_INTEGRITY_ERROR_ENABLE 55	enable data integrity error
L3MS_FIELD_CRC_ERROR_ENABLE    	   	   56	enable CRC error
L3MS_FIELD_RANDOM_BG_ENABLE            57	enable random background
L3MS_FIELD_CUSTOM_STREAM_ID_ENABLE	   58	enable custom stream id


	Example 1:

     ulIndex = 2 (start here)
	  ulCount = 3 (total number of patterns to use)
	  ulField = L3MS_FIELD_TTL (Time to Live field)
	  ulFieldCount = 4 (no. of patterns (elements) to use from array)
	  ulFieldRepeat = 2 (number of times to repeat pattern)
	  ulData [5] [7] [99] [100] (pattern definitions)
     
	 (Total fields changed ulCount * ulFieldRepeat = 6)
	  
		  Before			         After
	 Index  TTL-Value     Index  TTL-Value
		1      1             1       1
		2      1             2       5
		3      1             3       5
		4      1             4       7
		5      1             5       7
		6      1             6       99
		7      1             7       99
		8      1             8       1
		9      1             9       1
	   10      1            10       1

Example 2:

     ulIndex = 2 (start here)
	  ulCount = 4 (total number of patterns to use)
	  ulField = L3MS_FIELD_TTL (Time to Live field)
	  ulFieldCount = 2 (no. of patterns (elements) to use from array)
	  ulFieldRepeat = 2 (number of times to repeat pattern)
	  ulData [5] [7] [99] [100] (pattern definitions)

     (Total fields changed ulCount * ulFieldRepeat = 8)
	  
		  Before			         After
	 Index  TTL-Value     Index  TTL-Value
		1      1             1       1
		2      1             2       5
		3      1             3       5
		4      1             4       7
		5      1             5       7
		6      1             6       5
		7      1             7       5
		8      1             8       7
		9      1             9       7
	   10      1            10       1
 */
typedef struct tagLayer3ModifyStreamArray
 {
 unsigned long ulIndex; /* Index of the first stream to modify  */
 unsigned long ulCount; /* The total number of patterns to use  */
                        /* If ulCount is larger than ulFieldCount, */
                        /* patterns will be repeated.           */

 unsigned long ulField; /* Field in the stream structure to mod */
                        /* See L3MS_FIELD_n defines             */
 
 unsigned long ulFieldCount;  
                        /* Number of patterns/elements to use   */
                        /* from ulData[] array                  */

 unsigned long ulFieldRepeat;	
                        /* number of times each pattern will be  */
                        /* repeated in a row.                    */
                        /* ulFieldRepeat = 1 does the same thing */
                        /* as ulFieldRepeat = 0                  */
 
 unsigned long ulData[L3_MODIFY_STREAM_ARRAY_SIZE];
                        /* Array of 1,2, or 4 byte patterns/elements */
                        /* that will be overlaid (right justified)   */
                        /* in the Field   */
 } Layer3ModifyStreamArray;



/* Layer3ModifyStreamArray comment:

For related commands and instructions about
working with Streams, see Chapter 18
"How to Setup SmartMetrics / TeraMetrics Test" of the 
"SmartLib Overview and Procedures" manual.
*/


#define	L3MS_FIELD_DMAC		0	/* Dest MAC address, doesn't work */
#define	L3MS_FIELD_SMAC		1	/* Source MAC address */
#define	L3MS_FIELD_TTL	  	2	/* Time to Live field */
#define	L3MS_FIELD_ISEQNUM	3	/* Initial Sequence Number field */
#define	L3MS_FIELD_DIP		4	/* Dest IP address */
#define	L3MS_FIELD_SIP		5	/* Source IP address */
#define	L3MS_FIELD_NETMASK	6	/* The Netmask field */
#define	L3MS_FIELD_GATEWAY	7	/* Gateway address in the stream structure */
#define	L3MS_FIELD_SPRT		8	/* Source port number */
#define	L3MS_FIELD_DPRT		9	/* Dest port number */
#define	L3MS_FIELD_FRAMELEN	10
#define	L3MS_FIELD_DIPA	    11	/* First octet in dest IP address in the stream structure */
#define	L3MS_FIELD_DIPB	    12	/* Second octet in dest IP address in the stream structure */
#define	L3MS_FIELD_DIPC	    13	/* Third octet in dest IP address in the stream structure */
#define	L3MS_FIELD_DIPD	    14  /* Fourth octet in dest IP address in the stream structure */
#define	L3MS_FIELD_SIPA	    15	/* First octet in source IP address in the stream structure */
#define	L3MS_FIELD_SIPB	    16	/* Second octet in source IP address in the stream structure */
#define	L3MS_FIELD_SIPC	    17	/* Third octet in source IP address in the stream structure */
#define	L3MS_FIELD_SIPD	    18  /* Fourth octet in source IP address in the stream structure */
#define	L3MS_FIELD_GATEWAYA	19	/* First octet in Gateway address in the stream structure */
#define	L3MS_FIELD_GATEWAYB	20	/* Second octet in Gateway address in the stream structure */
#define	L3MS_FIELD_GATEWAYC	21	/* Third octet in Gateway address in the stream structure */
#define	L3MS_FIELD_GATEWAYD	22  /* Fourth octet in Gateway address in the stream structure */
/* The following are used in the TCP Structures
Note that L3MS_FIELD_SPRT and L3MS_FIELD_DPRT can be used in the TCP Streams
as well */
#define  L4MS_FIELD_VLANID          23  /*Vlan ID (2 bytes) in the packet*/
#define  L3MS_FIELD_VLANTAG         23  /*Vlan Tag (2 bytes) in the packet*/
#define  L4MS_FIELD_TCP_SEQUENCE    24  /*TCP Sequence in the Stream struc*/
#define  L4MS_FIELD_TCP_WINDOW      25  /*TCP Window size in the Stream struc*/
#define  L4MS_FIELD_TCP_FLAGS       26  /*TCP Flags in the Stream struc*/
#define  L4MS_FIELD_TCP_LENGTH      27  /*TCP Length in the Stream struc*/
#define  L3MS_FIELD_STREAM_ACTIVE   28  /*Modify the stream active bit      */
#define	L4MS_FIELD_STARTING_OFFSET	29	/*Starting time in transmit cycle*/

#define  L3MS_FIELD_RTP_SSRC        30  /*Modify RTP Synchronization Source ID */
#define  L3MS_FIELD_RTP_PT          31  /*Modify RTP Payload Type */

#define  L3MS_FIELD_STREAM_SIGNATURE 32  /* ucTagField in the stream struct */
#define  L3MS_FIELD_STREAM_START     33  /* start or stop active and configured stream(s) */
#define  L3MS_FIELD_IP_MAN_MODE	  	 34  /* ucIPManipulateMode in L3StreamExtension */
#define  L3MS_FIELD_IP_BITS_OFFSET   35  /* ucIPBitsOffset in L3StreamExtension */
#define  L3MS_FIELD_IP_LIMIT_COUNT	 36  /* ucIPLimitCount in L3StreamExtension */
#define	L3MS_FIELD_DMAC_BYTE01		 37  /* Dest MAC address bytes 0 and 1 */
#define	L3MS_FIELD_SMAC_BYTE01		 38  /* Source MAC address bytes 0 and 1 */
#define	L3MS_FIELD_FRAME_RATE		 39  /* ulFrameRate in WNStreamExtCfg */

/*********** IPv6 **********/
#define L3MS_FIELD_DIPV6			40 /* Dest IPv6 address */
#define L3MS_FIELD_SIPV6			41 /* Source IPv6 address */
#define L3MS_FIELD_ROUTER_ADDR		42 /* IPv6 router address */
#define L3MS_FIELD_TRAFFIC_CLASS	43 /* IPv6 traffic class */
#define L3MS_FIELD_FLOW_LABEL		44 /* IPv6 flow label */
#define L3MS_FIELD_HOP_LIMIT		45 /* IPv6 hop limit */
#define L3MS_FIELD_NEXT_HEADER		46 /* IPv6 next header */
#define L3MS_FIELD_VC_INDEX		47 /* VC index of ATM (Titan) */
#define L3MS_FIELD_ATM_FLAGS		48 /* ATM flag (Titan) */

/* Stream extension related constants */
#define L3MS_FIELD_SIG_SEQ_ID 		               49  /* Initial Signature sequence number */
#define L3MS_FIELD_STREAM_FRAME_RATE			      50  /* stream frame rate */
#define L3MS_FIELD_CUSTOM_STREAM_ID     			   51  /* custom stream id */
#define L3MS_FIELD_BG_INDEX			               52  /* background index */
#define L3MS_FIELD_IP_CHECKSUM_ERROR_ENABLE		   53  /* enable IP header checksum error */
#define L3MS_FIELD_DATA_CHECK_ENABLE		         54  /* enable data integrity */
#define L3MS_FIELD_DATA_INTEGRITY_ERROR_ENABLE     55  /* enable data integrity error */
#define L3MS_FIELD_CRC_ERROR_ENABLE    	   	   56  /* enable CRC error */
#define L3MS_FIELD_RANDOM_BG_ENABLE                57  /* enable random background */
#define L3MS_FIELD_CUSTOM_STREAM_ID_ENABLE		   58  /* enable custom stream id */

/* Fibre Channel related constants */
#define L3MS_FIELD_FC_COS	      59 /* Class of service of a Fibre Channel stream (defined using
                                       FC_DEFINE_STREAM or FC_DEFINE_STREAM_128) */
#define L3MS_FIELD_FC_SRC_WWN    60 /* Source WWN of a Fibre Channel stream (defined using
                                       FC_DEFINE_STREAM or FC_DEFINE_STREAM_128) */
#define L3MS_FIELD_FC_DEST_WWN   61 /* Destination WWN of a Fibre Channel stream (defined using
                                       FC_DEFINE_STREAM or FC_DEFINE_STREAM_128) */

#define L3MS_FIELD_FC_OXID			62 /* Modifies the Originator Exchange ID parameter, within 
                                    the FC2 header  */
#define L3MS_FIELD_FC_SOF			69 /* Modifies FC2 Header Start Of Frame parameter */
#define L3MS_FIELD_FC_EOF			70 /* Modifies FC2 Header End  Of Frame parameter */

/* VFD 1 and 2 related constants */
#define L3MS_FIELD_VFD1_CYCLE_COUNT	63 /* VFD1 Cycle parameter modifier */
#define L3MS_FIELD_VFD1_MODE		   64 /* VFD1 mode modifier. Use data values L3_VFD_OFF, 
                                       L3_VFD_INCR, L3_VFD_STATIC, L3_VFD_DECR and L3_VFD_RANDOM */
#define L3MS_FIELD_VFD1_PATTERN		65 /* VFD1 2 WORD pattern modifier. Pattern[0,1,2,3] reference 
                                       WORD1, Pattern[4,5] reference WORD2 */	
#define L3MS_FIELD_VFD2_CYCLE_COUNT	66 /* VFD2 Cycle parameter modifier */
#define L3MS_FIELD_VFD2_MODE		   67	/* VFD2 mode modifier. Use data values L3_VFD_OFF, 
                                       L3_VFD_INCR, L3_VFD_STATIC, L3_VFD_DECR and L3_VFD_RANDOM */
#define L3MS_FIELD_VFD2_PATTERN		68 /* VFD2 2 WORD pattern modifier. Pattern[0,1,2,3] reference 
                                       WORD1, Pattern[4,5] reference WORD2 */
#define L3MS_FIELD_VFD_CHAIN		   71 /* Modifies the VFD1 & VFD2 Carry chaining flags.*/

#define	L3MS_FIELD_DMAC_WITH_SKIP          72 /* Dest MAC address bytes 2, 3, 4,and 5. A value of 0
                                                 in the data indicates that the destination MAC
                                                 for the stream will not be modified. So that using
                                                 this constant can modify the MAC address of some
                                                 streams while leave MAC address of other streams
                                                 untouched */
#define	L3MS_FIELD_DMAC_BYTE01_WITH_SKIP   73 /* Dest MAC address bytes 0 and 1. A value of 0
                                                 in the data indicates that the destination MAC
                                                 for the stream will not be modified. So that using
                                                 this constant can modify the MAC address of some
                                                 streams while leave MAC address of other streams
                                                 untouched */
/*
Layer3Address Description:

This structure is used to set/get the device addresses of the
SmartCard as if it were a separate Layer 3 device.

Control of ARP replies with iControl field:
 1. If stream is configured and destination IP address of ARP request matches
    with the source IP address of the configured stream. No matter what is set
	for iControl, ARP is replying with matched stream's MAC address 
 2. If stream is not configured or not matched, and "L3_CTRL_ARP_RESPONSES" is
    set for iControl, ARP is replying with the port MAC address - the replied MAC
    address will always be the same for any ARP requests.
 3. If stream is not configured or not matched, and "L3_CTRL_ARP_RESPONSES_WITH_UNIQUE_MAC"
    is set for iControl, ARP is replying with unique MAC address - in which the
    first two bytes consists of the first two bytes of the port MAC address, and
    the last 4 bytes consists of the destination IP address of ARP request. e.g. if
    port MAC address:
             b1.b2.b3.b4.b5.b6
    ARP is received with destination IP address 
             a.b.c.b
    then the port will reply to ARP with this new MAC address
             b1.b2.a.b.c.d
*/

typedef struct tagLayer3Address
 {
 unsigned char szMACAddress[6];/* sets MAC addr of this SmartCard */
 unsigned char IP[4];          /* sets IP addr of this SmartCard  */
 unsigned char Netmask[4];     /* sets Netmask for this SmartCard */
 unsigned char Gateway[4];     /* sets Gateway addr for this Card */
 unsigned char PingTargetAddress[4];
										 /* the address where PINGs are sent*/

 int iControl;                 /* use L3_CTRL_ defines below     */
                               /* L3_CTRL_ARP_RESPONSES */
                               /* L3_CTRL_PING_RESPONSES */
                               /* L3_CTRL_SNMP_OR_RIP_RESPONSES */
                               /* L3_CTRL_ARP_RESPONSES_WITH_UNIQUE_MAC */
                               /* enables PING, ARP, SNMP or RIP */


 int iPingTime;                /* in seconds - 0 disables */
 int iSNMPTime;                /* in seconds - 0 disables */
 int iRIPTime;                 /* in seconds - 0 disables */

 int iGeneralIPResponse;       /* obsolete */

 } Layer3Address;

/* defines for the iControl variable */
#define L3_CTRL_ARP_RESPONSES			0x01
#define L3_CTRL_PING_RESPONSES			0x02
#define L3_CTRL_SNMP_OR_RIP_RESPONSES	0x04
#define L3_CTRL_ARP_RESPONSES_WITH_UNIQUE_MAC	0x08

/*
Structure:   Layer3IPv6Address
iType1:      L3_TX_IPV6_ADDRESS and L3_TX_IPV6_ADDRESS_INFO
Function:    HTSetStructure and HTGetStructure

Layer3IPv6Address Description:

This structure is used to set/get the IPv6 related addresses of the
SmartCard as if it were a separate Layer 3 device.

Control of Neighbor Discovery respond with iControl field:
 1. If stream is configured and destination IP address of Neighbor Discovery request 
    matches with the source IP address of the configured stream. No matter what is set
	for iControl, Neighbor Discovery is replying with matched stream's MAC address 
 2. If stream is not configured or not matched, and "L3_CTRL_IPV6_ND_RESPONSES" is
    set for iControl, Neighbor Discovery is replying with the port MAC address - the replied MAC
    address will always be the same for any Neighbor Discovery requests.
 3. If stream is not configured or not matched, and "L3_CTRL_IPV6_ND_RESPONSES_WITH_UNIQUE_MAC"
    is set for iControl, Neighbor Discovery is replying with unique MAC address - in which the
    first two bytes are the first two bytes of the port MAC address, and
    the last 4 bytes are the last 4 bytes of destination IP address of Neighbor Discovery request.
	e.g. if
    port MAC address:
             b1.b2.b3.b4.b5.b6
    Neighbor Discovery is received with destination IP address 
             FF02:0000:0000:0000:0000:0000:0a0b:0c0d
    then the port will reply to Neighbor Discovery with this new MAC address
             b1.b2.a.b.c.d
*/
typedef struct tagLayer3IPv6Address
{
	unsigned char ucMACAddress[6];	/* MAC address */
	unsigned char ucPrefixLength;	/* Prefix length in bits */
	unsigned char IP[16];			/* IP address */
	unsigned char Gateway[16];		/* Gateway address */
	unsigned long ulControl;   /* use L3_CTRL_IPV6 defines below           */
                               /* L3_CTRL_IPV6_ND_RESPONSES                 */ 
                               /* L3_CTRL_IPV6_ND_RESPONSES_WITH_UNIQUE_MAC */
                               /* enables Neighbor Discovery respond */
	unsigned char ucReserved[25];	/* Reserved */
} Layer3IPv6Address;

/* defines for the ulControl variable */
#define L3_CTRL_IPV6_ND_RESPONSES                     0x00000001   
#define L3_CTRL_IPV6_ND_RESPONSES_WITH_UNIQUE_MAC     0x00000002   


/*
Structure:   Layer3IPv6Protocol
iType1:      L3_TX_IPV6_PROTOCOL
Function:    HTSetStructure

Layer3IPv6Protocol Description:

This structure is used to set the Ping target address and Ping time.

*/
typedef struct tagLayer3IPv6Protocol
{
	unsigned char  ucPingTargetAddress[16];	/* Ping target address */
	unsigned short uiPingTime;			         /* Ping time: For TeraMetrics modules, this
                                             is in units of 1s; for the LAN-3101A, it is 
                                             in units of 100ms. A value of 0 disables 
                                             ping  */
	unsigned char  ucReserved[10];			/* Reserved */
} Layer3IPv6Protocol;

/*
Layer3CaptureCountInfo Description:

A simple structure which returns the number of
frames which are in
 the capture buffer.

*/
typedef struct tagLayer3CaptureCountInfo
 {
 unsigned long ulCount;    /* count of frames in Capture buffer */
 } Layer3CaptureCountInfo;

/*
Layer3CaptureData Description:

Layer3CaptureData is used to retrieve a captured frame from the
capture buffer. The length of the frame is given in uiLength, and the
captured frame data is put in cData.  Always use L3_CAPTURE_COUNT_INFO
to check the number of captured packets before using this command to
retrieve capture data.

*/
typedef struct tagLayer3CaptureData
	{
	unsigned short uiLength;	/* the number of bytes in cData which represent the captured frame */
	char cData[2048];				/* the captured frame data */
	} Layer3CaptureData;


/*
Layer3CaptureDetailInfo Description:

A structure which returns the details of any given
capture frame.
Note that to make the counters work properly you
must transmit a tagged stream, and you must clear
the histogram counters by first doing a group stop.
This is implmented in ML-7710 cards version 1.07 and
greater as well as ML-5710A cards.

*/
typedef struct tagLayer3CaptureDetailInfo
   {
   unsigned long   ulStatus;				 /* Status bits of the packet, use 
														 L3_CAPTURE_STATUS_XXX definitions */
   unsigned long   ulPacketLength;      /* Length of the packet received in bytes */
   unsigned long   ulRxTimestamp;       /* RxTimeStamp of Packet */
   unsigned long   ulTxTimestamp;       /* TxTimeStamp of Packet */
   unsigned long   ulSequenceNumber;    /* Stream transmitted sequence number */
   unsigned long   ulStreamNumber;      /* Stream number */
   unsigned char   reserved[96];
 } Layer3CaptureDetailInfo;

#define L3_CAPTURE_STATUS_CRC				0x01	/* CRC error */
#define L3_CAPTURE_STATUS_VLAN				0x02	/* VLAN frame */
#define L3_CAPTURE_STATUS_TRIGGER			0x04	/* trigger frame */
#define L3_CAPTURE_STATUS_SIGNATURE_TAG		0x08	/* signature frame */
#define L3_CAPTURE_STATUS_ALIGNMENT			0x80	/* alignment error */


/*
Structure:   Layer3CaptureSetup
iType1:      L3_CAPTURE_SETUP
Function:    HTSetStructure

Layer3CaptureSetup Description:

Configure the Capture engine to capture the correct frames.  

NOTES:
  
Some of the capture events only apply to certain cards:

CAPTURE_EVENTS_OUT_OF_SEQUENCE, CAPTURE_EVENTS_SIGNATURE, and
CAPTURE_EVENTS_NO_SIGNATURE only apply to the POS-3504A, POS-3505A,
LAN-3300A, LAN-3301A, LAN-3310A, LAN-3311A.

The AT-345x modules supports ONLY the following capture events:
   CAPTURE_EVENTS_RX_TRIGGER (triggers must be set up within the first cell of the frame)
   CAPTURE_EVENTS_ALL_FRAMES
*/
typedef struct tagLayer3CaptureSetup
{
   unsigned long  ulCaptureMode;				/* start, stop, or filter on events             
													CAPTURE_MODE_FILTER_ON_EVENTS
													CAPTURE_MODE_START_ON_EVENTS
													CAPTURE_MODE_STOP_ON_EVENTS
												*/
   unsigned long  ulCaptureLength;				/* use one of defined below
													CAPTURE_LENGTH_ENTIRE_FRAME	
													CAPTURE_LENGTH_1ST_64_BYTES	
													CAPTURE_LENGTH_LAST_64_BYTES
													CAPTURE_LENGTH_1ST_128_BYTES
													CAPTURE_LENGTH_LAST_128_BYTES
												*/

   unsigned long  ulCaptureEvents;				/* capture events                               
													CAPTURE_EVENTS_CRC_ERRORS
													CAPTURE_EVENTS_UNDERSIZE
													CAPTURE_EVENTS_OVERSIZE
													CAPTURE_EVENTS_VLAN_TAG
													CAPTURE_EVENTS_IP_CHECKSUM_ERROR
													CAPTURE_EVENTS_DATA_INTEGRITY_ERROR
													CAPTURE_EVENTS_RX_TRIGGER
													CAPTURE_EVENTS_RUNNING_DISPARITY_ERRORS
													CAPTURE_EVENTS_ABORT
													CAPTURE_EVENTS_COLLISIONS
													CAPTURE_EVENTS_ALIGNMENT_ERRORS
													CAPTURE_EVENTS_OUT_OF_SEQUENCE
													CAPTURE_EVENTS_SIGNATURE
													CAPTURE_EVENTS_NO_SIGNATURE
													CAPTURE_EVENTS_FILTER_FRAME_LENGTH
													CAPTURE_EVENTS_ALL_FRAMES
												*/
   unsigned short uiFilterFrameLength;		/* capture length filter frame; please include the
														CRC length(2 or 4 bytes)                  */
   unsigned char  ucReserved[10];				/* not used                                     */

} Layer3CaptureSetup;

#define CAPTURE_MODE_FILTER_ON_EVENTS				0
#define CAPTURE_MODE_START_ON_EVENTS				1
#define CAPTURE_MODE_STOP_ON_EVENTS					2

#define CAPTURE_LENGTH_ENTIRE_FRAME					0
#define CAPTURE_LENGTH_1ST_64_BYTES					1
#define CAPTURE_LENGTH_LAST_64_BYTES				2
#define CAPTURE_LENGTH_1ST_128_BYTES				3
#define CAPTURE_LENGTH_LAST_128_BYTES				4
#define CAPTURE_LENGTH_CUSTOM 						5

#define CAPTURE_EVENTS_CRC_ERRORS					0x00000001
#define CAPTURE_EVENTS_UNDERSIZE					0x00000002
#define CAPTURE_EVENTS_OVERSIZE						0x00000004
#define CAPTURE_EVENTS_VLAN_TAG						0x00000008
#define CAPTURE_EVENTS_IP_CHECKSUM_ERROR			0x00000010
#define CAPTURE_EVENTS_DATA_INTEGRITY_ERROR			0x00000020
#define CAPTURE_EVENTS_RX_TRIGGER					0x00000040
#define CAPTURE_EVENTS_RUNNING_DISPARITY_ERRORS		0x00000080
#define CAPTURE_EVENTS_ABORT						0x00000090
#define CAPTURE_EVENTS_COLLISIONS					0x00000100
#define CAPTURE_EVENTS_ALIGNMENT_ERRORS				0x00000200
#define CAPTURE_EVENTS_OUT_OF_SEQUENCE				0x00000400
#define CAPTURE_EVENTS_SIGNATURE					0x00000800
#define CAPTURE_EVENTS_NO_SIGNATURE					0x00001000
#define CAPTURE_EVENTS_FILTER_FRAME_LENGTH			0x00002000
#define CAPTURE_EVENTS_OAM_FRAME_ONLY			    0x00004000
#define CAPTURE_EVENTS_IP_OPTION		   			0x00008000
#define CAPTURE_EVENTS_ALL_FRAMES					0xFFFFFFFF


/*--------------------------------------------------*/
/*  Layer 3 Tests (Histogram results) Description:

The Layer 3 Test Functions are:

    Latency Distribution
	 Raw Tags (Signature information)
	 Sequence Tracking
	 Latency Over Time
	 V2 Latency Per Stream (combination histogram) Lat. Dist, Lat. Per Strm., Sequence.


Layer 3 SmartCards can transmit multiple Streams of data.
If a histogram is enabled on the Receiving card, and
if signature fields are enabled in the streams on the Transmit card,
the specified histogram collects data from the signature field embedded
in each test frame. Histogram result records are created, and can then
be retrieved.
Retrieval of the records causes collection of further data to cease. */

/*---------------------------------------------------------*/


/*
Layer3SequenceInfo Description:

Contains Sequence Tracking histogram results.

Sequence Tracking counts the number of frames per stream that are:
*  In sequence
*  Duplicate
*  Lost

A separate record is generated for each test stream received
by the specified port.

Sequence is tracked using the signature field embedded in each
test frame.

The Sequence Tracking algorithm is as follows:
-----------------------------------------------
*  As long as frames are received in sequence, the ulSequenced
   value is incremented.
*  If a frame is received that is greater than the one expected,
   the number of missing frames (hole size) is noted, and a variable
	for the	first of the missing frames is set.
*  Subsequent in-order frames falling after the sequence hole 
   increment the ulSequence counter.
*  If the frame from the start of the hole is received, the hole-size
   variable is decremented.
*  If a frame from the middle of the hole is received, the earlier 
   frames still not received from the sequence hole are counted as 
	lost (ulLost).	The hole-size variable is decremented, and the 	
	start of the hole begins after the received frame. The expected
	frame continues to be one more than the last frame received in
	sequence.


*  If another out-of-sequence frame is received before the previous
   sequence hole is filled, ulLost is incremented by the size of
	the previous sequence hole. The new hole is then tracked.
*  If while the new sequence hole is being tracked, a previous 
   out-of-sequence frame arrives, ulDuplicate is incremented.

*  The ulSequenced value continues to increment for every frame
   received in sequence after the current sequence hole.
	
	
 For Example:

1,2,3                - Three frames in sequence.
1,2,3,9,10,11,       - Sequence hole five frames. 10,11, in sequence.
1,2,3,9,10,11,4      - Sequence hole is now four frames.
1,2,3,9,10,11,4,15,  - First hole closed, ulLost incremented by four.
                       New hole three frames long.
1,2,3,9,10,11,4,15,5 - ulDuplicate incremented by one. (5 is counted
                       as a duplicate since the previous hole is 
							  no longer tracked).


*/
typedef struct tagLayer3SequenceInfo
 {
 unsigned long ulStream;   /* Stream identifier for this record   */
 unsigned long ulFrames;   /* no. of frames rcvd for this Stream  */
 unsigned long ulSequenced;/* no. of frames rcvd in sequence      */
 unsigned long ulDuplicate;/* no. of frames duplicated            */
 unsigned long ulLost;     /* no. of frames that broke the        */
                           /* sequence and were either never rcvd,*/
                           /* or not received before another out- */
                           /* of-sequence frame was noted.        */
 } Layer3SequenceInfo;

/* Layer3SequenceInfo Comment:

For related commands and detailed instructions for 
Histogram results, see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.
*/

/*
Layer3LatencyInfo Description:

16-bit Latency Over Time.

This tracks the Latency of frame traffic over time intervals.

The Layer3HistLatency structure must be used to setup the time
interval for each statistics gathering period. The user specifies
a time period  (in 100s of nanoseconds) and the test stores
results in up to 8,000 data collectors.

All incoming Stream frames have imbedded timestamps of when the
frame left the Layer 3 SmartCard. This timestamp is used to
calculate and track the minimum, maximum and total latency for all
frames received in each time interval. The average latency for
each time interval can be calculated by dividing the total latency
by the number of frames.

*/
typedef struct tagLayer3LatencyInfo
 {
 unsigned short uiMinimum; /* min frame latency in this interval */
 unsigned short uiMaximum; /* max frame latency in this interval */
 unsigned long  ulTotal;	/* sum of all latencies in this interval */
 unsigned long  ulFrames;	/* tagged frames received this interval */
 } Layer3LatencyInfo;

 
/*
Layer3LongLatencyInfo Description:

Contains Latency Over Time histogram results.

Provides the Minimum, Maximum, and Sum of Latency values for frames
received during specified intervals. The values are the composite
results of all streams averaged together. 

Setting the interval
--------------------
On the Rx port, use the Layer3HistLatency structure and
specify the ulInterval. This value determines how often latency
values are compared.

One Interval unit is 1 millisecond. 

The Latency measurements of, Minimum, Maximum, and Average Latency are 
calculated to the nearest .1 microsecond.

Each record (Min, Max, and Sum latency values) represents the
latencies of the frames arriving in each interval.  Use iType2 to
specify the index of the first record (interval) to retrieve.

Example
---------------
If ulInterval is set to 10:
The first Min, Max, and Sum latency value is for the first ten 
microseconds. The second Min, Max, and Sum latency value is for the 
second ten microseconds, and so on.

Latency values are calculated from the timestamp in the signature
field embedded within each test frame.

The average latency for each time interval can be calculated by
dividing the total latency by the number of frames.

Note that the following cards do not support the Sum latency
(u64Total): LAN-3300A, LAN-3301A, LAN-3310A, LAN-3311A, POS-3504A, and
POS-3505A.

*/
typedef struct tagLayer3LongLatencyInfo
 {
 unsigned long ulMinimum;   /* min frame latency in .1 microseconds */
 unsigned long ulMaximum;   /* max frame latency in .1 microseconds */
 U64           u64Total;    /* sum of all latencies .1 microseconds */
 unsigned long ulFrames;    /* frames with signature fields (tags), */
                            /* received in this interval.           */
 } Layer3LongLatencyInfo;

/* Layer3LongLatencyInfo Comment:

For related commands and detailed instructions for 
Histogram results,  see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.

This structure contains an embedded structure.
*/

/*
Layer3StreamLatencyInfo Description:

For 16-bit Latency Per Stream histogram.

This tracks the Latency characteristics of frame traffic on
a per Stream basis.

Each Layer 3 Stream frame received is tracked separately.
Data is kept on each Stream as to the number of frames received,
along with the min, max, and average Latency for that Stream.

There will be one record for each Stream received by the Layer 3
SmartCard.

*/
typedef struct tagLayer3StreamLatencyInfo
 {
 unsigned long  ulStream;  /* a unique Stream identifier          */
 unsigned short uiAverage; /* avg latency of this Stream's frames */
 unsigned short uiMinimum; /* min latency seen on this Stream     */
 unsigned short uiMaximum; /* max latency seen on this Stream     */
 unsigned long  ulFrames;/* total frames received for this Stream */
 } Layer3StreamLatencyInfo;


/*
Layer3StreamLatencyInfo32 Description:

For 32-bit Latency Per Stream histogram.

This tracks the Latency characteristics of frame traffic on
a per Stream basis.

Each Layer 3 Stream frame received is tracked separately.
Data is kept on each Stream as to the number of frames received,
along with the min, max, and average Latency for that Stream.

There will be one record for each Stream received by the Layer 3
SmartCard.

*/
typedef struct tagLayer3StreamLatencyInfo32
 {
 unsigned long  ulStream;  /* a unique Stream identifier          */
 unsigned long  ulFrames;/* total frames received for this Stream */
 U64            u64Total; /*Total Latency*/
 unsigned long ulMinimum; /* min latency seen on this Stream     */
 unsigned long ulMaximum; /* max latency seen on this Stream     */

 } Layer3StreamLatencyInfo32;

typedef Layer3StreamLatencyInfo32 Layer3V1StreamLatencyInfo;



/*
Layer3StreamLongLatencyInfo Description:

Contains results from a combination histogram, V2 Latency Per Stream. 

This histogram tracks: 
1.) Latency Per Stream (Min, Max, Average)
2.) Sequenc Tracking
3.) Latency Distribution.

One record is generated for each stream received. Statisics 
are tracked using the signature field embedded within each test 
frame.

To specify this histogram, use  L3_HIST_V2_LATENCY_PER_STREAM.

Latency Resolution and accuracy
-------------------------------
One unit is .1 microsecond / 100ns (one clock tick).

* For a pair of 10Mbit ports, accuracy is plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is 
  plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is 
  plus or minus .4 us.
* For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is 
  plus or minus .3 us.


Latency Per Stream Info.
********************************
Latency Per Stream finds the Sum, Min, and Max latency value for each
stream over the duration of the test.


Sequence Tracking Info.
********************************
Sequence Tracking counts the number of frames per stream that are:
*  Out of sequence
*  Duplicate
*  Lost

A separate record is generated for each test stream received
by the specified port.

The Sequence Tracking algorithm is as follows:
-----------------------------------------------
*  As long as frames are received in sequence, the ulSequenced
   value is incremented.
*  If a frame is received that is greater than the one expected,
   the number of missing frames (hole size) is noted, and a variable
	for the	first of the missing frames is set.
*  Subsequent in-order frames falling after the sequence hole 
   increment the ulSequence counter.
*  If the frame from the start of the hole is received, the hole-size
   variable is decremented. 
*  If a frame from the middle of the hole is received, the earlier 
   frames still not received from the sequence hole are counted as 
	lost (ulLost).	The hole-size variable is decremented, and the 	
	start of the hole begins after the received frame. The expected
	frame continues to be one more than the last frame received in
	sequence.


*  If another out-of-sequence frame is received before the previous
   sequence hole is filled, ulLost is incremented by the size of
	the previous sequence hole. The new hole is then tracked.
*  If while the new sequence hole is being tracked, a previous 
   out-of-sequence frame arrives, ulDuplicate is incremented.

*  The ulSequenced value continues to increment for every frame
   received in sequence after the current sequence hole.
	
	
 For Example:

1,2,3                - Three frames in sequence.
1,2,3,9,10,11,       - Sequence hole five frames. 10,11, in sequence
1,2,3,9,10,11,4      - Sequence hole is now four frames.
1,2,3,9,10,11,4,15,  - First hole closed, ulLost incremented by four.
                       New hole three frames long.
1,2,3,9,10,11,4,15,5 - ulDuplicate incremented by one. (5 is counted
                       as a duplicate since the previous hole is
							  no longer tracked). 




Latency Distribution Info.
********************************
Latency Distribution tracks the number of frames with a latency that
falls within a given range. (There are 16 configurable ranges).

Example Values
-------------- 
If ulInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2us to 1us.

Mechanics
---------
When a frame is received, correct ulFrame[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.

*/
typedef struct tagLayer3StreamLongLatencyInfo
 {
 unsigned long ulStream;     /* a unique Stream Identifier        */

                             /* Latency Per Stream info.          */
 U64           u64Total;     /* sum of latencies for this Stream  */
 unsigned long ulMinimum;    /* min frame latency for this Stream */
 unsigned long ulMaximum;    /* max frame latency for this Stream */
 
                             /* Sequenc Tracking info.              */   
 unsigned long ulTotalFrames;/* total frames rcvd for this Stream   */
 unsigned long ulSequenced;  /* no. frames rcvd in sequence         */  
                             /* MC only >> 1st timestamp rcvd for group stream */
 unsigned long ulDuplicate;  /* no. of frames duplicated            */
                             /* MC only >> last timestamp rcvd for group stream */
 unsigned long ulLost;       /* no. frames that broke the           */
                             /* sequence and were either never rcvd,*/
                             /* or not received before another out- */
                             /* of-sequence frame was noted.        */
                             /* currently unused for MC             */  
                             
                             /* Latency Distribution info.        */                                
 unsigned long ulFrames[16]; /* Contains the number of frames     */
                             /* with the specified latency range, */
                             /* for 16 different ranges .         */
                             
 } Layer3StreamLongLatencyInfo;

/*
Layer3StreamJitterComboInfo Description:

Contains results from a combination histogram, V2 Latency Per Stream. 

This histogram tracks: 
1.) Latency Per Stream (Min, Max, Total)
2.) Absolute value of Jitter (Total)
3.) Latency Distribution.

One record is generated for each stream received. Statisics 
are tracked using the signature field embedded within each test 
frame.

To specify this histogram, use  L3_HIST_JITTER_COMBO

Latency Resolution and accuracy
-------------------------------
One unit is .1 microsecond / 100ns (one clock tick).

* For a pair of 10Mbit ports, accuracy is plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is 
  plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is 
  plus or minus .4 us.
* For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is 
  plus or minus .3 us.


Latency Per Stream Info.
********************************
Latency Per Stream finds the Sum, Min, and Max latency value for each
stream over the duration of the test.


Total Jitter Info.
********************************
Total jitter, represented by the parameter u64TotalJitter, is the sum 
f the absolute value of the difference in latencies between frame N and
frame N-1.  The u64TotalJitter will not be available if two frames have
not been received in this stream, as recorded in the ulTotalFrames parameter.
If ulTotalFrames is greater than 1, then the average jitter can then be
computed by using the relationship:
   u64AverageJitter = u64TotalJitter / (ulTotalFrames - 1)


Latency Distribution Info.
********************************
Latency Distribution tracks the number of frames with a latency that
falls within a given range. (There are 16 configurable ranges).

Example Values
-------------- 
If ulInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2us to 1us.

Mechanics
---------
When a frame is received, correct ulFrame[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.

*/
typedef struct tagLayer3StreamJitterComboInfo
 {
 unsigned long ulStream;     /* a unique Stream Identifier        */

                             /* Latency Per Stream info.          */
 U64           u64Total;     /* sum of latencies for this Stream  */
 unsigned long ulMinimum;    /* min frame latency for this Stream */
 unsigned long ulMaximum;    /* max frame latency for this Stream */
 
                             /* Jitter Tracking info.             */   
 unsigned long ulTotalFrames;/* total frames rcvd for this Stream */
 U64           u64TotalJitter; /* sum of absolute jitter for this stream */
 unsigned long ulReserved;    /* reserved. set to zero            */
 
                             /* Latency Distribution info.        */                                
 unsigned long ulFrames[16]; /* Contains the number of frames     */
                             /* with the specified latency range, */
                             /* for 16 different ranges .         */
                             
 } Layer3StreamJitterComboInfo;

/* Layer3StreamLongLatencyInfo Comment:

For related commands and detailed instructions for 
Histogram results, see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.

This structure contains an embedded structure.
*/


/*
Layer3StreamMulticastInfo Description:

This test tracks Multicast Latency information on a per Stream
basis.

The actual latency information tracked is kept in the following items:

   ulFirstRxTime
   ulLastRxTime

The first frame received for each stream is kept in the  ulFirstRxTime.
The last frame received for each stream is kept in the ulLastRxTime

The Latency information is also tracked  in order to
keep the min, max, and average of all latencies for this
Stream. The second is to keep a distribution of frames received
over 16 different user-specified time ranges.

The Layer3V2HistDistribution structure must be used to setup the
time ranges which will comprise the gathering of the histogram
distribution. There are 16 such ranges defined. Each range will
accumulate one count for each frame whose latency measurement
falls within its range.

There will be one record for each Stream received at a SmartCard port.

*/
typedef struct tagLayer3StreamMulticastInfo
 {
 unsigned long	ulStream;      /* a unique Stream identifier        */
 U64           u64Total;      /* sum of latencies for this Stream  */
 unsigned long ulMinimum;     /* min frame latency for this Stream */
 unsigned long ulMaximum;     /* max frame latency for this Stream */
 unsigned long ulRxFrames;    /* total frames rcvd for this Stream */
 unsigned long ulFirstRxTime; /* first timestamp received for the group stream */
 unsigned long ulLastRxTime;  /* last timestamp received for the group stream */
 unsigned long ulReserved;    /* currently unused */
 unsigned long ulFrames[16];  /* distribution histogram count of   */
                  /* frames which have latency measurements which */
                  /* fall into the user-specified time ranges     */
 } Layer3StreamMulticastInfo;



/*
Layer3StreamDistributionInfo Description:

Contains Latency Distribution histogram results.

Latency Distribution tracks how many frames fall within a given
latency range. There are 16 configurable ranges in units of 
.1 microseconds.

Example Values
-------------- 
If uiInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2 us to 1 us.

Mechanics
---------
When a frame is received, the latency is calculated from the timestamp
in the signature field. The correct ulFrame[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.

Resolution and accuracy
-----------------------
One unit is .1 microsecond - 100ns (one clock tick).

For a pair of 10Mbit ports accuracy is plus or minus .2 microseconds (.2 us).
For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is plus or minus .4 us.
For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is plus or minus .3 us.

Setting Resolution (different structure) 
----------------------------------------
To set the distribution intervals, use L3_HIST_LATENCY_DISTRIBUTION.
This iType1 uses the Layer3HistDistribution structure, where
uiInterval[16] contains the different latency ranges.

*/
typedef struct tagLayer3StreamDistributionInfo
 {
 unsigned long ulStream;     /* a unique Stream identifier        */
 unsigned long ulFrames[16]; /* Contains the number of frames     */
                             /* with the specified latency range, */
                             /* for 16 different ranges.          */
 } Layer3StreamDistributionInfo;

/* Layer3StreamDistributionInfo Comment:

For related commands and detailed instructions for 
Histogram results, see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.
*/

/*
Layer3HistTagInfo Description:

Contains the signature field information for the Raw Tags histogram.

A separate record in generated for each SmartBits test frame (containing
a signature)received at this port.

*/
typedef struct tagLayer3HistTagInfo
 {
 unsigned long ulStream;      /* a unique Stream identifier       */
 unsigned long ulSequence;    /* frame serial number              */
 unsigned long ulTransmitTime;/* timestamp of when this frame     */
                              /* left its SmartBits port          */
 unsigned long ulReceiveTime; /* timestamp of when this frame was */
                              /* received by this SmartBits port  */
 } Layer3HistTagInfo;

/* Layer3HistTagInfo Comment:

For related commands and detailed instructions for 
Histogram results, see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.
*/


/*
Layer3HistLatency Description:

Used to setup time intervals for the Latency Over Time histogram.
This structure is used with L3_HIST_V2_LATENCY.

The Latency Over Time histogram provides the Minimum, Maximum, and
Average Latency for all streams at specified intervals.

ulInterval is the interval that latency values are checked. For
example, if ulInterval is 2, latency values are calculated every
200 nanoseconds (.2us).

Latency Resolution and accuracy
-------------------------------
One unit is 1 millisecond.

* For a pair of 10Mbit ports, accuracy is plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is 
  plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is 
  plus or minus .4 us.
* For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is 
  plus or minus .3 us.

Results are retrieved using the Layer3LongLatencyInfo structure.

*/
typedef struct tagLayer3HistLatency
 {
 unsigned long ulInterval;		/* 1 = 1 millisecond */
 } Layer3HistLatency;

/*
Layer3HistDistribution Description:

Defines the time interval ranges used in the 16-bit version
of the Latency Distribution histogram. The maximum latency it
can track is 6.5 milliseconds.

NOTE: For 32 bit Latency Distribution tracking (with latency 
tracking up to 429.4 seconds) use the combination histogram 
set by L3_HIST_V2_LATENCY_PER_STREAM.


Latency Distribution tracks how many frames fall within a given
latency range. There are 16 configurable ranges in units of 
.1 microseconds.

Example Values
-------------- 
If uiInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2us to 1us.

Mechanics
---------
When a frame is received, the latency is calculated from the timestamp
in the signature field. The correct ulFrame[i] is incremented by one. A
separate record containing the 16 different range tallies is generated 
for each stream.

Resolution and accuracy
-----------------------
One unit is .1 microsecond (one clock tick).

For a pair of 10Mbit ports accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is plus or minus .4 us.
For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is plus or minus .3 us.

Results for this histogram are retrieved using the
Layer3StreamDistributionInfo structure.

*/
typedef struct tagLayer3HistDistribution
 {
 unsigned short uiInterval[16];  		/* 1 = 100 nanoseconds */
 } Layer3HistDistribution;


/*
Layer3V2HistDistribution Description:

Defines the time interval ranges used in the combination histogram
specified by L3_HIST_V2_LATENCY_PER_STREAM. The maximum latency it
can track is 429.4 seconds.

Latency Distribution tracks how many frames have a latency that falls 
within a given range. There are 16 configurable ranges in units of 
.1 microseconds.

Example Values
--------------
If ulInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2us to 1us.

Mechanics
---------
When a frame is received, the latency is calculated from the timestamp
in the signature field. The correct ulFrame[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.

Resolution and accuracy
-----------------------
One unit is .1 microsecond (one clock tick).

For a pair of 10Mbit ports accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is plus or minus .4 us.
For a 10/100Mbit port transmitting to a 10Mbit port, accuracy is plus or minus .3 us.

Results for this histogram are retrieved using the
Layer3StreamDistributionInfo structure.


*/
typedef struct tagLayer3V2HistDistribution
 {
 unsigned long ulInterval[16];  		/* 1 = 100 nanoseconds */
 } Layer3V2HistDistribution;

/*
Layer3HistActiveTest Description:

Used to retrieve the total number of records generated by the active histogram
on the specified port.

It also reports which histogram is active.

Histogram records cease to be generated when:
*  Information is retrieved from the port using L3_HIST_ACTIVE_TEST_INFO.
*  Frames with signatures are no longer received.
*  Histogram records are retrieved from the port.

NOTE:

When running a 64 bit histogram test(using NS_HIST_RAW_SIGNATURE, NS_HIST_COMBO_PER_STREAM,
NS_HIST_LATENCY_OVER_TIME, NS_HIST_SEQUENCE_PER_STREAM or NS_HIST_LATENCY_DIST_PER_STREAM), currently
only the TeraMetrics modules will return the 64 bit histogram test constants(NS_HIST_TEST)
for "ulTest".  For other cards, the equivalent 32 bit histogram test constant(L3_HIST_TEST)
will be returned for this field instead.

*/
typedef struct tagLayer3HistActiveTest
	{
	unsigned long ulTest;       /* Histogram test currently active.  Defined constants:

                                   32 bit histogram tests:

                                   L3_HIST_TEST_SEQUENCE
                                   L3_HIST_TEST_LATENCY_DISTRIBUTION
                                   L3_HIST_TEST_RAW_TAGS
                                   L3_HIST_TEST_V2_LATENCY
                                   L3_HIST_TEST_V2_LATENCY_PER_STREAM
                                   L3_HIST_TEST_V1_LATENCY_PER_STREAM

                                   64 bit histogram tests:

                                   NS_HIST_TEST_RAW_SIGNATURE
                                   NS_HIST_TEST_COMBO_PER_STREAM
                                   NS_HIST_TEST_LATENCY_OVER_TIME
                                   NS_HIST_TEST_SEQUENCE_PER_STREAM
                                   NS_HIST_TEST_LATENCY_DIST_PER_STREAM
                                 */
	unsigned long ulRecords;     /* Total number of histogram records available */
	} Layer3HistActiveTest;

/* ulTest combination */
#define L3_HIST_TEST_SEQUENCE                           1
#define L3_HIST_TEST_LATENCY_DISTRIBUTION               4
#define L3_HIST_TEST_RAW_TAGS                           5
#define L3_HIST_TEST_V2_LATENCY                         6
#define L3_HIST_TEST_V2_LATENCY_PER_STREAM              7
#define L3_HIST_TEST_V1_LATENCY_PER_STREAM              10
#define NS_HIST_TEST_RAW_SIGNATURE				        15
#define NS_HIST_TEST_COMBO_PER_STREAM			        16
#define NS_HIST_TEST_LATENCY_OVER_TIME			        17
#define NS_HIST_TEST_SEQUENCE_PER_STREAM		        18
#define NS_HIST_TEST_LATENCY_DIST_PER_STREAM		    19

/* Layer3HistActiveTest Comment:

For related commands and detailed instructions for 
Histogram results, see Chapter 6
"Histograms: Getting Results" of the 
"SmartLib Overview and Procedures" manual.
*/


/*
Layer3IGMPInit Description:

This structure is to initialize the IGMP protocol stack.

*/
typedef struct tagLayer3IGMPInit
{
	unsigned char	ucVersion;           /* 1 = IGMP v1, 2 = IGMP v2 */
   unsigned char	ucOptions;           /* Init options for this port */
		/* This is a 8 bit field where 0 turns off all options */
		/* Fields available include: */
		/*    IGMP_INIT_ALWAYS_SEND_V2_LEAVE_REQUEST = force leave */
		/*                    requests on IGMP v2 configured ports */
	unsigned short	uiMaxGroups;         /* Max groups allowed for this port */
} Layer3IGMPInit;

/*
NSIGMPConfig Description:

This structure is to initialize and configure the IGMP protocol stack on the 
card. The maximum groups allowed for this port is based on the card being 
used.  It is set to 1002 for the 7710, 5710, and 3101 cards, and for the 
Terametrics family of cards the value 512 is used.  For the 3201 cards 2048 
is set as the max number of groups.  For the WN-3441A, 3442A, and 3445A 
cards, the max numberof groups is 2048. 

*/
typedef struct tagNSIGMPConfig
{
	unsigned char	ucVersion;           /* 1 = IGMP v1, 2 = IGMP v2 */
   unsigned char	ucOptions;           /* Init options for this port */
		/* This is a 8 bit field where 0 turns off all options */
		/* Fields available include: */
		/*    IGMP_INIT_ALWAYS_SEND_V2_LEAVE_REQUEST = force leave */
		/*                    requests on IGMP v2 configured ports */
	unsigned char	ucReserved[2];      /* Reserved */
} NSIGMPConfig;

/* ucOptions														*/
/* force leave requests on IGMP v2 configured ports	*/
#define IGMP_INIT_ALWAYS_SEND_V2_LEAVE_REQUEST     0x80

/*
NSIGMPAddress Description:

This structure is to specify an address to join or leave a multicast group.

*/
typedef struct tagNSIGMPAddress
{
	unsigned char ucIPAddress[4];	/* The IP address of the multicast group */
	unsigned long ulLineNo;			/* WAN cards only- T1/E1 line to do join */
	unsigned long ulChannelNo;		/* WAN cards only-
												Channel number within the T1/E1 line */
	unsigned long ulDLCI;			/* WAN cards only- Local DLCI number */
	unsigned char ucReserved[16];
} NSIGMPAddress;

/*
NSIGMPVlan Description:

This structure is to specify an address to join or leave a multicast group,
using the VLAN tags associated with it

*/
typedef struct tagNSIGMPAddressVLAN
{
 unsigned char  ucIPAddress[4];		/* The IP address of the multicast group */
 unsigned short uiTPID;					/* VLAN type (2 bytes), for now always
													assumes 0x8100 */
 unsigned char  ucPRI;					/* user priority 0-7 (3 bits), use
													ETH_VLAN_PRI_XXX definitions */
 unsigned char	 ucCFI;					/* 1 = RIF present, 0 = RIF absent (1
													bit), use ETH_VLAN_CFI_XXX
													definitions */
 unsigned short uiVID;					/* VLAN ID (12 bits) */
 unsigned char  ucReserved[4];		/* Reserved */
} NSIGMPAddressVLAN;

/*
NSIGMPCounterInfo Description:

This structure is used to retrieve IGMP counter information.

*/
typedef struct tagNSIGMPCounterInfo
{
   unsigned long   ulTxFrames;					/* Number of transmitted frames					*/
   unsigned long   ulTxJoinGroups;				/* Number of groups joined							*/
   unsigned long   ulTxLeaveGroups;				/* Number of groups that had a leave			*/
   unsigned long   ulRxFrames;					/* Number of received frames						*/
   unsigned long   ulRxUnknownType;				/* Number of unknown type frames					*/
   unsigned long   ulRxIPChecksumErrors;		/* Number of received IP Check sum errors		*/
   unsigned long   ulRxIGMPChecksumErrors;	/* Number of received IGMP Check sum errors	*/
   unsigned long   ulRxIGMPLengthErrors;		/* Number of received IGMP frames with an 
															   error in the length of the received packet*/
   unsigned long   ulRxWrongVersionQueries;	/* Number of queries done on the membership 
																for a specific group with a wrong version */
   unsigned char   ucReserved[96];				/* Reserved, currently unused						*/
} NSIGMPCounterInfo;

/*
NSIGMPTimestampInfo Description:

This structure is used to retrieve the IGMP join and leave timestamps
for a multicast group.

*/
typedef struct tagNSIGMPTimestampInfo
{
	unsigned char ucIPAddress[4];	/* The IP address of the multicast group */
	unsigned long ulLineNo;			/* Input - WAN cards only- T1/E1 line to do join */
	unsigned long ulChannelNo;		/* Input - WAN cards only-
												Channel number within the T1/E1 line */
	unsigned long ulDLCI;			/* Input - WAN cards only- Local DLCI number */
	unsigned long ulJoinTime;		/* Join timestamp */
	unsigned long ulLeaveTime;		/* Leave timestamp */
	unsigned char ucReserved[16];	/* Reserved */
} NSIGMPTimestampInfo;

/*
Layer3IGMPJoin Description:

This structure is to specify an address to join a multicast group.

*/
typedef struct tagLayer3IGMPJoin
{
 unsigned char ucIPAddress[4];
} Layer3IGMPJoin;

/*
Layer3IGMPLeave Description:

This structure is to specify an address to leave a multicast group.

*/
typedef struct tagLayer3IGMPLeave
{
 unsigned char ucIPAddress[4];
} Layer3IGMPLeave;

/*
IGMPJoinLeaveTimeStampInfo Description:

This structure is used to retrieve IGMP join and leave timestamps
relative to a specific multicast group on a particular SmartCard.

*/
typedef struct tagIGMPJoinLeaveTimeStampInfo
{
 unsigned char ucIPAddress[4];
 unsigned long ulJoinTime;
 unsigned long ulLeaveTime;
} IGMPJoinLeaveTimeStampInfo;

/*
NSIGMPVLANTimestampInfo Description:

This structure is used to retrieve IGMP join and leave timestamps
relative to a specific multicast VLAN tagged group on a particular SmartCard.

*/
typedef struct tagNSIGMPVLANTimestampInfo
{
 unsigned char ucIPAddress[4];  /* The IP address of the multicast group */
 unsigned long ulVLANId;        /* VLAN ID of the multicast group */
 unsigned long ulJoinTime;      /* Join timestamp */
 unsigned long ulLeaveTime;     /* Leave timestamp */
 unsigned char ucReserved[16];  /* Reserved */
} NSIGMPVLANTimestampInfo;


/********************* Begin of POS and LAN3201 card ****************************/

#define POS_CARD_BASE					0x6100

/*********************************************************************************
 * Structure:   L3DataCheck
 * iType1:      L3_WRITE_DATA_CHECK
 * Function:    HTSetStructure
 * L3DataCheck Description: Setup link layer configuration
***********************************************************************************/
typedef struct tagL3DataCheck
{
		unsigned char	bRcvMarkerCheck;		/* 1 check receive side data, 0 no  */
		unsigned char	ucReserved[3];
		unsigned char   ucMarker[8];			/* received data marker for checking */
} L3DataCheck;

#define L3_WRITE_DATA_CHECK				(POS_CARD_BASE + 0x0002)

/*********************************************************************************
 * Structure:   L3DataCheck
 * iType1:      L3_READ_DATA_CHECK
 * Function:    HTGetStructure
 * L3DataCheck Description: Get link layer configuration
***********************************************************************************/

#define L3_READ_DATA_CHECK				(POS_CARD_BASE + 0x0003)

/*********************************************************************************
 * Structure:   L3StreamExtension
 * iType1:      L3_DEFINE_STREAM_EXTENSION
				L3_MOD_STREAM_EXTENSION
				L3_DEFINE_MULTI_STREAM_EXTENSION
 * Function:    HTSetStructure
 */
 /* L3StreamExtension Description:

This structure is used in conjunction with the StreamXX structures
(StreamIP, StreamUDP, etc.).  It adds information to a pre-created
stream.  The structure is required by POS-3500 and LAN-3201 family of
cards.  Optionally, it may be applied in a limited fashion to the
ML-7710, LAN-3101A, LAN-3300A, LAN-3301A, LAN-3310A, LAN-3311A,
POS-3504A, and POS-3505A cards.  (See "L3StreamExtension Comment"
below.)  It is used to configure additional stream information,
including scheduling on a per-stream basis.

These structures are set up for every stream, so they should be sent
after the streams are defined.

This structure is used for 3 commands:
L3_DEFINE_STREAM_EXTENSION defines one or more L3StreamExtension.
L3_MOD_STREAM_EXTENSION overwrites one L3StreamExtension at a given
index.  
L3_DEFINE_MULTI_STREAM_EXTENSION creates an array of
L3StreamExtensions based on a previously defined L3StreamExtension.
*/
/***************************************************************************************************/
typedef struct tagL3StreamExtension
{
		unsigned long	ulFrameRate;				/* frame transmit rate, in
																packets per second */
		unsigned long	ulTxMode;       			/* frame transmit mode, use one
																of L3_CONTINUOUS_MODE,
																L3_SINGLE_BURST_MODE,
																L3_MULTIBURST_MODE,
																L3_CONTINUOUS_MULTIBURST_MODE */
		unsigned long	ulBurstCount;    			/* the burst number */
		unsigned long	ulMBurstCount;   			/* the multi burst number */
		unsigned long	ulBurstGap;      			/* the gap between burst, in
																32ns units */
		unsigned short	uiInitialSeqNumber;		/* IP initial sequence number */
		unsigned char	ucIPHeaderChecksumError;/* 1 enabled,
                                                0 disabled */
		unsigned char	ucIPTotalLengthError; 	/* 1 enabled, 0 disabled */
		unsigned char	ucIPManipulateMode;     /* IP_xxx manipulate mode */
		unsigned char	ucIncUDPPort;    			/* Increase UDP Source and Dst
																Port number per burst. 1
																enabled, 0 disabled */
		unsigned short	uiIPLimitCount;  			/* The limit/cycle count is the number of times 
                                                that the step value(ucStepCount) will be 
                                                added/subtracted from the field before it is 
                                                reset to its initial value.  Values can range 
                                                from 0 - 65535.   Note that 0 indicates 
                                                continuously incrementing/decrementing the field.
                                                For the LAN-3101x modules, this cycle count value
                                                applies to the first address referred to 
                                                by the following IP manipulate modes(ucIPManipulateMode):

                                                    IP_INC_SRC_IP_AND_DST_IP      (source IP)
                                                    IP_DEC_SRC_IP_AND_DST_IP      (source IP)
                                                    IP_INC_SRC_MAC_AND_DST_MAC    (source MAC)
                                                    IP_DEC_SRC_MAC_AND_DST_MAC    (source MAC) 

                                                Use uiIPLimitCount2 to set the cycle count for 
                                                the second address.
                                              */
      unsigned long	ulStartOffset;				/* all streams defined can not
																transmit at the same time,
																each stream has to start at
																the different time.
																ulStartOffset is the start
																offset from the previous
																stream.  ulStartOffset's
															   unit is tick. minimum is 10
																tick. 1(tick) = 32(ns) */
		unsigned long	ulBGPatternIndex;			/* index of the stream
																background fill pattern that
																defined by L3StreamBGConfig */
		unsigned char	ucDataCheckEnable;		/* 1 enable payload check
																error, 0 disable */
		unsigned char	ucCRCErrorEnable;			/* 1 enable, 0 disable */
		unsigned char	ucRandomBGEnable;			/* 1 enable, 0 disable */
		unsigned char	ucDataIntegrityErrorEnable;	/* 1 enable, 0
                                                      disable */
		unsigned char  ucStepCount;   			/* IP address increment/decrement step count: 1,3,5,etc.
                                                For the LAN-3101x modules, this value
                                                applies only to the first address referred to 
                                                by these IP manipulate modes(ucIPManipulateMode):
                                                   IP_INC_SRC_IP_AND_DST_IP      (source IP)
                                                   IP_DEC_SRC_IP_AND_DST_IP      (source IP)
                                                   IP_INC_SRC_MAC_AND_DST_MAC    (source MAC)
                                                   IP_DEC_SRC_MAC_AND_DST_MAC    (source MAC)      

                                                Use ucStepCount to set the step count for the 
                                                second address.
                                              */
		unsigned char  ucIPBitsOffset;			/* bit offset where the IP
																address is increment. */
		unsigned char  ucMPLSCount;				/* Number of MPLS labels. 0
																disable the MPLS */
		unsigned char	ucIPOptionsCount;			/* reserved */
		unsigned long	ulCustomStreamID;			/* reserved */
		unsigned char	ucEnableCustomStreamID;	    /* reserved */
      unsigned char   ucOAMHeaderPacketType;      /* defined constants:
                                                       OAM_PACKET_TYPE_NONE_OAM
                                                       OAM_PACKET_TYPE_NORMAL_OAM 
                                                       OAM_PACKET_TYPE_IDLE_OAM
                                                     */
      unsigned char  ucStepCount2;           /* Applicable for the LAN-3101 cards ONLY.
                                                This field is used to specify the
                                                Increment/decrement step count for the
                                                Second address referred to by these
                                                IP manipulate modes(ucIPManipulateMode):
                                                   IP_INC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_DEC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_INC_SRC_MAC_AND_DST_MAC    (dest. MAC)
                                                   IP_DEC_SRC_MAC_AND_DST_MAC    (dest. MAC)

                                                Use ucStepCount to set the step count for the 
                                                first address.
                                             */
  		unsigned short uiIPLimitCount2;        /* Applicable for the LAN-3101 cards ONLY.
                                                The limit/cycle count is the number of times 
                                                that the step value(ucStepCount2) will be 
                                                added/subtracted from the field before it is 
                                                reset to its initial value.  Values can range 
                                                from 0 - 65535.   Note that 0 indicates 
                                                continuously incrementing/decrementing the field.
                                                This value applies to the second address 
                                                referred to by the following IP manipulate 
                                                modes(ucIPManipulateMode):
                                                   IP_INC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_DEC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_INC_SRC_MAC_AND_DST_MAC    (dest. MAC)
                                                   IP_DEC_SRC_MAC_AND_DST_MAC    (dest. MAC)

                                                Use uiIPLimitCount to set the cycle count for 
                                                the first address.
                                             */
	   unsigned short uiBlockCount;           /* Applicable for the LAN-3101 cards ONLY.
                                                This field is used to specify the number
                                                Of frames that will repeat a pattern before
                                                Incrementing or decrementing to the next one.
                                                This applies to only the first address referred
                                                To by these IP manipulate modes(ucIPManipulateMode):
                                              
                                                   IP_INC_SRC_IP_AND_DST_IP      (source IP)
                                                   IP_DEC_SRC_IP_AND_DST_IP      (source IP)
                                                   IP_INC_SRC_MAC_AND_DST_MAC    (source MAC)
                                                   IP_DEC_SRC_MAC_AND_DST_MAC    (source MAC)

                                                Use uiBlockCount2 to set the block count for the 
                                                second address.
                                             */
	   unsigned short uiBlockCount2;          /* Applicable for the LAN-3101 cards ONLY.
                                                This field is used to specify the number
                                                Of frames that will repeat a pattern before
                                                Incrementing or decrementing to the next one.
                                                This applies to only the second address referred
                                                To by these IP manipulate modes(ucIPManipulateMode):
                                              
                                                   IP_INC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_DEC_SRC_IP_AND_DST_IP      (dest. IP)
                                                   IP_INC_SRC_MAC_AND_DST_MAC    (dest. MAC)
                                                   IP_DEC_SRC_MAC_AND_DST_MAC    (dest. MAC)

                                                Use uiBlockCount to set the block count for the 
                                                first address.
                                             */
		unsigned char	ucMulticastKeepAliveEnable;   /* Enable/Disable multicast keep alive
		                                                 1 - enable,  0 - disable (default)
		                                                 for Terametrics LAN/POS modules only
		                                                 used with command NS_MULTICAST_KEEP_ALIVE_CONFIG */       
		unsigned char	ucReserved[2];          /* Reserved */       
} L3StreamExtension;

#define OAM_PACKET_TYPE_NONE_OAM                0
#define OAM_PACKET_TYPE_NORMAL_OAM              1
#define OAM_PACKET_TYPE_IDLE_OAM                2


/*************************************************************
L3StreamExtension Comment:

Some cards support this structure in a limited fashion only:

The ML-7710 and LAN-3101A support the ucIPManipulateMode, ucStepCount,
and uiIPLimitCount fields.  

The ucDataIntegrityErrorEnable field currently applies to the
LAN-3101A card only.  

The LAN-3300A, LAN-3301A, LAN-3310A, LAN-3311A, POS-3504A, and
POS-3505A cards support the following fields: ulFrameRate,
ucIPHeaderChecksumError, ucIPTotalLengthError, ulBGPatternIndex,
ucDataCheckEnable, ucCRCErrorEnable, ucRandomBGEnable,
ulCustomStreamID, and ucEnableCustomStreamID.  

The LAN-3710 card supports the following fields: 
uiInitialSeqNumber, ucIPHeaderChecksumError, ulBGPatternIndex,
ucDataCheckEnable, ucCRCErrorEnable, ucRandomBGEnable,
ulCustomStreamID, ucEnableCustomStreamID, and ucOAMHeaderPacketType.  

The XLW-3720A and XLW-3721A cards supports the following fields: 
uiInitialSeqNumber, ucIPHeaderChecksumError, ulBGPatternIndex,
ucDataCheckEnable, ucCRCErrorEnable, ucRandomBGEnable,
ulCustomStreamID, and ucEnableCustomStreamID.  

The FBC-3601A and FBC-3602A cards supports the following fields:
ulTxMode, ulBurstCount, ulMBurstCount, ulBurstGap, ulBGPatternIndex,
ucDataCheckEnable, ucCRCErrorEnable, ucRandomBGEnable,
ucDataIntegrityErrorEnable, ulCustomStreamID and ucEnableCustomStreamID.

The AT-34xx cards supports the following fields:
ulFrameRate, ucIPHeaderChecksumError, ulBGPatternIndex, ucDataCheckEnable, 
ucCRCErrorEnable, ucDataIntegrityErrorEnable, ulCustomStreamID and 
ucEnableCustomStreamID. Notes for the AT-34xx cards:  
  -  All streams bound to the same VC must have the
     same frame rate(ulFrameRate).
  -  Data integrity(ucDataCheckEnable) and triggers can not be used at the same time.

Other fields in L3StreamExtension do not currently apply to these
cards.

The following modes for ucIPManipulateMode are currently supported on
the LAN-3201 and POS cards:
IP_INC_SRC_IP
IP_INC_DST_IP
IP_INC_DST_IP_AND_DST_MAC
IP_INC_SRC_IP_AND_SRC_MAC
IP_INC_SRC_IP_AND_DST_MAC
IP_INC_DST_IP_AND_DRC_MAC

The following modes for ucIPManipulateMode are currently supported on
the ML-7710 card:

IP_INC_SRC_IP
IP_INC_DST_IP
IP_DEC_SRC_IP
IP_DEC_DST_IP
IP_INC_SRC_IP_AND_SRC_MAC
IP_INC_DST_IP_AND_DST_MAC
IP_DEC_SRC_IP_AND_SRC_MAC
IP_DEC_DST_IP_AND_DST_MAC

The following modes for ucIPManipulateMode are currently supported on
the LAN-3101A card:

IP_INC_SRC_IP
IP_INC_DST_IP
IP_DEC_SRC_IP
IP_DEC_DST_IP
IP_INC_SRC_IP_AND_SRC_MAC
IP_INC_DST_IP_AND_DST_MAC
IP_DEC_SRC_IP_AND_SRC_MAC
IP_DEC_DST_IP_AND_DST_MAC
IP_INC_SRC_IP_AND_DST_IP
IP_DEC_SRC_IP_AND_DST_IP
IP_INC_SRC_MAC_AND_DST_MAC
IP_DEC_SRC_MAC_AND_DST_MAC

Notes for ulCustomStreamID with L3_READ_STREAM_EXTENSION:
Although stream ID (including custom stream ID or non-custom stream ID) is always 4 bytes, 
the signature field, by default provides only 2 bytes for the stream ID while the upper 
2 bytes are for card/chassis ID, etc. Only when custom stream ID is enabled, all 4 bytes 
are available to stream ID, and then it's up to user to make sure the chassis/card 
uniqueness is taken into account when generating custom stream IDs. Therefore when the 
stream ID is retrieved via L3_READ_STREAM_EXTENSION, the value in the whole 4 bytes are
valid only when custom stream ID is enabled. Otherwise only the lower 2 bytes values are
valid for the stream ID.

************************************************************/

/* for ucIPManipulateMode */
#define IP_INC_SEQ_NUM					0x10
#define IP_INC_SRC_IP  					0x11
#define IP_INC_DST_IP					0x12
#define IP_INC_SRC_MAC					0x13
#define IP_INC_DST_MAC					0x14
#define IP_DEC_SRC_IP					0x15
#define IP_DEC_DST_IP					0x16
#define IP_INC_DST_IP_AND_DST_MAC	0x17
#define IP_INC_SRC_IP_AND_SRC_MAC	0x18
#define IP_DEC_DST_IP_AND_DST_MAC	0x19
#define IP_DEC_SRC_IP_AND_SRC_MAC	0x1A
#define IP_INC_SRC_IP_AND_DST_MAC	0x1B
#define IP_INC_DST_IP_AND_SRC_MAC  	0x1C
#define IP_DEC_SRC_IP_AND_DST_MAC	0x1D
#define IP_DEC_DST_IP_AND_SRC_MAC	0x1E

// The following constants(with "AND") replaces the four obselete constants below.
#define IP_INC_SRC_IP_AND_DST_IP    0x1F
#define IP_DEC_SRC_IP_AND_DST_IP    0x20
#define IP_INC_SRC_MAC_AND_DST_MAC  0x21
#define IP_DEC_SRC_MAC_AND_DST_MAC  0x22

// OBSOLETED
#define IP_INC_SRC_IP_DST_IP        0x1F
#define IP_DEC_SRC_IP_DST_IP        0x20
#define IP_INC_SRC_MAC_DST_MAC      0x21
#define IP_DEC_SRC_MAC_DST_MAC      0x22

/* for ulTxMode */
#define L3_CONTINUOUS_MODE                0
#define L3_SINGLE_BURST_MODE              1
#define L3_MULTIBURST_MODE                3
#define L3_CONTINUOUS_MULTIBURST_MODE     2


/*********************************************************************************
MPLSItem Description:
	When it send over to firmware, it translate into the unsigned long.
	It is only right for POS3505/3500
***********************************************************************************/
typedef struct tagMPLSItem
{
		unsigned long  ulLabel;					/* [bit 11- 31] */
		unsigned char  ucExperimentalUse;	/* [bit 8 - 11] */
		unsigned char  ucBottomStack;			/* [bit 7 - 8 ] */
		unsigned char  ucTimeToLive;			/* [bit 0 - 7 ] */
}MPLSItem;

/*********************************************************************************
NSMPLSLabel Description:
	When it send over to firmware, it translate into the unsigned long.
	It is only right for POS3505/3500
***********************************************************************************/
typedef struct tagNSMPLSLabel
{
		unsigned long  ulLabel;					/* [bit 11- 31] */
		unsigned char  ucExperimentalUse;	/* [bit 8 - 11] */
		unsigned char  ucBottomStack;			/* [bit 7 - 8 ] */
		unsigned char  ucTimeToLive;			/* [bit 0 - 7 ] */
}NSMPLSLabel;

/*********************************************************************************
NSMPLSList Description:
	The array of NSMPLSLabel that supports 
		+ L3_DEFINE_MPLS
		+ L3_MOD_MPLS														

NOTE:  The LAN TeraMetrics modules currently supports a maximum of 12 labels.
       The ATM TeraMetrics modules currently supports a maximum of 9 labels. And when
	   using customized VC encapsulation, the maximum number of labels supported 
	   will depend on the encapsulation length because the card limitation that IP
	   checksum has to be in the first cell (within the first 48 bytes).

***********************************************************************************/
typedef struct tagNSMPLSList
{
		unsigned short uiNumLabels;		/* number of labels for this stream (32 max) */
		NSMPLSLabel Labels[32];				/* list of MPLS labels for this stream */
}NSMPLSList;


/*
VoiceTestSetup Description:
*/
typedef struct tagVoiceTestSetup
{
   unsigned long  ulTestDuration;       /* in seconds */
   unsigned long  ulReserved[7];
}VoiceTestSetup;



/*********************************************************************************
 * Structure:   L3StreamExtension
 * iType1:      L3_READ_STREAM_EXTENSION
 * iType2:		index
 * Function:    HTGetStructure
 * L3StreamExtension Description: 
***********************************************************************************/
#define L3_READ_STREAM_EXTENSION		NS_STREAM_EXTENSION_INFO	/* read back the stream extension parameters for a given stream specified by "index". */


/*********************************************************************************
 * Structure:   L3StreamBGConfig
 * iType1:      L3_WRITE_STREAM_BG
 * iType2:		index
 * Function:    HTSetStructure

L3StreamBGConfig Description: 
Represents one background fill pattern for use with a particular
stream.  Note that the POS-3500/3502 and LAN-3201/6201 cards allow a total of 16
different stream background patterns of 64 bytes each.  The other cards that support this
command only allow 2 different stream background patterns.  The pattern can be written or
read at an index between 0 and 1 or 15, depending upon the card, as given by iType2.  To
assign a defined pattern to a stream, use the ulBGPatternIndex field of the
L3StreamExtension structure.  Note that multiple streams can share the same stream
background pattern by using the same index.
***********************************************************************************/
typedef struct tagL3StreamBGConfig
{
	unsigned char	ucPattern[64];			/* background data pattern */
} L3StreamBGConfig;

#define L3_WRITE_STREAM_BG		0x0754	/* define the pattern for the stream background specified by "index". */

/*********************************************************************************
 * Structure:   L3StreamBGConfig
 * iType1:      L3_READ_STREAM_BG
 * iType2:		index  
 * Function:    HTGetStructure
***********************************************************************************/

#define L3_READ_STREAM_BG		0x0755	/* read back the pattern for the stream background specified by "index". */

/********************* End of POS and LAN3201 card *******************************/

/******************************************************************************
Structure:	NSVFD
iType1:  	L3_DEFINE_VFD
            L3_MOD_VFD
				L3_DEFINE_MULTI_VFD
Function: 	HTSetStructure
NSVFD Description:

This structure configures VFDs for a stream.  The VFDs can be placed
in the first 64 bytes of the frame; however the VFDs will be
overwritten by the following fields of the frame: IP sequence number,
IP header checksum, IP total length, UDP/TCP checksum, TCP sequence
number, and the signature field.

Example for ucCycleCount and ucBlockCount:

   ucMode = L3_VFD_INCR
	uiRange = 2
	ulCycleCount = 4
	ulBlockCount = 2
	ucPattern = {0 0 0 0 0 0}

	The transmitted patterns will be as follows (in hex):
	   00 00
	   00 00
		00 01
		00 01
	   00 02
	   00 02
	   00 03
	   00 03
	   00 00
		00 00
		...
	   

Example for ucStepValue and ucStepShift:

   ucMode = L3_VFD_INCR
	uiRange = 4
	ucStepValue = 3
	ucStepShift = 2
	ucPattern = {0 0 0 0 0 0}

	The transmitted patterns will be as follows (in hex):
	   00 00 00 00
		00 03 00 00
		00 06 00 00
		00 09 00 00
	   ...


Examples for ucSubnetMaskAware and ucSubnetMaskLength:

   ucMode = L3_VFD_INCR
	uiRange = 4
	ucStepValue = 1
	ucPattern = (0 0 0 0xFD 0 0}
	ucSubnetMaskAware = 1

   case 1:
	ucSubnetMaskLength = 24	
	The transmitted patterns will be as follows (in hex):
	   00 00 00 FD
		00 00 00 FE
		00 00 01 01  <-- skipping 00 00 00 FF and 00 00 01 00
		00 00 01 02
		...

   case 2:
   ucSubnetMaskLength = 16
	The transmitted patterns will be as follows (in hex):
      00 00 00 FD
      00 00 00 FE
      00 00 00 FF
      00 00 01 00
      00 00 01 01
      ....
      00 00 FF FD
      00 00 FF FE
      00 01 00 01  <-- skipping 00 00 FF FF and 00 01 00 00
      00 01 00 02
      ...

  case 3:
   ucSubnetMaskLength = 8
	The transmitted patterns will be as follows (in hex):
      00 00 00 FD
      00 00 00 FE
      00 00 00 FF
      00 00 01 00
      00 00 01 01
      ...
      00 FF FF FD
      00 FF FF FE
      01 00 00 01 <-- skipping 00 FF FF FF and 01 00 00 00
      01 00 01 02
      ...

NOTES:

For the AT-345x modules, the following fields will increment when used with
L3_DEFINE_MULTI_VFD:

   uiOffset
   ulCycleCount
   uiBlockCount
   ucStepValue
   ucStepShift
   ucSubnetMaskLength
******************************************************************************/

typedef struct tagNSVFD
{
      unsigned char  ucType;  /* Specifies VFD1 or VFD2; use
                                    L3_VFD1 or L3_VFD2. */
      unsigned char  ucMode;  /* VFD mode: static, increment,
                                    decrement, or random; use
                                    L3_VFD_STATIC, L3_VFD_INCR,
                                    L3_VFD_DECR, L3_VFD_RANDOM, or
                                    L3_VFD_OFF. */
      unsigned short uiOffset;   /* Offset of the VFD, in bits.  The
                                    VFD must fall within the first 128
                                    bytes of the frame.  Also, if the
                                    VFD falls in the last 18 bytes of
                                    the payload, and the signature
                                    field is enabled, the signature
                                    field will overwrite the VFD. */
      unsigned short uiRange;    /* Range (length) of the VFD, in
                                    bytes.  Valid ranges are from 1 to
                                    6 bytes. */
      unsigned long ulCycleCount;  /* For increment or decrement
                                       mode, the number of patterns
                                       before resetting to initial VFD
                                       pattern.  May range from 0 to
                                       16777215.  If 0, the pattern
                                       will increment or decrement
                                       through its entire range
                                       without resetting. */
      unsigned short uiBlockCount;  /* For increment or decrement
                                       mode, the number of frames that
                                       will repeat a pattern before
                                       incrementing or decrementing to
                                       the next one.  May range from 0
                                       to 4095.  When used with
                                       ulCycleCount each block of
                                       patterns only counts as one
                                       toward the cycle count.
		                                 NOTE: it is always fixed value 1 
		                                 when used with multicast keep alive
		                                 stream (NS_MULTICAST_KEEP_ALIVE_CONFIG)*/
      unsigned char ucStepValue;   /* For increment or decrement
                                       mode, the amount to add or
                                       subtract from the previous
                                       pattern.  May range from 0 to
                                       255. Not available when ucSubnetAware 
                                       is enabled.  See the example in the
                                       structure description. 
                                       When the ucMode = L3_VFD_INCR and 
                                       ucStepValue = 0, the result will be 
                                       static which means no change at all.
                                       When the ucMode = L3_VFD_INCR and 
                                       ucStepValue = 1, the result will be 
                                       incrementing by step as 1. */
      unsigned char ucStepShift;   /* For increment or decrement
                                       mode, this field specifies the
                                       location in the pattern where
                                       the change will occur.  The
                                       ucStepShift is the number of
                                       bytes to shift the step value
                                       left before adding or
                                       subtracting from the previous
                                       pattern.  May range from 0 to
                                       5, and is limited by the range
                                       of the pattern.  See the
                                       example in the structure
                                       description. */
      unsigned char  ucSubnetAware; /* Skip VFD patterns which are
                                       interpreted as subnet (0) or
                                       broadcast (255) addresses.  1 =
                                       enable, 0 = disable.  See the
                                       example in the structure
                                       description. NOTE:  This feature
                                       only works when uiRange is set to
                                       4 and ucStepValue is set to 1. */
      unsigned char ucSubnetMaskLength;  /* If ucSubnetAware is
                                             enabled, this is the
                                             number of bits in the
                                             subnet mask.  See the
                                             example in the structure
                                             description. */
      unsigned char ucEnableCarryChaining;	/* For increment or
                                          decrement mode, this field
                                          enables carry over from VFD1
                                          to VFD2 on overflow or
                                          underflow.  1 = enable, 0 =
                                          disable.  To enable the
                                          feature, this field must be
                                          set for both VFD1 and VFD2.
                                          VFD2 will remain static
                                          until VFD1 overflows or
                                          underflows.  At that point,
                                          the next VFD pattern will
                                          begin (increment, decrement,
                                          or random). */
      unsigned char  ucPattern[6];     /* Initial VFD pattern.  Note:
                                          the transmitted pattern will
                                          start with the byte at index
                                          0, even if the range is less
                                          than 6 bytes. */
      unsigned char  ucReserved[16];   /* reserved */
} NSVFD;

#define L3_VFD1	1
#define L3_VFD2	2
#define L3_VFD3	3
#define L3_VFD4	4
#define L3_VFD5	5


#define L3_VFD_STATIC			0x00
#define L3_VFD_INCR				0x01
#define L3_VFD_DECR				0x02
#define L3_VFD_RANDOM			0x03
#define L3_VFD_OFF				0x04

/*********************************************************************************
 * Structure:   L3StreamBinding
 * iType1:      L3_DEFINE_STREAM_BINDING
 * Function:    HTSetStructure

 * iType1:      L3_MOD_STREAM_BINDING
 * iType2:      <index> Stream Index to bind one VC's(Virtual Circuit) and update CLP setting.  
 * Function:    HTSetStructure

 * iType1:      L3_DEFINE_MULTI_STREAM_BINDING
 * iType2:      <index> Index of the base stream to be copied to update VC's(Virtual Circuit)
 *                      and CLP setting of appending streams.  
 * iType3:      <count> Stream Count to bind VC's(Virtual Circuit) and update CLP setting.  
 * Function:    HTSetStructure

 * iType1:      L3_STREAM_BINDING_INFO
 * iType2:      <index> Stream Index to get the info of bound VC's(Virtual Circuit) and CLP setting.  
 * Function:    HTSetStructure

 ************************************************************************************/
/* L3StreamBinding Description:
Binds streams to VC index and update CLP (ATM cards) or retrieve the info of the bound VC's
and CLP setting.

Use L3_DEFINE_STREAM_BINDING with one single or an array of L3StreamBinding structures
to bind one single or a continuous sequence of streams to VC/VCs, and update the stream CLP
setting. The index of streams to be bound always starts at 1. The number of streams to
be bound is the size of the array of L3StreamBinding.

Use L3_MOD_STREAM_BINDING with one single L3StreamBinding structure to bind one single
stream to one single VC, and update the stream CLP setting. The index of stream to be bound is
iType2.

Use L3_DEFINE_MULTI_STREAM_BINDING with one single L3StreamBinding structure
to copy the stream binding of one stream to multiple streams. The base stream is of
<index>, the newly set stream is of <index+1>, <index+2>, ..., <index+count>. The
uiBindIndex is the delta value, and the uiATMFlags is ignored.

Use L3_STREAM_BINDING_INFO with one single L3StreamBinding structure to retrieve VC and CLP
setting for a stream. Pass the stream index as iType2

*/
typedef struct tagL3StreamBinding
{
   unsigned char ucBindMode;    /* STREAM_BIND_VC (binding to VC for ATM),                                    
                                   required input for both configuration and
                                   reading back configurations */ 
   unsigned short uiBindIndex;	/* VC index for ATM cards */                                     
   unsigned short uiATMFlags;		   /* Flag to set CLP bit in ATM header for ATM card,
                                    AT_CLP_ON  - set CLP bit in ATM header
                                    AT_CLP_OFF - not set CLP bit in ATM header*/
   
   unsigned char ucReserved[56];
} L3StreamBinding;

//#define STREAM_BIND_PPPOE_TRANSMIT_ON_SESSION_UP 0x0001 /* Don't start stream traffic until session is up */
//#define STREAM_BIND_PPPOE_TRANSMIT_ALL_TIME       0x0002  /* Start stream traffic regardless of PPP session status */
//#define STREAM_BIND_PPPOE_STOP_TRANSMIT_SESSION_DOWN 0x0004 /* Stop transmission when session is down */


#define STREAM_BIND_VC     1
//#define STREAM_BIND_PPPOE  2

#define AT_CLP_OFF   0x0000
#define AT_CLP_ON    0x0001





/*---- OBSOLETE ---- OBSOLETE --------------------- OBSOLETE ----- OBSOLETE ---*/
/*---- OBSOLETE -------------------- OBSOLETE -------------------- OBSOLETE ---*/
/*---- OBSOLETE ---- OBSOLETE --------------------- OBSOLETE ----- OBSOLETE ---*/

/* The items listed in this section below are obsolete and should NOT be
 * used. They exist for backward compatibility for old programs but are
 * NOT recommended for use in new programs.
 */

/*-------- Layer 3 iType1 values  ---------*/
#define L3_ENGINE_TRANSMIT				0x0	
#define L3_ENGINE_RECEIVE				0x1

#define L3_HIST_LATENCY_PER_STREAM_INFO_32		NS_HIST_LATENCY_PER_STREAM_INFO_32	/* Get 32-bit Latency per Stream histogram results */
#define L3_HIST_LATENCY_PER_STREAM_32			   NS_HIST_LATENCY_PER_STREAM_32	/* Specify/Activate 32-bit Latency per Stream histogram for Rx port */


#define L3_SET_DEFINESTREAMS			0x10
#define L3_SET_MULTIDEFINESTREAMS	0x12

#define L3_SET_MODIFYSTREAM			0x11
#define L3_SET_MODIFYSTREAMS			0x13

#define L3_MODIFY_STREAMS				0x50
#define L3_MODIFY_STREAMS_ARRAY		0x51

/*-------- Layer 3 iType2 values  ---------*/
/*           none defined                  */
/*		WAS used for the stream number 		 */

/*-------- Layer 3 iType3 values  ---------*/
#define L3_TRANSMIT_START_ARPS     9
#define L3_TRANSMIT_GETSTREAM      10
#define L3_TRANSMIT_GETSTREAMCOUNT 11
#define L3_TRANSMIT_GETADDRESS     12

#define L3_RECEIVE_GETCAPTUREPACKET					1
#define L3_RECEIVE_SETCAPTURETYPE					2
#define L3_RECEIVE_TRACKING_TYPE						3
#define L3_RECEIVE_TRACKING_START					4
#define L3_RECEIVE_TRACKING_REPORT					5
#define L3_RECEIVE_ARPTIMES_REPORT					6
#define L3_RECEIVE_GETCAPTURECOUNT					7
#define L3_RECEIVE_TRACKING_ACTIVE_TEST			9
#define L3_RECEIVE_TRACKING_SUMMARY					12
#define L3_RECEIVE_TRACKING_LATENCY_PRECISION	14
#define L3_RECEIVE_GETCAPTUREPACKETS				18

/*-------- Layer 3 iType4 values  ---------*/
#define L3_RECEIVE_TRACKING_SEQUENCE            1
#define L3_RECEIVE_TRACKING_LATENCY             2
#define L3_RECEIVE_TRACKING_LATENCYPERSTREAM    3
#define L3_RECEIVE_TRACKING_LATENCYDISTRIBUTION 4
#define L3_RECEIVE_TRACKING_RAWTAGS             5
#define L3_RECEIVE_TRACKING_V2_LATENCY        	6
#define L3_RECEIVE_TRACKING_V2_LATENCYPERSTREAM 7
#define L3_RECEIVE_TRACKING_TCP_ISP             8
#define L3_RECEIVE_TRACKING_MC_LATENCYPERSTREAM 9
#define L3_RECEIVE_TRACKING_32_LATENCYPERSTREAM 10
#define L3_RECEIVE_TRACKING_V2_LATENCYDISTRIBUTION 11
#define L3_RECEIVE_TRACKING_JITTER_COMBO           14
#define NS_RECEIVE_TRACKING_MC_LATENCYPERSTREAM	15

/*-------- Layer 3 Capture params  ---------*/
#define L3_RECEIVE_CAPTURE_OFF                  0
#define L3_RECEIVE_CAPTURE_ALL                  1
#define L3_RECEIVE_CAPTURE_BADPACKETS           2
#define L3_RECEIVE_CAPTURE_SPECIAL              3
#define L3_RECEIVE_CAPTURE_TRIGGERS             4


typedef struct tagL3ModifyStream
	{
	unsigned long		ulIndex;
	unsigned long		ulCount;
	unsigned long		ulField;
	unsigned long		ulFieldCount;
	unsigned long		ulDelta;
	} L3ModifyStream;

typedef struct tagL3ModifyStreamArray
	{
	unsigned long		ulIndex;
	unsigned long		ulCount;
	unsigned long		ulField;
	unsigned long		ulFieldCount;
	unsigned long     ulFieldRepeat;
	unsigned long		ulData[L3_MODIFY_STREAM_ARRAY_SIZE];
	} L3ModifyStreamArray;

typedef struct tagLayer3_Tracking_Latency
	{
	unsigned long ulInterval;
	} Layer3_Tracking_Latency;

typedef struct tagLayer3_Tracking_Distribution
	{
	unsigned short uiInterval[16];
	} Layer3_Tracking_Distribution;

typedef struct tagLayer3_V2_Tracking_Distribution
	{
	unsigned long ulInterval[16];
	} Layer3_V2_Tracking_Distribution;

typedef struct tagLayer3_TrackingActiveTest
	{
	unsigned long ulTest;
	unsigned long ulRecords;
	} Layer3_TrackingActiveTest;

typedef struct tagLayer3TagInfo
	{
	unsigned long ulStream;
	unsigned long ulSequence;
	unsigned long ulTransmitTime;
	unsigned long ulReceiveTime;
	} Layer3TagInfo;

/* ************************ */

typedef struct tagLayer3TrackingLatency
	{
	unsigned long ulInterval;
	} Layer3TrackingLatency;

typedef struct tagLayer3TrackingDistribution
	{
	unsigned short uiInterval[16];
	} Layer3TrackingDistribution;

typedef struct tagLayer3V2TrackingDistribution
	{
	unsigned long ulInterval[16];
	} Layer3V2TrackingDistribution;

typedef struct tagLayer3TrackingActiveTest
	{
	unsigned long ulTest;
	unsigned long ulRecords;
	} Layer3TrackingActiveTest;


typedef struct tagLayer3MulticastCounters
	{
	unsigned long   ulTxFrames;
   unsigned long   ulTxJoinGroups;
   unsigned long   ulTxLeaveGroups;
   unsigned long   ulRxFrames;
   unsigned long   ulRxUnknownType;
   unsigned long   ulRxIpChecksumErrors;
   unsigned long   ulRxIgmpChecksumErrors;
   unsigned long   ulRxIgmpLengthErrors;
   unsigned long   ulRxWrongVersionQueries;
   unsigned char   reserved[96];
	} Layer3MulticastCounters;



#define L3_STREAM_UDPDHCP			  STREAM_PROTOCOL_UDPDHCP		/* a UDPDHCP Stream type */
#define L3_DEFINE_UDPDHCP_STREAM					NS_DEFINE_UDPDHCP_STREAM	/* Create a list with one or more UDPDHCP compliant Tx Streams. */
                                                                    /* Clears previous streams, disables first stream (at index zero "0.")*/
#define L3_DEFINE_MULTI_UDPDHCP_STREAM				NS_DEFINE_MULTI_UDPDHCP_STREAM	/* Append similar copies of a UDPDHCP Stream */
#define L3_MOD_UDPDHCP_STREAM							NS_MOD_UDPDHCP_STREAM	/* Overwrite one UDPDHCP Stream in the list at a given index */


/* old names for L3StreamExtension, ucIPManipulateMode */
#define IP_INC_IP_AND_MAC_DST    0x17
#define IP_INC_IP_AND_MAC_SRC    0x18
#define IP_DEC_IP_AND_MAC_DST    0x19
#define IP_DEC_IP_AND_MAC_SRC    0x1A

/* old "L3" counters for POS/3201--use ETHExtendedCounterInfo instead */
typedef struct tagL3StatsInfo{
	U64				u64RxVlanFrames;
	U64				u64RxIPFrames;
	U64				u64IPChecksumError;
	unsigned long	ulArpReplySent;
	unsigned long	ulArpReplyRecv;
	unsigned long	ulArpRequestSent;
	unsigned long	ulArpRequestRecv;
	unsigned long	ulPingReplySent;
	unsigned long	ulPingReplyRecv;
	unsigned long	ulPingRequestSent;
	unsigned long	ulPingRequestRecv;
	unsigned long	ulRxStackCount;
	unsigned long	ulTxStackCount;
   U64            u64RxDataIntegrityError;
   U64            u64RxSignatureFrames;
   U64            u64TxSignatureFrames;
	unsigned long	ulReserved[2];
} L3StatsInfo;

#define L3_READ_COUNTERS			0x0613

#define L3_MAX_GROUPS				100	/* replaced by L3_MAX_GROUP_SIZE */




#endif

