/*****************************************************************************
 * mplsitems.h
 * iType1 and data structure definitions for the MPLS commands.
 * These are visible to the user.
 *
 * Copyright (c) 1993-2001, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/
#ifndef _MPLSITEMS_H_
#define _MPLSITEMS_H_


#define  MPLS_BASE_NUM                  0x9800


/* MPLS iTypes */
#define MPLS_START							(MPLS_BASE_NUM + 2)		/* Starts MPLS signalling */
#define MPLS_LSP_NOT_COMPLETE				(MPLS_BASE_NUM + 3)		/* Checks whether all LSP's have been established*/

#define MPLS_ROUTING_DOMAIN_CREATE			(MPLS_BASE_NUM + 5)		/* Configures MPLS interface */
#define MPLS_ROUTING_DOMAIN_DELETE_ALL		(MPLS_BASE_NUM + 6)		/* Deletes MPLS interface */

#define MPLS_LSP_CREATE						(MPLS_BASE_NUM + 8)		/* Creates LSP's */
#define MPLS_CREATE_SINGLE_LSP				(MPLS_BASE_NUM + 9)		/* Create one LSP at a time */

#define MPLS_LSP_DELETE_ALL					(MPLS_BASE_NUM + 10)	/* Delete all LSP's */

#define MPLS_SERVICE_OBJECT_CREATE			(MPLS_BASE_NUM + 13)	/*Creates Service Object */
#define MPLS_OPAQUE_OBJECT_CREATE			(MPLS_BASE_NUM + 14)	/*Creates Opaque Object */	
#define MPLS_ATTRIBUTE_OBJECT_CREATE		(MPLS_BASE_NUM + 15)	/*Creates Attribute Object */
#define MPLS_EXPLICIT_ROUTE_OBJECT_CREATE	(MPLS_BASE_NUM + 17)	/*Creates Explicit Object */
#define MPLS_LSP_COPY_DELTA					(MPLS_BASE_NUM + 18)	/*Copies an existing LSP */
#define MPLS_LABEL_DATA_INFO				(MPLS_BASE_NUM + 19)	/*Gets Labels for all LSP's on a Routing Domain*/
#define MPLS_RSVP_COUNT_INFO				(MPLS_BASE_NUM + 20)	/*Gets RSVP information on a Routing Domain*/
#define MPLS_LSP_INFO						(MPLS_BASE_NUM + 21)	/*Gets status for an LSP*/
#define MPLS_LSP_BIND_STREAMS				(MPLS_BASE_NUM + 22)	/*Binds streams to an LSP*/
#define MPLS_OBJECT_DELETE					(MPLS_BASE_NUM + 23)	/*Removes objects in Object Pool*/
#define MPLS_LSP_COUNT_INFO					(MPLS_BASE_NUM + 25)	/* Number of LSP's in a Routing Domain */
#define MPLS_LDP_TEST						(MPLS_BASE_NUM + 26)	/* Added for Firmware testing */


/*********************************************************************************
 * Structure:   MPLSStart
 * iType1:      MPLS_START
 * Function:    HTSetStructure
 * Description: Starts MPLS signalling.Call after all of MPLS
 *				Configurations have been done. 
 **********************************************************************************/
typedef struct tagMPLSStart
{
     unsigned long ulPacketRate;       /* Per second, required packet per second.
										Minimum is 1 */
     unsigned char ucReserved[8];    

}MPLSStart;

/*********************************************************************************
 * Structure:   MPLSISLSPComplete
 * iType1:      MPLS_LSP_NOT_COMPLETE
 * Function:    HTGetStructure
 * Description: Returns information on whether all LSP's have been established.
 *				If it returns zero, this function should not be called again.
 *
 **********************************************************************************/
typedef struct tagMPLSISLSPComplete
{
      unsigned long ulCount;		/* Number of uncompleted LSP's */

}MPLSLSPNotComplete;

/*********************************************************************************
 * Structure:   MPLSRoutingDomainCreate
 * iType1:      MPLS_ROUTING_DOMAIN_CREATE
 * Function:    HTSetStructure
 * Description: Use this command to create one or more Routing Domains 
 *				for a given port. 
 *				Use this command before adding objects and before creating LSP's.
 *
 **********************************************************************************/

typedef struct tagMPLSRoutingDomain
{
    
    unsigned long ulOptions;				/*	MPLS-RSVP_UDP_ENABLE,
												MPLS_RSVP_REFRESH_REDUCTION_CAPABLE,
												MPLS_RSVP_PHP_ENABLE */        
	unsigned char ucLocalIPAddress[4];		/* IP Address of this Routing Domain */				
    unsigned char ucPeerIPAddress[4];		/* The destination IP of the MPLS 
											frame. This is the next MPLS hop, 
											not the final IP destination. */
    unsigned char ucLocalNetMask[4];		/* IP NetMask of this Routing Domain */
    unsigned long ulMaxLSPRequest;			/* Maximum LSP's on Ingress */                    
    unsigned long ulMaxLSPDistribution;		/* Maximum number of Egress distribution 
											frames per second (if used), per Routing 
											Domain */                    
    unsigned long ulMeanRefreshInterval;	/* Number of milli-seconds between refresh message
											frames. Default is 0 */ 
	
	unsigned short uiRSVPRetransmitDelay;	/* Delay for first transmission, default is 5000(5s)
											Units is in milli-seconds */
	unsigned short uiRSVPRetransmitDelta;	/* Time to retransmit again, default is 1s 
											Units is in milli-seconds */
	unsigned short uiRSVPMaxRetransmitCount;/* Maximum retransmit count, default is 3 */
    
	unsigned long ulSummaryMessageTime;
	unsigned long ulBundleMessageTime;

	unsigned long ulRoutingDomainIndex;
	unsigned long ulReserved[48];

}MPLSRoutingDomain;

#define MPLS_RSVP_UDP_ENABLE                    0x00000001  /* RSVP packet will be carried by UDP */
#define MPLS_RSVP_REFRESH_REDUCTION_CAPABLE     0x00000002  
#define MPLS_RSVP_INTERFACE_LABEL				0x00000004 /* label is per interface rather than plateform */
#define MPLS_RSVP_PHP_ENABLE					0x00000008 /* Enable PHP mode */
#define MPLS_RSVP_REFRESH_ACK_DESIRED           0x00000010
#define MPLS_RSVP_ENABLE_BUNDLE_MSG             0x00000100


/*********************************************************************************
 * Structure:   MPLSRoutingDomainDeleteAll
 * iType1:      MPLS_ROUTING_DOMAIN_DELETE_ALL
 * Function:    HTSetStructure
 * Description: Use this command to delete all Routing Domains (and related LSP's)
 *				on a given port. Optionally, this can be used to delete the 
 *				Routing Domains without deleting the LSP's..
 *
 **********************************************************************************/

typedef struct tagMPLSRoutingDomainDeleteAll
{
    
    
	unsigned long	ulPacketRate;       /* Packet per second, tear down speed */
    unsigned long	ulLeaveLSPs;		/* 0 - Delete LSP's also default, 1 - Delete 
										Routing Domain but leave related LSPs */
	unsigned char ucReserved[4];
}MPLSRoutingDomainDeleteAll;

/*********************************************************************************
 * Structure:   MPLSLSPCreate
 * iType1:      MPLS_LSP_CREATE
 * Function:    HTSetStructure
 * Description: Use this command to create one or more LSP's. This command 
 *				accepts one structure or an array of structures. Create
 *				the Rounting Domains with MPLS_ROUTING_DOMAIN_CREATE, 
 *				then create the related LSP(s). At this time, this command
 *				simple starts creating LSP's at index 0, and then appends to 
 *				the list of existing LSP each additional time it is called.
 *				It does not over-write or delete. Use the OBJECT_CREATE commands 
 *				before adding the objects here in the LSPObjectList is an array 
 *				containing object ID's and type of objects to bind to an
 *				LSP.
 *				Object Types - uiObjectType:
 *				MPLS_EXPLICIT_ROUTE_OBJECT		0
 *				MPLS_SERVICE_OBJECT				1
 *				MPLS_OPAQUE_OBJECT				3
 *				MPLS_FILTER_OBJECT				5
 **********************************************************************************/
#define MAX_OBJECTS							10

typedef struct tagMPLSObjectID
{
	unsigned short uiObjectType;		/* MPLS_EXPLICIT_ROUTE_OBJECT,
										MPLS_SERVICE_OBJECT,
										MPLS_OPAQUE_OBJECT,
										MPLS_ATTRIBUTE_OBJECT,
										MPLS_FILTER_OBJECT */
	unsigned short uiObjectIndex;		/* Object Index, starts from 0,1,2.. */
}MPLSObjectID;


typedef struct tagMPLSLSP
{
	
	unsigned long ulRoutingDomainIndex;		/* The RoutingDomain must be configured before
											the related LSP is configured */
	
	unsigned short uiIngressLSPOptions;		/* MPLS_RSVP_RECORD_ROUTE */
	unsigned char ucEgressIP[4];			/*	For each ingress LSP that is defined, a corresponding egress LSP
											is automatically created. This information is used to create the corrasponding 
											Egress LSP.	*/
    unsigned short uiTunnelID;				/* Id used for establishing LSP tunnel */
    unsigned long ulExtendedTunnelID;		/*	Id used for establishing LSP external tunnel */	
	unsigned short uiNumberOfObjects;		/* Number of objects that will bind to this LSP */
	MPLSObjectID ObjectList[MAX_OBJECTS];	/* Objects on this LSP */
	unsigned long ulLSPIndex;
	unsigned char ucReserved[4];

}MPLSLSP;

#define MPLS_RSVP_RECORD_ROUTE					0x0001
/*********************************************************************************
 * Objects
 **********************************************************************************/

#define MPLS_EXPLICIT_ROUTE_OBJECT              0
#define MPLS_SERVICE_OBJECT                     1
#define MPLS_OPAQUE_OBJECT                      3
#define MPLS_ATTRIBUTE_OBJECT                   4
#define MPLS_FILTER_OBJECT                      5

/*********************************************************************************
 * Structure:   MPLSLSPDeleteAll
 * iType1:      MPLS_LSP_DELETE_ALL
 * Function:    HTSetStructure
 * Description: Use this command to delete all LSP's on a given routing domain.
 *
 **********************************************************************************/
typedef struct tagMPLSLSPDeleteAll
{
	unsigned long ulPacketRate;			/* Packets per second, teardown rate */
	unsigned char ucReserved[4];

}MPLSLSPDeleteAll;


/*********************************************************************************
 * Structure:   MPLSServiceObjectCreate
 * iType1:      MPLS_SERVICE_OBJECT_CREATE
 * Function:    HTSetStructure
 * Description: This command supports creating an array of Service Objects.
 *				The terms "Object" (for RSVP) and "TLV" (for LDP) are equivilants. 
 *				SmartLib simply uses the term "Object." Note that there are 
 *				three different service objects to choose from. The uiObjectType 
 *				field determines which field values are needed. Some "Objects" 
 *				are specific to RSVP or LDP. Configure the desired Objects.
 *				Then use MPLS_LSP_CREATE to specify which 
 *				Objects are to be used for a given LSP. MPLS_LSP_CREATE 
 *				supports sending an array of different Objects. 
 *				When modifying an existing object, IType2 is used for the object ID.
 **********************************************************************************/
typedef struct tagMPLSServiceObject
{
	unsigned short uiObjectType;	/*	RSVP_SERVICE_COS_OBJECT,
										RSVP_SERVICE_CONTROLLED_LOAD_OBJECT,
										RSVP_SERVICE_GUARANTEED_OBJECT */									

    unsigned short uiMaxPacketSize;	/* bytes, RFC-2211, COS, Controlled, or Guaranteed object type.*/
										

    unsigned char ucCOS;			/* 0-7 - for COS(class of service) object type. */
										
   
	float fTokenBucketRate;			/* bytes per second */
									
    float fTokenBucketSize;			/* bytes */
									
    float fPeakDataRate;			/* bytes per second */
									
    unsigned long ulMinPoliceUnit;	/* guaranteed QoS. */
								
    float fRate;					/* bytes per second, Guaranteed QoS.*/
									
    unsigned long ulSlackTerm;		/* number of micro seconds,Guaranteed QoS object type. */									

	unsigned long ulServiceObjectID;
	unsigned char ucReserved[32];


}MPLSServiceObject;

#define MPLS_RSVP_SERVICE_COS_OBJECT					1
#define	MPLS_RSVP_SERVICE_CONTROLLED_LOAD_OBJECT		2
#define	MPLS_RSVP_SERVICE_GUARANTEED_OBJECT				3		


/*********************************************************************************
 * Structure:   MPLSOpaqueObjectCreate
 * iType1:      MPLS_OPAQUE_OBJECT_CREATE
 * Function:    HTSetStructure
 * Description: The "Opaque" object is used in MPLS as a custom object.  Opaque 
 *				objects can also be used to create objects which SmartLib does not 
 *				support, such as the Policy object.
 *				When modifying an existing object, IType2 is used for the object ID.
 **********************************************************************************/
typedef struct tagMPLSOpaqueObject
{
	unsigned short uiLength;		/* size of object */		
	unsigned char ucClassNumber;		
	unsigned char ucClassType;		/* object type */		
	unsigned char ucContents[128];	/* object contents */
	unsigned long ulOpaqueObjectID;
	unsigned char ucReserved[32];		

}MPLSOpaqueObject;

#define MPLS_RSVP_OPAQUE					1

/*********************************************************************************
 * Structure:   MPLSAttributeObjectCreate
 * iType1:      MPLS_ATTRIBUTE_OBJECT_CREATE
 * Function:    HTSetStructure
 * Description: This command supports creating an array of Attribute Objects. 
 *				When modifying an existing object, IType2 is used for the object ID.
 *
 **********************************************************************************/
#define MAX_OBJ_BUFF_SIZE                       100
typedef struct tagMPLSAttributeObject
{
    unsigned char ucSetupPriority;				/* (0-7) priority for setup */
	unsigned char ucHoldPriority;				/* (0-7)*/
	unsigned char ucOptions;					/* MPLS_RSVP_ATTRIBUTE */
	unsigned char ucNameLength;					/* length of tunnel name */
	unsigned char ucName[MAX_OBJ_BUFF_SIZE];	/* name of tunnel */  
												
	unsigned long ulAttributeObjectID;
	unsigned char ucReserved[32];

}MPLSAttributeObject;

#define MPLS_RSVP_ATTRIBUTE				1



/*********************************************************************************
 * Structure:   MPLSExplicitObjectCreate
 * iType1:      MPLS_EXPLICIT_ROUTE_OBJECT_CREATE
 * Function:    HTSetStructure
 * Description: This command supports creating an array of Filter Objects. 
 *				When modifying an existing object, IType2 is used for the object ID.
 **********************************************************************************/
typedef struct tagMPLSExplicitObject
{
	unsigned short uiExplicitRouteType;	/* EXPLICIT_ROUTE_IPV4 supported 
											EXPLICIT_ROUTE_IPV6 not supported
											EXPLICIT_ROUTE_AS not supported
											EXPLICIT_ROUTE_LSP_ID not supported */
	unsigned char ucIPAddress[16];		/*IP Address of Router/Intermediate Hop */
										
	unsigned char ucLoose;				/*It Indicates whether intermidiate 
										Router/Hop must  follow the given path or 
										not */
	unsigned char ucPrefix;				/* Network mask prefix..related with IP Address */			
	unsigned char ucFlags;				/* specify whether to use RSVP or CR-LDP (LDP) 
										at each router. 1 - RSVP ONLY, 0 - any protocol
										Default is 0 */
             
	unsigned long ulExplicitObjectID;
	unsigned char ucReserved[32];	
}MPLSExplicitObject;

#define MPLS_EXPLICIT_ROUTE_IPV4                            0x0001
#define MPLS_EXPLICIT_ROUTE_IPV6                            0x0002
#define MPLS_EXPLICIT_ROUTE_AS                              0x0003
#define MPLS_EXPLICIT_ROUTE_LSP_ID                          0x0004

/*********************************************************************************
 * Structure:   MPLSLSPCopyDelta
 * iType1:      MPLS_LSP_COPY_DELTA
 * Function:    HTSetStructure
 * Description: This command uses an existing LSP as the prototype to create additional
 *	LSP's. New LSP indexes begin at the source LSP index + 1. The second parameter(iType2)
 *  is the index of the source LSP. The third parameter(iType3) is the number of additional
 *  LSP's to create.
 *	For fields that support incrementing, a value of 1 or more 	increments the field in the 
 *	following LSP by that field value.
 *	For example: 
 *	The value of the example field is 2.
 *	The value of the COPY_DELTA field is 2.
 *	The resulting field in the each new LSP is 4, 6, 8, 10, ...
 *	A value of 0 leaves the field the same value as the source LSP. All
 *	fields not listed in the structure remain the same.
 *
 **********************************************************************************/
typedef struct tagMPLSLSPCopyDelta
{
    unsigned char	ucEgressIp[4];			/* Enter value to increment field by.*/
    unsigned long	ulExtendedTunnelID;		/* Enter value to increment field by.*/
    unsigned short	uiTunnelID;				/* Enter value to increment field by.*/     
	unsigned char	ucReserved[50];

}MPLSLSPCopyDelta;

/*********************************************************************************
 * Structure:   MPLSRoutingDomainLabelInfo
 * iType1:      MPLS_LABEL_DATA_INFO
 * Function:    HTGetStructure
 * Description: This command gets LSP labels for one Routing Domain(Interface). 
 *				Its  called after MPLS_ISLSP_COMPLETE. Routing Domain Index is put 
 *				in Itype2. Use MPLS_LSP_COUNT_INFO to get the number of LSP's on
 *				that Routing Domain, so you can allocate the correct storage to
 *				receive the data.
 **********************************************************************************/

typedef struct tagMPLSLabelDataInfo
{
	unsigned long  ulLSPIndex;					/* Index of LSP's */
	unsigned long  ulLabel;						/* Label on LSP */          

}MPLSLabelDataInfo;

/*********************************************************************************
 * Structure:   MPLSRSVPCountInfo
 * iType1:      MPLS_RSVP_COUNT_INFO
 * Function:    HTGetStructure
 * Description: This command gets statistical counters on a Routing Domain. 
 *				Itype2 is input for Routing Domain Index.
 **********************************************************************************/

typedef struct tagMPLSRSVPCountInfo
{
    unsigned long ulType;
	unsigned long ulResvIn;			/* number of reservation in received */
    unsigned long ulPathIn;			/* number of path in */
    unsigned long ulResvTearIn;
    unsigned long ulPathTearIn;
    unsigned long ulResvErrorIn;
    unsigned long ulPathErrorIn;
    unsigned long ulAckIn;
    
    unsigned long ulResvOut;
    unsigned long ulPathOut;
    unsigned long ulResvTearOut;
    unsigned long ulPathTearOut;
    unsigned long ulResvErrorOut;
    unsigned long ulPathErrorOut;
    unsigned long ulAckOut;

    unsigned long ulLSPIngress;
    unsigned long ulLSPEgress;
    unsigned long ulLabelIn;
    unsigned long ulLabelOut;

    unsigned long ulCardTimeStamp; 
	unsigned char ucReserved[32];
}MPLSRSVPCountInfo;

/*********************************************************************************
 * Structure:   MPLSLSPInfo
 * iType1:      MPLS_LSP_INFO
 * Function:    HTGetStructure
 * Description: This command gets information on a specific LSP. Lsp index
 *				is in iType2. Information on a  range of LSP's can
 *				also be obtained with this command. iType2 will the starting
 *				index, and iType3 the number of LSP's or range(excluding the starting LSP).	
 **********************************************************************************/

typedef struct tagMPLSLSPInfo
{
    unsigned long ulLabel;			/* Label on the LSP */
    unsigned char ucStatus;   /*	MPLS_LSP_NOT_INITIALIZED,
                                 MPLS_LSP_INITIALIZED,
                                 MPLS_LSP_SIGNALING,
                                 MPLS_LSP_ESTABLISHED,
                                 MPLS_LSP_DOWN */
    unsigned char ucReserved[7];
}MPLSLSPInfo;


#define MPLS_LSP_NOT_INITIALIZED          0x1
#define MPLS_LSP_INITIALIZED              0x2
#define MPLS_LSP_SIGNALING                0x3
#define MPLS_LSP_ESTABLISHED              0x4
#define MPLS_LSP_DOWN                     0x5

/*********************************************************************************
 * Structure:   MPLSLSPBindStreams
 * iType1:      MPLS_LSP_BIND_STREAMS
 * Function:    HTsetStructure
 * Description: This binds SmartBits streams to an LSP.Itype2 is the input for 
 *              the index of the LSP. uiStreamIndex will contain the streamindexes
 *				of the streams that will bind to the LSP. It can be an array
 *				containing the streamindexes
 **********************************************************************************/

typedef struct tagMPLSLSPBindStreams
{
	unsigned short uiStreamIndex;  /* StreamIndex or StreamIndexes */

}MPLSLSPBindStreams;

/*********************************************************************************
 * Structure:   MPLSObjectRemove
 * iType1:      MPLS_OBJECT_DELETE
 * Function:    HTSetStructure
 * Description: This command removes all the objects for a particular object Type. 
 **********************************************************************************/
typedef struct tagMPLSObjectDelete
{
    unsigned short uiObjectType;	/* Type of Object to remove, all objects of this type
									will be removed. Possible values are:
									MPLS_EXPLICIT_ROUTE_OBJECT              0
									MPLS_SERVICE_OBJECT                     1
									MPLS_OPAQUE_OBJECT                      3
									MPLS_ATTRIBUTE_OBJECT                   4 */
	
	unsigned char ucReserved[4];

}MPLSObjectDelete;

/*********************************************************************************
 * Structure:   MPLSLSPCountInfo
 * iType1:      MPLS_LSP_COUNT_INFO
 * Function:    HTGetStructure
 * Description: This command gives the number of LSP's on a Routing Domain. 
 *				The index for the Rounting Domain is put in iType2.
 *				This command is called first to determine the number of LSP's in a
 *				Routing Domain before calling MPLS_LABEL_DATA_INFO so users can set 
 *				aside enough memory space.
 **********************************************************************************/
typedef struct tagMPLSLSPCountInfo
{
    unsigned long ulLSPCount;		/* Number of LSP's on the Routing Domain */

}MPLSLSPCountInfo;

/*********************************************************************************
 * Structure:   MPLSLDPTest
 * iType1:      MPLS_LDP_TEST
 * Function:    HTSetStructure
 * Description: This command is a temporal added for firmware testing it will be
 *				later. 
 * **********************************************************************************/
typedef struct tagMPLSLDPTest
{
    unsigned long ulTest; 
}MPLSLDPTest;

#endif


