/*
	Copyright (c) 1993-2003, Spirent Communications of Calabasas, Inc.
	Netcom Systems, Inc.
	Copyright (C) 1999. All Rights Reserved.
*/


#ifndef _NSSTREAMITEMS_H_
#define _NSSTREAMITEMS_H_

#include "nsitems.h"

#define NS_MAX_STREAM_CONFIG_OBJECTS   30000
#define NS_MAX_STREAMS                 30000
#define NS_MAX_HEADERS                 500

#define NS_APPEND 0
#define NS_INSERT 1

typedef struct tagNSStreamConfig
{
   int 		      iStreamConfigID;	/* unique stream configuration ID */
	unsigned char 	ucOption;		   /* insert (NS_INSERT) or append (NS_APPEND) */
	unsigned short uiInsertIndex;		/* index of stream to insert after */
	unsigned short uiCount;		      /* number of streams to insert or append */
   unsigned char 	ucReserved[64];	/* Reserved */
} NSStreamConfig;

typedef struct tagNSCopyStreamInfo
{
   int 		      iStreamConfigID;	/* unique stream configuration ID */
	unsigned int 	uiStreamIndex;		/* index of the stream to copy */
	unsigned short uiCount;		      /* number of streams to copy */
   unsigned char 	ucReserved[64];	/* Reserved */
} NSCopyStreamInfo;

#define NS_VFD1   0
#define NS_VFD2   1

/* VFD modes */
#define NS_VFD_STATIC   0x00
#define NS_VFD_INCR		0x01
#define NS_VFD_DECR		0x02
#define NS_VFD_RANDOM	0x03
#define NS_VFD_OFF		0x04

typedef struct tagNSVFDConfig
{
   unsigned char  ucMode;           /* VFD modes (NS_VFD_STATIC, NS_VFD_INCR, NS_VFD_DECR, 
                                       NS_VFD_RANDOM or NS_VFD_OFF) */
   unsigned short uiOffset;         /* Offset of the VFD, in bits.  The VFD must fall within 
                                       the first 128 bytes of the frame.  Also, if the
                                       VFD falls in the last 18 bytes of the payload, and the 
                                       signature field is enabled, the signature field will 
                                       overwrite the VFD. */
   unsigned short uiRange;          /* Range (length) of the VFD, in bytes.  Valid ranges are 
                                       from 1 to 6 bytes. */
   unsigned long 	ulCycleCount;     /* For increment or decrement mode, the number of patterns
                                       before resetting to initial VFD pattern.  May range from 
                                       0 to 16777215.  If 0, the pattern will increment or 
                                       decrement through its entire range without resetting. */
   unsigned short uiBlockCount;     /* For increment or decrement mode, the number of frames that
                                       will repeat a pattern before incrementing or decrementing 
                                       to the next one.  May range from 0 to 4095.  When used with
                                       ulCycleCount each block of patterns only counts as one
                                       toward the cycle count. */
   unsigned char 	ucStepValue;      /* For increment or decrement mode, the amount to add or
                                       subtract from the previous pattern.  May range from 0 to
                                       255. Not available when ucSubnetAware is enabled.
                                       When the ucMode = NS_VFD_INCR and ucStepValue = 0, the 
                                       result will be static which means no change at all.
                                       When the ucMode = L3_VFD_INCR and ucStepValue = 1, the 
                                       result will be incrementing by step as 1. */
   unsigned char 	ucStepShift;      /* For increment or decrement mode, this field specifies the
                                       location in the pattern where the change will occur.  The
                                       ucStepShift is the number of bytes to shift the step value
                                       left before adding or subtracting from the previous
                                       pattern.  May range from 0 to 5, and is limited by the 
                                       range of the pattern. */
   unsigned char  ucEnableSubnetAware; /* Skip VFD patterns which are interpreted as subnet(0) or
                                       broadcast(255) addresses.  1 = enable, 0 = disable.
                                       NOTE:  This feature only works when uiRange is set to
                                       4 and ucStepValue is set to 1. */
   unsigned char 	ucSubnetMaskLength;     /* If ucSubnetAware is enabled, this is the number of 
                                          bits in the subnet mask. */
   unsigned char 	ucEnableCarryChaining;  /* For increment or decrement mode, this field enables 
                                          carry over from VFD1 to VFD2 on overflow or underflow.  
                                          1 = enable, 0 = disable.  To enable the feature, this 
                                          field must be set for both VFD1 and VFD2.  VFD2 will 
                                          remain static until VFD1 overflows or underflows.  At 
                                          that point, the next VFD pattern will begin (increment, 
                                          decrement, or random). */
   unsigned char  ucPattern[6];           /* Initial VFD pattern.  Note: the transmitted pattern 
                                          will start with the byte at index 0, even if the range 
                                          is less than 6 bytes. */
   unsigned char 	ucReserved[32];         /* Reserved */
} NSVFDConfig;

typedef struct tagNSTxConfig
{
	unsigned char	ucEnableStream;		         /* enable/disable the stream */
	unsigned long	ulFrameLength;			         /* frame length in bytes */
	unsigned long	ulFrameRate;			         /* rate in frames per second */
	unsigned char 	ucEnableSignatureField;	      /* enable/disable insertion of the 18 byte signature field */
	unsigned char	ucBackgroundIndex;		      /* Stream background to use.  Currently there 2 
                                                different background patterns available.  The pattern 
                                                for these backgrounds are defined using the 
                                                L3_WRITE_STREAM_BG command. */
	unsigned char 	ucEnableRandomBackground;	   /* enable/disable random background */
	unsigned char	ucEnableRandomLength;	      /* enable/disable random frame length */
	unsigned char 	ucEnableCustomStreamID;	      /* enable/disable setting the stream id field in 
                                                the signature field */
	unsigned long	ulCustomStreamID;		         /* Indicates the custom id value to use if
							                           ucEnableCustomStreamID is set to 1. */
	unsigned short	uiInitialSignatureSeqNumber;  /* Initial value for the sequence number field in
							                           signature field */						
   unsigned char	ucEnableDataIntegrity;		   /* enable/disable insertion of the data integrity
                                                marker */
	unsigned char 	ucEnableDataIntegrityError;	/* enable/disable data integrity error generation */
	unsigned char	ucEnableIPChecksumError;	   /* enable/disable IP checksum error generation */
	unsigned char 	ucEnableCRCError;		         /* enable/disable CRC error generation */
	unsigned char	ucEnableIPTotalLengthError;	/* enable/disable IP length error generation */
   unsigned char   ucOAMHeaderPacketType;       /* defined constants:
                                                	OAM_PACKET_TYPE_NONE_OAM
                                                	OAM_PACKET_TYPE_NORMAL_OAM 
                                                	OAM_PACKET_TYPE_IDLE_OAM  */
	unsigned char	ucEnableMulticastKeepAlive;   /* enable/disable multicast keep alive
	                                                 1 - enable, 0 - disable (default)
	                                                 for TM LAN/POS modules only
	                                                 used with command NS_MULTICAST_KEEP_ALIVE_CONFIG */
	unsigned char	ucDisableProtocolCheck;       /* Reserved */
   unsigned char 	ucReserved[127];              /* Reserved */
} NSTxConfig;

typedef struct tagNSCreateHeaderInfo
{
	int            iStreamConfigID;  /* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to create this header for */
	unsigned char  ucOption;	      /* insert (NS_INSERT) or append (NS_APPEND) */
	unsigned short uiInsertIndex;	   /* index of protocol header to insert after */
	unsigned short uiCount;	         /* number of streams to insert or append a header for */
	unsigned short uiProtocolType;	/* The type of protocol header to create (e.g. NS_IPV4_HEADER) */
   unsigned char  ucReserved[32];   /* Reserved */
} NSCreateHeaderInfo;

typedef struct tagNSUpdateHeaderInfo
{
	int            iStreamConfigID;	/* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream containing the protocol header to update */
	unsigned short uiHeaderIndex; 	/* index of the protocol header to update */
	unsigned short uiCount;	         /* number of streams to update the header for */
	unsigned short uiProtocolType;	/* The protocol type of the header specified by uiHeaderIndex
                                    (e.g. NS_IPV4_HEADER) */
   unsigned char  ucReserved[32];  	/* Reserved */
} NSUpdateHeaderInfo;

typedef struct tagNSCopyHeaderInfo
{
	int            iStreamConfigID;	/* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream containing the protocol header to copy */
	unsigned short uiHeaderIndex; 	/* index of the protocol header to copy */
	unsigned short uiCount;	         /* number of streams to copy the header for */
	unsigned short uiProtocolType;	/* The protocol type of the header specified by 
                                    uiHeaderIndex (e.g. NS_IPV4_HEADER) */
  	unsigned char  ucReserved[32];  	/* Reserved */
} NSCopyHeaderInfo;

typedef struct tagNSGetHeaderInfo
{
	int            iStreamConfigID;	/* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream containing the protocol header to update */
	unsigned short uiHeaderIndex; 	/* index of the protocol header to update */
	unsigned short uiCount;	         /* number of streams to retrieve the header for */
	unsigned short uiProtocolType;	/* The protocol type of the header specified by uiHeaderIndex */
   unsigned char  ucReserved[32];   /* Reserved */
} NSGetHeaderInfo;

typedef struct tagNSHeaderStackInfo
{
	/* input */
	int            iStreamConfigID;           /* unique stream configuration ID */
	unsigned short uiStreamIndex;	            /* index of the stream to get information for */

	/* output */
	unsigned short uiHeaderCount; 	         /* The number of protocol headers in the stream's protocol stack. */
	unsigned short uiHeader[NS_MAX_HEADERS];	/* Contains information about the protocol type for the 
                                                different headers that make up the stream's protocol 
                                                stack.  "uiHeader[0]" is the protocol type for the 
                                                first header in the stack. */
   
   unsigned char  ucReserved[32];  	         /* Reserved */
} NSHeaderStackInfo;

typedef struct tagNSUpdateTxConfigInfo
{
	int            iStreamConfigID;  /* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to update */
	unsigned short uiCount; 		   /* the number of streams to update the transmit settings for */
   unsigned char  ucReserved[32];   /* Reserved */
} NSUpdateTxConfigInfo;

typedef struct tagNSCopyTxConfigInfo
{
	int            iStreamConfigID;  /* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to update */
	unsigned short uiCount; 		   /* the number of streams to copy the transmit settings for */
   unsigned char  ucReserved[32];  	/* Reserved */
} NSCopyTxConfigInfo;

typedef struct tagNSGetTxConfigInfo
{
	int            iStreamConfigID;  /* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to update */
	unsigned short uiCount; 		   /* the number of streams to retrieve the transmit settings for */
   unsigned char  ucReserved[32];   /* Reserved */
} NSGetTxConfigInfo;

typedef struct tagNSUpdateVFDInfo
{
	int            iStreamConfigID;  /* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to update */
	unsigned char  ucVFD;		      /* VFD to update (NS_VFD1, NS_VFD2) */ 
	unsigned short uiCount; 		   /* the number of streams to update the VFD settings for */
   unsigned char  ucReserved[32];   /* Reserved */
} NSUpdateVFDInfo;

typedef struct tagNSGetVFDInfo
{
	int            iStreamConfigID;	/* unique stream configuration ID */
	unsigned short uiStreamIndex;	   /* index of the stream to update */
	unsigned char  ucVFD;		      /* VFD to update (NS_VFD1, NS_VFD2) */ 
	unsigned short uiCount; 		   /* the number of streams to retrieve the VFD settings for */
   unsigned char  ucReserved[32];  	/* Reserved */
} NSGetVFDInfo;

typedef struct tagNSCommitStreamConfig
{
	int            iStreamConfigID;  /* unique stream configuration ID for the object to commit */
	int            iHub;             /* hub number */
	int            iSlot;            /* slot number */
	int            iPort;            /* port number */
   unsigned char  ucReserved[32];   /* Reserved */
} NSCommitStreamConfig;


// -------------------------------------------
// Protocol header structures and constants
// -------------------------------------------

#define NS_ETHERNET_HEADER                1
#define NS_VLAN_HEADER                    2
#define NS_IPV4_HEADER                    3
#define NS_IPV4_OPTION_HEADER             4
#define NS_IPV6_HEADER                    5
#define NS_TCP_HEADER                     6
#define NS_UDP_HEADER                     7
#define NS_CUSTOM_HEADER                  8  
#define NS_ICMP_HEADER                    9
#define NS_MPLS_HEADER                    10
#define NS_IPV6_EXT_HOP_BY_HOP_HEADER     11
#define NS_IPV6_EXT_FRAGMENT_HEADER       12
#define NS_IPV6_EXT_DESTINATION_HEADER    13
#define NS_IPV6_EXT_ROUTING_HEADER        14
#define NS_IPV6_EXT_AUTHENTICATION_HEADER 15
#define NS_IPV6_EXT_ESP_HEADER            16
#define NS_IPX_HEADER                     17
#define NS_ATM_HEADER                     18
#define NS_PPP_HEADER                     19
#define NS_GRE_HEADER                     20

// constants only used in NSStreamMultiConfig
#define NS_TX_CONFIG                      21
#define NS_VFD1_CONFIG                     22
#define NS_VFD2_CONFIG                     23

typedef struct tagNSEthernetHeader
{
	unsigned char	ucSourceMAC[6];
	unsigned char	ucDestinationMAC[6];
	unsigned char	ucEnableLength;      /* 0 indicates to insert the "Protocol Type" 
                                       field after the source MAC address in the 
                                       ethernet header.  1 indicates to insert the
                                       "Length" field after the source MAC address.
                                       The "Length" field is required to support
                                       802.2 and SNAP headers that may follow the
                                       ethernet header
                                       */
	unsigned char	ucReserved[15];     
} NSEthernetHeader;

#define NS_VLAN_LIST_SIZE   32

typedef struct tagNSVLANHeader
{
	unsigned short uiTPID; 	         /* VLAN type (e.g. 0x8100) */
	unsigned char 	ucPRI;	         /* user priority 0-7 (3 bits) */
	unsigned char	ucCFI;	         /* 1 = RIF present, 0 = RIF absent (1 bit) */
	unsigned short	uiVID;	         /* VLAN ID (12 bits) */
	unsigned char	ucReserved[8];    /* Reserved */     
} NSVLANHeader;

typedef struct tagNSVLANHeaderList
{
	unsigned short uiCount;                      /* Number of VLANs (VLAN) to configure */
   NSVLANHeader   Header[NS_VLAN_LIST_SIZE];    /* VLAN headers */
   unsigned char ucEnableCustomEthernetType; /* Indicates whether to use a 
                                                custom ethernet type */
   unsigned short uiCustomEthernetType;   /* Specify custom ethernet type to use
                                             if ucEnableCustomEthernetType
                                             is enabled */
   unsigned char ucReserved[13];               /* Reserved */     
} NSVLANHeaderList;

typedef struct tagNSIPv4Header
{
	unsigned char	ucTypeOfService;
	unsigned char	ucTimeToLive;
	unsigned short	uiInitialSequenceNumber;
	unsigned char	ucDestinationIP[4];
	unsigned char	ucSourceIP[4];
	unsigned char	ucNetmask[4];
	unsigned char	ucGateway[4];
	unsigned char	ucProtocol; 
	unsigned short	uiFragmentOffset;
	unsigned char	ucFlags;
	unsigned char	ucReserved[16];      
} NSIPv4Header;

typedef struct tagNSIPv4OptionHeader
{
	unsigned char	ucCode;		      /* Type of IP Option,
                               			IP_OPTION_RECORD_ROUTE
                               			IP_OPTION_LOOSE_SOURCE_RECORD_ROUTE
                               			IP_OPTION_STRICT_SOURCE_RECORD_ROUTE */
	unsigned short	uiOptionLength;	/* Option Length,includes the option type code,
						                     length octet, pointer octet and route data */
	unsigned short	uiPointer;		   /* Pointer offset into Route data, bytes */
	unsigned short uiDataLength;	   /* number of bytes to use from ucData */
	unsigned char 	ucData[124];		/* Contains route data, for Record Route,
      						               LSRR and SSRR it may contain IP address */
	unsigned char	ucReserved[16];     /* Reserved */
} NSIPv4OptionHeader;

typedef struct tagNSIPv6Header
{
	unsigned char 	ucTrafficClass;
	unsigned char	ucNextHeader; 
	unsigned char 	ucHopLimit;
	unsigned long 	ulFlowLabel;
	unsigned char 	ucSourceIP[16];
	unsigned char 	ucDestinationIP[16];
	unsigned char	ucRouterIP[16];
	unsigned char	ucPayloadLengthError;
	unsigned char	ucReserved[16];
} NSIPv6Header;

typedef struct tagNSTCPHeader
{
	unsigned short	uiSourcePort;
	unsigned short	uiDestinationPort;
	unsigned long	ulSequence;
	unsigned long	ulAck;
	unsigned char	ucOffset;
	unsigned char	ucFlags;
	unsigned short	uiWindow;
	unsigned short	uiUrgentPointer;
	unsigned char	ucReserved[16];
} NSTCPHeader;

typedef struct tagNSUDPHeader
{
	unsigned short	uiSourcePort;
	unsigned short	uiDestinationPort;
	unsigned short	uiLength;
	unsigned char	ucReserved[16];
} NSUDPHeader;

typedef struct tagNSCustomHeader
{
	unsigned short	uiLength;         /* Number of bytes to use from ucPayload */
	unsigned char	ucPayload[128];   /* Custom data */
	unsigned char	ucReserved[16];   /* Reserved */
} NSCustomHeader;

typedef struct tagNSICMPHeader
{
	unsigned char  ucType;
   unsigned char 	ucCode;
   unsigned short uiIdentifier;
   unsigned char  ucReserved[16];
} NSICMPHeader;

#define NS_MPLS_LIST_SIZE 32

typedef struct tagNSMPLSHeader
{
 	unsigned long  ulLabel;					/* [bit 11- 31] */
	unsigned char  ucExperimentalUse;   /* [bit 8 - 11] */
	unsigned char  ucBottomStack;			/* [bit 7 - 8 ] */
   unsigned char  ucTimeToLive;			/* [bit 0 - 7 ] */
	unsigned char  ucReserved[8];	      /* Reserved */
} NSMPLSHeader;


typedef struct tagNSMPLSHeaderList
{
   unsigned short uiCount;	                     /* Number of MPLS headers/labels (MPLS) to configure */
	NSMPLSHeader   Header[NS_MPLS_LIST_SIZE];	   /* MPLS headers */
	unsigned char  ucReserved[16];	            /* Reserved */
} NSMPLSHeaderList;

typedef struct tagNSIPv6ExtHopByHopHeader
{
   unsigned char  ucNextHeader;   		      /* Identifies the type of header immediately 
                                					   following the Hop-by-Hop Options header.  
                                                Possible values: 

                                                   IPV6_EXT_NONE   
                                                   IPV6_EXT_HOP_BY_HOP
                                                   IPV6_EXT_FRAGMENT
                                                   IPV6_EXT_AUTHENTICATION
                                                   IPV6_EXT_ESP
                                                   IPV6_EXT_ROUTING_TYPE_0
                                                   IPV6_EXT_DESTINATION
                                             */
   unsigned char  ucHeaderExtensionLength;   /* Length of the Hop-by-Hop Options header 
                                                in 8-byte units, including all fields */
   unsigned char  ucOptionDataLength; 		   /* Length of the Option Data field of 
                                					   to be used, bytes */
   unsigned char 	ucOptionData[255];  	      /* Option-Type-specific data */  
  	unsigned char	ucReserved[16];            /* Reserved */
} NSIPv6ExtHopByHopHeader;

typedef struct tagNSIPv6ExtFragmentHeader
{
   unsigned char 	ucNextHeader;   	/* Identifies the type of header immediately 
                             				following the Fragment header.
                                       Possible values: 

                                          IPV6_EXT_NONE   
                                          IPV6_EXT_HOP_BY_HOP
                                          IPV6_EXT_FRAGMENT
                                          IPV6_EXT_AUTHENTICATION
                                          IPV6_EXT_ESP
                                          IPV6_EXT_ROUTING_TYPE_0
                                          IPV6_EXT_DESTINATION
                                    */
   unsigned short uiFragmentOffset; /* The offset, in 8-byte units, of the
                                   		data following this header is relative to
                                   		the start of the Fragment-able Part of 
                                   		the original packet. */
   unsigned char 	ucMFlag;          /* 1 = more fragments; 0 = last fragment */
   unsigned long 	ulIdentification; /* Unique Identification for packet that 
                                    	need to be fragmented*/ 
  	unsigned char  ucReserved[16];   /* Reserved */
} NSIPv6ExtFragmentHeader;

typedef struct tagNSIPv6ExtDestinationHeader
{
  	unsigned char ucNextHeader;   			/* Identifies the type of header immediately 
                                				   following the Destination  header.
                                             Possible values: 

                                                IPV6_EXT_NONE   
                                                IPV6_EXT_HOP_BY_HOP
                                                IPV6_EXT_FRAGMENT
                                                IPV6_EXT_AUTHENTICATION
                                                IPV6_EXT_ESP
                                                IPV6_EXT_ROUTING_TYPE_0
                                                IPV6_EXT_DESTINATION
                                          */
  	unsigned char ucHeaderExtensionLength; /* Length of the Destination header
                                         		in 8-byte units, including all fields */ 
  	unsigned char ucOptionDataLength;   	/* Length of the Option Data field of 
                                   				to be used, in bytes*/
  	unsigned char ucOptionData[255];       /* Option-Type-specific data*/ 
  	unsigned char ucReserved[16];          /* Reserved */
} NSIPv6ExtDestinationHeader;

typedef struct tagNSIPv6ExtRoutingHeader
{
   unsigned char ucNextHeader;   			/* Identifies the type of header 
           		                       		   immediately following the Routing header.
                                             Possible values: 

                                                IPV6_EXT_NONE   
                                                IPV6_EXT_HOP_BY_HOP
                                                IPV6_EXT_FRAGMENT
                                                IPV6_EXT_AUTHENTICATION
                                                IPV6_EXT_ESP
                                                IPV6_EXT_ROUTING_TYPE_0
                                                IPV6_EXT_DESTINATION
                                          */
   unsigned char ucHeaderExtensionLength; /* Length of the Routing header
                                      			in 8-byte units, including all
                                      			fields */
   unsigned char ucSegmentsLeft; 			/* Number of route segments remaining,
                                					i.e., number of explicitly listed 
                                					intermediate nodes still to be visited
                                					before reaching the final destination */
  	unsigned char ucNumAddress;  			   /* Number of addresses to use in IPAddress */
   NSIPv6Address IPAddress[20];   		   /* The maximum accepted number of addresses
                             					   for Terametrics LAN cards and for
                             					   Terametrics POS cards is 4 */
  	unsigned char ucReserved[16];          /* Reserved */
} NSIPv6ExtRoutingHeader;

typedef struct tagNSIPv6ExtAuthenticationHeader
{
  	unsigned char ucNextHeader; 			   /* Identifies the type of header immediately
                             					   following the Authentication header.
                                             Possible values: 

                                                IPV6_EXT_NONE   
                                                IPV6_EXT_HOP_BY_HOP
                                                IPV6_EXT_FRAGMENT
                                                IPV6_EXT_AUTHENTICATION
                                                IPV6_EXT_ESP
                                                IPV6_EXT_ROUTING_TYPE_0
                                                IPV6_EXT_DESTINATION
   
                                          */
  	unsigned char ucHeaderExtensionLength; /* Length of AH in 4-byte units, 
                          					      including all fields */  
  	unsigned long ulSPI; 				      /* Security Parameters index, an arbitrary value
                                             that, in combination with the destination IP 
                                             address and security protocol (AH), uniquely 
                                             identifies the security association for this 
                                             packet */
  	unsigned long ulSequenceNumber; 		   /* monotonically increasing counter value
                             					   (sequence number).  However, in this MRQ  
                             					   implementation, this field won't be 
                             					   incremented with each packet but a static 
                             					   value configured by user.  Or user may enable
                             					   a VFD field to do the increment. */
  	unsigned char ucAuthenticationDataLength; /* Length of Authenication Data field */
  	unsigned char ucAuthenticationData[255];  /* contains the Integrity 
                                         		   Check Value (ICV) for this packet */
  	unsigned char ucReserved[16];             /* Reserved */
} NSIPv6ExtAuthenticationHeader;

typedef struct tagNSIPv6ExtESPHeader
{
  	unsigned char ucNextHeader; 	      /* Identifies the type of header immediately
                            			      following the ESP header.  
                                          Possible values: 

                                             IPV6_EXT_NONE   
                                             IPV6_EXT_HOP_BY_HOP
                                             IPV6_EXT_FRAGMENT
                                             IPV6_EXT_AUTHENTICATION
                                             IPV6_EXT_ESP
                                             IPV6_EXT_ROUTING_TYPE_0
                                             IPV6_EXT_DESTINATION
                                       */ 
  	unsigned long ulSPI; 		         /* Security Parameters index, an arbitrary value that,
                      				         in combination with the destination IP address and
                      				         security protocol (ESP), uniquely identifies the 
                      				         security association for this packet */
  	unsigned long ulSequenceNumber; 	   /* monotonically increasing counter value
                             				   (sequence number).  However, in this MRQ
                             				   implementation, this field won't be incremented
                             				   with each packet but a static value configured
                             				   by user.  Or user may enable a VFD field to
                             				   do the increment. */
  	unsigned char ucPayloadDataLength;  /* Length of Payload Data field */
  	unsigned char ucPayloadData[255];  	/* a variable-length field 
                            				   containing data described by the Next Header 
                            				   field. The Payload Data field is mandatory and
                            				   is an integral number of bytes in length */
  	unsigned char ucPaddingLength;      /* Length in bytes of ucPadding */
  	unsigned char ucPadding[255];       /* The sender MAY add 0-255 bytes of padding.
                             			      Inclusion of the Padding field in an ESP 
                             			      packet is optional, Note: for Terametrics LAN
                             			      maximum accepted length is 74 bytes and for
                             			      POS TM is 84 bytes */
  	unsigned char ucAuthenticationDataLength; /* Length of Authenication Data field */
  	unsigned char ucAuthenticationData[255];  /* contains the Integrity 
                                   				   Check Value (ICV) for this packet */
  	unsigned char ucReserved[16];
} NSIPv6ExtESPHeader;

typedef struct tagNSIPXHeader
{
	unsigned short	uiIPXLength;
	unsigned char	ucHop;
	unsigned char	ucType;
	unsigned char	ucDestinationNetwork[4];
	unsigned char	ucDestinationHost[6];
	unsigned short	uiDestinationSocket;
	unsigned char	ucSourceNetwork[4];
	unsigned char	ucSourceHost[6];
	unsigned short	uiSourceSocket;
	unsigned char	reserved[16];
} NSIPXHeader;

typedef struct tagNSATMHeader
{
	unsigned short uiVCIndex; 
	unsigned short uiATMFlags; 
   	unsigned char  ucReserved[16];  
} NSATMHeader;

typedef struct tagNSPPPHeader
{
   unsigned char  ucReserved[16];  
} NSPPPHeader;



typedef struct tagNSGREHeader
{
  unsigned short uiProtocolType;     /* Protocol type of GRE payload, possible values are
														GRE_PAYLOAD_IPV4, GRE_PAYLOAD_IPV6 and GRE_PAYLOAD_IPX */
  unsigned char ucReserved[256];      /* Reserved field */ 
} NSGREHeader;

 

#define GRE_PAYLOAD_IPV4 0x0800
#define GRE_PAYLOAD_IPV6 0x08DD
#define GRE_PAYLOAD_IPX  0x8137

typedef struct tagNSStreamMultiConfigInfo {
	unsigned char ucMode;  /* Valid input
							NS_STREAM_MULTI_CONFIG_MODE_MOD
							    Modify one stream of the specified index.
								This mode is similar to L3_MOD_xx_STREAM.
								
							NS_STREAM_MULTI_CONFIG_MODE_COPY
                                Create one or multiple streams based on
								the stream of specified index.
								It appends similar copies of the existing
								stream. The values of the fields of the
								structures are delta values. A value of zero
								retains the current value of the structure
								member (as set for the original stream);
								otherwise the non-zero value is used as
								the amount by which to increment the
								structure member in each additional stream
								that is created (See User Manual for detail).
								This mode is similar to L3_DEFINE_MULTI_xx_STREAM.

							*/
	unsigned long ulStreamIndex; /*stream idex:
								index of the to-be-modified stream for MOD mode
								or
								index of base stream for COPY mode */
	unsigned long ulStreamCount; /* count of streams to config,
								valid only with COPY mode */
	unsigned char ucStructureCount;  /*	count of configuration structures,
									which are passed through the void  
									pointers "void* pHeaderDataX" of command
									NSStreamMultiConfig interface.
									valid range 1-16  */
	unsigned char ucStructureTypeArray[16]; /* array of the types of configuration 
									structures, in the order of which passed through
									the void pointers "void* pHeaderDataX" 
									of command NSStreamMultiConfig interface.
									valid type
										NS_ETHERNET_HEADER
										NS_VLAN_HEADER
										NS_IPV4_HEADER
										NS_IPV6_HEADER
										NS_TCP_HEADER
										NS_UDP_HEADER
										NS_ICMP_HEADER
										NS_ATM_HEADER
										NS_PPP_HEADER
										NS_TX_CONFIG */
	unsigned int uiStructureSizeArray[16];  /*array of the size of the configuration
									structures, which are passed through the void
									pointers "void* pHeaderDataX" of command
									NSStreamMultiConfig interface. It needs valid
									input for C/C++ interface */
	unsigned char ucReserved[256];      /* Reserved field */ 
} NSStreamMultiConfigInfo;

#define NS_STREAM_MULTI_CONFIG_MODE_MOD   1
#define NS_STREAM_MULTI_CONFIG_MODE_COPY  2

#endif
