/*****************************************************************************
 * pmcitems.h
 * iType1 and data structure definitions for the PMC commands.
 * These are visible to the user.
 *
 * Copyright (c) 1993-2001, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/
#ifndef _PMCITEMS_H_
#define _PMCITEMS_H_

#define NS_PMC_BASE_NUM                  0x6600

/* PMC iTypes */
#define NS_PMC_DEVICE_INFO				(NS_PMC_BASE_NUM + 2)		
#define NS_PMC_FLASH_INFO				(NS_PMC_BASE_NUM + 3)
#define NS_PMC_VPN_INFO					(NS_PMC_BASE_NUM + 4)
#define NS_PMC_PARTITION_DISK			(NS_PMC_BASE_NUM + 5)
#define NS_PMC_DISK_INFO				(NS_PMC_BASE_NUM + 6)
#define NS_PMC_FLASH_MEM_TEST_INFO		(NS_PMC_BASE_NUM + 7)
#define NS_PMC_HIFN_MEM_TEST_INFO		(NS_PMC_BASE_NUM + 8)
#define NS_PMC_VPN_HW_TEST_INFO		(NS_PMC_BASE_NUM + 9)

/*********************************************************************************
 * Structure:   NSPMCDeviceInfo
 * iType1:      NS_PMC_DEVICE_INFO
 * Function:    HTGetStructure
 * Description: Retrieve PMC devices Info. All types of devices existed on PMC 
 * will be returned in the format of a bit mask shown in ulDevices. 
 **********************************************************************************/
#define PMC_FLASH	0x00000001
#define PMC_VPN		0x00000002
typedef struct tagNSPMCDeviceInfo
{
	unsigned long ulDevices;			/* Types of devices available on the card (output) */		  
    unsigned char ucReserved[128];		/* Reserved (input, output) */
} NSPMCDeviceInfo;

/*********************************************************************************
 * Structure:   NSPMCFlashInfo
 * iType1:      NS_PMC_FLASH_INFO
 * Function:    HTGetStructure
 * Description: Detect and Retrieve Flash (Disk) info. 
 **********************************************************************************/
#define PMC_MEM_TEST_FAILURE	0x00000001
typedef struct tagNSPMCFlashInfo
{
	unsigned long ulDeviceType;				/* Type of device to detect (input) */
	unsigned char ucReserved[128];			/* Reserved (input, output) */
	char szName[64];						/* Device name (output) */
	char szVendor[64];						/* Vendor (output) */
	unsigned long ulCapacity;				/* in kByte. (output) */
	unsigned long ulFlashStatus;			/* Flash status (output) */
} NSPMCFlashInfo;

/**********************************************************************************
 * Structure:   NSPMCVPNInfo 
 * iType1:      NS_PMC_VPN_INFO
 * Function:    HTGetStructure
 * Description: Detect and Retrieve VPN info. 
 **********************************************************************************/
typedef struct tagNSPMCVPNInfo
{
	unsigned long ulDeviceType;				/* Type of devices to detect (input) */
	unsigned char ucReserved[128];			/* Reserved (input, output) */
	char szName[64];						/* Device name (output) */
	char szVendor[64];						/* Vendor (output) */
	unsigned long ulVPNStatus;				/* VPN status (output) */
} NSPMCVPNInfo;

/*********************************************************************************
 * Structure:   NSPMCPartitionDisk
 * iType1:      NS_PMC_PARTITION_DISK
 * Function:    HTSetStructure
 * Description: Partition PMC Flash (Disk). If called, all data in the PMC Flash 
 * will be erased. After partition, disk will be formated as well.
 **********************************************************************************/
#define PMC_MAX_DISK_PARTITIONS		4
typedef struct tagNSPMCOnePartition
{
	unsigned long ulSize;				/* Partition size (input) */ 
	char szName[24];					/* Partition name (input) */
	unsigned char ucReserved[24];		/* Reserved (input) */
} NSPMCOnePartition;

typedef struct tagNSPMCPartitionDisk
{
	unsigned long ulPartitionCount;		/* Number of partitions (input) */
	NSPMCOnePartition mPMCPartition[PMC_MAX_DISK_PARTITIONS]; /* Partitions (input) */
	unsigned char ucReserved[64];		/* Reserved (output) */
} NSPMCPartitionDisk;

/*********************************************************************************
 * Structure:   NSPMCDiskInfo
 * iType1:      NS_PMC_DISK_INFO
 * Function:    HTGetStructure
 * Description: Retrieve the Flash (Disk) info for all partitions.
 **********************************************************************************/
//status
#define PMC_DISK_NO_ERROR	0x00000001
#define PMC_DISK_ERROR		0x00000002
typedef struct tagNSPMCOnePartitionInfo
{
	char szName[24];					/* Partition name (output) */
	unsigned long ulStatus;				/* Partition status (output) */
	unsigned long ulCapacity;			/* Partition capacity (output) */
	unsigned long ulFreeSpace;			/* Free space (output) */
	unsigned char ucReserved[12];		/* Reserved (output) */
} NSPMCOnePartitionInfo;

typedef struct tagNSPMCDiskInfo
{
	unsigned char ucReserved[24];		/* Reserved (input, output) */
	unsigned long ulPartitionCount;		/* Partition count (output) */
	NSPMCOnePartitionInfo mPMCDiskInfo[PMC_MAX_DISK_PARTITIONS];  /* Flash info (output) */
	unsigned char ucReserved1[20];		/* Reserved (output) */
} NSPMCDiskInfo;

/******************************************************************************** 
 * Structure:	NSPMCFlashMemTestInfo
 * iType1:		NS_PMC_FLASH_MEM_TEST_INFO
 * Function:	HTGetStructure
 * Description: Retrieve the result for Flash (Disk) integrety test.
 ********************************************************************************/
#define PMC_DISK_MEM_TEST_FAILURE	0x00000001
typedef struct tagNSPMCFlashMemTestInfo
{
	unsigned long ulFlashStatus;		/* Flash status (output) */
	unsigned char ucReserved[24];		/* Reserved (input, output) */
} NSPMCFlashMemTestInfo;

/********************************************************************************
 * Structure:  NSPMCVPNHardwareTestInfo
 * iType1:     NS_PMC_VPN_HW_TEST_INFO
 * Function:   HTGetStructure
 * Description:Retrieve the test result for the VPN (Virtual Private Network) hardware
               accelerator present on PMC1 or PMC2.
 ********************************************************************************/
#define PMC_VPN_HW_TEST_PASS     0x00000000
#define PMC_VPN_HW_TEST_FAILURE  0x00000001
typedef struct tagNSPMCVPNHardwareTestInfo
{
   unsigned long ulStatus;        /* VPN (Virtual Private Network)Hardware Test status (output) */
   unsigned char ucReserved[24];  /* Reserved */
} NSPMCVPNHardwareTestInfo;

/********************************************************************************
 * Structure:	NSPMCHifnMemTestInfo
 * iType1:		NS_PMC_HIFN_MEM_TEST_INFO
 * Function:	HTGetStructure
 * Description:	Retrieve the result for HiFn Security Processor mem test.
 ********************************************************************************/
#define PMC_HIFN_MEM_TEST_FAILURE	0x00000001
typedef struct tagNSPMCHifnMemTestInfo
{
	unsigned long ulHifnStatus;			/* Hifn status (output) */
	unsigned char ucReserved[24];		/* Reserved (input, output) */
} NSPMCHifnMemTestInfo;

#endif
