/************************************************************************
 *	Netcom Systems, Inc.

 *	file: positems.h
 *	POS SmartCard Configuration definitions

 *	Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 *	Copyright (C) 1993-1999. All Rights Reserved.
 ************************************************************************/

#ifndef  _POSITEMS_H_
#define  _POSITEMS_H_

#include "ettypes.h"
#include "l3items.h"

#ifndef POS_CARD_BASE 
#define POS_CARD_BASE 0x6100
#endif


/* iTypes for HTSetStructure */
#define POS_CARD_LINE_CONFIG		(POS_CARD_BASE + 0x0004)
#define POS_CARD_PORT_ENCAP			(POS_CARD_BASE + 0x0014)
#define POS_SONET_PAYLOAD_CONFIG	(POS_CARD_BASE + 0x0016)
#define POS_STRUC_TRIGGER           (POS_CARD_BASE + 0x0018)  	/* Set up triggers. */
#define POS_CONFIG					(POS_CARD_BASE + 0x0019)	/* Configure POS transceiver */
#define POS_CONFIG_INFO				(POS_CARD_BASE + 0x0020)	/* Retrieve POS transceiver configurations */
#define NS_SONET_ALARM_COUNTER_INFO	(POS_CARD_BASE + 0x0021)	/* Retrieve Port Configuration */

	
/* iTypes for HTGetStructure */
#define POS_CARD_LINE_CONFIG_INFO 	      (POS_CARD_BASE + 0x0022) /* Read back POS line configurations */
#define POS_CARD_PORT_ENCAP_INFO 	      (POS_CARD_BASE + 0x0023) /* Read back  POS encapsulation type *


/*********************************************************************************
 * Structure:   POSCardLineConfig
 * iType1:      POS_CARD_LINE_CONFIG
 * Function:    HTSetStructure
 * POSCardLineConfig Description: This Structure is used for setup POS card Line config

***********************************************************************************/

typedef struct tagPOSCardLineConfig
{
	unsigned char	ucCRC32Enabled;			/* 1 enable CRC32, 0 enable CRC16,   */
	unsigned char	ucScramble;				   /* 1 enable Scramble, 0 disable Scramble */
   unsigned short uiSONETAlarmError;	   /* SONET Alarm/error bitmask, see predefined
                                             bitmasks:  SONET_xxx_ERROR, SONET_xxx_ALARMS below */
} POSCardLineConfig;

/* The SONET Alarm Error field is bit-map: */
#define  SONET_FRAMING_A1A2_ERRORS			0x0001
#define	SONET_SECTION_BIP8_ERRORS			0x0002
#define	SONET_LINE_BIP96_ERRORS				0x0004
#define	SONET_PATH_BIP8_ERRORS				0x0008
#define	SONET_LINE_AIS_ALARMS				0x0010
#define	SONET_LINE_RDI_ALARMS				0x0020
#define	SONET_PATH_AIS_ALARMS				0x0040

/*********************************************************************************
 * Structure:   POSCardPortEncapsulation
 * iType1:      POS_CARD_PORT_ENCAP
 * Function:    HTSetStructure
 * POSCardPortEncapsulation Description: This Structure is used for setup POS card
 * encapsulation type. 
 *    ucEncapStyle = PROTOCOL_ENCAP_TYPE_STD_PPP
 *                   PROTOCOL_ENCAP_TYPE_HDLC_WITH_ETHERTYPE 
***********************************************************************************/

typedef struct tagPOSCardPortEncapsulation
{
	unsigned char	ucEncapStyle;
	char			Pad[3];
} POSCardPortEncapsulation;

#define PROTOCOL_ENCAP_TYPE_STD_PPP		         0x21	
#define PROTOCOL_ENCAP_TYPE_HDLC_WITH_ETHERTYPE	0x25	
#define PROTOCOL_ENCAP_TYPE_MPLS_STACK	         0x27	


/*********************************************************************************
 * Structure:   POSCardSetSpeed
 * iType1:      POS_SET_SPEED
 * Function:    HTSetCommand
 * POSCardSetSpeed Description: This Structure is used for setup POS card speed.
 *  default is OC12, but the user can switch to OC3.
 *  The user can change speed using HTSetSpeed(POS_SPEED_OC3, iHub,iSlot,iPort) also.
***********************************************************************************/

typedef struct tagPOSCardSetSpeed
{
	unsigned short	uiSpeed;
} POSCardSetSpeed;

#define POS_SET_SPEED		0x0726

/* for set uiSpeed */
#define POS_SPEED_OC1		0x0001
#define POS_SPEED_OC3		0x0002
#define POS_SPEED_OC12		0x0004
#define POS_SPEED_OC48		0x0008
#define POS_SPEED_OC192		0x00010


/*********************************************************************************
 * Structure:   POSCardGetSpeedInfo
 * iType1:      POS_READ_SPEED
 * Function:    HTGetStructure
 * POSCardGetSpeedInfo Description: This structure is used to get information about
 * a POS cards current port speed, speed capabilities, and transceiver mode.
 Possible values for uiSpeed are:
 POS_SPEED_OC1
 POS_SPEED_OC3
 POS_SPEED_OC12
 POS_SPEED_OC48
 POS_SPEED_OC192
***********************************************************************************/

typedef struct tagPOSCardGetSpeedInfo
{
	unsigned short	uiSpeed;			/* Current setting speed */
	unsigned short	uiSpeedCap;			/* the speed capabilities that the card can be set*/
	unsigned short	uiTransMode;		/* the card transciever mode*/
} POSCardGetSpeedInfo;

#define POS_READ_SPEED		0x0725 /* Retrieve information about a POS cards current port speed, speed capabilities, and transceiver mode. */

/* for get uiSpeed */
/*
#define POS_SPEED_OC1		0x0001
#define POS_SPEED_OC3		0x0002
#define POS_SPEED_OC12		0x0004
#define POS_SPEED_OC48		0x0008
#define POS_SPEED_OC192		0x00010
*/

/* for transciever mode */
#define POS_TRANSCIEVER_MODE_SINGLE		0x00
#define POS_TRANSCIEVER_MODE_MULTI		0x01



#define POS_TRANSCEIVER_MODE_SINGLE		0x00
#define POS_TRANSCEIVER_MODE_MULTI		0x01

/*********************************************************************************
 * Structure:   POSSonetPayloadConfig
 * iType1:      POS_SONET_PAYLOAD_CONFIG
 * Function:    HTSetStructure */
/* POSSonetPayloadConfig Description: 
	Configure the SONET payload type
*/
/*********************************************************************************/

typedef struct tagPOSSonetPayloadConfig
{
		unsigned char ucType;	/* use POS_SONET_PAYLOAD_TYPE_XXX
											definitions */
		unsigned char ucReserved[7];
} POSSonetPayloadConfig;

#define POS_SONET_PAYLOAD_TYPE_UNEQUIPPED		0x00
#define POS_SONET_PAYLOAD_TYPE_NON_SPECIFIC 	0x01
#define POS_SONET_PAYLOAD_TYPE_SYNCHRONOUS	0x10
#define POS_SONET_PAYLOAD_TYPE_PPP				0xCF


/******************************************************************************
 * TRIGGER PARAMETERS
 *
 * Structure: POSTrigger
 * iType1:    POS_STRUC_TRIGGER
 * Function: HTSetStructure
 * POSTrigger Description:

This structure sets up the triggers for a gigabit card.  This
structure is similar to the HTTrigger function.  The ucTriggerMode
field can be set to specify what combination of triggers must occur to
create a trigger event.

******************************************************************************/
typedef struct tagPOSTrigger
{
 unsigned char ucTrigger1Mode;    /* reserved - not currently in use
												 (0 = default) */
 unsigned char ucTrigger1Range;   /* range of trigger 1 (in bytes)
												 (0 = default) */
 unsigned short uiTrigger1Offset; /* offset of trigger 1 (in bits)
												 (0 = default) */
 unsigned char ucTrigger1Data[8]; /* trigger 1 data (0 = default) */
 unsigned char ucTrigger1Mask[8]; /* trigger 1 mask
												 (0xFF = defaults) */

 unsigned char ucTrigger2Mode;    /* reserved - not currently in use
												 (0 = default) */
 unsigned char ucTrigger2Range;   /* range of trigger 2 (in bytes)
												 (0 = default) */
 unsigned short uiTrigger2Offset; /* offset of trigger 2 (in bits)
												 (0 = default) */
 unsigned char ucTrigger2Data[8]; /* trigger 2 data (0 = default) */
 unsigned char ucTrigger2Mask[8]; /* trigger 2 mask
												 (0xFF = default) */

 unsigned char ucTriggerMode;     /* use trigger combination defines
												 (GIG_TRIGGER1_ONLY = default)*/
 unsigned char ucReserved;        /* reserved - not currently in use
												 (0 = default) */
} POSTrigger;

/* Trigger combination */
#define POS_TRIGGER1_ONLY                 1
#define POS_TRIGGER2_ONLY                 0
#define POS_TRIGGER1_OR_TRIGGER2          3
#define POS_TRIGGER1_AND_TRIGGER2         2
#define POS_TRIGGER_OFF                   4
#define POS_QOS_TRIGGER					  8	/* reserved for future use */

/*********************************************************************************
 * Structure:   POSConfig
 * iType1:      POS_CONFIG/POS_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * Description: This message is used to set and get configurations for the POS 
 *				transceiver.  
 **********************************************************************************/
typedef struct tagPOSConfig
{
	unsigned char ucTxClockSource;		/* Clock Source -
														POS_CLOCK_SOURCE_INTERNAL,
														POS_CLOCK_SOURCE_LOOP_TIMED
													*/
	unsigned char ucFramingMode;		/* Framing Mode -
										POS_FRAMING_MODE_SONET(default), POS_FRAMING_MODE_SDH */
	unsigned char ucLoopBackMode;		/* LoopBack Mode - Only one mode can be used
										POS_LOOPBACK_MODE_OFF(default),
										POS_LOOPBACK_MODE_LOCAL_PHY,
										POS_LOOPBACK_MODE_REMOTE_PHY,
										POS_LOOPBACK_MODE_LOCAL_TRANSCEIVER,
										POS_LOOPBACK_MODE_REMOTE_TRANSCEIVER,
										*/
	unsigned char ucReserved[20];
}POSConfig;

#define POS_CLOCK_SOURCE_INTERNAL		0
#define POS_CLOCK_SOURCE_LOOP_TIMED		1

#define POS_FRAMING_MODE_SONET 	0
#define POS_FRAMING_MODE_SDH	1

#define POS_LOOPBACK_MODE_OFF			0
#define POS_LOOPBACK_MODE_LOCAL_PHY		2
#define POS_LOOPBACK_MODE_REMOTE_PHY	3
#define POS_LOOPBACK_MODE_LOCAL_TRANSCEIVER		4	
#define POS_LOOPBACK_MODE_REMOTE_TRANSCEIVER	5
#define POS_LOOPBACK_MODE_MONITOR_PHY	5 /* Equivalent mode as POS_LOOPBACK_MODE_REMOTE_TRANSCEIVER */



#endif

