/****************************************************************************
 * pppitems.h
 * PPP Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

#ifndef _PPPITEMS_H_
#define _PPPITEMS_H_

#include "ettypes.h"

#define MAX_DELTA			32
#define MAX_ARRAY_DIM	2048

/* We have this for Terametric cards because for PPPoE the maximum
data we can send to the PPPoE deamon is 1884 */
#define MAX_ARRAY_DIM_TM	1870

/****************************************************************************
 *
 * PPP Message Function ID Defines
 *
 ****************************************************************************/

#define PPP_CONFIG	  			0x5201		/* Set PPP configuration structure
															params.					 				*/
#define PPP_SET_CTRL				0x5202		/* Set PPP control structure params.*/
#define PPP_STATS_INFO			0x5203		/* Retrieves PPP Status info. 		*/
#define PPP_STATUS_INFO			0x5204		/* Get PPP status data.					*/
#define PPP_PARAMS_COPY			0x5205		/* Copy PPP params to a given# of
															streams.									*/
#define PPP_PARAMS_FILL			0x5206		/* Fill in PPP params for a given #
															of streams, using a delta value.	*/
#define PPP_PARAMS_MODIFY		0x5207		/* Modify PPP params of a given # of
															streams.									*/
#define PPP_CONFIG_INFO			0x5208		/* Retrieves the PPP configuration
															for one or more PPP Sessions.
															To retrieve information about
															multiple sessions, use an array
															of PPPParamCfg structures.			*/
#define PPP_OE_STATS_INFO		0x5209		/* Retrieves the (PPPoE)
															PPP over Ethernet statistics of
															one or more Sessions.				*/
#define PPP_OE_SESSION_START	0x5210		/* Start one or more PPPoE sessions.
															Use iType2 as first instance to
															start, iType3 as count of sessions
															to start.								*/
#define PPP_OE_SESSION_STOP	0x5211		/* Stop one or more PPPoE sessions.
															Use iType2 as first instance to
															stop, iType3 as count of sessions
															to stop.									*/
#define PPP_DEL_SESSION			0x5212		/* Delete one or more PPP sessions	*/
#define PPP_DEL_ALL				0x5213		/* Delete all existing PPP sessions 
															WN344X cards only						*/
#define PPP_STATUS_SEARCH_INFO 0x5214		/* Return info for matching status
															information.							*/
#define PPP_CONFIG_QUERY		0x5215		/* Retrieves the PPP configuration
															for one or more PPP Sessions.
															To retrieve information about
															multiple sessions, use an array
															of PPPParamCfg structures.			*/
#define PPP_STATS_QUERY			0x5216		/* Retrieves PPP Statistics info. 	*/
#define PPP_STATS_RESET  		0x5217		/* Reset PPP statistics info			*/
#define PPP_STATUS_QUERY		0x5218		/* Get PPP status data.					*/
#define PPP_DELETE				0x5219		/* Delete a PPP session 
													WN344X cards only */
#define PPP_DELETE_ALL			0x5220		/* Delete all PPP's 
													WN344X cards only */

#define PPP_IPV6_CONFIG	  			0x5221		/* Set PPP IPv6 configuration settings. */
#define PPP_IPV6_CONFIG_INFO		0x5222		/* Retrieve PPP IPv6 configuration settings. */
#define PPP_IPV6_STATUS_INFO		0x5223		/* Retrieve PPP IPv6 status information. */

#define PPP_SESSION_STATS_INFO	0x5224		/* Retrieves PPP global session statistics maintained by the stack. */

#define PPP_ENHANCED_CONFIG		0x5225 /* Set up PPP configurations for IPV4 and IPV6 (VLAN and non-VLAN). */
#define PPP_ENHANCED_CONFIG_INFO	0x5226 /* Retrieve PPP configurations for IPV4 and IPV6 (VLAN and non-VLAN).  
                                           Use iType2 to indicate the first PPP instance to retrieve.  
                                           To retrieve configurations for multiple sessions, use an array of PPPEnhancedConfig structures. */
/********************************************************************************
 * Structure:   PPPParamCfg
 * iType1:      PPP_CONFIG, PPP_CONFIG_INFO
 * Function:    HTSetStructure, HTGetStructure
 *
 * PPPParamCfg Description:
 * Setup or retrieve PPP configuration.  Use iType2 to indicate the first
 * instance(non WAN cards only).  To retrieve configurations for multiple
 * sessions, use an array of PPPParamCfg structures.
 *
 * Defined values for
 *
 * Current PPP negotiation options:
 *	PPPO_MRU          		0x0001
 * PPPO_USECHAPAUTH  		0x0010
 * PPPO_USEPAPAUTH   		0x0020
 * PPPO_USEMAGIC     		0x0080
 * PPPO_USENONE				0x0000
 *
 * CHAP authentication:
 * PPP_CHAPMD5					0x05
 * PPP_CHAPMS					0x80
 *
 * PPP Configure structure default values:
 * PPP_CONFIGURE_MRU				1500
 * PPP_CONFIGURE_MAXFAILURE	5
 * PPP_CONFIGURE_MAXCONFIGURE	10
 * PPP_CONFIGURE_MAXTERMINATE	2
 * PPP_CONFIGURE_MAGICNUMBER	2
 * PPP_CONFIGURE_ECHOFREQ		1 ( not applicable for the ML-5710A and
 *                                LAN-3101A/3111A/3102A cards )
 * PPP_CONFIGURE_ECHOERRFREQ	0 ( not applicable for the ML-5710A and
 *                                LAN-3101A/3111A/3102A cards )
 *
 * PPPoE Parameters:-
 * Mode:
 * PPP_OE_CLIENT						0x01
 * PPP_OE_SERVER						0x02	- Not supported yet
 *
 * Options:
 * PPP_OE_SELECT_AC_BY_SVCNAME		0x0001
 * PPP_OE_SELECT_AC_BY_ACNAME			0x0002
 * PPP_OE_USE_ZEROLEN_SVCNAME			0x0004
 * PPP_OE_OFFER_AVAILABLE_SERVICE	0x0010	- Not supported yet
 * PPP_OE_USE_DOUBLE_TIMEOUT			0x1000
 *
 ********************************************************************************/
typedef struct tagPPPParamCfg
{
	unsigned long	ulLineNo;				/* Input - Wan cards only - T1/E1 Line */
	unsigned long	ulChannelNo;			/* Input - Wan cards only - 
											   Channel number within the T1/E1 Line */
	unsigned long	ulpppCount;				/* Input - 
											   Number of PPP Instance to configure starting from pppInstance */
	unsigned long	ulpppInstance;			/* Starting instance ID of PPP when multiple PPP instances used
													 * range: 0-128 for PPP over FR	on WAN
													 * range: 0 for PPP over HDLC on WAN and POS
													 * range: 0-2048 for PPP over ATM
													 * For WN344X don't use these field 
													 */
	
	/* LCP Configurations options to negotiate/accept */
	unsigned short	uipppWeWish;			/* options we use in Configure-Request */
	unsigned short	uipppWeMust;			/* options we must be acked before peer's Configure ACK */
	unsigned short	uipppWeCan;				/* options we can ack in Configure ACK */

	/* LCP parameters */
	unsigned char	ucpppEnablePPP;		/* Enable LCP when link is UP and ready */
	unsigned char	ucpppCHAPAlgo;			/* CHAP algorithm */
	unsigned short	uipppMRU;				/* Max. Receive Unit - default 1500 */
	unsigned short	uipppMaxFailure;		/* Max. Configure NAK to send - default 5 */
	unsigned short	uipppMaxConfigure;	/* Max. Configure Request to send without acked - default 10 */
	unsigned short	uipppMaxTerminate;	/* times to send Terminate Request without acked - default 2 */
	unsigned long	ulpppMagicNumber;		/* Magic Number : 0 = a random number will be genrated */

	/* Authentication */
	unsigned char	ucpppOurID[32];		/* Login(Outgoing/as a client) ID for authentication */
	unsigned char	ucpppOurPW[32];		/* Login(Outgoing/as a client) Password for authentication */
	unsigned char	ucpppPeerID[32];		/* Peer(Incoming/as a server) ID for authentication */
	unsigned char	ucpppPeerPW[32];		/* Peer(Incoming/as a server) Password for authentication */

	/* IP parameters */
	unsigned char	ucpppIPEnable;			/* Enable IP NCP - if LCP is enabled */
	unsigned char	ucpppNegotiateIPAddr;	/* Was Reserved - used to negotiate local & peer IP Addresses */
	unsigned short	uipppIPCompress;		/* Reserved */
	unsigned char	ucpppOurIPAddr[4];	/* Proposed Local IP addr */
	unsigned char	ucpppPeerIPAddr[4];	/* Proposed Peer IP addr */

	/* IPX parameters - reserved */
	unsigned long	ulpppIPXNet;			/* IPX Net */
	unsigned char	ucpppIPXEnable;			/* Enable IPX NCP - if LCP is enabled */
	unsigned char	ucpppIPXNode[6];		/* IPX node */
	unsigned char	ucReserved;				/* Reserved */
	unsigned short	uipppIPXCompress;		/* Reserved */
	unsigned short	uipppIPXRoutingProt;	/* IPX routing protocol */

	unsigned short	uipppRestartTimer;		/* PPP Restart Timer */
	unsigned short	uipppRetryCount;		/* Number of times PPP retry LCP after failure
											 * 0=forvever */
	unsigned char	ucModFrame;				/* Modify frame with dynamic data from
														session negotiation, where:
														0x00 - indicates no modifications
														0x01 - indicates modify the Local IP
														0x02 - indicates modify PPPoE Session ID
														0x04 - indicates modify Destination MAC address
														0x08 - indicates modify Source MAC address */
	unsigned char	ucReserved1;			/* Reserved */

	/* PPPoE parameters */
	unsigned char	ucMode;					/* Mode */
	unsigned char	ucTimer;				/* In seconds */
	unsigned short	uiRetry;				/* Retry */
	unsigned short	uiOptions;				/* Options */
	unsigned char	ucSourceMAC[6];			/* Source MAC address */
	unsigned char	ucDestMAC[6];			/* Destination MAC address */
	unsigned short	uiServiceNameLen;		/* Service name length */
	unsigned char	ucServiceName[16];		/* Service name */
	unsigned short	uiAcNameLen;			/* Ac name length */
	unsigned char	ucAcName[16];			/* Ac name */
} PPPParamCfg;


/* Comment:
	LAN-6101 specific:
	If using the 0x01 mod. of ucModFrame field in PPPParamCfg, user should enable 
	IP negotiate (ucpppNegotiateIPAddr) and leave local IP addresses as 0s.
	This will allow the session to be able to come up.
	The reason being if user enables IP negotiation and defines IP addresses in PPP configuration, 
	the PPP sessions won't come up in some routers (ex. RedBack).
 */

/* Current PPP negotiation options */
#define PPPO_MRU          		0x0001	/* negotiate maximum receive unit */
#define PPPO_USECHAPAUTH  		0x0010	/* use the CHAP authentication */
#define PPPO_USEPAPAUTH   		0x0020	/* use the PAP authentication */
#define PPPO_USEMAGIC     		0x0080	/* use magic numbers */
#define PPPO_USENONE			0x0000	/* Use no negotiation options */

/* CHAP authentication  */
#define PPP_CHAPMD5				0x05		/* Message Digest version 5 (MD5) CHAP Algorithm */
#define PPP_CHAPMS				0x80		/* MS - Microsoft CHAP Algorithm */

/* PPP Configure structure default values */
#define PPP_CONFIGURE_MRU			1500	/* Default max receive unit size */
#define PPP_CONFIGURE_MAXFAILURE	5	 	/* Default max Configure NAK to sent before a Terminate Request is sent */
#define PPP_CONFIGURE_MAXCONFIGURE	10		/* Default max Configure Request to sent */
#define PPP_CONFIGURE_MAXTERMINATE	2		/* Default max Terminate Request to sent */
#define PPP_CONFIGURE_MAGICNUMBER	2		/* Default magic number */
#define PPP_CONFIGURE_ECHOFREQ		1		/* Default Echo Request frequency to 1 second */
#define PPP_CONFIGURE_ECHOERRFREQ	0		/* Default to no error in Echo Request */

/* PPPoE Configuration parameters */
/* Mode */
#define	PPP_OE_CLIENT					0x01
#define	PPP_OE_SERVER					0x02	/*	Not supported yet */

/* Options */
#define PPP_OE_SELECT_AC_BY_SVCNAME		0x0001
#define PPP_OE_SELECT_AC_BY_ACNAME		0x0002
#define PPP_OE_USE_ZEROLEN_SVCNAME		0x0004
#define PPP_OE_OFFER_AVAILABLE_SERVICE	0x0010	/* Not supported yet */
#define PPP_OE_USE_DOUBLE_TIMEOUT		0x1000
#define PPP_OE_ADD_EOL_TAG					0x0008
#define PPP_OE_IGNORE_EOL_TAG			   0x0020

#define	PPP_MOD_SRCIP				0x01  /* modify the Local IP */
#define	PPP_MOD_SESSID				0x02  /* modify PPP Session ID */
#define	PPP_MOD_DESTMAC			0x04	/* modify Destination MAC address */
#define	PPP_MOD_SRCMAC				0x08	/* modify Source MAC address */
#define  PPP_MOD_SRCIPV6		   0x10  /* modify Source IP Address(IPV6), not supported */
#define  PPP_MOD_DESTIPV6			0x20  /* modify Dest IP Address(IPV6), not supported */
#define  PPP_MOD_SESSION_STATUS	0x40  /* modify Session Status, not supported */


/*
Note that a magic number of zero implies that a random number will be used.
Note that in order to set up authentication, you must set up the parameters as follow:

1) Incoming CHAP
		pppWeMust = PPPO_USECHAPAUTH
		pppWeWish = PPPO_USECHAPAUTH
2) Incoming PAP
		pppWeMust = PPPO_USEPAPAUTH
		pppWeWish = PPPO_USEPAPAUTH
3)  Outgoing CHAP
		pppWeCan = PPPO_USECHAPAUTH
4)   Outgoing PAP
		pppWeCan = PPPO_USEPAPAUTH

*/


/********************************************************************************
 * Structure:   PPPControlCfg
 * iType1:      PPP_SET_CTRL
 * Function:    HTSetStructure
 *
 * PPPControlCfg Description: Setup PPP Control configuration
 *
 * Defined values for ucpppAction:
 * PPP_NO_ACTION	0
 *	PPP_OPEN_LCP	1
 *	PPP_CLOSE_LCP	2
 *	PPP_ECHO_START	3
 * PPP_ECHO_STOP	4
 * PPP_START      5
 * PPP_STOP       6
 * PPP_RESET      7
 * PPP_CLEAR_SESSION_STATS 8
 * PPP_CLEAR_STATS 9 - Not Supported
 ********************************************************************************/
typedef struct tagPPPControlCfg				/* Control of LCP, IPCP, IPXCP */
{
	unsigned long	ulLineNo;				/* Input - Wan cards only - T1/E1 Line */
	unsigned long	ulChannelNo;			/* Input - Wan cards only - 
											   Channel number within the T1/E1 Line */
	unsigned long	ulpppCount;				/* Input - Number of times to repeat command starting from pppInstance */
	unsigned long	ulpppInstance;			/* Starting instance ID of PPP when multiple PPP instances used */
											/* For WN344X cards don't use this field*/
	unsigned char	ucpppAction;				/* action to take; can be
                                             PPP_NO_ACTION,
                                             PPP_OPEN_LCP ( not applicable for the ML-5710A,
                                                            LAN-3101A/3111A/3102A, and LAN-33xxA cards ),
                                             PPP_CLOSE_LCP ( not applicable for the ML-5710A,
                                                            LAN-3101A/3111A/3102A, and LAN-33xxA cards ),
                                             PPP_START,
                                             PPP_STOP,
                                             PPP_ECHO_START,
                                             PPP_ECHO_STOP,
                                             PPP_RESET ( applicable to ML-5710, LAN-3101A,
                                                         LAN-33xx, and ATM-34xx cards only)
                                              deletes PPP session,
                                             PPP_CLEAR_SESSION_STATS ( applicable to LAN-33xx
                                                                       and ATM-34xx cards only)
                                               Clear session statistics. 
                                             PPP_CLEAR_STATS (Clear statistics counters) */
	unsigned char	ucpppLCPPassiveMode;		/* Global LCP passive mode */
	unsigned char	ucpppIPCPPassiveMode;	/* Global IPCP passive mode */
	unsigned char	ucpppSessionBurstSize;	/* Number of sessions to start per inter connect delay.
                                             Applicable to LAN-33xx and ATM-34xx only. */
	unsigned long	ulpppEchoFreq;				/* Echo frequency - send Echo Request every pppEchoFreq seconds */
	unsigned long	ulpppEchoErrFreq;			/* Echo error frequency - for every (pppEchoErrFreq-1) Echo Requests, insert one with error */
   unsigned long	ulpppInterConnDelay;		/* Global Inter connect delay in msec. */
	unsigned short uiLCPStartDelay;
	unsigned short uiIPCPStartDelay;
} PPPControlCfg;

/* Comment:
 */

/* PPP Action types */
#define	PPP_NO_ACTION              0     /* No action */
#define	PPP_OPEN_LCP               1     /* Open LCP if currently is DOWN */
#define	PPP_CLOSE_LCP              2     /* Close LCP */
#define	PPP_ECHO_START             3     /* Start sending Echo Request at specified
                                             frequency and error rate  */
#define	PPP_ECHO_STOP              4     /* Stop sending Echo Request */
#define	PPP_START                  5     /* Start PPPoE, LAN-3101A/B,ML-5710 */
#define	PPP_STOP                   6     /* Stop PPPoE, LAN-3101A/B,ML-5710,
                                             LAN-33xx, ATM-34xx */
#define	PPP_RESET                  7     /* Delete the PPPoE session. Applicable to ML-5710,
                                             LAN-3101A, LAN-33xx, and ATM-34xx cards only  */
#define	PPP_CLEAR_SESSION_STATS    8     /* Clear global session statistics.
                                             Applicable to LAN-33xx and ATM-34xx cards only */
#define  PPP_CLEAR_STATS	         	9	   /* Clear statistics counters, not supported */


/********************************************************************************
 * Structure:   PPPDelCfg
 * iType1:      PPP_DEL_SESSION
 * Function:    HTSetStructure
 *
 * PPPDelCfg Description: Delete PPP sessions
 * Defined values for Action:
 * 
 ********************************************************************************/
typedef struct tagPPPDelCfg
{
	unsigned long	ulpppInstance;		/* Starting instance ID of PPP when multiple PPP instances used */
												/* WN3445A 0 -- PPP over channel, else DLCI number */
	unsigned long	ulpppCount;			/* Number of times to repeat command starting from pppInstance */
} PPPDelCfg;


/********************************************************************************
 * Structure:   PPPDelete
 * iType1:      PPP_DELETE
 * Function:    HTSetStructure
 * PPPDelete Description: Delete PPP sessions
 * Comments:    It's applicable for WN344X only.
 ********************************************************************************/
typedef struct tagPPPDelete
{
	unsigned long	ulLineNo;				/* Input - T1/E1 Line */
	unsigned long	ulChannelNo;			/* Input - Channel number within the T1/E1 Line */
	unsigned long	ulpppCount;				/* Number of PPP Instances to delete starting from
													   the initial PPP instance specified by ulLineNo
														and ulChannelNo(the line and channel numbers map
														to a PPP instance) */
} PPPDelete;


/* Comment:
 */

/********************************************************************************
 * Structure:   PPPStatusInfo
 * iType1:      PPP_STATUS_INFO
 * iType2:      PPP Instance         current set 0
 * iType3:      PPP Count            current set 1
 * Function:    HTGetStructure
 *
 * PPPStatusInfo Description: 

   Get PPP Status. PPPStatusinfo records the States, failure code and the negotiated
	fields for each PPP session.
 
	Defined values for
 
   PPP Status, LCP State:
 	PPP_LCP_UP 				 	0
   PPP_LCP_DOWN				1
   PPP_LCP_AUTHENTICATING	2
 
   PPP Status, NCP State:
   PPP_NCP_UP					0
   PPP_NCP_DOWN			  	1
 
 
   PPP Status, LCP/NCP Failure reason code:
   LCP_CLOSE_REASON_UNKNOWN				0x00
   LCP_CLOSE_AUTH_FAILURE_NO_RSP			0x01
   LCP_CLOSE_AUTH_FAILURE_LOCAL_REJ		0x02
   LCP_CLOSE_AUTH_FAILURE_PEER_REJ 		0x03
   LCP_CONFIG_FAILURE						0x04
   LCP_CONFIG_TIMEOUT						0x05
   LCP_CONFIG_FAILURE						0x06
   NCP_CONFIG_TIMEOUT						0x07
   NO_FAILURE									0x08
   PPP_OE_TIMEOUT_NO_RSP					0x09
   PPP_OE_GEN_ERR								0x0A
   PPP_OE_SVC_ERR								0x0B
   PPP_OE_AC_ERR								0x0C
   PPP_OE_NO_AC								0x0D
   PPP_SESSION_CLOSE_USER              14 - Not supported
   LCP_CLOSE_LINK_DOWN                 15 - Not supported

  
   PPP Status, PPP_OE Session State:
   PPP_OE_INACTIVE							0
   PPP_OE_STARTED								1
   PPP_OE_PADO_SENT							2
   PPP_OE_PADR_SENT							3
   PPP_OE_SESSION_STATE						4

   PPP Status, LCP/IPCP detailed state
   PPP_LCP_IPCP_INIT							0	
   PPP_LCP_IPCP_STARTING 					1	
   PPP_LCP_IPCP_CLOSED						2	
   PPP_LCP_IPCP_STOPPED						3	
   PPP_LCP_IPCP_CLOSING						4	
   PPP_LCP_IPCP_STOPPING 					5	
   PPP_LCP_IPCP_REQSENT						6	
   PPP_LCP_IPCP_ACKRCV						7	
   PPP_LCP_IPCP_ACKSENT						8	
   PPP_LCP_IPCP_OPENED						9	

 ********************************************************************************/
typedef struct tagPPPStatusInfo
{
	unsigned long	ulpppInstance;			/* Instance ID of PPP, not used for Wan-344x cards */
	unsigned long	ulLineNo;				/* Input - WN-344X cards only */
	unsigned long	ulChannelNo;			/* Input - WN- 344X cards only */		
	unsigned long	ulpppCount;				/* Use as input for WN-344X cards
											Number of PPP Instances that have data returned */
	unsigned char	ucppplcpState;			/* LCP state */
	unsigned char	ucpppipcpState;  		/* IP NCP state */
	unsigned char	ucpppipxcpState;		/* IPX NCP state */
	unsigned char	ucppplcpFailCode;		/* Authentication fail reason*/
	unsigned long	ulpppMagicNumber;		/* Negotiated Magic Number */
	unsigned char	ucpppOurIPAddr[4];	/* Negotiated local IP addr */
	unsigned char	ucpppPeerIPAddr[4]; 	/* Negotiated Peer IP addr */
	unsigned long	ulpppWeGot;				/* Options we got acked */
	unsigned long	ulpppWeAcked;			/* Options we did ack */
	unsigned short	uipppMRU;				/* Negotiated RX Max Unit */
	unsigned short	uipppMTU;				/* Negotiated TX Max unit */
	U64				ullpppLatency;			/* Total time to establish a PPP session in 100 ns*/
	U64				ullpppTotalLatency;	/* Total time to establish all PPP sessions in 100 ns */

	/* PPPoE Status */
	unsigned char	ucState;					/* PPPoE Session state */
	unsigned char	ucMode;  				/* Whether Client/Server? */
	unsigned short	uiSessionID;
	unsigned char	ucSourceMAC[6];
	unsigned char	ucDestMAC[6];
    /* PPP Status for TeraMetrics cards */
	unsigned short	uipppNumRetries; 	 	/* Number of attempts of PPP session */
	unsigned char	ucppplcpDetailedState; 	/* Detail LCP state according to RFC , see micro defined */
	unsigned char	ucpppipcpDetailedState;	/* Detail IPCP state according to RFC, see micro defined */

	unsigned long	ulReserved[5];
} PPPStatusInfo;

/* Comment:
 * Extended to support PPPoE.
 *
 */

/* PPP Status, LCP State */
#define PPP_LCP_UP 						0	/* LCP Layer is UP */
#define PPP_LCP_DOWN						1	/* LCP Layer is DOWN */
#define PPP_LCP_AUTHENTICATING		2	/* LCP Layer is authencticating */

/* PPP Status, NCP State */
#define PPP_NCP_UP						0	/* NCP Layer is UP */
#define PPP_NCP_DOWN						1	/* NCP Layer is DONW */


/* PPP Status, LCP/NCP Failure reason code */
#define LCP_CLOSE_REASON_UNKNOWN				0x00		/* unknown */
#define LCP_CLOSE_AUTH_FAILURE_NO_RSP	 	0x01		/* no authentication info received or timeout */
#define LCP_CLOSE_AUTH_FAILURE_LOCAL_REJ	0x02		/* login/pwd failed -  local reject*/
#define LCP_CLOSE_AUTH_FAILURE_PEER_REJ 	0x03		/* login/pwd failed -  peer reject*/
#define LCP_CONFIG_FAILURE						0x04		/* LCP establishment failure */
#define LCP_CONFIG_TIMEOUT						0x05		/* LCP establishement timeout */
#define NCP_CONFIG_FAILURE						0x06		/* NCP establishment failure */
#define NCP_CONFIG_TIMEOUT						0x07		/* NCP establishment timeout */
#define NO_FAILURE								0x08
#define PPP_OE_TIMEOUT_NO_RSP					0x09		/* Session Timeout */
#define PPP_OE_GEN_ERR							0x0A		/* Generic Error */
#define PPP_OE_SVC_ERR							0x0B		/* Service name Error */
#define PPP_OE_AC_ERR							0x0C		/* Client (AC) system Error */
#define PPP_OE_NO_AC								0x0D		/* No Client available */
#define PPP_SESSION_CLOSE_USER		      14 /* (not supported) */
#define LCP_CLOSE_LINK_DOWN			      15 /* (not supported) */

#define PPP_OE_INACTIVE							0			/* Applicable to both */
#define PPP_OE_STARTED							1			/* Applicable to both */
#define PPP_OE_PADO_SENT						2			/* Server side - Offer sent to Client */
#define PPP_OE_PADR_SENT						3			/* Client side - Req. sent to Server */
#define PPP_OE_SESSION_STATE					4			/* Applicable to both */

/* PPP Status, LCP/IPCP detailed state code */
#define PPP_LCP_IPCP_INIT						0	/* initial state */
#define PPP_LCP_IPCP_STARTING					1	/* starting state */
#define PPP_LCP_IPCP_CLOSED 					2	/* LINK closed */
#define PPP_LCP_IPCP_STOPPED 					3	/* LINK stopped */
#define PPP_LCP_IPCP_CLOSING					4	/* LINK is closing */
#define PPP_LCP_IPCP_STOPPING					5	/* LINK is stopping */
#define PPP_LCP_IPCP_REQSENT					6	/* request sent */
#define PPP_LCP_IPCP_ACKRCV 					7	/* ack received */
#define PPP_LCP_IPCP_ACKSENT					8	/* ack sent */
#define PPP_LCP_IPCP_OPENED 					9	/* LINK is opened */

/********************************************************************************
 * Structure:   PPPStatsInfo
 * iType1:      PPP_STATS_INFO
 * iType2:      PPP Instance         current set 0
 * iType3:      PPP Count            current set 1
 * Function:    HTGetStructure
 *

*********************************************************************************/

/* PPPStatsInfo Description:

 Get PPP counters.

*/

typedef struct tagPPPStatsInfo {
	unsigned long	ulpppInstance;			/* Starting instance ID of PPP when
														multiple PPP instances used for PPP
														over HDLC, this must be set to 0  */
	unsigned long	ulLineNo;				/* Input - WN-344X cards only */
	unsigned long	ulChannelNo;			/* Input - WN- 344X cards only */	
	unsigned long	ulpppCount;				/* Input - Number of times to repeat */
	unsigned long	ultimestamp;			/* Time of last update of statistics */
	unsigned long	ullcpConfReqSent;		/* LCP Configure Request sent */
	unsigned long	ullcpConfAckSent;		/* LCP Configure Ack sent */
	unsigned long	ullcpConfNakSent;		/* LCP Configure NAK sent */
	unsigned long 	ullcpConfRejectSent;	/* LCP Configure Reject Sent */
	unsigned long	ullcpTermReqSent;		/* LCP Terminate Request Sent */
	unsigned long	ullcpTermAckSent;		/* LCP Terminate Ack sent */
	unsigned long	ullcpProtoRejectSent; /* LCP Protocol Reject sent */
	unsigned long	ullcpEchoReqSent;		/* LCP Echo Request sent */

	unsigned long	ullcpEchoReplySent;	/* LCP	Echo Reply Sent */
	unsigned long	ullcpEchoReqErrSent;	/* LCP Echo Request with error sent */
	unsigned long	ullcpEchoReplyErrSent;	/* LCP Echo  Reply with Error sent  - reserved */

	unsigned long	ullcpDiscardReqSent;	/* LCP Discard Request sent */
	unsigned long	ullcpCodeRejectSent;	/* LCP Code Reject sent */
	unsigned long	ullcpResetReqSent;  	/* LCP Reset Request sent */
	unsigned long	ullcpResetAckSent;  	/* LCP Reset ACK sent */


	unsigned long	ullcpPAPReqSent;		/* PAP Request sent */
	unsigned long	ullcpPAPAckSent;		/* PAP ACK Sent */
	unsigned long	ullcpPAPNakSent;		/* PAP NAP Sent */


	unsigned long	ullcpCHAPChlMSSent; 	/* CHAP Challenge with MS Algorithm sent */
	unsigned long	ullcpCHAPChlMD5Sent;	/* CHAP Challenge with MDS Algorithm sent */
	unsigned long	ullcpCHAPRspMSSent; 	/* CHAP Response with MS Algorithm sent */
	unsigned long	ullcpCHAPRspMD5Sent;	/* CHAP Response with MDS Algorithm sent */
	unsigned long	ullcpCHAPSuccessSent;/* CHAP Success sent */
	unsigned long	ullcpCHAPFailSent;	/* CHAP Failure sent */

	unsigned long	ullcpConfReqRcvd;		/* Same as above for receive */
	unsigned long	ullcpConfAckRcvd;
	unsigned long	ullcpConfNakRcvd;
	unsigned long	ullcpConfRejectRcvd;
	unsigned long	ullcpTermReqRcvd;
	unsigned long	ullcpTermAckRcvd;
	unsigned long	ullcpProtoRejectRcvd;
	unsigned long	ullcpEchoReqRcvd;
	unsigned long	ullcpEchoReplyRcvd;
	unsigned long	ullcpEchoReqErrRcvd;
	unsigned long	ullcpEchoReplyErrRcvd;
	unsigned long	ullcpDiscardReqRcvd;
	unsigned long	ullcpCodeRejectRcvd;
	unsigned long	ullcpResetReqRcvd;
	unsigned long	ullcpResetAckRcvd;

	unsigned long	ullcpPAPReqRcvd;
	unsigned long	ullcpPAPAckRcvd;
	unsigned long	ullcpPAPNakRcvd;

	unsigned long	ullcpCHAPChlMSRcvd;
	unsigned long	ullcpCHAPChlMD5Rcvd;
	unsigned long	ullcpCHAPRspMSRcvd;
	unsigned long	ullcpCHAPRspMD5Rcvd;
	unsigned long	ullcpCHAPSuccessRcvd;
	unsigned long	ullcpCHAPFailRcvd;
	unsigned long	ulReserved[14];
} PPPStatsInfo;

/* Comment:
 *  This is only applicable to the WAN cards.
 */

/********************************************************************************
 * Structure: 	PPPoEStatsInfo
 * iType1:		PPP_OE_STATS_INFO
 * iType2: 		PPP Instance
 * Function:	HTGetStructure
 *
 *	PPPoEStatistics Description:
 * Get PPPoE Statistics of one or more Sessions.  These are 32-bit
 * counters representing both the  Discovery and PPP packets combined.
 */
 typedef struct tagPPPoEStatsInfo {
	unsigned long	ulStreamIndex;
	unsigned long	ulSent;
	unsigned long	ulReceived;
	unsigned long	ulDropped;
 } PPPoEStatsInfo;

 /* Comment:
  * Use iType2 to indicate the first instance.
  * To retrieve stats for multiple sessions, use an
  * array of PPPoEStatsInfo structures.
  */

/********************************************************************************
 * Structure:   PPPParamsCopy
 * iType1:      PPP_PARAMS_COPY
 * Function:    HTSetStructure
 *
 * PPPParamsCopy Description: PPPParamsCopy is used to create a given number
 * of streams with the same parameters specified in the Conf-Req
 *******************************************************************************/
typedef struct 	tagPPPParamsCopy
{
	unsigned short	uipppSrcStrNum;		/* "Source" stream index. */
	unsigned short	uipppDstStrNum;		/* Starting stream idx in which the info
													 * of the "Source" Stream is to be copied to.*/
	unsigned short	uipppDstStrCount;		/* The number of streams to be created with the
													 * "Source" Stream's info. */
	unsigned short	uiReserved;
	unsigned long	ulReserved;
} PPPParamsCopy;

/* Comment:
 */
/********************************************************************************
 * Structure:   PPPParamsModify
 * iType1:      PPP_PARAMS_MODIFY
 * Function:    HTSetStructure
 *
 * PPPParamsModify Description: The PPPParamsModify structure can be used to
 * modify the parameters of any given number of streams which already exist,
 * with an absolute value.
 * The uipppParamItemID field to be modified is specified as follows:
 * PPP_REQUESTED_OPTIONS		0
 * PPP_REQUIRED_OPTIONS			1
 * PPP_ACCEPTABLE_OPTIONS		2
 * PPP_MAX_FAILURE				3
 * PPP_MAX_CONFIGURE				4
 * PPP_MAX_TERMINATE				5
 * PPP_LOCAL_AUTH_ID				6
 * PPP_LOCAL_AUTH_PW				7
 * PPP_PEER_AUTH_ID				8
 * PPP_PEER_AUTH_PW				9
 * PPP_CHAP_ALGORITHM			10
 * PPP_IP_ENABLE					11
 * PPP_NEGOTIATE_IP				12
 * PPP_LOCAL_IPADDR				13
 * PPP_PEER_IPADDR				14
 * PPP_IPX_ENABLE					15
 * PPP_IPX_NET						16
 * PPP_IPX_NODE					17
 * PPP_IPX_COMPRESS		  		18
 * PPP_IPX_ROUTING				19
 * PPP_RESTART_TIMER				20
 * PPP_MRU							21
 * PPP_MAGICNUMBER				22
 * PPP_OE_MOD_FRAME				23
 * PPP_OE_MODE			 			24
 * PPP_OE_RETRYTIMER	 			25
 * PPP_OE_RETRY		 			26
 * PPP_OE_OPTIONS		 			27
 * PPP_OE_SOURCEMAC				28
 * PPP_OE_DESTMAC		 			29
 * PPP_OE_SERVICENAME  			30
 * PPP_OE_ACNAME					31
 * PPP_OE_IPV6_ENABLE		   32 - Not Supported
 * PPP_OE_NEGOTIATE_IPV6		33 - Not Supported
 * PPP_OE_LOCAL_IPV6_ADDR		34 - Not Supported
 * PPP_OE_PEER_IPV6_ADDR		35 - Not Supported
 For Terametric cards the maximum for ucpppData is 1870
 ********************************************************************************/
typedef struct 	tagPPPParamsModify
{
	unsigned short	uipppStartStrNum;			/* Stream index of the first stream to be modified. */
	unsigned short	uipppStrCount;				/* The number of streams which are to be modified.  */
	unsigned short	uipppParamItemID;			/* Parameter ID which is to be modified	on all requested
														 * streams - use one of the following defined below. */
	unsigned short	uipppParamCount;			/* The number of elements to be specified for the
														 * pppParamItemID value. This does not include the
														 * parameter size.  */
	unsigned char	ucpppData[MAX_ARRAY_DIM];/* Array contains the number of bytes specified by the
														 * pppParamCount*ParamSize */
} PPPParamsModify;

/* Comment:
 * Extended to support PPPoE.
 *
 */
#define PPP_REQUESTED_OPTIONS			0		/* We Wish options */
#define PPP_REQUIRED_OPTIONS			1		/* We Must options */
#define PPP_ACCEPTABLE_OPTIONS		2		/* We Can options */
#define PPP_MAX_FAILURE				  	3
#define PPP_MAX_CONFIGURE				4
#define PPP_MAX_TERMINATE				5
#define PPP_LOCAL_AUTH_ID				6
#define PPP_LOCAL_AUTH_PW				7
#define PPP_PEER_AUTH_ID				8
#define PPP_PEER_AUTH_PW				9
#define PPP_CHAP_ALGORITHM				10
#define PPP_IP_ENABLE					11
#define PPP_NEGOTIATE_IP				12
#define PPP_LOCAL_IPADDR				13
#define PPP_PEER_IPADDR					14
#define PPP_IPX_ENABLE					15
#define PPP_IPX_NET						16
#define PPP_IPX_NODE						17
#define PPP_IPX_COMPRESS				18
#define PPP_IPX_ROUTING					19
#define PPP_RESTART_TIMER				20
#define PPP_MRU							21
#define PPP_MAGICNUMBER					22
#define PPP_OE_MOD_FRAME 				23
#define PPP_OE_MODE						24
#define PPP_OE_RETRYTIMER				25
#define PPP_OE_RETRY						26
#define PPP_OE_OPTIONS					27
#define PPP_OE_SOURCEMAC 				28
#define PPP_OE_DESTMAC					29
#define PPP_OE_SERVICENAME 			30
#define PPP_OE_ACNAME					31
#define PPP_OE_IPV6_ENABLE		      32 /* (not supported) */
#define PPP_OE_NEGOTIATE_IPV6		   33 /* (not supported) */
#define PPP_OE_LOCAL_IPV6_ADDR		34 /* (not supported) */
#define PPP_OE_PEER_IPV6_ADDR		   35 /* (not supported) */


/********************************************************************************
 * Structure:   PPPParamsFill
 * iType1:      PPP_PARAMS_FILL
 * Function:    HTSetStructure
 *
 * PPPParamsFill Description: PPPParamsFill is used to modify a parameter field
 * of a given number of streams which already exist, using a Source stream index
 * as a base, a starting destination index, and count, whose contents are to be
 *  modified, based on the parameter-id, followed by a delta value which
 *  will be used as the successive incremental value.
 *
 * The uipppParamItemID field to be modified is specified as follows:
 * PPP_LOCAL_AUTH_ID				6 (not supported)
 * PPP_LOCAL_AUTH_PW				7 (not supported)
 * PPP_PEER_AUTH_ID				8 (not supported)
 * PPP_PEER_AUTH_PW				9 (not supported)
 * PPP_LOCAL_IPADDR		     13
 * PPP_PEER_IPADDR		     14
 * PPP_IPX_NET				     16 (not supported)
 * PPP_IPX_NODE			     17 (not supported)
 * PPP_MAGICNUMBER		     22
 * PPP_OE_SOURCEMAC		     28
 * PPP_OE_DESTMAC  		     29
 * PPP_OE_LOCAL_IPV6_ADDR	  34 (not supported)
 * PPP_OE_PEER_IPV6_ADDR     35 (not supported)
 * 
 * To modify with PPP_MAGICNUMBER with 5(example) set ucpppDelta
 * to: ucpppDelta[0] = 0, ucpppDelta[1] = 0, ucpppDelta[2] = 0 ucpppDelta[3] = 5
 * Each element for MAGICNUMBER is 4 bytes
 ********************************************************************************/
typedef struct 	tagPPPParamsFill
{
	unsigned short	uipppSrcStrNum;			/* Stream index of the stream	whose value
														 * for the desired param is to be used as
														 *	an initial value for the fill.			*/
	unsigned short	uipppDstStrNum;			/* Stream index of the first stream whose
														 * param is to be filled.					*/
	unsigned short	uipppDstStrCount;			/* The number of streams which are to be filled. */
	unsigned short	uipppParamItemID;			/* Parameter ID which is to be filled on all
														 * requested streams - look at the comment section.	*/
	unsigned char	ucpppDelta[MAX_DELTA];	/* Successive increment values.			*/
} PPPParamsFill;

/* Comment:
 * Extended to support PPPoE.
 *
 */

/*****************************************************************************
PPPStatusSearchInfo Description:
The PPP Status Search is used to retrieve a particular field in the
PPP Status structure, which fall within the range specified by the
ulSearchRangeLow - ulSearchRange values.  It uses the ReturnItemId
and uiSearchItemId, as a basis for the search and returns the values
of the ReturnItemId using the ulItem array.

Defined values for uiReturnItemId/uiSearchItemId:
PPP_STATUS_STREAM_INDEX			0	(4-bytes)
PPP_STATUS_LCP_STATE				1	(1-byte)
PPP_STATUS_IPCP_STATE			2	(1-byte)
PPP_STATUS_IPXCP_STATE			3	(1-byte)
PPP_STATUS_FAILURE_CODE			4	(1-byte)
PPP_STATUS_LOCAL_MAGICNUMBER	5	(4-bytes)
PPP_STATUS_LOCAL_IPADDR			6	(4-bytes)
PPP_STATUS_PEER_IPADDR			7	(4-bytes)
PPP_STATUS_WEGOT_OPTIONS		8	(4-bytes)
PPP_STATUS_WEACK_OPTIONS		9	(4-bytes)
PPP_STATUS_MRU						10	(2-bytes)
PPP_STATUS_MTU						11	(2-bytes)
PPP_STATUS_LATENCY				12	(8-bytes)
PPP_STATUS_PPPOE_STATE			13	(1-byte)
PPP_STATUS_PPPOE_MODE			14	(1-byte)
PPP_STATUS_PPPOE_SESSIONID		15	(2-bytes)
PPP_STATUS_PPPOE_SOURCE_MAC	16	(6-bytes)
PPP_STATUS_PPPOE_DEST_MAC		17	(6-bytes)

PPP_STATUS_PPPOE_IPV6CP_STATE	   18 - Not Supported
PPP_STATUS_OUR_IFACE_ID		      19 - Not Supported
PPP_STATUS_PEER_IFACE_ID		   20 - Not Supported
PPP_STATUS_OSI_STATE			      21 - Not Supported
PPP_STATUS_OSI_ALIGNMENT		   22 - Not Supported
PPP_STATUS_OSI_RX_ALIGNMENT	   23 - Not Supported
PPP_STATUS_MIN_OUR_IPV4_ADDR	   24, Return smallest negotiated local IPv4
                                    - Not Supported
PPP_STATUS_MAX_PEER_IPV4_ADDR	   25, Return largest negotiated peer IPv4 addr
                                    - Not Supported  
PPP_STATUS_MIN_OUR_IPV6_ADDR	   26, Return smallest negotiated local IPv6 addr
                                    - Not Supported 		
PPP_STATUS_MAX_PEER_IPV6_ADDR	   27, Return largest negotiated IPv6 addr
                                    - Not Supported 

Example:
	PPPStatusSrchInfo.uipppStartIndex = 0;
	PPPStatusSrchInfo.uipppCount = 10;
	PPPStatusSrchInfo.uipppReturnItemId = PPP_STATUS_STREAM_INDEX;
	PPPStatusSrchInfo.uipppSearchItemId = PPP_STATUS_FAILURE_CODE;
	PPPStatusSrchInfo.ullpppSearchRangeLow = 8;
	PPPStatusSrchInfo.ullpppSearchRangeHigh = 8;

	HTGetStructure $PPP_STATUS_SEARCH_INFO 0 10 0 PPPStatusSrchInfo 0 Hub Slot Port;

	Results obtained:
		ulpppItem[0] = 0x00
		ulpppItem[1] = 0x01
		ulpppItem[2] = 0x02
		...
*/

typedef struct tagPPPStatusSearchInfo
{
	unsigned short	uipppStartIndex;
	unsigned short	uipppCount;
	unsigned short	uipppReturnItemId;
	unsigned short	uipppSearchItemId;
	U64	ullpppSearchRangeLow;
	U64	ullpppSearchRangeHigh;
	unsigned short	uipppReturnItemSize;
	unsigned short	uipppReserved;
	U64	ullpppItem[2048];
} PPPStatusSearchInfo;					/* PPP_STATUS_SEARCH_INFO; */
/* PPPStatusSearchInfo Comment:
*/

/* Stream status item id's */
#define PPP_STATUS_STREAM_INDEX			0
#define PPP_STATUS_LCP_STATE				1
#define PPP_STATUS_IPCP_STATE				2
#define PPP_STATUS_IPXCP_STATE			3
#define PPP_STATUS_FAILURE_CODE			4
#define PPP_STATUS_LOCAL_MAGICNUMBER	5
#define PPP_STATUS_LOCAL_IPADDR			6
#define PPP_STATUS_PEER_IPADDR			7
#define PPP_STATUS_WEGOT_OPTIONS			8
#define PPP_STATUS_WEACK_OPTIONS			9
#define PPP_STATUS_MRU						10
#define PPP_STATUS_MTU						11
#define PPP_STATUS_LATENCY					12
#define PPP_STATUS_PPPOE_STATE			13
#define PPP_STATUS_PPPOE_MODE				14
#define PPP_STATUS_PPPOE_SESSIONID		15
#define PPP_STATUS_PPPOE_SOURCE_MAC		16
#define PPP_STATUS_PPPOE_DEST_MAC		17

#define PPP_STATUS_PPPOE_IPV6CP_STATE	18 /* not supported */
#define PPP_STATUS_OUR_IFACE_ID		   19 /* not supported */
#define PPP_STATUS_PEER_IFACE_ID		   20 /* not supported */
#define PPP_STATUS_OSI_STATE			   21 /* not supported */
#define PPP_STATUS_OSI_ALIGNMENT		   22 /* not supported */

#define PPP_STATUS_OSI_RX_ALIGNMENT		23 /* not supported */
#define PPP_STATUS_MIN_OUR_IPV4_ADDR	24 /* Return smallest negotiated local IPv4,
                                          /* not supported */
#define PPP_STATUS_MAX_PEER_IPV4_ADDR	25 /* Return largest negotiated peer IPv4 addr, 
                                          not supported */
#define PPP_STATUS_MIN_OUR_IPV6_ADDR	26 /* Return smallest negotiated local IPv6 addr,
                                          not supported */
#define PPP_STATUS_MAX_PEER_IPV6_ADDR	27 /* Return largest negotiated IPv6 addr,
                                          not supported */

/* IPv6 support */

/* Constants for detailed states */
#define PPP_NCPS_INIT			0	/* initial state */
#define PPP_NCPS_STARTING		1	/* starting state */
#define PPP_NCPS_CLOSED			2	/* LINK closed */
#define PPP_NCPS_STOPPED		3	/* LINK stopped */
#define PPP_NCPS_CLOSING		4	/* LINK is closing */
#define PPP_NCPS_STOPPING		5	/* LINK is stopping */
#define PPP_NCPS_REQSENT		6	/* request sent */
#define PPP_NCPS_ACKRCV			7	/* ack received */
#define PPP_NCPS_ACKSENT		8	/* ack sent */
#define PPP_NCPS_OPENED			9	/* LINK is opened */

/* PPP IPv6 Configuration Type */

/********************************************************************************
 * Structure:   PPPIPv6ParamCfg
 * iType1:      PPP_IPV6_CONFIG, PPP_IPV6_CONFIG_INFO
 * Function:    HTSetStructure, HTGetStructure
 *
 * PPPIPv6ParamCfg Description:

 Setup or retrieve PPP configuration.  Use iType2 to indicate the first
 instance.  To retrieve configurations for multiple sessions, use an array of 
 PPPIPv6ParamCfg structures.

 Defined values for

 Current PPP negotiation options:
	PPPO_MRU                0x0001
	PPPO_USECHAPAUTH        0x0010
	PPPO_USEPAPAUTH         0x0020
	PPPO_USEMAGIC           0x0080
	PPPO_USENONE            0x0000

 CHAP authentication:
	PPP_CHAPMD5             0x05
	PPP_CHAPMS              0x80

 PPP Configure structure default values:
	PPP_CONFIGURE_MRU           1500
	PPP_CONFIGURE_MAXFAILURE    5
	PPP_CONFIGURE_MAXCONFIGURE  10
	PPP_CONFIGURE_MAXTERMINATE  2
	PPP_CONFIGURE_MAGICNUMBER   2
	PPP_CONFIGURE_ECHOFREQ      1
	PPP_CONFIGURE_ECHOERRFREQ   0

 PPPoE Parameters:-
 
   Mode:

   PPP_OE_CLIENT						0x01
   PPP_OE_SERVER						0x02	- Not supported yet

   Options:

   PPP_OE_SELECT_AC_BY_SVCNAME   		0x0001
   PPP_OE_SELECT_AC_BY_ACNAME    		0x0002
   PPP_OE_USE_ZEROLEN_SVCNAME    		0x0004
   PPP_OE_OFFER_AVAILABLE_SERVICE		0x0010	- Not supported yet
   PPP_OE_USE_DOUBLE_TIMEOUT     		0x1000
*********************************************************************************/
typedef struct tagPPPIPv6ParamCfg 
{
	unsigned long       ulpppInstance;   /* Start instance ID of PPP when multiple PPP instances used */
	unsigned long       ulpppCount;      /* Number of times to repeat */

	/* LCP Configurations options to negotiate/accept */
	unsigned short      uipppWeWish;     /* options we configure-request */
	unsigned short      uipppWeMust;     /* options we must have acked */
	unsigned short      uipppWeCan;      /* options we can ack */

	/* LCP parameters */
	unsigned char       ucpppEnablePPP;    /* Enable LCP */
	unsigned char       ucpppCHAPAlgo;     /* CHAP algorithm */
	unsigned short      uipppMRU;          /* Max. Receive Unit - default 1500 */
	unsigned short      uipppMaxFailure;   /* times to send CONF-NAK unacked - default 5 */
	unsigned short      uipppMaxConfigure; /* times to send CONF unacked - default 10 */
	unsigned short      uipppMaxTerminate; /* times to send TERM unacked - defautl 2 */
	unsigned long       ulpppMagicNumber;  /* Magic Number */

	/* Authentication */
	unsigned char       ucpppOurID[32];     /* Login ID for authentication */
	unsigned char       ucpppOurPW[32];		/* Out Password for authentication */
	unsigned char       ucpppPeerID[32];	/* Login ID for authentication */
	unsigned char       ucpppPeerPW[32];	/* Inc Password for authentication */


	/* IP parameters */
	unsigned char       ucpppIPEnable;           /* Enable IP NCP - if LCP is enabled */
	unsigned char       ucpppNegotiateIPAddr;    /* Enable IP Address Negotiate */
	unsigned short      uipppIPCompress;         /* Reserved */
	unsigned char       ucpppOurIPAddr[4];       /* Local IP addr */
	unsigned char       ucpppPeerIPAddr[4];      /* Peer IP addr */


	/* IPX parameters */
	unsigned long       ulpppIPXNet;            /* IPX net */
	unsigned char       ucpppIPXEnable;         /* Enable IPX NCP - if LCP is enabled */
	unsigned char       ucpppIPXNode[6];        /* IPX node */
	unsigned char       ucReserved;             /* Reserved */
	unsigned short      uipppIPXCompress;       /* Reserved */
	unsigned short      uipppIPXRoutingProt;    /* IPX routing protocol */
	unsigned short      uipppRestartTimer;      /* times to send TERM unacked - defautl 2 */
	unsigned short      uipppRetryCount;        /* Number of time to retry before giving up */
	unsigned char       ucModFrame;             /* Modify frame with dynamic parameters */              
	unsigned char       ucReserved1;            /* Reserved */
    
	/* PPPoE Parameters */
	unsigned char           ucMode;             /* Mode */
	unsigned char           ucTimer;            /* In seconds */
	unsigned short          uiRetry;            /* Retry */
	unsigned short          uiOptions;          /* Options */
	unsigned char           ucSourceMAC[6];     /* Source MAC address */
	unsigned char           ucDestMAC[6];       /* Destination MAC address */
	unsigned short          uiServiceNameLen;   /* Service name length */
	unsigned char           ucServiceName[16];  /* Service name */
	unsigned short          uiAcNameLen;        /* Ac name length */
	unsigned char           ucAcName[16];       /* Ac name */
	unsigned long           ulConnectionHandle; /* Reserved for the Titan ATM card */
    
	/* MPLS control plane */
	unsigned char           ucMPLSEnable;           /* Enable MPLS control plane */

	/* OSI control plane */
	unsigned char           ucOSIEnable;            /* Enable OSI control plane */
	unsigned char           ucNegotiateNpduPad;     /* Negotiate NPDU */
	unsigned char           ucOSITxNpduPad;           /* This field specifies the offset of the
                                                       beginning of the OSI NPDU relative to the
                                                       beginning of the PPP packet header(not
                                                       including any leading Flag Sequences) 
													   The number of octet of zero padding.*/


	/* IPv6 control plane Parameters */
	unsigned char           ucpppIPv6Enable;        /* Enable IPv6 control plane */
	unsigned char           ucIPv6NegotiateIfaceId; /* Enable IPv6 control plane Interface Identifier
                                                       negotiation option.  Currently, if 
                                                       ucpppIPv6Enable is set to 1, the card
                                                       will force this to enable. */
	unsigned char           ucOSIRxNpduPad;
	unsigned char           ucReserved2;            /* Reserved */
	unsigned char           ucpppOurIPv6Addr[16];   /* 128 bit our IPv6 address. The lower 64
                                                       bits are used for IPv6 control plane interface identifier
                                                       negotiation and the upper 64 bits are used to
                                                       set the port IPv6 address.  If the lower 64
                                                       bits are set to 0, the card will try to get the
                                                       64 bit interface identifier from the peer */
	unsigned char           ucpppPeerIPv6Addr[16];  /* 128 bit peer IPv6 address. The lower 64 bits
                                                       are used for IPv6 control plane interface identifier
                                                       negotiation and the upper 64 bits are used to
                                                       set the routing information of the peer for the
                                                       port.  If the peer asks us to provide the 64 bit
                                                       interface identifier, the card will provide this
                                                       lower 64 bits.  If the lower 64 bit is 0, then the
                                                       card will generate a random number and send it to
                                                       the peer. */
} PPPIPv6ParamCfg;


/********************************************************************************
 * Structure:   PPPIPv6StatusInfo
 * iType1:      PPP_IPV6_STATUS_INFO
 * iType2:      PPP Instance         current set 0
 * iType3:      PPP Count            current set 1
 * Function:    HTGetStructure
 *
 * PPPIPv6StatusInfo Description: 

   Get PPP IPv6 Status. PPPIPv6StatusInfo records the States, failure code and the negotiated
	fields for each PPP session.
 
	Defined values for
 
   PPP Status, LCP State:
   PPP_LCP_UP            	0
   PPP_LCP_DOWN				1
   PPP_LCP_AUTHENTICATING	2
 
   PPP Status, NCP State:
   PPP_NCP_UP               0
   PPP_NCP_DOWN             1
 
 
   PPP Status, LCP/NCP Failure reason code:
   LCP_CLOSE_REASON_UNKNOWN             0x00
   LCP_CLOSE_AUTH_FAILURE_NO_RSP        0x01
   LCP_CLOSE_AUTH_FAILURE_LOCAL_REJ     0x02
   LCP_CLOSE_AUTH_FAILURE_PEER_REJ      0x03
   LCP_CONFIG_FAILURE                   0x04
   LCP_CONFIG_TIMEOUT                   0x05
   LCP_CONFIG_FAILURE                   0x06
   NCP_CONFIG_TIMEOUT                   0x07
   NO_FAILURE                           0x08
   PPP_OE_TIMEOUT_NO_RSP                0x09
   PPP_OE_GEN_ERR                       0x0A
   PPP_OE_SVC_ERR                       0x0B
   PPP_OE_AC_ERR                        0x0C
   PPP_OE_NO_AC                         0x0D
  
   PPP Status, PPP_OE Session State:
   PPP_OE_INACTIVE     						0
   PPP_OE_STARTED      						1
   PPP_OE_PADO_SENT    						2
   PPP_OE_PADR_SENT    						3
   PPP_OE_SESSION_STATE						4

   PPP Status, LCP/IPCP detailed state
   PPP_LCP_IPCP_INIT    					0	
   PPP_LCP_IPCP_STARTING 					1	
   PPP_LCP_IPCP_CLOSED  					2	
   PPP_LCP_IPCP_STOPPED 					3	
   PPP_LCP_IPCP_CLOSING 					4	
   PPP_LCP_IPCP_STOPPING 					5	
   PPP_LCP_IPCP_REQSENT 					6	
   PPP_LCP_IPCP_ACKRCV  					7	
   PPP_LCP_IPCP_ACKSENT 					8	
   PPP_LCP_IPCP_OPENED  					9	

 ********************************************************************************/
typedef struct tagPPPIPv6StatusInfo
{
    unsigned long   ulpppInstance;      /* Start inst. ID of PPP when multiple used*/
    unsigned long   ulpppCount;         /* Number of times to repeat */
    unsigned char   ucppplcpState;      /* LCP state */       
    unsigned char   ucpppipcpState;     /* IP NCP state */
    unsigned char   ucpppipxcpState;    /* IPX NCP state */
    unsigned char   ucppplcpFailCode;   /* LCP failure code */
    unsigned long   ulpppMagicNumber;   /* Negotiated Magic Number */
    unsigned char   ucpppOurIPAddr[4];  /* Negotiated local IP address */
    unsigned char   ucpppPeerIPAddr[4]; /* Negotiated Peer IP address */
    unsigned long   ulpppWeGot;         /* Options we got ack */
    unsigned long   ulpppWeAcked;       /* Options we did ack */
    unsigned short  uipppMRU;           /* Negotiated RX Max Unit */
    unsigned short  uipppMTU;           /* Negotiated TX Max unit */

    U64				ullpppLatency;      /* Total time to establish a PPP session in 100 ns */
    U64				ullpppTotalLatency; /* Total time to establish all PPP sessions in 100 ns */
	
    /* PPPoE */
    unsigned char   ucState;            /* PPPoE Session state */
    unsigned char   ucMode;             /* Whether Client/Server? */
    unsigned short  uiSessionID;        /* Session ID */
    unsigned char   ucSourceMAC[6];     /* Source MAC address */
    unsigned char   ucDestMAC[6];       /* Destination MAC address */
        
    /* newly added PPP status for TeraMetrics cards */
    unsigned short  uiRetries;              /* Number of attempts of establishing a PPP session */
    unsigned char   uclcpDetailedState;     /* Detail LCP state according to RFC */
    unsigned char   ucipcpDetailedState;    /* Detail IPCP state according to RFC */

    /* OSI control plane */
    unsigned char   ucosicpState;           /* OSI control plane state */
    unsigned char   ucosiDetailedState;     /* OSI detailed state */
    unsigned char   ucosiTxAlignment;         /* OSI Tx Alignment */
    unsigned char   ucosiRxAlignment;          /* OSI Rx Alignment */

     /* IPV6CP */
    unsigned char   ucipv6cpState;          /* IPv6 control plane state */
    unsigned char   ucipv6cpDetailedState;  /* IPv6 control plane detailed state */
    unsigned char   ucMPLSState;         /* MPLS State */
    unsigned char   ucReserved1;            /* Reserved */
    unsigned char   ucpppOurIPv6Addr[16];   /* Negotiated local IPv6 address */
    unsigned char   ucpppPeerIPv6Addr[16];  /* Negotiated peer IPv6 address */

    unsigned long   ulReserved2;            /* Reserved */
} PPPIPv6StatusInfo;


/********************************************************************************
 * Structure:   PPPSessionStatsInfo
 * iType1:      PPP_SESSION_STATS_INFO
 * iType2:      0
 * iType3:      0
 * Function:    HTGetStructure
 *
 * PPPSessionStatsInfo Description: 
   Get PPP Global Session Statistics with struct PPPSessionStatsInfo. This commands
   provides the global session statistics maintained by the stack.
 ********************************************************************************/
typedef struct 	tagPPPSessionStatsInfo
{
    U64              ullTimeofDay;              /* time of day statistics is updated */
    unsigned long		ulTotalSessionAttempted;   /* Total number of times sessions are initiated 
                                                   (go into active queues) including any retries */
    unsigned long		ulTotalSessionSuccessful;  /* Total number of times sessions are sucessful
                                                   established */
    unsigned long		ulTotalSessionFailed;      /* Total number of times sessions have failed,  
                                                   including multiple retries */
    unsigned long		ulTotalSessionRetries;     /* Total number of times sessions are retried */
    unsigned long		ulNumSessionRetries;       /* Number of sessions being retried. Actual 
                                                   started/in throttle state (???) */
    unsigned long		ulNumSessionFailed;        /* Failed - all retries exhausted - in IDLE state. 
                                                   Session not considered failed once is is restarted
                                                   by the user */
    unsigned long		ulNumSessionCfged;         /* Number of sessions configured by the user */ 
    unsigned long		ulActiveSession;           /* active session */
    unsigned long		ulOpenSession;             /* Num of sessions currently UP */
    unsigned long		ulIdleSession;             /* Num of sessions configured, but not in action */
    unsigned long		ulLinkdownSession;         /* Num of sessions in linkdown state */
    unsigned long		ulThrottleSession;         /* Num of sessions started or being retried, but 
                                                   in throttle state */
    unsigned long		ulTerminateThrottleSession; /* Num of sessions stopped by user, but in 
                                                   terminate throttle state */
    unsigned long		ulTerminatingSession;      /* Num of sessions stopped by user, and terminating */
    unsigned long		ulAvailableSession;        /* Server - available sessions */
    unsigned long    ulEchoReqSent;		         /* Number of echo requests sent */  
    unsigned long    ulEchoReplySent;		      /* Number of echo replies sent */  
    unsigned long    ulEchoReqRcvd;		         /* Number of echo requests received */  
    unsigned long    ulEchoReplyRcvd;		      /* Number of echo replies received 	*/  
    unsigned long    ulEchoReqPerBurst;         /* Number of echo request per burst */  
    unsigned long    ulpppPacktSent;		      /* Packets sent */  
    unsigned long    ulpppPacktRcvd;		      /* Packets received */    
    unsigned long		ulReserved[4];

} PPPSessionStatsInfo;





/////////////////////////////////////////////////////////////////////////////////

/********************************************************************************
 * Structure:   PPPEnhancedConfig
 * iType1:      PPP_ENHANCED_CONFIG, PPP_ENHANCED_CONFIG_INFO
 * Function:    HTSetStructure, HTGetStructure
 *
 * PPPEnhancedConfig Description:

 Setup or retrieve PPP(IPV4 and IPV6)  configuration for Terametrics cards.
 Use iType2 to indicate the first instance.  To retrieve configurations for
 multiple sessions, use an array of PPPEnhancedConfig structures.

 Pos Cards don't support PPP VLAN configuration.
 Defined values for

 Current PPP negotiation options (fields uipppWeWish,uipppWeMust,uipppWeCan):
	PPPO_MRU                0x0001
	PPPO_USECHAPAUTH        0x0010
	PPPO_USEPAPAUTH         0x0020
	PPPO_USEMAGIC           0x0080
	PPPO_USENONE            0x0000

 CHAP authentication (ucpppCHAPAlgo field):
	PPP_CHAPMD5             0x05
	PPP_CHAPMS              0x80

 PPPoE Parameters:-
 
   Mode( ucMode field):

   PPP_OE_CLIENT						0x01
   PPP_OE_SERVER						0x02	- Not supported yet

   Options (uiOptions field):

   PPP_OE_SELECT_AC_BY_SVCNAME   		0x0001
   PPP_OE_SELECT_AC_BY_ACNAME    		0x0002
   PPP_OE_USE_ZEROLEN_SVCNAME    		0x0004
   PPP_OE_OFFER_AVAILABLE_SERVICE		0x0010	- Not supported yet
   PPP_OE_USE_DOUBLE_TIMEOUT     		0x1000
	PPP_OE_ADD_EOL_TAG						0x0008
	PPP_OE_IGNORE_EOL_TAG					0x0020

   Modify Frames (ucModFrame field):
	Modify frame with dynamic data from	session negotiation.	
	Default										0x00									
	PPP_MOD_SRCIP								0x01  modify the Local IP
	PPP_MOD_SESSID								0x02  modify PPP Session ID
	PPP_MOD_DESTMAC							0x04	modify Destination MAC address
	PPP_MOD_SRCMAC 							0x08	modify Source MAC address
   PPP_MOD_SRCIPV6		               0x10
   PPP_MOD_DESTIPV6			            0x20
   PPP_MOD_SESSION_STATUS		         0x40

  
 PPP Configure structure default values:
	PPP_CONFIGURE_MRU           1500
	PPP_CONFIGURE_MAXFAILURE    5
	PPP_CONFIGURE_MAXCONFIGURE  10
	PPP_CONFIGURE_MAXTERMINATE  2
	PPP_CONFIGURE_MAGICNUMBER   2
	PPP_CONFIGURE_ECHOFREQ      1
	PPP_CONFIGURE_ECHOERRFREQ   0
*********************************************************************************/
typedef struct tagPPPEnhancedConfig
{
	unsigned long       ulpppInstance;   /* starting PPP instance ID */
	unsigned long       ulpppCount;      /* number of PPP instances to be 
                                           configured */

	/* LCP configuration options to be negotiated/accepted */
	unsigned short      uipppWeWish;     /* options wished to be used in Conf-Req */
	unsigned short      uipppWeMust;     /* options that must be acked before peer's 							
                                           Conf-Ack */
	unsigned short      uipppWeCan;      /* options we can ack for peer's Conf-Ack */

	/* LCP parameters */
	unsigned char       ucpppEnablePPP;    /* enable LCP when the link is up/ready */
	unsigned char       ucpppCHAPAlgo;     /* the algorithm of CHAP */
	unsigned short      uipppMRU;          /* Max. Receive Unit - default 1500 */
	unsigned short      uipppMaxFailure;   /* times to send CONF-NAK unacked - default 5 */
	unsigned short      uipppMaxConfigure; /* times to send CONF unacked - default 10 */
	unsigned short      uipppMaxTerminate; /* times to send TERM unacked - defautl 2 */
	unsigned long       ulpppMagicNumber;  /* Magic Number */

	/* Authentication */
	unsigned char       ucpppOurID[32];     /* Login ID for authentication */
	unsigned char       ucpppOurPW[32];		/* Out Password for authentication */
	unsigned char       ucpppPeerID[32];	/* Login ID for authentication */
	unsigned char       ucpppPeerPW[32];	/* Inc Password for authentication */


	/* IP parameters */
	unsigned char       ucpppIPEnable;           /* Enable IP NCP - if LCP is enabled */
	unsigned char       ucpppNegotiateIPAddr;    /* Enable IP Address Negotiate */
	unsigned short      uipppIPCompress;         /* Reserved */
	unsigned char       ucpppOurIPAddr[4];       /* Local IP addr */
	unsigned char       ucpppPeerIPAddr[4];      /* Peer IP addr */


	/* IPX parameters */
	unsigned long       ulpppIPXNet;            /* IPX net */
	unsigned char       ucpppIPXEnable;         /* Enable IPX NCP - if LCP is enabled */
	unsigned char       ucpppIPXNode[6];        /* IPX node */
	unsigned char       ucReserved;             /* Reserved */
	unsigned short      uipppIPXCompress;       /* Reserved */
	unsigned short      uipppIPXRoutingProt;    /* IPX routing protocol */
	unsigned short      uipppRestartTimer;      /* times to send TERM unacked - defautl 2 */
	unsigned short      uipppRetryCount;        /* Number of time to retry before giving up */
	unsigned char       ucModFrame;             /* Modify frame with dynamic parameters */              
	unsigned char       ucReserved1;            /* Reserved */
    
	/* PPPoE Parameters */
	unsigned char        ucMode;             /* Mode,PPP_OE_CLIENT,PPP_OE_SERVER	 */
	unsigned char        ucTimer;            /* In seconds */
	unsigned short       uiRetry;            /* Retry */
	unsigned short       uiOptions;          /* Options */
	unsigned char        ucSourceMAC[6];     /* Source MAC address */
	unsigned char        ucDestMAC[6];       /* Destination MAC address */
	unsigned short       uiServiceNameLen;   /* Service name length */
	unsigned char        ucServiceName[16];  /* Service name */
	unsigned short       uiAcNameLen;        /* Ac name length */
	unsigned char        ucAcName[16];       /* Ac name */
	unsigned long        ulConnectionHandle; /* Reserved for the Titan ATM card */
    
	/* MPLS control plane */
	unsigned char        ucMPLSEnable;           /* Enable MPLS control plane */

	/* OSI control plane */
	unsigned char        ucOSIEnable;            /* Enable OSI control plane */
	unsigned char        ucNegotiateNpduPad;     /* Negotiate NPDU */
	unsigned char        ucOSITxNpduPad;           /* This field specifies the offset of the
                                                       beginning of the OSI NPDU relative to the
                                                       beginning of the PPP packet header(not
                                                       including any leading Flag Sequences) 
													   The number of octet of zero padding.*/


	/* IPv6 control plane Parameters */
	unsigned char       ucpppIPv6Enable;        /* Enable IPv6 control plane */
	unsigned char       ucIPv6NegotiateIfaceId; /* Enable IPv6 control plane Interface Identifier
                                                       negotiation option.  Currently, if 
                                                       ucpppIPv6Enable is set to 1, the card
                                                       will force this to enable. */
	unsigned char       ucOSIRxNpduPad;          /* Negotiate interface ID */
	unsigned char       ucReserved2;            /* Reserved */
	unsigned char       ucpppOurIPv6Addr[16];   /* 128 bit our IPv6 address. The lower 64
                                                       bits are used for IPv6 control plane interface identifier
                                                       negotiation and the upper 64 bits are used to
                                                       set the port IPv6 address.  If the lower 64
                                                       bits are set to 0, the card will try to get the
                                                       64 bit interface identifier from the peer */
	unsigned char        ucpppPeerIPv6Addr[16];  /* 128 bit peer IPv6 address. The lower 64 bits
                                                       are used for IPv6 control plane interface identifier
                                                       negotiation and the upper 64 bits are used to
                                                       set the routing information of the peer for the
                                                       port.  If the peer asks us to provide the 64 bit
                                                       interface identifier, the card will provide this
                                                       lower 64 bits.  If the lower 64 bit is 0, then the
                                                       card will generate a random number and send it to
                                                       the peer. */


	unsigned char			ucEnableVLAN; 		/* Enable/Disable VLAN */	
	unsigned char 			ucReserved3;
	unsigned char			ucPRI;					/* user vlan priority 0-7 (3 bits) */
	unsigned char			ucCFI;					/* vlan canonical format indicator
                                             1 = RIF present, 0 = RIF absent  */
	unsigned short			uiVID;		         /* VLAN ID (12 bits) */				
	unsigned long	      ulStreamIndex;		/* Data plane associated stream
													0xFFFFFFFF means all related stream */
	unsigned char 		      ucReserved4[64];							
}PPPEnhancedConfig;








/*************************************************************
 ***** OBSOLETE section
 *************************************************************/
#define PPP_SET_CONFIG	  		PPP_CONFIG		/* Set PPP configuration structure
																params.					 				*/

#endif


