/*
	Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
	Netcom Systems, Inc.
	Copyright (C) 1993-1999. All Rights Reserved.
*/
#ifndef _TCPISP_H_
#define _TCPISP_H_

#include "ettypes.h"

#if   defined WIN32
#include <pshpack1.h>
#endif

#define MAX_URL 20
#define MAX_URI 20
#define MAX_COOKIE 20
#define MAX_AGENT 20
#define MAX_URL_LEN 8
#define MAX_COOKIE_LEN 128
#define MAX_URI_LEN 128
#define MAX_AGENT_LEN 128
#define MAX_URL_OBJ_LEN 20

#define TCP_SET_ISP_CONNECTIONDATA				0x0060
#define TCP_SET_ISP_CONNECTIONDATA_CURVE		0x0061
#define TCP_SET_ISP_CONNECTIONDATA_ARRAY		0x0062

#define TCP_URL_ADD					0x0063

#define TCP_ARP_ALL					0x7012
#define TCP_REARP_ALL				0x7013

#define TCP_ISP_RESERVED_COMMAND 0x0079

#define TCPISP_CONNECTIONDATA_TYPE_UNKNOWN       0
#define TCPISP_CONNECTIONDATA_TYPE_LISTEN        1
#define TCPISP_CONNECTIONDATA_TYPE_CONNECTION    2

#define TCP_CONNECT           	0x7001
#define TCP_LISTEN_ONE         	0x7002


#define TCP_CLOSE_ONE           	0x7003
#define TCP_CLOSE_ALL         	0x7004
#define TCP_RESET             	0x7005
#define TCP_RESET_ALL         	0x7006
#define TCP_GET_CONNECTIONS   	0x7007
#define TCP_GET_CONNECTION      	0x7008
#define TCP_GET_TX_LOG        	0x7009
#define TCP_GET_RX_LOG        	0x700a
#define TCP_GET_RX_LOG_2        	0x700b
#define TCP_START_TEST        	0x700c
#define TCP_INIT_STACK_MODE		0x700d
#define TCP_END_STACK_MODE			0x700e
#define TCP_ARP_PARAMS        	0x700f
#define TCP_SEND_DATA          	0x7010
#define TCP_GET_CONNECTIONS_INFO 0x7011
#define TCP_ARP_SET_ENTRY     	0x7020
#define TCP_ARP_GET_ENTRIES   	0x7021

#define TCP_GET_ALL_CONNECTIONS_STATUS    0x7029

#define TCP_ICMP_PING				0x7030
#define TCP_ICMP_GET_ROUTE     	0x7031

#define TCP_DISABLE_DATA_SEND    0x7032
#define TCP_ENABLE_DATA_SEND     0x7033

#define TCP_MAX_CONNECTIONS		2048

#define TCP_CONN_GAP_CFG 					0x7041
#define TCP_CONN_EVENT_INFO			 	0x7042
#define L3_HIST_TCP_CONNECTION_INFO		0x7043
#define TCP_CONN_STATE_INFO 				0x7044
#define TCP_TIME_COUNT_INFO				0x7045
#define TCP_TEAR_DOWN						0x7046
#define TCP_TEAR_DOWN_CLEAN				0x7047

#define TCP_HTTP_CONNECTION_CONFIG		0x7050
#define TCP_HTTP_URI_CONFIG				0x7051
#define TCP_EXTENDED_CONN_EVENT_INFO	0x7052
#define TCP_HTTP_EXTENDED_CONN_EVENT_INFO 0x7057
#define TCP_HTTP_EXTENDED_CONFIG		0x7058
#define TCP_HTTP_STOP_EXTENDED_TEST		0x7059
#define TCP_HTTP_START_VERIFICATION		0x7060
#define TCP_HTTP_STOP_VERIFICATION		0x7061
#define TCP_HTTP_COOKIE_CONFIG			0x7053
#define TCP_HTTP_AGENT_CONFIG			0x7055
#define TCP_HTTP_URL_OBJ_LEN_CONFIG		0x7056
#define TCP_GET_URI_DISTRIBUTION_INFO	0x7054
#define TCP_GET_URI_DISTRIBUTION			TCP_GET_URL_DISTRIBUTION

#define TCP_GET_TX_TIME_INFO           0x7048  /* for SmartTCP SYN time stamps on Tx Card */
#define TCP_SET_TEARDOWN_TIME_MODE     0x7049  /* for SmartTCP FIN time stamps on Tx Card */
#define TCP_SET_EXTENSION_MODE         0x709A  /* for SmartTCP extension*/
#define TCP_SET_CONFIG_EXT					0x709B  /* for SmartTCP 6XXX dispatch mode, VIP is per server card*/
#define TCP_GET_URL_DISTRIBUTION_INFO  0x709C  /* for SmartTCP, URL distribution*/
#define TCP_GET_URL_DISTRIBUTION       0x709D  /* for SmartTCP, no of url distibution count in the card*/
#define TCP_CONN_REQUEST_TRIGGER			1005
#define TCP_ADD_GENERATOR_ADDR			1015
#define TCP_ADD_ACCEPTOR_ADDR				1020
#define TCP_CFG_CONNECT_REQUEST			1025
//support for websuite2.0
#define TCP_PREPARE_TEST			   0x7062
#define TCP_CLEAR_STREAM			   0x7063
#define TCP_SETUP_STREAM			   0x7064
#define TCP_HIST_ACTIVE_TEST_INFO	   0x7065
#define TCP_HIST_TCP_CONNECTION_INFO   0x7066
#define TCP_GET_TEST_STATUS			   0x7067	

typedef struct tagTCPTimeInfoCount
{
	unsigned long  ulTest;
	unsigned long  ulRecords;
} TCPTimeInfoCount;

typedef struct tagTCPGaps
{
	unsigned long  ulSYNGap;
	unsigned long  ulFINGap;
	unsigned long  ulInterframeGap;
	unsigned long  ulTimeInterval;
} TCPGaps; 


typedef struct tagTCPConnectionStatusOnly
{
	 unsigned short  uiConnId;
	 unsigned char   ucConnected;
		/*unsigned char   ucClosed;*/
		/*unsigned char   ucReseted;*/
} TCPConnectionStatusOnly;   

/*******************************************************************/
/* TCPStats Description:
	The statistics collected by this testing are in addition to the normal
	packet and octet count and rate statistics that will be generated by
	the SmartCard. This is the structure we use it to retrieve the statistics.
*/

typedef struct tagTCPConnEventInfo
{
	unsigned long   InitiatedConnections;            /* # of connection requests (SYN) sent by this card */
	unsigned long   ConnectionReqRecv;               /* # of unique connection requests (SYN) recvd by this card that were not directed to an openned conn. */
	unsigned long   UnexpectedConnReq;               /* # of connection requests (SYN) recvd that cooresponded to a connection that already exists.
																	  *   The previous connection is overwritten by this new connection */
	unsigned long   SYNACKSent;                      /* # of SYNACK sent by this card */
	unsigned long   ExpectedSYNACKRecv;              /* # of SYNACK received by this card that were expected.  This card expects SYNACKs for only
																		 connections it requested to open (had previously sent a SYN packet */
	unsigned long   UnexpectedSYNACKRecv;            /* # of times it received a SYNACK for a connection this card did not initiate. */
	unsigned long   DuplicatedSYNACKRecv;            /* # of SYNACKs received for a connection that already received a SYNACK */
	unsigned long   CloseFINACKSent;                 /* # of initial FINs sent for this connection */
	unsigned long   AckFINACKSent;                   /* # of FINs sent after receving first FIN.  final FIN */
	unsigned long   ExpectedFINACK;                  /* # of connection close requests (FINACKs) received after a connection has been openned completely,
																		 but before this card initiated any close connections */
	unsigned long   ExpectedFinalFINACK;             /* The final connection close requests (FINACKs) received after this card initiated a close. */
	unsigned long   UnexpectedFINACK;                /* # of FIN's received when not connection has been established */
	unsigned long   UnexpectedFINACKWaitingForAck;   /* # of FIN's received while waiting for the final ACK of a connection creation */
   unsigned long   UnexpectedFINACKAfterRecvFin;    /* # of FIN's received after a FIN was receive and the FINACK sent */
   unsigned long   ACKSent;                         /* # of ACKs for SYNACKs sent */
	unsigned long   FinalFIN_ACKSent;                /* # of ACKs for the final/last FIN sent */
   unsigned long   SYNACK_ACKRecv;                  /* # of ACKs of a SYNACK request received */
   unsigned long   FINACK_ACKRecv;                  /* # of ACKs received after FIN was received and FINACK sent */
   unsigned long   NoConnectUnexpectedACKRecv;      /* # of ACKs received for connections that do not exist on this card */
   unsigned long   RSTRecv;                         /* # of RSTs received regardless if a connection is openned or not */
   unsigned long   RSTRecvForConnection;            /* # of RSTs received for connections that exist or exist partially */
   unsigned long   CurrentConnections;              /* SYNs sent (add2), SYNs received, SYN/SYNACK/no close --,
																	  * another SYN for connection openned, SYN/SYNACK/ACK/no close--,
                                                     * final FIN--, final ack of fins-- */
   unsigned long   AbandonedConnections;            /* RST, SYNs received, */
   unsigned long   NoDPResources;                   /* could not send to tx processor */
   unsigned long   NoMoreConnectionEntries;         /* no more free entries for connections */
   unsigned long   NoTxResources;

   unsigned long   NumberOfHTTPGetRx;               /* HTTP Get received by Server */
   unsigned long   NumberOfHTTPReplyRx;             /* HTTP Reply received by Client */
} TCPConnEventInfo;

typedef struct tagTCPConnTimeInfo
{
	unsigned long  notUsed;                /* used internally on 7710 card only */                  
	unsigned long  NumbConnStarted;        /* The number of connections started */
	unsigned long  NumbConnCompleted;      /* The number of connections completed */
	unsigned long  NumbConnCycleCompleted; /* The number of connection cycles
															compeleted (That is the connection
															closed) */
}TCPConnTimeInfo; 


typedef struct tagTCPTransRateInfo {
    unsigned short     Version;          /* used only in HTTcpRecordCount */
    unsigned short     Records;          	 /* used only in HTTcpRecordCount */
    unsigned long      IpAddress;
    unsigned long      FirstTimeStamp;
    unsigned long      LastTimeStamp;
    unsigned long      NumberOfPackets;
    unsigned long      BitMask;
}TCPTransRateInfo;


/*******************************************************************/
/* TCPInfo Description:
	This is the structure we use it to retrieve the stats of all current
	connections. The state is a constant */
#define	IDLE			0
#define	LISTENACK	1
#define	LISTENFIN	2
#define	SYNACK		3
#define	SYNFIN		4
#define	SYNEND		5

typedef struct tagTCPStateInfo
{
	struct tagTCPInfo *link;
	unsigned long  SourceIP;
	unsigned short SourcePort;
	unsigned short DestPort;
	unsigned long  DestIP;
	unsigned char  State;
	unsigned char 	Spare[3];
} TCPStateInfo;  

typedef struct tagTCPConnRequestTrigger
{
 unsigned char  ucEnable;    			/* Enable/disable triggers */
 unsigned char  ucDirection; 			/* Tx or Rx - currently used for both*/
 unsigned char  ucCompCombo; 			/* Trigger types: one of FR_TRIG_COMP*/
 unsigned char  ucReserved1;

 unsigned short uiTrig1Offset;     	/* Offset into frame for pattern											  test in bytes */
 unsigned short uiTrig1Range;      	/* Number of bytes to match */
 unsigned char  ucTrig1Pattern[6]; 	/* Pattern to match */
 unsigned char  ucTrig1Mask[6];    	/* Bit mask for pattern */

 unsigned short uiTrig2Offset;     	/* Offset into frame for pattern											  test in byte */
 unsigned short uiTrig2Range;      	/* Number of bytes to match */
 unsigned char  ucTrig2Pattern[6]; 	/* Pattern to match */
 unsigned char  ucTrig2Mask[6];    	/* Bit mask for pattern */

 unsigned char  ucReserved[20];
}TCPConnRequestTrigger;

typedef struct		tagTCPConnectRequest
{
	unsigned long	ulTCPConnectRequestRate;
	unsigned long	ulBurstCnt;
	unsigned char	ucBurstMode;
	BOOL           bTearDownTCPConnection;
}TCPConnectRequest;

typedef struct tagTCPDataLogEventTx{
	 unsigned short  uiConnId;             /* ? - or tuple?  what about reset? */
	 unsigned short  uiDataLen;            /* payload data ?-include signature-? */
	 unsigned short  uiWindowSize;
	 unsigned long   ulSeq;
	 unsigned long   ulAck;
	 unsigned short  uiIpSequence;
	 unsigned char   ucTcpFlag;
	 unsigned char   ucRetryCount;
} TCPDataLogEventTx;

typedef struct tagTCPDataLogEventRx{
	 unsigned long   ulSrcIpAddress;
	 unsigned short  uiSrcPort;
	 unsigned short  uiDestPort;
	 unsigned long   ulDestIpAddress;
	 unsigned long   ulTxTimeStamp;        /* from packet */
	 unsigned long   ulRxTimeStamp;        /* checked when packet received */
	 unsigned short  uiDataLen;            /* payload data ?-include signature-? */
	 unsigned short  uiWindowSize;
	 unsigned long   ulSeq;
	 unsigned long   ulAck;
	 unsigned short  uiIpSequence;
	 unsigned char   ucTtl;
	 unsigned char   ucTcpFlag;
	 unsigned char   ucFlagMask;	 /* unsigned char   ucFragmented:1; ucChecksumError:1; */
} TCPDataLogEventRx;

typedef struct tagTCPDataLogEventRx2{
   unsigned short   uiDestPort;
   unsigned long    ulRxTimeStamp;
   unsigned long    ulTxTimeStamp;
   unsigned long    ulSeq;
   unsigned short   uiIpSequence;
} TCPDataLogEventRx2;     

typedef struct tagTCPConnectionStatus{
	unsigned short uiConnId;
	unsigned long  ulSrcIpAddress;
	unsigned short uiSrcPort;
	unsigned long  ulDestIpAddress;
	unsigned short uiDestPort;

	unsigned long  ulBeginSequence;
	unsigned long  ulLastSequence;

	unsigned long  ulDataStartTime;
	unsigned long  ulDataStopTime;

	unsigned long  ulMinLatency;
	unsigned long  ulMaxLatency;
	unsigned long  ulTotalLatency;

	unsigned long  ulPacketsTx;
	unsigned long  ulPacketsRx;

	unsigned long  ulTotalTimeouts;

	/*unsigned long  ulTotalRetransmits;*/
	/*unsigned long  ulBeginSequence;*/

	unsigned long	ulTotalDataRetransmits;
	unsigned long  ulStartTimeMS;
	unsigned long  ulStartTimeNS;
	unsigned long  ulStopTimeMS;
	unsigned long  ulStopTimeNS;
	unsigned long  ulConnectionSynNS;
	unsigned long  ulConnectionFinNS;
	unsigned long  ulNumberFragments;
	unsigned long  ulTtlChanges;
	unsigned long  ulDataOutOfOrder;
	unsigned short uiAverageTxWindowSize;

	unsigned char	ucConnStatusMask;
	/* connected, closed, reset, response */
} TCPConnectionStatus;

// New Structure based on the previous struct TCPConnectionStatus but with extra fields
typedef struct tagTCPConnectionsInfo{
	unsigned short uiConnId;
	unsigned long  ulSrcIpAddress;
	unsigned short uiSrcPort;
	unsigned long  ulDestIpAddress;
	unsigned short uiDestPort;

	unsigned long  ulBeginSequence;
	unsigned long  ulLastSequence;

	unsigned long  ulDataStartTime;
	unsigned long  ulDataStopTime;

	unsigned long  ulMinLatency;
	unsigned long  ulMaxLatency;
	unsigned long  ulTotalLatency;

	unsigned long  ulPacketsTx;
	unsigned long  ulPacketsRx;

	unsigned long  ulTotalTimeouts;

	/*unsigned long  ulTotalRetransmits;*/
	/*unsigned long  ulBeginSequence;*/

	unsigned long	ulTotalDataRetransmits;
	unsigned long  ulStartTimeMS;
	unsigned long  ulStartTimeNS;
	unsigned long  ulStopTimeMS;
	unsigned long  ulStopTimeNS;
	unsigned long  ulConnectionSynNS;
	unsigned long  ulConnectionFinNS;
	unsigned long  ulNumberFragments;
	unsigned long  ulTtlChanges;
	unsigned long  ulDataOutOfOrder;
	unsigned short uiAverageTxWindowSize;

	unsigned char	ucConnStatusMask;
	/* connected, closed, reset, response */
	unsigned long	ulIndex;									/* New field vs. TCPConnectionStatus */
	unsigned long   ulObjLen;
	unsigned char	ucReserved[60];						/* New field vs. TCPConnectionStatus */
} TCPConnectionsInfo;

typedef struct TCPExtendedConnEventInfo
{
	unsigned long   ulNoCompletedHTTPSessions;			/* # of completed HTTP sessions lower 32 bits */
	unsigned long   ulNoUnexpectedPacketsRx;			/* # of unexpected packets received */
	unsigned long   ulNoCompletedHTTPSessionsUp32;		/* # of completed HTTP sessions higher 32 bits */
	unsigned long	ulNoCompletedTCPConnections;		/* # of completed TCP connections lower 32 bits */
	unsigned long	ulNoCompletedTCPConnectionsUp32;	/* # of completed TCP connections higher 32 bits */
	unsigned long	ulNoLostTCPConnections;				/* # of TCP connections lost */
	unsigned long	ulDroppedSYN;						/* # of SYN dropped by server */
	unsigned long   ulPacketsDroppedByHW;				/* # of packets dropped by hardware */
	unsigned long	ulNoCookie[20];						/* # of cookie hits (SmartTCP) */
	unsigned long   ulTotalObjectSizeReceived;			/* # of object size received (DataTCP) */
	unsigned long	ulTotalObjectSizeSent;				/* # of object size sent (DataTCP) */
	unsigned long	ulTotalTimeouts;					/* # of timeouts (DataTCP) */
	unsigned long	ulTotalDataRetransmits;				/* # of data retransmissions (DataTCP) */
	unsigned long   ulReserved[98];
} TCPExtendedConnEventInfo;

typedef struct tagARPEntry{
	unsigned long	ulIpAddress;
	unsigned char	ucMacAddress[6];
	unsigned char	ucType; 			/*(1=Dynamic, 2= Static)*/
} ARPEntry;

typedef struct tagTCPSetup
{
	unsigned long	ulMeAddress;
	unsigned short uiMePort;
	unsigned long  ulHisAddress;
	unsigned short uiHisPort;
	unsigned long  ulRouterAddress;
	unsigned short uiRetransmitTimeout;
	unsigned short uiSendTimeout;
	unsigned short uiMss;
	unsigned char  ucTtl;
	unsigned char  ucTos;
	unsigned short uiWindowSize;
	unsigned long  ulDataToSend;
	unsigned char  ucRetry;
	unsigned long  ulFrameGap;
   unsigned long  ulOption1;
   unsigned long  ulOption2;
   unsigned long  ulOption3;
   unsigned long  ulOption4;
}TCPSetup;


/*New Alternative Structure Used in place of SetCommand TCP_CONNECT*/
typedef struct tagTCPISPConnectionData {
	unsigned long   ulType;               /* TCPISP_CONNETIONDATA_TYPE_* */
   unsigned long   ulUserId;
   unsigned long   ulSourceAddress;
   unsigned long   ulVIPAddress;
   unsigned long   ulSourceTCPPort;
   unsigned long   ulDestinationAddress;
   unsigned long   ulDestinationPort;
	unsigned long   ulRouterAddress;      /* 0=no router */
   unsigned long   ulIfg;

   /* IP Controls */
   unsigned long   ulTos;
	unsigned long   ulTtl;                /* max value is 126 */

   /* Misc TCP controls */
   unsigned long   ulSendDataTimeout;
   unsigned long   ulKeepAliveTimer;
   unsigned long   ulWindowSize;
   unsigned long   ulMss;
   unsigned long   ulDataToSend;
   unsigned long   ulAckRatio;

   /* Congestion Control (CC) */
   unsigned long   ulCcOptions;
   unsigned long   ulCcValue1;
   unsigned long   ulCcValue2;

   /* RTT Timer */
   unsigned long   ulRetryCount;
   unsigned long   ulRttOptions;
   unsigned long   ulRttTimeout;
   unsigned long   ulRttAlpha;
   unsigned long   ulRttBeta;
   unsigned long   ulRttDelta;
   unsigned long   ulRttRho;
   unsigned long   ulRttEta;

   unsigned long   ulOptionBits1;
   unsigned long   ulOptionBits2;
   unsigned long   ulOptionBits3;
   unsigned long   ulOptionBits4;

   unsigned long   ulKeepAliveTime;

   unsigned long   ulDataExpected;

   unsigned char   ucURL[20];

   unsigned char   ucReserved[128]; 
} TCPISPConnectionData;

typedef struct tagTCPConnectionHTTPConfig
{
	unsigned long	ulTCPConnectionClient;
	unsigned short	uiHTTPMode;
	unsigned short	uiNoOfHTTPTransactions;
	unsigned short	uiHTTPUseURI;
	unsigned short	uiTCPCloseOptions;
	unsigned char   ucPersistentMode;			
	unsigned char   ucReserved[127];
} TCPConnectionHTTPConfig;

typedef struct tagTCPHTTPExtendedConfig
{
	unsigned short uiExtendedTestMode;		/* (SmartTCP, DataTCP) flag for extended duration test */
	unsigned short uiRetransmitWaitTime;	/* (DataTCP) time between TCP connection close and 
												initiating another one */
	unsigned short uiConnSetupVerifyMode;	/* (SmartTCP) flag for connection setup verification */
	unsigned short uiConnSetupWithGet;		/* (SmartTCP) flag for first HTTP GET/REPLY */
	unsigned short uiCookieMode;			/* (SmartTCP, DataTCP) dynamic/static cookie */
	unsigned short uiDelayedAck;			/* (DataTCP) flag for delayed ack */
	unsigned short uiSimpleReqRep;			/*  SmartTCP flags for simple request reply */
	unsigned short uiKeepAlive;				/* SmartTCP Flags for KeepAlive */
	unsigned short uiReserved[8];		
} TCPHTTPExtendedConfig;

// uiTCPCloseOptions
#define NO_CLOSE                    0
#define SERVER_CLOSE_RST            1
#define CLIENT_CLOSE_RST            2
#define SERVER_CLOSE_3WAY           3
#define CLIENT_CLOSE_3WAY           4
#define SERVER_CLOSE_4WAY           5
#define CLIENT_CLOSE_4WAY           6

typedef struct tagTCPCurveTimeData
{
   /*This structure is called from TCPCurveRecord*/
   unsigned long ulTime;
   unsigned long ulDataSize;
} TCPCurveTimeData;


typedef struct tagTCPCurveRecord
{
   /*This structure is called from TCPISPConnectionDataCurve*/
   unsigned long ulConnId;
   unsigned long ulDataPoints;
   TCPCurveTimeData CurveTimeData[64];
} TCPCurveRecord;

typedef struct tagTCPISPConnectionDataCurve
{
   unsigned long ulRecords;
   TCPCurveRecord CurveRecords[64];
} TCPISPConnectionDataCurve;


typedef struct tagTCPISPConnectionDataArray
{
   unsigned char ucData[1024];
} TCPISPConnectionDataArray;


typedef struct tagTCPISPReservedStructure
{
   unsigned long ulOption1;
   unsigned long ulOption2;
   unsigned long ulOption3;
   unsigned long ulOption4;
   unsigned long ulOption5;
   unsigned long ulOption6;
   unsigned long ulOption7;
   unsigned long ulOption8;
   unsigned long ulOption9;
   unsigned long ulOption10;
   unsigned long ulOption11;
   unsigned long ulOption12;
   unsigned long ulOption13;
   unsigned long ulOption14;
   unsigned long ulOption15;
   unsigned long ulOption16;
   unsigned long ulOption17;
   unsigned long ulOption18;
} TCPISPReservedStructure;

typedef struct tagTCPArpParams
{
	unsigned long	ulClearEntries;
	unsigned long  ulAgingTime;
	unsigned long  ulGetRetries;
	unsigned long  ulGetDelay;
}TCPArpParams;

typedef struct tagTCPArpEntry
{
	unsigned long	ulIpAddress;
	unsigned long  ulMacAddr1_4;
	unsigned short uiMacAddr56;
	unsigned char  ucType;
}TCPArpEntry;

typedef struct tagTCPICMPPing
{
	unsigned long	ulDestIP;
	unsigned long	ulRouterIP;
	unsigned long	ulSourceIP;
	unsigned short	uiTraceRouterNumb;
	unsigned long  ulTraceRouterIndex;
}TCPICMPPing;

typedef struct tagTCPInitStackMode
{
	unsigned long	ulRateThrottle;	/* rate in bytes per second; 0 = full rate;
													rate is rounded down to increments of
													10,000 bytes per second */
}TCPInitStackMode;

typedef struct tagTCPConfigExt
{
	unsigned long ulVIP;
   unsigned char ucDispatchEnable;
   unsigned char ucSMACFilterEnable;
   unsigned short uiSMACFilterValue;
   unsigned short uiHTTPReplyLength;
   unsigned char  ucHTTPReplyCount;
   unsigned char ucReserved;
   unsigned long ulReserved1;
}TCPConfigExt;

typedef struct tagTCPURLOne
{
   char szURL[MAX_URL_LEN];
}TCPURLOne;

typedef struct tagTCPURLArray
{
   unsigned short uiNumberOfURL;
   TCPURLOne URL[MAX_URL]; 
                             
}TCPURLArray;

typedef struct tagTCPURIOne
{
   char szURI[MAX_URI_LEN];
}TCPURIOne;

typedef struct tagTCPURIArray
{
	unsigned long	ulNumOfURIElements;			/* Specifies how many URI's are in this struct */
	TCPURIOne		URI[MAX_URI];
} TCPURIArray;

typedef struct tagTCPCookieOne
{
	char	szCookie[MAX_COOKIE_LEN];
} TCPCookieOne;

typedef struct tagTCPCookieArray
{
	unsigned long	ulNumOfCookies;			/* Specifies how many Cookies are in this struct */
	TCPCookieOne	Cookie[MAX_COOKIE];
} TCPCookieArray;

typedef struct tagTCPAgentOne
{
	char	szAgent[MAX_AGENT_LEN];
} TCPAgentOne;

typedef struct tagTCPAgentArray
{
	unsigned long	ulNumOfAgents;			/* Specifies how many Agents are in this struct */
	TCPAgentOne		Agent[MAX_AGENT];
} TCPAgentArray;

typedef struct tagHTTPURLObjLenArray
{
	unsigned long ulNumOfURLObjLens;		/* Specifies how many URL object lengths are in this struct */
	unsigned long ulURLObjLen[MAX_URL_OBJ_LEN];
} HTTPURLObjLenArray;

typedef struct tagTCPURLDistribution
{
   char szURL[MAX_URL_LEN];
   unsigned long ulCount;
} TCPURLDistribution; 

typedef struct tagTCPURIDistribution
{
   char szURI[MAX_URI_LEN];
   unsigned long ulCount;
} TCPURIDistribution; 

//added for websuite 2.0

typedef struct tagTCPSetupStream
{
	unsigned long ulCount;
	unsigned long ulReserved[8];

}TCPSetupStream;

typedef struct tagTCPTestStatus {
	unsigned long ulStatus;
	unsigned long ulReserved[4];
}TCPTestStatus;


#if   defined WIN32
#include <poppack.h>
#endif

#endif    /* endif _TCPISP_H_ */
