/*****************************************************************************
 * tcpitems.h
 * TCP Configuration definitions
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

/****************************************************************************/

#ifndef _TCPITEMS_H_
#define _TCPITEMS_H_

#include "ettypes.h"

/* Define a few helpful return macros */
#define TCP_IF_ERR_STATE_ABORT( er, bl )		\
	{                    						\
	if( iRsp < 0 )                    		\
		{                    					\
		pTCP_Result->iTestState = (short)er;	\
		bAborting = TRUE;							\
		return bl;									\
		}                    					\
	}

#define TCP_ERR_RETURN(a)							\
	{                    						\
	pTCP_Result->iTestState = (short)a; \
	return;              						\
	}

#define TCP_ERR_RETURN_TRUE(a)						\
	{                    						\
	pTCP_Result->iTestState = (short)a; \
	return TRUE;           						\
	}

#define TCP_ERR_RETURN_FALSE(a)					\
	{                    						\
	pTCP_Result->iTestState = (short)a; \
	return FALSE;          						\
	}

typedef struct		tagSocketRange
{
	int				iRangeIndex;
	unsigned char	ucStartIP[4];
	unsigned char	ucEndIP[4];
	unsigned long	ulStartPort;
	unsigned long	ulEndPort;
	int				iPrimaryKey;
} SocketRange;

typedef struct 	tagTCPGeneratorAddr
{
	SocketRange		SrcRange; 		/* Source address specified by range */
	int				iDestRangeCount;
	SocketRange		*pDestRange; 	/* Destination address specified by range */
}TCPGeneratorAddr;

typedef struct 	tagTCPAcceptorAddr
{
	int		iAddrListIndex;
	unsigned char	ucIP[4];
	unsigned long	ulPort;
}TCPAcceptorAddr;

#endif
/* _TCPITEMS_H_ */

	/*
	 count informatiom
	 Those variables will be used to test Peak Binding Rate,
	 Peak Session Rate, Peak Redirect Rate

	 TEST 1.	Peak Binding Rate:
		The max rate of tcp session establishment during
		ulMaxDuration without failed of establishment if
		we don't tear down any session.

	 TEST 2. Peak Session Rate:
		The max rate of tcp session establishment during
		ulMaxDuration without failed of establishment if
		we continuously setup and tear down session.

	 without failed means:
	 ulEstablishFailedCount == 0 in every card  &&
	 all ulEstablishedCount in Generator side
		== all ulEstablishedCount in Generator side

	 We may need use tcp trigger to make sure that the requsets we
	 received by acceptor are those requests we send out by generators

	 TEST 3. Peak Redirect Rate:
		The max rate of tcp connection requests without failed
		on acceptor of receive syn of SYNs send by generator

	 without failed means:
	 ulSendSynCount in all generator cards ==
		ulRecvSynCount in all acceptor cards
	*/

	/*
		time stamp information, SEQ number and ACK number
		Those variable will be used to test the

		TEST 4. setup performance

		This test measures session setup time as the offered session
		load increases, we use a curve to display their relationship.
		To do so, we need give min rate, max rate and step rate.
		Also specify certain time as time duration. During this
		time duration we use one of the many rate to setup tcp session.
		If no one failed, then we try to establish a single tcp session
		and measure the time it take which is
		ulLastSendSynTime - ulLastRecvAckTime
		We can make sure the one we recv is the one we send by using
		trigger or all those SEQ number and ACK number

		TEST 3. Also we can test redirect latency by
		ulLastSendSynTime - ulLastRecvSynTime
	*/

	/*
	 the number of active connections before first failed can be used
	 to test

	 TEST 5. tcp session capacity

	 Issues tcp connection setup requests at a user selected Rate
	 and test duration. Connections are continuously
	 being setup at the user selected rate without tear down. The
	 first connection setup with fails will indicate that the DUT
	 has reached its connection capacity.
	 We will keep retrieving this structure until the first failed
	 connection happen, then the ulTcpFirstFailedIndex is the session
	 capacity we need test.
	 before reach this point, ulTcpFirstFailedIndex we return -1
	*/

