#ifndef __testcmmn_h
#define __testcmmn_h

#include "atmitems.h"
#include "fritems.h"
#include "gigitems.h"
#include "pppitems.h"


#if defined WIN16 || defined WIN32
#include <windows.h>
#else

#define IDOK                1                                   
#define IDCANCEL            2
#define IDABORT             3
#define IDRETRY             4
#define IDIGNORE            5
#define IDYES               6
#define IDNO                7
#endif

#ifndef _MAX_PATH
#define _MAX_PATH 260
#endif

/* Duplex defines */

#define 	CARD_HALFDUPLEX				0
#define 	CARD_FULLDUPLEX				1

/* Token ring defines */

#define 		CARD_MSAU_STATION		 	0
#define		CARD_MSAU_PORT				1
#define		CARD_TOKEN_DEFAULT		1
#define		CARD_TOKEN_EARLYRELEASE	2

/* Message Mode... */

#define OKMODE								0
#define YESNOMODE							1
#define RETRYMODE							2

/* Status Message Mode... */
#define MM_VERBOSE			0
#define MM_NO_MESSAGE		1
#define MM_TERSE			2
#define MM_ERRORS_ONLY		3

/* Test Error code... */

#define TEST_DONE							1
#define TEST_ABORT						-100
#define TEST_UNDEFINED					-101
#define TEST_CONNECT_FAILED			-102
#define TEST_INVALID_PORT				-103

#define CARD_NOT_RESERVED				-200	

/******************************************************************/
/*
SCTokenRing Description:

*/

typedef struct 	tagSCTokenRing
 {
 BOOL  bTR_MSAU_Port; /* TRUE sets this port as an MSAU port.     */
                      /* FALSE, sets the port as a station device */
 short iTR_EarlyTokenRelease; /* CARD_TOKEN_EARLYRELEASE to enable*/
             /* CARD_TOKEN_DEFAULT to disable early token release */
 char  cSRA[32];      /* char array of Source Route Address fields*/
        /* The first two bytes are the SRA control field,         */
        /* followed by successive byte pairs indicating the "hop" */
        /* addresses associated with this SRA field               */
 BOOL  bSendMonitorPolls; /* 1 = Enabled, 0 = Disabled            */
 BOOL  bUseSRA;           /* 1 = Enabled, 0 = Disabled            */
 BOOL  bUseSNAPFrames;    /* 1 = Enabled, 0 = Disabled            */
 }	SCTokenRing;

/******************************************************************/
/*
SCAtm Description:
*/
typedef struct tagSCAtm
 {
 ATMELANRegister  ElanRegister; /* The ELAN registration params   */
										  /*   see atmitems.h for details   */
 ATMConfigureDUT  ConfigureDUT; /* ATM port configuration params  */
										  /*   see atmitems.h for details   */
 } SCAtm;


/******************************************************************/
/*
SCFrameRelay Description:
*/
typedef struct tagSCFrameRelay
 {
 FRLineCfg           Line;       		/* The Line params for this port */
 FRCardCfg           Card;       		/* Card cfg params for this port */
 FRLmiCfg            Lmi;        		/* The LMI params for this port  */
 FRPvcTableEntry     Pvc;        		/* The PVC params for this port  */
 FRIPSubnetRegister  IPSubnetRegister; /* IPSubnet params for this port */
 FRT1E1LineCfg       T1E1Line;   		/* The Line params for this port */
 FRCardProtocolCfg	CardPrCfg;			/* Stack protocol and encapslation params */
													/*   see fritems.h for details   */
/* PPP */
 PPPParamCfg 			PPPPaCfg;			/*   see PPP.h for details  */
 PPPControlCfg 		PPPCtCfg;

 char						reserve[688];
 }SCFrameRelay;

/******************************************************************/
/*
PortStructure Description:

*/
typedef struct 	tagPortStructure
 {
 short         iType;     /* the type of test to be performed.    */
								  /*  Can be one of the following:
								  TEST_NONE        No test performed
								  TEST_THROUGHPUT  Throughput test
								  TEST_LATENCY     Latency test
								  TEST_PACKET_LOSS Packet Loss test
								  TEST_BACK2-BACK  Back To Back test
								  TEST_MESH        One to Many Mesh test  */
 short iHub;              /* short integer giving Hub address     */
 short iSlot;             /* short integer giving Slot address    */
 short iPort;             /* short integer giving Port address    */
 short iSpeedLevel;       /* In SmartCards which allow a speed
			 /* selection, this value assigns the speed level.
				  For Ethernet SmartCards, the options are:
								  CARD_SPEED_10M   Operate at 10 MB
								  CARD_SPEED_100M  Operate at 100 MB
				  For TokenRing SmartCards the options are:
								  CARD_SPEED_4M    Operate at 4 MB
								  CARD_SPEED_16M   Operate at 16 MB  */
 short         iDuplexLevel;/* In SmartCards which allow a duplex */
				  /* selection, this value assigns the duplex level.
				  For Ethernet and TokenRing SmartCards, the options are:
						CARD_HALFDUPLEX  Set the port in half duplex mode
						CARD_FULLDUPLEX  Set the port in full duplex */
 unsigned char MACDestinationAddr[6]; /* The 6 byte address which
	 will be used in the MAC destination address portion of the
	 generated test frames indicating the device address to which
	 this port is attempting to transmit frames to.                */
 unsigned char MACSourceAddr[6]; /* The 6 byte address which
	 will be used in the MAC source address portion of the
	 generated test frames indicating the MAC address of the
	 port which is generating traffic.                             */
 unsigned char IPRouterAddr[4]; /* The IP address of the Router
	 connected to this SmartCard port                              */
 unsigned char IPSourceAddr[4]; /* IP addr of the SmartCard port  */
 unsigned char IPXNetworkSource[4];      /* IPX Network addr of   */
													  /* the source port       */
 unsigned char IPXNetworkDestination[4]; /* IPX Network addr of   */
													  /* the destination port  */
 SCTokenRing   TR;           /* Token Ring specific port settings */
 short         iProtocol;    /* designates what to put in the
						  protocol section of the test frames
				PROTOCOL_IP   puts an IP frame in the protocol section
				PROTOCOL_UDP  puts a UDP frame in the protocol section
				PROTOCOL_IPX  puts an IPX frame in the protocol section
				PROTOCOL_ZERO puts all zeros in the protocol section
				PROTOCOL_ONE  puts all FF's in the protocol section
				FILL_0        fills the whole frame with zero's
				FILL_1        fills the whole frame with 0xFF bytes
				FILL_5        fills the whole frame with 0x55 bytes
				FILL_A        fills the whole frame with 0xAA bytes
				FILL_C        fills the whole frame with 0xCC bytes   */
 SCAtm         AS;           /* ATM specific port settings        */
 double        dResult;      /* floating point value results      */
 long          lResult;      /* integer value results returned    */
 unsigned long lNetsIPs[20]; /* array of next hop IP addresses    */
 SCFrameRelay  FR;           /* FrameRelay specific port settings */
 char				cObeyPauseControl; /* ObeyPauseFlowControl for     */
 char				cUseAutoNegotiation;
 char				cUse8023Format;
 char				cReserve1; /* reserved */
 GIGAutoFiberNegotiate AFN;  /* Auto negotiation for gigabit      */
 char				cIPXHop;
 char				cIPXType;
 unsigned short		uiDstSocket;
 unsigned short		uiSrcSocket;
 unsigned short		uiPortIndex;	/* reserved */
 unsigned short		uiSystemOffsetTRSourceRoute;
 unsigned short     uiUDPSrcPort;
 unsigned short     uiUDPDstPort;
 char				cLLC_DSAP;
 char				cLLC_SSAP;
 char				cLLC_Control;
 char				cReserve0;
 double				dAvgPassedRate;
 char				cReserve[37]; /* reserved */
 }	PortStructure;

/******************************************************************/
/*
TestSetup Description:

*/
typedef struct		tagTestSetup
 {
 unsigned short iComPort;  /* ComPort to connect to               */
 unsigned short iBaudRate; /* Baud rate to connect at             */
 short  iSendLearningPacketsMode; /* indicates how often          */
											 /* to send learning packets     */
 char	  ucDoAutoNegotiation;	/* 1: do auto negotiation for this test */
 char   cReserved1;    /* reserved */     
 BOOL   bDisableETDisplay; /* Disable ET1000 Display              */
 short  iTrialLength;      /* seconds per trial (or repetition)   */
 short  iNumberofTrials;   /* Number of trials to run             */
 short  iLearningPackets;  /* learning frames per learning cycle  */
 short  iLearningRetries;  /* Number of learning cycle retries    */
 BOOL   bStopOnError;      /* Some test events warn the user of a
	 condition which may affect the test results. Setting this TRUE
	 will set the default error handling routine to prompt the user
	 with a "Retry, Abort, Ignore" message. Setting to FALSE will
	 always treat such warning/error messages as if the user would
	 have selected "Ignore". In either case, the warning message is
	 recorded in the log file.                                     */
/// BOOL	bOfferedLoad;		///
/// BOOL	bEnableHTMLOutput;	///
/// BOOL	bNewTestSeries;		/// non-zero indicates start of a New Test Series.
 short  iPacketSizeTest;   /* packet size to be tested            */
 char   cResetFRLink;
 char   cDelayAfterTransmit;    /* get counter after delay */  
 double dStepPercent;      /* reserved */
 double dTolerance;        /* percent resolution of results       */
 double dMinPercent;       /* min value allowed during this trial */
 double dMaxPercent;       /* max value allowed during this trial */
 double dInitialPercent;   /* the first value attempted           */
 double dBackOffPercent;   /* reserved */
 long   lStatusPeriod;     /* seconds between Status Callbacks    */
 BOOL   bRouterTest;       /* 1 = do ARP exchange, 0 = no ARPs    */
 BOOL   bBidirectional;    /* 1 = allow bi-directional measurements*/
 BOOL   bTeardown;         /* 1 = teardown SVCs after Trial and   */
          /* create new SVC's at start of Trial with new ELANs    */
          /* 0 = leave SVCs up at end of Trial, next Trial will   */
			 /* use existing SVCs - with old ELAN registration !!    */
          /* Teardown = 1 is recommended - use with caution       */
 BOOL   bNextHopTest;      /* 1 = Use next hop dest addr table    */
 char   cUseAutoDetectDLCI;/* 1 = Auto detect DLCI for PVC,       */
									/* 0 = User defines DLCI no for PVC    */
 char   cUnlinkWhenFinished;/* 1 = Unlink SmartBits when it's done*/
									/*  0 = leave link along               */
 char   cUseComPort;       /*  1 = Use serial connection          */
									/*  0 = Use IP connection              */
 BOOL	bOfferedLoad;		///
 BOOL	bEnableHTMLOutput;	///
 BOOL	bNewTestSeries;		/// non-zero indicates start of a New Test Series.
 char   cReserved[5];     /* reserved */
 char   szLogFilename[_MAX_PATH];    /* filename for which to log */
			  /* all intermediate counter and test trial information */
 char   szReportFilename[_MAX_PATH]; /* filename for which to     */
			  /* write the "presentation" format of the final report */
			  /* for this test.                                      */
/// char	szHTMLOutputPath[_MAX_PATH]; /* Can be either a full or relative path */
						 	  /* to where HTML report files are to be written */
/// char	szHTMLIndexFile[_MAX_PATH]; /* FileName for HTML report Index file */
char   szRawDataFilename[_MAX_PATH]; /* filename for which to    */
			  /* log the final trial results in a "regular" format   */
			  /* for passing to another program. This "regular"      */
			  /* format will be easily parsable strings of data with */
			  /* minimal labeling, which could be fed directly into  */
			  /* a spreadsheet or other QA type program for tracking */
			  /* results[data separators are tabs, commas, or spaces]*/
			  /*         [Not yet Implemented]                       */
 char   szHostAddress[_MAX_PATH]; /* Host address - not been used yet */
 long	  lPortNum;                 /* Port number associate Host - not been used yet */
 char	  szVendorName[80];  		/* Vendor Name for report */
 char	  szProductName[80]; 		/* Vendor product name for report */
 char	  szSoftwareVersion[80]; 	/* SmartApplication Version for report */
 char	  szTestConfiguration[80]; /* User's test configuration name for report */
 char   szProtocol[20]; 			/* reserverd, not been used */
 BOOL	bThroughput2Results;		/* flag to show bi-directional report */
 ATMCallSetupParams atmTrafficDescriptor;
 char	szHTMLOutputPath[_MAX_PATH]; /* Can be either a full or relative path */
						 	  /* to where HTML report files are to be written */
 char	szHTMLIndexFile[_MAX_PATH]; /* FileName for HTML report Index file */
 char	szTestComment[240];		///???
 char	cReserve2[11];
 ///char   cReserve1[952];      		/* reserved */     
 char	cLatencySmartMetricsMode;
 double dAcceptableLossRate;
 char   cReserve1[423];      		/* reserved */ 
 }	TestSetup;    

/******************************************************************/
/*
ATMTestSetup Description:

*/
typedef struct		tagATMTestSetup
 {
 unsigned short iComPort;  /* ComPort to connect to               */
 unsigned short iBaudRate; /* Baud rate to connect at             */
 BOOL   bDisableETDisplay; /* 1 = Disable ET1000 Display,         */
									/* 0 = Enable                          */
 long   lTrialLength;      /* seconds per trial (or repetition)   */
 short  iNumberofTrials;   /* Number of trials to run             */
 short  iStopOnError;      /* Some test events warn the user of a
	 condition which may affect the test results. Setting this TRUE
	 will set the default error handling routine to prompt the user
	 with a "Retry, Abort, Ignore" message. Setting to FALSE will
	 always treat such warning/error messages as if the user would
	 have selected "Ignore". In either case, the warning message is
	 recorded in the log file.                                     */
 double dRateStepIncrement;/* increment step as a rate value
										 (i.e. 50 calls/sec) */
 double dTolerance;        /* percent resolution of results       */
 double dMinRate;/* min call setup rate allowed during this trial */
 double dMaxRate;/* max call setup rate allowed during this trial */
 double dInitialRate;      /* initial call setup rate */
 double dBackOffPercent;   /* percentage of current value of which*/
									/* to back off upon failure            */
 long   lStatusPeriod;     /* seconds between Status Callbacks    */
 char   szLogFilename[_MAX_PATH];    /* filename for which to log */
			  /* all intermediate counter and test trial information */
 char   szReportFilename[_MAX_PATH]; /* filename for which to     */
			  /* write the "presentation" format of the final report */
			  /* for this test.                                      */
 char   szRawDataFilename[_MAX_PATH]; /* filename for which to    */
			  /* log the final trial results in a "regular" format   */
			  /* for passing to another program. This "regular"      */
			  /* format will be easily parsable strings of data with */
			  /* minimal labeling, which could be fed directly into  */
			  /* a spreadsheet or other QA type program for tracking */
			  /* results[data separators are tabs, commas, or spaces]*/
			  /*         [Not yet Implemented]                       */
 long   lNextSizeMethod;    /* 1: use step size,                  */
									 /* 0: use backoff ratio               */
 long   lTeardownCalls;     /* 1: Teardown calls after connection */
 long   lUseIdenticalRate;  /* 0: not use same rate, 1: use same rate */
 long   lRestartDelay;  	 /* 0-300 now */
 long	lRegDelayBetweenPorts;	/* 0-100000 milliseconds delay between registering ports */
 long   reserved[56];       /* reserverd									*/
 }	ATMTestSetup;



 typedef struct		tagATMPvcSvcTestSetup
	{
	unsigned short iComPort;				/* ComPort to connect */
	unsigned short iBaudRate;				/* Baud rate to connect */
	BOOL				bDisableETDisplay;	/* Disable ET1000 Display */
	long				lTrialLength;       	/* number of seconds per trial */
	short  			iNumberofTrials;   	/* Number of trials to run             */
	short				iStopOnError;      	/* non-zero if we are to stop on error */
	short				iNumberOfVCs;			/* Number of PVC's/SVC's to test */
	short				iVCNo;					/* Connection# selected to inject errors  ---- int */
	unsigned long	ulErrorType;			/* Type of Error to inject */
	unsigned char	ucEncap;					/* Encapsulation type.   */
	unsigned char	ucRateClass;			/* UBR, CBR  */
	char   			reserved[2];			/* reserved */
	unsigned long	ulLineCellRate;		/* Used for calc PCR, SCR */
	long				lStatusPeriod;			/* for status callbacks */

	char				szLogFilename[_MAX_PATH];
	char				szReportFilename[_MAX_PATH];
	char				szRawDataFilename[_MAX_PATH];
	}	ATMPvcSvcTestSetup;


/******************************************************************/
/*
MCIPTestSetup Comment:

The following hold the test params for each particular MCIP test.

 typedef struct MCTParams
 typedef struct AMTParams
 typedef struct SGFMParams
 typedef struct MCLatencyParams
 typedef struct GLJDParams

*/

#define SEARCH_BY_PURE_BACKOFF         1
#define SEARCH_BY_STEP_SCAN            2
#define SEARCH_BY_STEP_THEN_BACKOFF    3

typedef struct 	tagMCTParams
	{
	unsigned long ulSearchType;/*The type of search to be performed*/
	/* search types can be
		SEARCH_BY_PURE_BACKOFF : Start test at Initial Percent.
			Assume LastPassed was just below MinPercent,
			assume LastFailed was just above MaxPercent.
			After each trial repetition, compute next percentage
			load to be:
                                 
			NextPercent = LastFailed +
            ((abs(LastFailed - LastPassed) * BackOffPercent)
                                   
			Test is considered to be finished when CurrentPercent
         and NextPercent is within Tolerance of each other, or
         if the new NextPercent value is so minute that it
         does not effect a change in the test parameters for
         the next repetition.
                                     
		SEARCH_BY_STEP_SCAN : Start test at Initial percent
			Ignore pass/fail conditions. At the end of each
         trial reptition simply compute next percentage load
         to be the greater of:
                                       
         NextPercent = CurrentPercnet + StepPercent,  or
				NextPercent = MaxPercent
                                         
         Test is considered to be finished when MaxPercent
         has been tested.
                                           
		SEARCH_BY_STEP_THEN_BACKOFF : Start test at Initial percent
			Assume LastPassed was just below MinPercent,
			assume LastFailed was just above MaxPercent.
         After each trial repetition, if passed, then set
         LastPassed to be current load percentage, and compute
         next percentage load to be:
                                             
         NextPercent = LastPassed + StepPercent
                                               
         If failed, then LastFailed is set to current load
         and we start applying the Backoff algorithm above.
                                                 
         Test is considered to be finished when CurrentPercent
         and NextPercent is within Tolerance of each other, or
         if the new NextPercent value is so minute that it
         does not effect a change in the test parameters for
			the next repetition.                               */
    
    double  dStepPercent;   /*if step search, this is the step % */
    double  dTolerance;     /*percent resolution of results      */
    
    double  dMinPercent;    /*min value allowed during this trial*/
    double  dMaxPercent;    /*max value allowed during this trial*/
    double  dInitialPercent;/*the first value attempted          */
    double  dBackOffPercent;/*search style - binary, 1/sqrt(2)...*/
    
    double  dUnicastPercent;/*the percent load of Unicast frames */
    short   iUCTrackingFlag;/*0 = Unicast rate does not change   */
									 /*1 = does track the MC rate         */
	 char		cReserved[128];
    } MCTParams;

typedef struct 	tagAMTParams
 {
 unsigned short   uiInitialGroupRxCount;/* the first value attempted */
 unsigned short   uiMaxGroupRxCount;    /* max value allowed during this trial */
 unsigned short   uiStepGroupRxCount;   /* the increment value */

 short   iStayAfterEachAttemptFlag; /* 0 = Ports don't leave IGMP group and rejoin after each attempt. */
                                     /* 1 = Ports leave IGMP group and rejoin after each attempt. */
 
 double  dTolerance;          /* percent resolution of results       */

 double  dMinPercent;         /* min value allowed during this trial */
 double  dMaxPercent;         /* max value allowed during this trial */
 double  dInitialPercent;     /* the first value attempted           */
 double  dBackOffPercent;     /* search style - binary, 1/sqrt(2)... */
 char		cReserved[128];
 } AMTParams;

typedef struct 	tagSGFMParams
 {
 double  dPercentLoad;        /* the load */
 short   iInitialGroupCount;  /* the first value attempted, then step one */
 short   iMaxGroupCount;      /* max value allowed during this trial */
 char    cReserved[128];
 } SGFMParams;

typedef struct 	tagMCLatencyParams
 {
 double        dPercentLoad;  /* the load */
 unsigned long ulBuckets[16]; /* for the distribution */
 char				cReserved[128];
 } MCLatencyParams;

typedef struct 	tagGLJDParams
 {
 double  dPercentLoad;        /* the load */
 short   iGroupCount;         /* how many groups to Leave/Join at a time */
 char				cReserved[128];
 } GLJDParams;

typedef struct		tagIPAddress
 {
 unsigned char  ucIP[4];    /* array of IP addr.s to connect to */
 } IPAddress;

#if 0
/******************************************************************/
/*
MCIPTestSetup Description:

Holds test params for the MCIP tests.

*/
typedef struct		tagMCIPTestSetup
	{
	long    lTrialLength;   /* seconds per trial (or repetition)   */
	unsigned short   uiNumberofTrials;/* Number of trials to run             */
	unsigned short   uiJoinDelay;     /*delay after IGMP join request is sent*/
	short   iStopOnError;   /* Some test events warn the user of a
	 condition which may affect the test results. Setting this TRUE
	 will set the default error handling routine to prompt the user
	 with a "Retry, Abort, Ignore" message. Setting to FALSE will
	 always treat such warning/error messages as if the user would
	 have selected "Ignore". In either case, the warning message is
	 recorded in the log file.                                     */

	short   iMCFrameSize; /* frame size to be tested (without CRC) */
	short   iUCFrameSize; /* frame size to be tested (without CRC) */
								 /* 0 = leave linked                 */
	short   iLogFileFlag;
		/* 0=Append data to the log file. (default)
			1=Disable logging of data to the log file.
			2=Create New Logfile...abort if file w/same name exists  */

	MCTParams        MCT;
	AMTParams        AMT;
	SGFMParams       SGFM;
	MCLatencyParams  MCL;
	GLJDParams       GJLD;

	long   lStatusPeriod;   /* seconds between Status Callbacks    */

	char   szLogFilename[_MAX_PATH]; /* filename for which to log */
			  /* all intermediate counter and test trial information */
	char   szReportFilename[_MAX_PATH]; /* filename for which to   */
			  /* write the "presentation" format of the final report */
			  /* for this test. (NOT YET IMPLEMENTED)                */
	char   szRawDataFilename[_MAX_PATH]; /* filename for which to  */
			  /* log the final trial results in a "regular" format   */
			  /* for passing to another program. This "regular"      */
			  /* format will be easily parsable strings of data with */
			  /* minimal labeling, which could be fed directly into  */
			  /* a spreadsheet or other QA type program for tracking */
			  /* results[data separators are tabs, commas, or spaces]*/
			  /*         NOT YET IMPLEMENTED                       */

	char	  szVendorName[80];  	/* Vendor Name for report */
	char	  szProductName[80]; 	/* Vendor product name for report */
	char	  szSoftwareVersion[80];/* Application Version for report */
	char	  szTestConfiguration[80]; 
				/* User's test configuration name for report */
	unsigned short	  uiSyncHubFlag;
	/* The following values are allowed:
		HUB_GROUP_DEFAULT_ACTION			0
		HUB_GROUP_INDEPENDENT_ACTION		1
		HUB_GROUP_UNIT_ACTION				2
		HUB_GROUP_SYNC_ACTION				3
	*/
	unsigned long	  ulGPSDelay;
		/* GPS Delay for start of 1pps latch */
		/* If 0, the SmartLib default value for the delay will be
			used. */
	char   cReserved[1016];      	/* reserved */
} MCIPTestSetup;

#define MCIP_APPEND_LOG						0
#define MCIP_DISABLE_LOG					1
#define MCIP_CREATE_NEW_LOG					2
#endif

/******************************************************************/
/*
TestStatus Description:

Holds overall status of test. This structure is passed the user's
status callback routine.

*/
typedef struct tagTestStatus
 {
 short iState;           /* The current state of the test trial   */
								 /* in progress. Can be: ENGINE_HALTED,   */
								 /* ENGINE_RUNNING, ENGINE_RESET, etc.    */
 short iTrials;          /* total Trials requested                */
 short iPacketSize;      /* current frame size being tested       */
 short iCurrTrialNumber; /* current trial number in progress      */
 short iCurrTrialReps;   /* current repetition number in progress */
 short iSecondsLeft;     /* seconds remaining in the current      */
								 /* test repetition (or trial)            */
 short iTrialLength;     /* Trial Length which was requested (sec)*/
 short iTotalTrialsRun;  /* number of trials run so far           */
 long  lMinTested;       /* min load (or time) tested up to now   */
 long  lMaxTested;       /* max load (or time) tested up to now   */
 long  lCurTested;       /* current load (or time) testing now    */
 char  szActivity[80];   /* String to show the current activity.  */
 char  szLog[512];       /* String to show the current activity.  */
 }	TestStatus;

#endif

