
/*
 *
 *  TDR (TDR.c): 
 *  The TLK110 uses time domain reflectometry (TDR) to determine the quality   
 *  Of the cables, connectors, and terminations in addition to estimating the 
 *  Cable Length.
 *  Some of the possible problems that can be diagnosed include opens, shorts,   
 *  Cable impedance mismatches, bad connectors, termination mismatches, and   
 *  Any discontinuities on the cable.
 *  The TLK110 device transmits a test pulse of known amplitude (1 V) down  
 *  Each of the two pairs of an attached cable. The transmitted signal continues   
 *  Down the cable and reflects from each cable imperfection, fault, bad   
 *  Connector and the end of the cable itself. After the pulse transmission is 
 *  Completed, the TLK110 measures the return time and amplitude of all these    
 *  Reflected pulses. This Technique enables measuring the distance and     
 *  Magnitude (impedance) of non-terminated cables (open or short),
 *  Discontinuities (bad connectors), and improperly-terminated cables.
 *
 *  Run a TDR test while there is no link and when you suspect a cable fault   
 *  Exists. The TDR software post processing is not yet implemented.
 */

#include < stdio.h >
#include <math.h> 
#include "registers.h"
#include "TDR.h"
#include "read_write.h"
#include "Resource files/et1000.h" 


int TDR(int phy_id, int *reflection, double *impedance, int averaging, TDR_status *TDR_status_out)
{
int  error=0;
int bmcr_data;
int TDR_DATA_1=0;
int TDR_DATA_2=0; 
int TDR_DATA_4=0;
int TDR_DATA_8=0;
int TDR_DATA_7=0;
int TDR_DATA_6=0;
int TDR_DATA_9=0;
int AE_DATA=0;
int CDCR_data=0;
int CDLRR1_data=0;
int CDLRR2_data=0;
int CDLRR3_data=0;
int CDLRR4_data=0;
int CDLRR5_data=0;
int CDARR1_data=0;
int CDARR2_data=0;
int CDARR3_data=0;
int CDARR4_data=0;
int CDARR5_data=0;
int CDGRR_data=0;
int CDGRR_data_a=0;
int CDGRR_data_b=0;
int poll;
int i;
double reflection_temp=0;
int cross_mode_a, cross_mode_b, overflow_a, overflow_b, high_cross_a, high_cross_b;
int tdr_peaks_sign_a[5] = {0};
int tdr_peaks_sign_b[5]= {0};
int peaks_number=0;
double high_thresh_vec[10] = {0};
int high_threshold = 0; 
int open_cha;
//set TDR defaults

	//averaging =1
	TDR_DATA_1 = phy_read(phy_id, TDR_1); 
	if (TDR_DATA_1 < 0)// error
	{
		return error = TDR_DATA_1;
	}
    TDR_DATA_1 &= 0xf0ff ; 
    TDR_DATA_1 |= 0x0100 ; 
	error = phy_write(phy_id, TDR_1, TDR_DATA_1); //write
    if (error < 0)
	{
	     return error;
	}		




	TDR_DATA_2 = phy_read(phy_id, TDR_2); 
	if (TDR_DATA_2 < 0)// error
	{
		return error = TDR_DATA_1;
	}
    TDR_DATA_2 &= 0xfff0 ;   //set initial skip to higher values, helps to ignore self returns
    TDR_DATA_2 |= 0x000c ; 
	error = phy_write(phy_id, TDR_2, TDR_DATA_2); //write
    if (error < 0)
	{
	     return error;
	}		

	TDR_DATA_4 = phy_read(phy_id, TDR_4); 
	if (TDR_DATA_4 < 0)// error
	{
		return error = TDR_DATA_4;
	}
    TDR_DATA_4 |= 0xFF00 ;   //set cfg_tdr_seg_duration_seg5 to higher value to allow high cable range detection (up to 200m)
    error = phy_write(phy_id, TDR_4, TDR_DATA_4); //write
    if (error < 0)
	{
	     return error;
	}		

	TDR_DATA_8 = phy_read(phy_id, TDR_8); 
	if (TDR_DATA_8 < 0)// error
	{
		return error = TDR_DATA_8;
	}
	TDR_DATA_8 &= 0xe0ff ;
    TDR_DATA_8 |= 0x1800 ;   //set seg1_high_threshold higher value
    error = phy_write(phy_id, TDR_8, TDR_DATA_8); //write
    if (error < 0)
	{
	     return error;
	}		
    
    //set seg1_threshold
	TDR_DATA_7 = phy_read(phy_id, TDR_7); 
	if (TDR_DATA_7 < 0)// error
	{
		return error = TDR_DATA_7;
	}
	TDR_DATA_7 &= 0xffe0 ;
    TDR_DATA_7 |= 0x001d ; 
    error = phy_write(phy_id, TDR_7, TDR_DATA_7); //write
    if (error < 0)
	{
	     return error;
	}		

    //set TX PULSE AMPLITUDE
	//TDR_DATA_6 = phy_read(phy_id, TDR_6); 
	//if (TDR_DATA_6 < 0)// error
	//{
	//	return error = TDR_DATA_6;
	//}
	//TDR_DATA_6 &= 0xff0f ;
    //TDR_DATA_6 |= 0x00f0 ; 
    //error = phy_write(phy_id, TDR_6, TDR_DATA_6); //write
    //if (error < 0)
	//{
	//     return error;
	//}		

    //set TX pulse width
	TDR_DATA_9 = phy_read(phy_id, TDR_9);
	if (TDR_DATA_9 < 0)// error
	{
		return error = TDR_DATA_9;
	}
	TDR_DATA_9 &= 0xfff0 ;
    TDR_DATA_9 |= 0x0009 ; 
    error = phy_write(phy_id, TDR_9, TDR_DATA_9); //write
    if (error < 0)
	{
	     return error;
	}		
    
	//''force 100bt
	bmcr_data = 0x2000 ;   //set bit 13 = 1 (force 100bt)  
    error = phy_write(phy_id, BMCR, bmcr_data); //write
    if (error < 0)
	{
	    return error;
	}		


    //set TX_PCB 40% TXPCB
	//AE_DATA = phy_read(phy_id, TXPCB);
	//if (AE_DATA < 0)// error
	//{
	//	return error = TDR_DATA_9;
	//}
	//AE_DATA &= 0xfe3f ;
    //AE_DATA |= 0x00c0 ; 
    //error = phy_write(phy_id, TXPCB, AE_DATA); //write
    //if (error < 0)
	//{
	//     return error;
	//}		

	
	
	//start test
	CDCR_data = phy_read(phy_id, CDCR); 
	if (CDCR_data < 0)// error
	{
		return error = CDCR_data;
	}
    CDCR_data |= 0x8000 ;   //bit 15 start test
    error = phy_write(phy_id, CDCR, CDCR_data); //write
    if (error < 0)
	{
	     return error;
	}		
	
    //check that TDR is done and not fail
	// polling the "done" bit 
	poll = polling(phy_id, CDCR, 1, 2000); 
	if(poll == -1) // timeout	
	{
		return -1;
    }

	CDCR_data = phy_read(phy_id, CDCR);
	CDCR_data &= 0x0003; 
	if (CDCR_data != 2)// error
	{
		printf("TDR fail\n");
		return error = CDCR_data;
	}

    //************ read locations; *******************//

	CDLRR1_data = phy_read(phy_id, CDLRR1); 
	if (CDLRR1_data < 0)// error
	{
		return error = CDLRR1_data;
	}
	//ch_a peak 0
	reflection_temp = CDLRR1_data & 0x00ff;
	if (reflection_temp < 12  && reflection_temp > 0)
	{
		reflection[0] = -2;
	}
	else
	{
	reflection[0] = (int) reflection_temp;
	}

	//ch_a peak 1
	reflection_temp = CDLRR1_data >> 8; 
    if (reflection_temp < 12 && reflection_temp > 0)
	{
		reflection[1] = -2;
	}
	else
	{
	reflection[1] = (int) reflection_temp;
    }
	CDLRR2_data = phy_read(phy_id, CDLRR2); 
	if (CDLRR2_data < 0)// error
	{
		return error = CDLRR2_data;
	}
	//ch_a peak 2  
	reflection_temp = CDLRR2_data & 0x00ff;
	if (reflection_temp == 0)
	{
		reflection[2] = 0;
	}
	else
	{
	reflection[2] = (int) reflection_temp;
	}
	//ch_a peak 3
	reflection_temp = CDLRR2_data >> 8;
	if (reflection_temp == 0)
	{
		reflection[3] = 0;
	}
	else
	{
	reflection[3] = (int) reflection_temp;
    }
	CDLRR3_data = phy_read(phy_id, CDLRR3); 
	if (CDLRR3_data < 0)// error
	{
		return error = CDLRR3_data;
	}
	//ch_a peak 4  
	reflection_temp = CDLRR3_data & 0x00ff;
	if (reflection_temp == 0)
	{
		reflection[4] = 0;
	}
	else
	{
	reflection[4] = (int) reflection_temp;
	}
	//ch_b peak 0
	reflection_temp = CDLRR3_data >> 8;
	if (reflection_temp < 12 && reflection_temp > 0)
	{
		reflection[5] = -2;
	}
	else
	{
	reflection[5] = (int) reflection_temp;
	}
	CDLRR4_data = phy_read(phy_id, CDLRR4); 
	if (CDLRR4_data < 0)// error
	{
		return error = CDLRR4_data;
	}
	//ch_b peak 1  
	reflection_temp = CDLRR4_data & 0x00ff;
	if (reflection_temp < 12 && reflection_temp > 0)
	{
		reflection[6] = -2;
	}
	else
	{
 	reflection[6] = (int) reflection_temp;
	}
	//ch_b peak 2
	reflection_temp = CDLRR4_data >> 8;
	if (reflection_temp == 0)
	{
		reflection[7] = 0;
	}
	else
	{
	reflection[7] = (int) reflection_temp;
	}
	CDLRR5_data = phy_read(phy_id, CDLRR5); 
	if (CDLRR5_data < 0)// error
	{
		return error = CDLRR5_data;
	}
	//ch_b peak 3  
	reflection_temp = CDLRR5_data & 0x00ff;
	if (reflection_temp == 0)
	{
		reflection[8] = 0;
	}
	else
	{
	reflection[8] = (int) reflection_temp;
	}
	//ch_b peak 4
	reflection_temp = CDLRR5_data >> 8;
	if (reflection_temp == 0)
	{
		reflection[9] = 0;
	}
	else
	{
	reflection[9] = (int) reflection_temp;
	}
	//************************************************************//

   //************ read amplitudes; *******************//

	CDARR1_data = phy_read(phy_id, CDARR1); 
	if (CDARR1_data < 0)// error
	{
		return error = CDARR1_data;
	}
	//ch_a amp 0  
	impedance[0] = (int)(CDARR1_data & 0x00ff);
	//ch_a amp 1
	impedance[1] = (int)(CDARR1_data >> 8);

	CDARR2_data = phy_read(phy_id, CDARR2); 
	if (CDARR2_data < 0)// error
	{
		return error = CDARR2_data;
	}
	//ch_a amp 2  
	impedance[2] = (int)(CDARR2_data & 0x00ff);
	//ch_a amp 3
	impedance[3] = (int)(CDARR2_data >> 8);

	CDARR3_data = phy_read(phy_id, CDARR3); 
	if (CDARR3_data < 0)// error
	{
		return error = CDARR3_data;
	}
	//ch_a amp 4  
	impedance[4] = (int)(CDARR3_data & 0x00ff);
	//ch_b amp 0
	impedance[5] = (int)(CDARR3_data >> 8);

	CDARR4_data = phy_read(phy_id, CDARR4); 
	if (CDARR4_data < 0)// error
	{
		return error = CDARR4_data;
	}
	//ch_b amp 1  
	impedance[6] = (int)(CDARR4_data & 0x00ff);
	//ch_b amp 2
	impedance[7] = (int)(CDARR4_data >> 8);

	CDARR5_data = phy_read(phy_id, CDARR5); 
	if (CDARR5_data < 0)// error
	{
		return error = CDARR5_data;
	}
	//ch_b amp 3  
	impedance[8] = (int)(CDARR5_data & 0x00ff);
	//ch_b amp 4
	impedance[9] = (int)(CDARR5_data >> 8);

	//************************************************************//
	// read status of the TDR reg 0x18a CDGRR_data=0;
	CDGRR_data = phy_read(phy_id, CDGRR); 
	if (CDGRR_data < 0)// error
	{
		return error = CDGRR_data;
	}

    //check for crossed flags
	cross_mode_a = (int)((CDGRR_data >> 5) & 0x1 );
	cross_mode_b = (int)((CDGRR_data >> 4) & 0x1 ); 
	//check for peaks overflow
	overflow_a = (int)((CDGRR_data >> 3) & 0x1 );
	overflow_b = (int)((CDGRR_data >> 2) & 0x1 ); 
    //check for high_cross
	high_cross_a = (int)((CDGRR_data >> 1) & 0x1 );
	high_cross_b = (int)((CDGRR_data >> 0) & 0x1 ); 
    CDGRR_data_a = CDGRR_data;
	CDGRR_data_b = CDGRR_data;
	//check peaks sign
	        //for (i=0;i<5;i++)
			//{
            //    tdr_peaks_sign_a[i] = (CDGRR_data_a >> (11 + i)  & 0x1);
			//}
            //for (i=5;i<10;i++)
            //{
            //    tdr_peaks_sign_b[i] = (CDGRR_data_b >> (1 + i)  & 0x1);
            //}
 	//************************************************************//
    
    //**********************  channel A *************************//

			// check if the channel is terminated --> there are no peaks.
			peaks_number = 0;
	        for (i=0;i<5;i++)
			{
                if (reflection[i] != 0)
				{
					peaks_number = peaks_number +1;
				}
			}

			if (peaks_number != 0)// peaks were found for ch_a, continue channel a
            {
			 
				 //calculate high threshold
		        for (i=0;i<5;i++)
				{	             
                 high_thresh_vec[i] = 0.0039 * pow(reflection[i],2) - 1.397 * reflection[i] + 115;
				}
                  
                if (cross_mode_a)
				{
					i = 1;
                    TDR_status_out->cross_cha_status = cross_mode_a;
				}
				else
				{
					i = 0;
				}

		        for (;i<5;i++)
				{	             
                 if (high_threshold)//high threshold was allready crossed
				 {
                  reflection[i] = 0;
				  impedance[i] = 0;
				 }
				 else
				 {
				 }
				 if (impedance[i] > high_thresh_vec[i])
				 {
                     high_threshold = 1;
					 if (CDGRR_data >> (11 + i)  & 0x1)
					 {
					   TDR_status_out->open_cha_status = 1;//open = open_cha;
                       
					 }
					 else
					 {
					   TDR_status_out->short_cha_status = 1;
					 }
				 }
                 else
				 {
				 }
				}    




			} //end of peaks were found for ch_a, continue channel a
			else //channel is terminated peaks number = 0;
            {				
				TDR_status_out->terminated_cha_status = 1;
			}

	//**********************  channel B *************************//

			// check if the channel is terminated --> there are no peaks.
			peaks_number = 0;
	        for (i=5;i<10;i++)
			{
                if (reflection[i] != 0)
				{
					peaks_number = peaks_number +1;
				}
			}

			if (peaks_number != 0)// peaks were found for ch_a, continue channel a
            {
			 
				 //calculate high threshold
				high_threshold = 0;
		        for (i=5;i<10;i++)
				{	             
                 high_thresh_vec[i] = 0.0039 * pow(reflection[i],2) - 1.397 * reflection[i] + 115;
				}
                  
                if (cross_mode_b)
				{
					i = 6;
                    TDR_status_out->cross_chb_status = cross_mode_b;
				}
				else
				{
					i = 5;
				}

		        for (;i<10;i++)
				{	             
                 if (high_threshold)//high threshold was allready crossed
				 {
                  reflection[i] = 0;
				  impedance[i] = 0;
				 }
				 else
				 {
				 }
				 if (impedance[i] > high_thresh_vec[i])
				 {
                     high_threshold = 1;					 
					 if ((CDGRR_data >> (1 + i)  & 0x1))
					 {
					   TDR_status_out->open_chb_status = 1;//open = open_cha;
                       
					 }
					 else
					 {
					   TDR_status_out->short_chb_status = 1;
					 }
				 
				 				 
				 }
                 else
				 {
				 }
				}    




			} //end of peaks were found for ch_a, continue channel a
			else //channel is terminated peaks number = 0;
            {				
				TDR_status_out->terminated_chb_status = 1;
			}
			
			
			
	for (i=0;i<10;i++)
	{
    if (reflection[i] != 0)
	{
    reflection_temp = (reflection[i] * 0.8621) - 8;      
	reflection_temp = reflection_temp +(70 - reflection_temp)*0.01;
	}
	else
	{
    reflection_temp = 0;
	}
	reflection[i] = (int) reflection_temp;
	
    impedance[i] = impedance[i]/128/2; //'' adc is +128 for +0.5(v) to -128 for -0.5(v)
	}
			
			
			return 1;  // Passed

}





