
/*                                              
 * this function sets the loopback of the phy   
 *  
 * the following options are available:
 * Normal: No loopback is selected
 * MII Loop.
 * PCS Loop: The device can establish a link with itself at 100BT speed using the Force link
 * Digital Loop: The device can establish a link with itself at 100BT speed using the Force link
 * Analog Loop: The device can establish a link with itself at 10/100BT speed using the Force link
 * Reverse Loop: (Far-End Loopback): This option is a special test mode 
 * that allows the user to test the PHY from the link partner side.
 *
 */                                              


#include "registers.h"
#include "loopback.h"
#include "read_write.h"


int loopback(int phy_id,int loopback_mode)
{

	    int  error=0;

		// set loopback
		int  biscr_data=0, b4_data = 0, b8_data = 0, bmcr_data=0 ;


		//clear bits 4,3 in reg B8 and bit 10 in reg B4 --> these bits are used for the analog loopback, so in any case clear them before
         b8_data = phy_read(phy_id, B8); // read B8_DATA holds the value of B8	   
		 if (b8_data < 0)// error
		 {			   
	         return error = b8_data;
		 }		 
         b8_data &= 0xFFE7 ;   // clear bits 4,3		
         error = phy_write(phy_id, B8, b8_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }

         b4_data = phy_read(phy_id, B4); // read B4_DATA holds the value of B4	   
		 if (b4_data < 0)// error
		 {			   
	         return error = b4_data;
		 }		 
         b4_data &= 0xFBFF ;   // clear bit 10		
         error = phy_write(phy_id, B4, b4_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
        //////////////////////////////////////////////////


		switch (loopback_mode)
        {
         case LOOPBACK_NORMAL: // 
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_MII: // 
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
         bmcr_data = phy_read(phy_id, BMCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data |= 0x4000 ;   // bit 14 = MII loopback
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_PCS_INPUT: // 
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
 		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         biscr_data |= 0x0001 ;   // bit 0 = pcs input loopback
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_PCS_OUTPUT: // 
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
 		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         biscr_data |= 0x0002 ;   // bit 1 = pcs output loopback
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_DIGITAL: // 
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         biscr_data |= 0x0004 ;   // bit 2 = digital loopback
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_ANALOG: // 

         b8_data = phy_read(phy_id, B8); // read B8_DATA holds the value of B8	   
		 if (b8_data < 0)// error
		 {			   
	         return error = b8_data;
		 }		 
         b8_data &= 0xFFE7 ;   // clear bits 4,3		
         b8_data |= 0x0018 ;   // set bits 4,3
         error = phy_write(phy_id, B8, b8_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }

         b4_data = phy_read(phy_id, B4); // read B8_DATA holds the value of B8	   
		 if (b4_data < 0)// error
		 {			   
	         return error = b4_data;
		 }		 
          b4_data &= 0xFBFF ;   // clear bit 10		
         b4_data |= 0x0400 ;   // set bits 10
         error = phy_write(phy_id, B4, b4_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }

         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         biscr_data |= 0x0008 ;   // bit 3 = analog loopback
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 case LOOPBACK_REVERSE: //
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         biscr_data |= 0x0010 ;   // bit 4 = reverse loopback
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		 default: // loopback_mode = NORMAL (no loopback)
         biscr_data = phy_read(phy_id, BISCR); // read BISCR_DATA holds the value of BISCR 	   
 		 if (biscr_data < 0)// error
		 {			   
	         return error = biscr_data;
		 }		 
         biscr_data &= 0xFFE0 ;   // clear bits [4:0]		
         error = phy_write(phy_id, BISCR, biscr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 bmcr_data = phy_read(phy_id, BMCR); // read BMCR_DATA holds the value of BMSCR 	   
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		         
		 bmcr_data &= 0xBFFF ;   // clear bit [14]
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }		 
		 break;

		}

		return 0;
}



