
/*
 * settings (settings.c): configures the PHY for the required setup:
 *  Auto negotiation or Force
 *	Speed: 100BT / 10BT
 *	Duplex: full / half
 *	Pair swap: MDI / MDI-X / Auto_MDI
 *
 */







#include < stdio.h > 
#include < string.h >
#include "registers.h"
#include "settings.h"
#include "status.h"
#include "read_write.h"


  // link setup i.e: auto_neg/force. 100BT/10BT. FD/HD

int link_setup(int phy_id, int Set_link_behavior, int Set_speed, int Set_duplex, int Set_MDI)   
{

    int  error=0;
	int  phycr_data=0,bmcr_data=0, anar_data=0,physcr_data=0;

    // fix indentention

        // Set_MDI  
		switch (Set_MDI)
        {
         case MDI: // Set_MDI = mdi
         phycr_data = phy_read(phy_id, PHYCR); // read PHYCR_DATA holds the value of PHYCR
		 if (phycr_data < 0)// error
		 {
	         return error = phycr_data;
		 }
         phycr_data &= 0x3FFF ;   // clear bits 14 & 15		
         error = phy_write(phy_id, PHYCR, phycr_data); //write
		 if (error < 0)
		 {
			 return error;
		 }
		 break;

 
		 case MDIX: // Set_MDI = mdix 
         phycr_data = phy_read(phy_id, PHYCR);  	   
		 if (phycr_data < 0)// error
		 {
	         return error = phycr_data;
		 }
         phycr_data &= 0x3FFF;   		 
         phycr_data |= 0x4000;// bit 14 = 1   
         error = phy_write(phy_id, PHYCR, phycr_data); 
		 if (error < 0)
		 {
			 return error;
		 }
		 break;

		 case AUTO_MDI: // Set_MDI = auto mdi 
         phycr_data = phy_read(phy_id, PHYCR);
		 if (phycr_data < 0)// error
		 {
	         return error = phycr_data;
		 }		 
         phycr_data &= 0x3FFF ;   		
         phycr_data |= 0x8000 ;   
         error = phy_write(phy_id, PHYCR, phycr_data); 
		 if (error < 0)
		 {
			 return error;
		 }
		 break;

		 default: // Set_MDI = auto mdi  
         phycr_data = phy_read(phy_id, PHYCR);
		 if (phycr_data < 0)// error
		 {
	         return error = phycr_data;
		 }		 		 
         phycr_data &= 0x3FFF ;   		
         phycr_data |= 0x8000 ;   
         error = phy_write(phy_id, PHYCR, phycr_data);
		 if (error < 0)
		 {
			 return error;
		 }
		 break;
        } 




    	switch (Set_link_behavior) 
		{
	     case AUTO_NEG: // auto negotiation mode
		 switch (Set_speed) 
         {
		  case SPD_100: //set speed 100
		  switch (Set_duplex) 
          {
           case FD: //set duplex full
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data |= 0x01E0 ;   // set bits 8,7,6,5 to 1111 advertise all 100/10. FD/HD capabilities   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
 
           case HD: //set duplex half
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 		   
           anar_data &= 0xFE1F;   // clear bits [8:5] 	     
           anar_data |= 0x00A0 ;   // set bits 7,5 to 1,1 HD 
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;

           default: //set duplex full
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data |= 0x01E0 ;   // set bits 8,7,6,5 to 1111 advertise all 100/10. FD/HD capabilities   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
		  }
           break;
		 
		  case SPD_10: //speed 10BT
		  switch (Set_duplex)
		  {
           case FD: // case FD
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data &= 0xFE1F;   // clear bits [8:5]     
           anar_data |= 0x0060 ;   // set bits 6,5 = 1,1 (10BT)   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
	 
		   case HD: // case HD
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data &= 0xFE1F;   // clear bits [8:5] 	 		 
           anar_data |= 0x0020 ;   // set bit 5 = 1 (10BT HD)   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
	       break;
			 
           default: // case FD
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data &= 0xFE1F;   // clear bits [8:5]     
           anar_data |= 0x0060 ;   // set bits 6,5 = 1,1 (10BT)   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
		  }
          break;

		  default: //set speed 100
		  switch (Set_duplex) 
          {
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data |= 0x01E0 ;   // set bits 8,7,6,5 to 1111 advertise all 100/10. FD/HD capabilities   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
 
           case HD: //set duplex half
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data &= 0xFE1F;   // clear bits [8:5] 	     
           anar_data |= 0x00B0 ;   // set bits 7,5 to 1,1 HD 
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;

           default: //set duplex full
           anar_data = phy_read(phy_id, ANAR); // read autonegotiation register 	     
		   if (anar_data < 0)// error
		   {
	           return error = anar_data;
		   }		 
           anar_data |= 0x01E0 ;   // set bits 8,7,6,5 to 1111 advertise all 100/10. FD/HD capabilities   
           error = phy_write(phy_id, ANAR, anar_data); //write
	       if (error < 0)
		   {
			   return error;
		   }
		   break;
		  }
           break;

		 }

	     // write BMCR register to set auto negotiation

         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data |= 0x1200 ;   // set bit 12 = 1 (auto-neg enable) and bit 9 = 1 (restart auto neg)   		 
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	       if (error < 0)
		   {
			   return error;
		   }

         break; // case auto_neg
		 
		 case FORCE: // Set_link_behavior = force mode 
		 bmcr_data = phy_read(phy_id, BMCR);	     
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data &= 0xEDFF ;   // clear bit 12 (auto-neg enable) and bit 9 (restart auto neg) of BMCR_DATA 	     
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	       if (error < 0)
		   {
			   return error;
		   }

         switch (Set_speed)
         {
		 case SPD_100: 
         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data |= 0x2000 ;   // set bit 13 = 1 force 100BT
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;
         
		 case SPD_10: // speed = "10"
         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data = bmcr_data & 0xDFFF ;   // clear bit 13 100BT       
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;

		 default: 
         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data |= 0x2000 ;   // set bit 13 = 1 force 100BT
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;
         }
		 
	     switch (Set_duplex) //set FULL DUPLEX 
         {
         case FD:
         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data |= 0x0100 ;   // set bit 8 = 1 (FULL DUPLEX)   
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;
		 
		 case HD: //(Set_duplex = "HD") set HALF DUPLEX */
         bmcr_data = phy_read(phy_id, BMCR); 	     
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data &= 0xFEFF ;   // clear bit 8 (HALF DUPLEX)	     
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;

         default:
         bmcr_data = phy_read(phy_id, BMCR);
		 if (bmcr_data < 0)// error
		 {			   
	         return error = bmcr_data;
		 }		 
         bmcr_data |= 0x0100 ;   // set bit 8 = 1 (FULL DUPLEX)   
         error = phy_write(phy_id, BMCR, bmcr_data); //write
	     if (error < 0)
		 {			   
			 return error;
		 }
		 break;
         }


         break; 
	}


          return 0;

}




