/*****************************************************************************
 * nsitems.h
 * iType1 and data structure definitions for the NS commands.
 *
 * Copyright (c) 1993-2000, Spirent Communications of Calabasas, Inc.
 * Copyright (c) 1996-1999, Netcom Systems, Inc.
 ****************************************************************************/

#ifndef _NSITEMS_H_
#define _NSITEMS_H_

#include "ettypes.h"

#define	MAX_SCHED_ENTRIES			  2048
#define NS_BASE_NUM					  0x9999

/****************************************************************************
 *					iTypes
 ****************************************************************************/

/*------------------------------------------------------------------------*/
/*----------------------- iTypes for HTSetStructure ----------------------*/
/*------------------------------------------------------------------------*/
#define NS_PORT_TRANSMIT						0x500B	/* set up transmit parameters */
#define NS_STREAM_SCHEDULE						0x500C	/* set up the stream schedule table */
#define NS_DIFF_SERV								0x500D	/* set up diffserv */

/*-Subprocess control-*/
#define NS_CREATE_SUBPROCESS					0x500E	/* Creates a new subprocess or on-board application */
#define NS_DESTROY_SUBPROCESS					0x500F	/* Destroys a subprocess */
#define NS_WRITE_SUBPROCESS					0x502A	/* Submits input to subprocesses/applications */
#define NS_SIGNAL_SUBPROCESS					0x502B	/* Sends a signal to a subprocess/application */

/*-64-bit-Histograms-*/
#define NS_HIST_RAW_SIGNATURE						0x3020   /* Set up raw Signature histogram tracking. */
#define NS_HIST_COMBO_PER_STREAM					0x3021   /* Set up combination histogram tracking: latency distribution, latency per stream, and sequence tracking. */
#define NS_HIST_LATENCY_OVER_TIME				0x3022   /* Set up latency over time histogram tracking. */
#define NS_HIST_SEQUENCE_PER_STREAM				0x3023   /* Set up Sequence histogram tracking. */
#define NS_HIST_LATENCY_DIST_PER_STREAM		0x3024   /* Set up Latency Distribution per stream histogram tracking. */

/*-IGMP-*/
#define NS_IGMP_RESET								0x7015	/* Reset IGMP protocol stack */
#define NS_IGMP_CONFIG								0x7016	/* Configure and initialize the IGMP protocol stack */
#define NS_IGMP_JOIN									0x7017	/* Join multicast group */
#define NS_IGMP_LEAVE								0x7018	/* Leave multicast group */
#define NS_IGMP_LEAVE_VLAN							0x701A	/* Leave multicast group with VLAN tag*/
#define NS_IGMP_JOIN_VLAN							0x7023	/* Join multicast group with VLAN tag */
#define NS_HIST_MULTICAST_LATENCY_PER_STREAM	0x3252	/* Specify/Activate MulticastIP Latency Dist hist with 1st and last Rx timestamp */
/*------------------------------------------------------------------------*/
/*----------------------- iTypes for HTGetStructure ----------------------*/
/*------------------------------------------------------------------------*/
#define NS_CAPTURE_STATS_INFO						0x2004  /* Get statistics about one or more captured frames.  Note that "index" is the frame to get statistics for. */
#define NS_CAPTURE_DATA_INFO						0x2005  /* Get a captured frame.  Note that "index" is the frame to retrieve. */

#define NS_STREAM_SCHEDULE_INFO					0x5024	/* get the stream schedule table */
#define NS_STREAM_SCHEDULE_COUNT_INFO			0x5025	/* get the total entry of the stream schedule table */
#define NS_DIFF_SERV_INFO							0x5026	/* get diffserv structure */
#define NS_DIFF_SERV_COUNTER_INFO				0x5027	/* get diffserv counter structure */
#define NS_QUERY_SUBPROCESS						0x5028	/* Queries the state of a subprocess */
#define NS_READ_SUBPROCESS							0x5029	/* Retrieves output from subprocesses/applications */

#define NS_FFS_INFO									0x5030	/* Retrieve information about the file system on TeraMetrics cards. */
#define NS_RPM_LIST_INFO							0x5031	/* Retrieve a list of RPMs currently loaded on a TeraMetrics cards.  
																			The string (character array) returned as data represents the list. */

#define NS_PORT_TRANSMIT_INFO						0xD001	/* read tx_port*/

/*-64-bit-Histograms-*/
#define NS_HIST_RAW_SIGNATURE_INFO				0x3025 /* Retrieve raw signature histogram information. */
#define NS_HIST_COMBO_PER_STREAM_INFO			0x3026 /* Retrieve combination histogram tracking records. */
#define NS_HIST_LATENCY_OVER_TIME_INFO			0x3027 /* Retrieve latency over time histogram records. */
#define NS_HIST_SEQUENCE_PER_STREAM_INFO		0x3028 /* Retrieve sequence histogram records. */
#define NS_HIST_LATENCY_DIST_PER_STREAM_INFO	0x3029 /* Retrieve latency distribution per stream histogram records. */

/*-IGMP-*/
#define NS_IGMP_TIMESTAMP_INFO					0x7019	/* Retrieve the join and leave timestamps for one or more multicast groups.  An array of NSIGMPTimestampInfo structures is required to retrieve information for multiple groups. */
#define NS_IGMP_VLAN_TIMESTAMP_INFO					0x702A	/* Get multicast VLAN tagged group Join and Leave timestamps */   
#define NS_IGMP_COUNTER_INFO						0x7022	/* Request IGMP counters. */
#define NS_HIST_MULTICAST_LATENCY_PER_STREAM_INFO	0x3011	/* Get MulticastIP Latency Dist hist with 1st and last Rx timestamp.  Note that "index" is the stream to get these results for. */


#define NS_SONET_COUNTER_INFO						(NS_BASE_NUM + 1) /* Retrieve the SONET alarms and counters. */
#define NS_CAPTURE_SETUP							(NS_BASE_NUM + 2) /* configure layer 3 capture on a port   */
#define NS_PORT_ADDRESS								(NS_BASE_NUM + 3) /* Define IP address on a port*/
#define NS_PORT_ADDRESS_INFO						(NS_BASE_NUM + 4)
#define NS_SONET_CONFIG								(NS_BASE_NUM + 5) /* Configures Port characteristics */ 
#define NS_SONET_CONFIG_INFO						(NS_BASE_NUM + 7) /* Retrieves port characteristics */
#define NS_CAPTURE_COUNT_INFO						(NS_BASE_NUM + 9) /* Get the count of captured frames */	

/* Retrieve the hardware information */
#define NS_HW_CONFIG									(NS_BASE_NUM + 10)	/* Configure Port */
#define NS_HW_CONFIG_INFO							(NS_BASE_NUM + 11)	/* Retrieve Port Configuration */
#define NS_CARD_HARDWARE_INFO						(NS_BASE_NUM + 12)	/* Retrieve Card Hardware Info */

/* Capture start and stop commands */
#define NS_CAPTURE_STOP							   (NS_BASE_NUM + 13)  /* Turn Capture Off. */
#define NS_CAPTURE_START						   (NS_BASE_NUM + 14)  /* Turn Capture On. */

/* Terametrics Cut-through iTypes */
#define NS_CT_ENABLE_PROCESS                        (NS_BASE_NUM + 15) /* Enable cut-through capture process. */
#define NS_CT_DISABLE_PROCESS                       (NS_BASE_NUM + 16) /* Disable cut-through capture process. */
#define NS_CT_CONFIG_STORAGE_FILE                   (NS_BASE_NUM + 17) /* Configure where and how frames captured from the cut-through channel are stored. */
#define NS_CT_CLEAR_BUFFER                          (NS_BASE_NUM + 18) /* Clear the contents of a cut-through capture buffer(file) and counters. */
#define NS_CT_CONFIG_CAPTURE_PARAMS                 (NS_BASE_NUM + 19) /* Configure cut-through capture parameters. */
#define NS_CT_CONFIG_CAPTURE_FILTER_PARAMS          (NS_BASE_NUM + 20) /* Configure cut-through capture filter parameters. */
#define NS_CT_START_CAPTURE                         (NS_BASE_NUM + 21) /* Start capturing frames from the cut-through channel. */
#define NS_CT_STOP_CAPTURE                          (NS_BASE_NUM + 22) /* Stop capturing frames from the cut-through channel. */
#define NS_CT_CAPTURE_FRAME_COUNT_INFO              (NS_BASE_NUM + 23) /* Retrieve the number of frames captured from the cut-through channel. */
#define NS_CT_CAPTURE_FRAME_INFO                    (NS_BASE_NUM + 24) /* Retrieve the latest frame captured from the cut-through channel. */
#define NS_CT_CAPTURE_FRAME_V2_INFO                 (NS_BASE_NUM + 30) /* Retrieve the latest frame captured from the cut-through channel. */

#define NS_PER_STREAM_COUNTER_INFO                  (NS_BASE_NUM + 25)	/* Get per stream counter information. Note that "index" is the first stream and "count" is the total number of streams to retrieve counters for. */

/* Configure histogram related options */
#define NS_HIST_LATENCY_OPTION						(NS_BASE_NUM + 26) /* Configure histogram related options. */

/* NS Real Time Tracking Commands */
#define NS_REAL_TIME_TRACKING_TX_CONFIG			(NS_BASE_NUM + 27) /* Configure Real Time Tracking on TX */
#define NS_REAL_TIME_TRACKING_RX_CONFIG			(NS_BASE_NUM + 28) /* Configure Real Time Tracking on RX */
#define NS_REAL_TIME_TRACKING_TX_STOP				(NS_BASE_NUM + 29) /* Stop Real Time Tracking on TX */
#define NS_REAL_TIME_TRACKING_RX_STOP				(NS_BASE_NUM + 40) /* Stop Real Time Tracking on RX */
#define NS_REAL_TIME_TRACKING_TX_COUNTERS			(NS_BASE_NUM + 41) /* Get Real Time Tracking counters on TX */
#define NS_REAL_TIME_TRACKING_RX_COUNTERS			(NS_BASE_NUM + 42) /* Get Real Time Tracking counters on RX */

/* MDIO Registers iTypes */
#define NS_READ_MDIO_INFO							(NS_BASE_NUM + 43) /* Read MDIO Register */
#define NS_WRITE_MDIO								(NS_BASE_NUM + 44) /* Write to MDIO Register */

#define NS_IPV6_COUNTER_INFO			            (NS_BASE_NUM + 45) /* Retrieve IPv6 related counters. */
#define NS_IPV6_RATE_INFO				            (NS_BASE_NUM + 46) /* Retrieve IPv6 related rate counters. */

/* Currently only used internally */
#define NS_HALF_DUPLEX_COUNTER_INFO			        (NS_BASE_NUM + 47)
#define NS_HALF_DUPLEX_RATE_INFO			        (NS_BASE_NUM + 48)

#define NS_L2_STAT_COUNTER_INFO				        (NS_BASE_NUM + 49)
#define NS_L2_STAT_RATE_INFO				        (NS_BASE_NUM + 50)
#define NS_M_GET_L3_STAT_INFO				        (NS_BASE_NUM + 51)

#define NS_IGMPV3_GROUP_CONFIG				        (NS_BASE_NUM + 52) /* Sets the interface for one or more groups. */
#define NS_IGMPV3_GROUP_MOD							(NS_BASE_NUM + 53) /* Modify an existing multicast group or add a new multicast group if the multicast group is new. */
#define NS_IGMPV3_GROUP_INFO				        (NS_BASE_NUM + 54) /* Retrieve the join and leave timestamp information for a multicast group. */
#define NS_IGMPV3_STATS_INFO				        (NS_BASE_NUM + 55) /* Collect IGMPv3 data */
#define NS_IGMPV3_CONFIG							(NS_BASE_NUM + 56) /* Initialize and configure the IGMP stack */
#define NS_IGMPV3_LEAVE_ALL							(NS_BASE_NUM + 57) /* Leave all multicast groups */
#define NS_IGMPV3_ALL_GROUP_INFO					(NS_BASE_NUM + 58) /* Retrieve the join and leave timestamp information for all multicast groups. */

#define NS_WAIT_FOR_EVENT							(NS_BASE_NUM + 59) /* Wait until a particular event occurs. */
#define NS_RESOLVE_ARPS								(NS_BASE_NUM + 60) /* Resolve ARPs for streams on a single port. */

#define NS_STREAM_TYPE_INFO							(NS_BASE_NUM + 62) /* Determine type of stream */
#define NS_IPV6_STREAM_INFO							(NS_BASE_NUM + 63) /* Readback IPV6 stream data */
#define NS_IPV6_STREAM_VLAN_INFO					(NS_BASE_NUM + 64) /* Readback IPV6 stream vlan data */
#define NS_UDP_IPV6_STREAM_INFO						(NS_BASE_NUM + 65) /* Readback UDP IPV6 stream data */
#define NS_UDP_IPV6_STREAM_VLAN_INFO				(NS_BASE_NUM + 66) /* Readback UDP IPV6 vlan stream data */
#define NS_TCP_IPV6_STREAM_INFO						(NS_BASE_NUM + 67) /* Readback TCP IPV6 stream data */
#define NS_TCP_IPV6_STREAM_VLAN_INFO				(NS_BASE_NUM + 68) /* Readback TCP IPV6 vlan stream data */
						
/* OAM commands */
#define NS_OAM_CONFIG	                            (NS_BASE_NUM + 69)  /* Configure the OAM setting. */
#define NS_OAM_PATTERN								(NS_BASE_NUM + 70)  /* Set the OAM pattern. Currently the maximum pattern size is 768 bytes(128 unique OAM patterns * 6 bytes per pattern). */
#define NS_OAM_COUNTER_INFO                         (NS_BASE_NUM + 71)  /* Retrieve OAM counter information. */
#define NS_OAM_RATE_INFO                            (NS_BASE_NUM + 72)  /* Retrieve OAM rate information. */

#define NS_IP_OPTION_CONFIG							(NS_BASE_NUM + 73)	/* Configure IP Option on streams */								

#define NS_ARP_CONFIG							    (NS_BASE_NUM + 74) /* Enables Virtual Streams */

#define NS_DOWNLOAD_FILE							(NS_BASE_NUM + 75) /* Download file to Terametrics card from PC */
#define NS_UPLOAD_FILE							    (NS_BASE_NUM + 76) /* Upload file from Terametrics card to PC*/
#define NS_COUNTER_INFO								(NS_BASE_NUM + 77) /* Get L2 Counters */

#define NS_COMMIT_CONFIG							(NS_BASE_NUM + 78) /* Commit all Tx configuration  */

/* Undocumented commands */
#define NS_MFG_PROM_CONFIG                          (NS_BASE_NUM + 79)   /* Write data onto MFG PROM of TeraMetrics cards */
#define NS_MFG_PROM_INFO                            (NS_BASE_NUM + 80)   /* Read data from MFG PROM of TeraMetrics cards */

/* Trigger command(s) */
#define NS_TRIGGER_CONFIG                           (NS_BASE_NUM + 81)   /* Configure trigger(s) */

/* Alternate key command(s) */
#define NS_ALTERNATE_KEY_CONFIG                     (NS_BASE_NUM + 82)   /* Configure Alternate Key */
#define NS_ALTERNATE_KEY_HASH_CONFIG                (NS_BASE_NUM + 83)   /* Configure Alternate Key Hash */


#define NS_ARP_STATUS_INFO                          (NS_BASE_NUM + 84)   /* Query the ARP counters */

/* IPV6 Stack */
#define NS_IPV6_CONFIG                              (NS_BASE_NUM + 85)   /* Configures the IPv6 Protocol Stack */
#define NS_IPV6_CONFIG_INFO                         (NS_BASE_NUM + 86)   /* Query the IPv6 Protocol Stack */
#define NS_IPV6_CONTROL                             (NS_BASE_NUM + 87)   /* Control the IPv6 stack for protocol streams. */
#define NS_IPV6_STATUS_INFO                         (NS_BASE_NUM + 88)   /* To retrieve the status of the IPv6 stack. */

/* Router and Prefix Discovery */
#define NS_IPV6_ROUTER_DISCOVERY_COUNT_INFO         (NS_BASE_NUM + 89)   /* To retrieve the number of router discovery information obtained from received router advertisements.*/
#define NS_IPV6_ROUTER_DISCOVERY_INFO               (NS_BASE_NUM + 90)   /* To retrieve information obtained from Router Advertisements excluding prefix information.*/
#define NS_IPV6_ROUTER_PREFIX_COUNT_INFO            (NS_BASE_NUM + 91)   /* To retrieve the number of prefix information obtained from received router advertisements.*/
#define NS_IPV6_ROUTER_PREFIX_INFO                  (NS_BASE_NUM + 92)   /* To retrieve prefix information obtained from received Router Advertisements */

/* Stateless Address AutoConfiguration */
#define NS_IPV6_STATELESS_ADDRESS_COUNT_INFO        (NS_BASE_NUM + 93)   /* To retrieve number configured address currently stored. */
#define NS_IPV6_STATELESS_ADDRESS_INFO              (NS_BASE_NUM + 94)   /* To retrieve the configured addresses for protocol streams.*/

/* 40 bytes IP frames Detection */
#define NS_SIGNATURE_DETECT_MODE                    (NS_BASE_NUM + 95)   /* Set the mode for detection of signature fields which are not right-aligned in incoming IP frames. 
                                                                            This command allows detection of the signature field on IP frames of 40 bytes. */

/* Translation IPv6 to IPv4 */
#define NS_IPV6_IPV4_ADDRESS_MAP_INFO               (NS_BASE_NUM + 96)   /* This message maps ranges of IPv4 address to IPv6 address for use in translation. */
#define NS_IPV6_IPV4_ADDRESS_MAP_DELETE             (NS_BASE_NUM + 97)   /* Delete a previously defined address map.*/
#define NS_IPV6_IPV4_TRANSLATION                    (NS_BASE_NUM + 98)   /* Indicate the destination of a protocol stream specifically for IPv6-IPv4 translation.*/

/* New IGMP V1/V2 messages for Terametrics */
#define NS_IGMPV2_JOIN                             (NS_BASE_NUM + 99)  /* Join one or more multicast group for IGMP v1/v2. */
#define NS_IGMPV2_LEAVE                            (NS_BASE_NUM + 100) /* Leave multicast group for IGMP v1/v2. */
#define NS_IGMPV2_INFO                             (NS_BASE_NUM + 101) /* Retrieve the join and leave timestamp for a specific multicast group (v1/v2) */
#define NS_IGMPV2_ALL_INFO                         (NS_BASE_NUM + 102) /* Retrieve join and leave timestamp for all specific v1 and v2 multicast groups.
                                                                          It returns an array of structures. */

/* Alternate key command(s) Continue */
#define NS_ALTERNATE_KEY_CONFIG_INFO                (NS_BASE_NUM + 103)   /* Query the configured Alternate Key */
#define NS_ALTERNATE_KEY_HASH_CONFIG_INFO           (NS_BASE_NUM + 104)   /* Query the configured Alternate Key Hash */

/* Next Hop */
#define NS_IPV6_NEXT_HOP_RESULTS_INFO               (NS_BASE_NUM + 105)   /* Retrieve the results of IPv6 Next-Hop Determination on a per-stream basis */

/* 40 bytes IP frames Detection continue.... */
#define NS_TRANSMIT_PADDING_MODE                    (NS_BASE_NUM + 106)   /* Set the padding mode for transmitted frames.*/
#define NS_TRANSMIT_PADDING_MODE_INFO               (NS_BASE_NUM + 107)   /* Query the mode for padding on the transmit frame.*/
#define NS_SIGNATURE_DETECT_MODE_INFO               (NS_BASE_NUM + 108)   /* Query the mode for detection of signature fields which are not right-aligned in incoming IP frames. */

/* Protocol Counters */
#define NS_PROTOCOL_COUNTER_INFO                    (NS_BASE_NUM + 109)   /* Get counters for a port from the card protocol stack */
#define NS_PROTOCOL_RATE_INFO                       (NS_BASE_NUM + 110)   /* Get rates for a port from the card protocol stack, in frames per second*/

/* DiffServ commands */
#define NS_DIFF_SERV_CONFIG                         (NS_BASE_NUM + 111)   /* Configure DiffServ settings. */
#define NS_DIFF_SERV_CONFIG_INFO                    (NS_BASE_NUM + 112)   /* Retrieve DiffServ settings. */
#define NS_DIFF_SERV_RATE_INFO                      (NS_BASE_NUM + 113)   /* Retrieve DiffServ rates. */

/* MLD Multicast Listener Discovery */
#define NS_MLD_CONFIG                               (NS_BASE_NUM + 114)  /* Initialize and configure MLD Stack */
#define NS_MLD_RESET                                (NS_BASE_NUM + 115)  /* Reset MLD stack */
#define NS_MLD_COUNTER_INFO                         (NS_BASE_NUM + 116)  /* Retrieve MLD counter information */
#define NS_MLDV1_LISTEN                             (NS_BASE_NUM + 117)  /* Specify one or more Multicast address to Start or Stop Listening */
#define NS_MLD_TIMESTAMP_INFO                       (NS_BASE_NUM + 118)  /* Retrieve join and leave timestamps for all multicast groups */

#define NS_GET_SUBSCRIPTION                         (NS_BASE_NUM + 119)  /* Get the percentage of linespeed bandwidth that can be utilized, given the 
                                                                         current active streams, their size, checksumming method, & framerate settings*/
/* IPv6 Stream Extension headers */
#define NS_DEFINE_IPV6_EXT_HOP_BY_HOP               (NS_BASE_NUM + 120) /* Define one or more IPv6 Hop-by-Hop Extension headers (can be used with an array)*/
#define NS_DEFINE_IPV6_EXT_ROUTING                  (NS_BASE_NUM + 121) /* Define one or more IPv6 Routing Extension headers (can be used with an array)*/
#define NS_DEFINE_IPV6_EXT_FRAGMENT                 (NS_BASE_NUM + 122) /* Define one or more IPv6 Fragment Extension headers (can be used with an array)*/
#define NS_DEFINE_IPV6_EXT_DESTINATION              (NS_BASE_NUM + 123) /* Define one or more IPv6 Destination Extension headers (can be used with an array)*/
#define NS_DEFINE_IPV6_EXT_AUTHENTICATION                       (NS_BASE_NUM + 124) /* Define one or more IPv6 Authentication Extension headers (can be used with an array)*/
#define NS_DEFINE_IPV6_EXT_ESP                      (NS_BASE_NUM + 125) /* Define one or more IPv6 Encapsulated security payload(ESP)  Extension headers (can be used with an array)*/

#define NS_MOD_IPV6_EXT_HOP_BY_HOP                  (NS_BASE_NUM + 126) /* Modify one stream at a given index with IPv6 Hop-by-Hop Extension headers */
#define NS_MOD_IPV6_EXT_ROUTING                     (NS_BASE_NUM + 127) /* Modify one stream at a given index with IPv6 Routing Extension header */
#define NS_MOD_IPV6_EXT_FRAGMENT                    (NS_BASE_NUM + 128) /* Modify one stream at a given index with IPv6 Fragment Extension headers */
#define NS_MOD_IPV6_EXT_DESTINATION                 (NS_BASE_NUM + 129) /* Modify one stream at a given index with IPv6 Destination  Extension headers */
#define NS_MOD_IPV6_EXT_AUTHENTICATION              (NS_BASE_NUM + 130) /* Modify one stream at a given index with IPv6 Authentication Extension headers */
#define NS_MOD_IPV6_EXT_ESP                         (NS_BASE_NUM + 131) /* Modify one stream at a given index with IPv6 Encapsulated Security Payload(ESP) Extension headers */

/* IPv6 over IPv4 Tunneling commands */
#define NS_DEFINE_IPV6_OVER_IPV4_TUNNELING          (NS_BASE_NUM + 132) /* Create one or more IPv4 streams (packets) that will be used to encapsulate existing IPv6 Streams (packets).
                                                                        Can be used with an array*/
#define NS_MOD_IPV6_OVER_IPV4_TUNNELING             (NS_BASE_NUM + 133) /* Modify IPv4 protocol part of an existing IPv6-over-IPv4 Tunneled stream at a specified index. 
                                                                        If the stream at the specified index is not tunneled, it will be tunneled.*/
#define NS_DEFINE_MULTI_IPV6_OVER_IPV4_TUNNELING    (NS_BASE_NUM + 134) /* Create one or more IPv6-Over-IPv4 tunneled streams based on an existing Tunneled stream. 
                                                                        The "index" is the stream to copy and "count" is the number of streams to create. */

/* Eagle interface */
#define NS_PHY_CONFIG                               (NS_BASE_NUM + 135) /* This command configures the layer 2 protocol mode of operation */
#define NS_PHY_CONFIG_INFO                          (NS_BASE_NUM + 136) /* This command queries the layer 2 protocol mode of operation */

/* Next Hop */
#define NS_IPV6_NEXT_HOP_RESULTS_COUNT_INFO         (NS_BASE_NUM + 137) /* Retrieve the number of Next-Hop Determination on a per-port */

#define NS_ARP_CONFIG_INFO							       (NS_BASE_NUM + 138) /* Retrieve ARP settings. */

#define NS_ETH_PHY_COUNTERS							    (NS_BASE_NUM + 139) /* Internal Message used for ETH_PHY counters */
#define NS_ETH_PHY_RATES							       (NS_BASE_NUM + 140) /* Internal Message used for ETH_PHY RATES */
#define NS_RATE_INFO							             (NS_BASE_NUM + 141) /* Get rates for a port from the card protocol stack,in frames per second */
#define NS_IPV4_COUNTERS							       (NS_BASE_NUM + 142) /* Internal Message used for IPv4 counters */
#define NS_IPV4_RATES							          (NS_BASE_NUM + 143) /* Internal Message used for IPv4 RATES */
#define NS_PROT_COUNTERS							       (NS_BASE_NUM + 144) /* Internal Message used for Protocol counters */
#define NS_PROT_RATES							          (NS_BASE_NUM + 145) /* Internal Message used for Protocol RATES */

#define NS_MULTI_COUNTER_INFO                      (NS_BASE_NUM + 146) /* Retrieve all counters supported by Terametric cards*/

/* MLDv2 Messages */
#define NS_MLDV2_GROUP_CONFIG                      (NS_BASE_NUM + 147) /* Configures one or more multicast groups */
#define NS_MLDV2_GROUP_MOD                         (NS_BASE_NUM + 148) /* Modify existing multicast group or add a new multicast group if 
                                                                           multicast group or interface is new. */
#define NS_MLDV2_STATS_INFO                        (NS_BASE_NUM + 149) /* Retrieve report counters for a specific multicast group */
#define NS_MLD_STOP_LISTEN                         (NS_BASE_NUM + 150) /* Stop listening for all groups both MLDv1 and MLDv2  */
#define NS_MLD_GROUP_INFO                          (NS_BASE_NUM + 151) /* Retrieve group information for a specfic multicast group */
#define NS_MLDV2_LISTENER_REPORT_CONFIG            (NS_BASE_NUM + 152) /* Configures the Type and the Destination Address fields for Multicast Listener Report */
#define NS_MLD_ALL_GROUP_INFO                      (NS_BASE_NUM + 153) /* Retrieve information on all multicast groups */

/* Configuration message for all TM cards */
#define NS_PORT_CONFIG                             (NS_BASE_NUM + 154) /* Configure port settings. */
#define NS_PORT_CONFIG_INFO                        (NS_BASE_NUM + 155) /* Retrieve port settings. */

#define NS_CT_CONFIG											(NS_BASE_NUM + 156) /* Setup cut-through configurations */
#define NS_CT_CONFIG_INFO									(NS_BASE_NUM + 157) /* Retrieve cut-through configurations   */

#define NS_IGMP_GROUP_COUNT_INFO							(NS_BASE_NUM + 158) /* This command returns the number of multicast (IGMP) Groups on a port. A multicast configuration with the same multicast address but different multicast interface configuration is considered to be in separate multicast Groups.  A multicast Group is a distinct combination of multicast interface and multicast address configuration */
#define NS_MLD_GROUP_COUNT_INFO							(NS_BASE_NUM + 159) /* This command returns the number of multicast(MLD) Groups on a port. A multicast configuration with the same multicast address but different multicast interface configuration is considered to be in separate multicast Groups.  A multicast Group is a distinct combination of multicast interface and multicast address configuration */
/* Trigger Readback command(s) */
#define NS_TRIGGER_CONFIG_INFO                     (NS_BASE_NUM + 160)   /* Retrieve Trigger Configurations */

/* New NS stream configuration command */
#define NS_COMMIT_STREAM_CONFIG_OBJECT             (NS_BASE_NUM + 161)   /* Commit a stream configuration to a port */

/* 802.1x Commands */
#define NS_DOT1X_SUPPLICANT_PORT_CONFIG				(NS_BASE_NUM + 162)   /* Port Configuration for Supplicants */
#define NS_DOT1X_SUPPLICANT_PORT_CONFIG_INFO			(NS_BASE_NUM + 163)   /* Retrieve Port Configuration for Supplicants */
#define NS_DOT1X_SUPPLICANT_CONFIG						(NS_BASE_NUM + 164)   /* Configure one or more Supplicants */
#define NS_DOT1X_SUPPLICANT_CONFIG_INFO				(NS_BASE_NUM + 165)   /* Retrieve Configuration for one or more Supplicants */
#define NS_DOT1X_SUPPLICANT_STATS_INFO					(NS_BASE_NUM + 166)   /* Retrieve Statistics of one or more Supplicants  */
#define NS_DOT1X_SUPPLICANT_CONTROL						(NS_BASE_NUM + 167)   /* Send an action on one or more supplicants */
#define NS_DOT1X_SUPPLICANT_RESET						(NS_BASE_NUM + 168)   /* Delete all supplicants, and clear all the supplicants and session statistics on the port */
#define NS_DOT1X_SUPPLICANT_STATUS_INFO				(NS_BASE_NUM + 169)   /* Retrieval the status information for one or multiple supplicants  */
#define NS_DOT1X_SUPPLICANT_SESSION_STATS_INFO		(NS_BASE_NUM + 170)   /* Retrieve global supplicant statistics for a port  */
#define NS_DOT1X_SUPPLICANT_COPY             		(NS_BASE_NUM + 171)   /* Copy configuration of one supplicant to other supplicants  */
#define NS_DOT1X_SUPPLICANT_MODIFY             		(NS_BASE_NUM + 172)   /* Modify one parameter for one or multiple supplicants  */
#define NS_DOT1X_SUPPLICANT_FILL             		(NS_BASE_NUM + 173)   /* Increment a single configuration parameter for one or multiple supplicants  */
#define NS_DOT1X_SUPPLICANT_STATUS_SEARCH_INFO     (NS_BASE_NUM + 174)    /* Return info for matching status information  */
#define NS_DOT1X_DOWNLOAD_CERTIFICATE_FILES        (NS_BASE_NUM + 175)   /* Download Certificate and Key files */


/* Retrieve histogram related options */
#define NS_HIST_LATENCY_OPTION_INFO						(NS_BASE_NUM + 178) /* Retrieve histogram related options. */

#define NS_STREAM_ID_TABLE_INFO						   (NS_BASE_NUM + 179) /* Retrieve the stream IDs currently being tracked on a port. */

/* Configure Phy  default configuration at boot up time */
#define NS_PHY_DEFAULT_CONFIG                       (NS_BASE_NUM + 180) /* Configure Phy default settings for TM LAN port at boot time */
#define NS_PHY_DEFAULT_CONFIG_INFO                  (NS_BASE_NUM + 181) /* Read back Phy default settings for TM LAN port */

#define NS_MLD_CLEAR_COUNTERS                       (NS_BASE_NUM + 182) /* Clear IGMP port counters and group statistics */
#define NS_IGMP_CLEAR_COUNTERS                      (NS_BASE_NUM + 183) /* Clear MLD port counters and group statistics  */
#define NS_MULTICAST_KEEP_ALIVE_CONFIG              (NS_BASE_NUM + 184) /* To start or stop sending of multicast "keep-alive" UDP
                                                                           packets periodically to multicast group addresses, to 
                                                                           extend the PIM-SM timers to prevent the multicast router 
                                                                           entry from being deleted. This is a port based command,
                                                                           it will control the multicast "keep-alive" packet sending
                                                                           for the streams which have the flag "ucMulticastKeepAliveEnable"
                                                                           enabled in stream extension. */
/* WAN Sonet interface Commands for 10G test modules */
#define NS_WIS_CONFIG                               (NS_BASE_NUM + 185) /* Configure WAN Interface Sublayer */
#define NS_WIS_CONFIG_INFO                          (NS_BASE_NUM + 186) /* Read back WAN Interface Sublayer settings */
#define NS_WIS_LINE_STATUS_RESET                    (NS_BASE_NUM + 187) /* Clear WAN Interface Sublayer counters (events/rates) */
#define NS_WIS_LINE_STATUS_INFO                     (NS_BASE_NUM + 188) /* Retrieve WAN Interface Sublayer counters (events/rates) */

#define NS_RUNTIME_HIST_COMBO_PER_STREAM_INFO		 (NS_BASE_NUM + 189) /* Internal command for run time histogram statistics */
#define NS_RUNTIME_HIST_STATS_CONFIG					 (NS_BASE_NUM + 190) /* This command is used to specify the stream ID's to be tracked for RunTime stats */

/* DiffServ commands */
#define NS_DIFF_SERV_V2_CONFIG                      (NS_BASE_NUM + 191) /* Configure DiffServ settings. */
#define NS_DIFF_SERV_V2_CONFIG_INFO                 (NS_BASE_NUM + 192) /* Retrieve DiffServ settings. */
#define NS_DIFF_SERV_V2_COUNTER_INFO                (NS_BASE_NUM + 193) /* Retrieve DiffServ counters. */
#define NS_DIFF_SERV_V2_RATE_INFO                   (NS_BASE_NUM + 194) /* Retrieve DiffServ rates. */

#define NS_IPV6_PROTOCOL_HEADER_INFO					 (NS_BASE_NUM + 195) /* Get IPv6 Protocol information */
#define NS_IPV4_PROTOCOL_HEADER_INFO					 (NS_BASE_NUM + 196) /* Get IPv4 Protocol information */


#define NS_MOD_V2_STREAMS_ARRAY							 (NS_BASE_NUM + 197)	/* modify a Stream field in a block of Streams by overlaying an array of values. Terametrics LAN XD cards */
#define NS_PROTOCOL_HEADER_INFO							 (NS_BASE_NUM + 198) /* Get Protcol header information */
#define NS_FILL_PATTERN										 (NS_BASE_NUM + 199)	/* Specifies the background fill pattern. Terametrics LAN XD cards */

#define NS_LINK_FAULT_CONFIG 							    (NS_BASE_NUM + 200)	/* Configure/Clear Remote and Local Faults for XFP test modules */
#define NS_LINK_FAULT_INFO 								 (NS_BASE_NUM + 201)	/* Retrieve the type of fault present on the port for XFP test modules */

/* New NS stream mod/copy configuration command */
#define NS_STREAM_MULTI_CONFIG								(NS_BASE_NUM + 202)   /* modify or copy stream to a port */

#define NS_HIST_ENHANCED_LATENCY_OPTION					(NS_BASE_NUM + 203) /* Configure a port to keep track of a specifed latency type when running latency histogram tests*/
#define NS_HIST_ENHANCED_LATENCY_OPTION_INFO				(NS_BASE_NUM + 204) /* Retrieve Histogram Lantency settings */  

#define NS_RUNTIME_ENHANCED_HIST_STATS						(NS_BASE_NUM + 205) /* Internal command for enhanced runtime histograms */ 
#define NS_STREAM_ARP_STATUS_INFO			(NS_BASE_NUM + 206) /* query ARP status of a specified range of streams */ 
#define NS_GET_MULTI_CAPTURE_DATA			(NS_BASE_NUM + 207) /* retrieve multiple captured data plane packets of specific range */
/****************************************************************************/
/* Structures to be used with the NS iTypes                                 */
/****************************************************************************/


/*************************************************************************************
 * Structure:   NSHistLatencyOption
 * iType1:      NS_HIST_LATENCY_OPTION/NS_HIST_LATENCY_OPTION_INFO
 * iType2:      0
 * iType3:      0
 * iType4:      0
 * Function:    HTSetCommand
 * Description: Configure a port to keep track of either the minimum or total latency
 *				when running the latency histogram tests.
 *************************************************************************************/
/* NSHistLatencyOption Description:

Configure a port to keep track of either the minimum or total latency
when running the latency histogram tests.

This command currently only applies for the TeraMetrics modules.
             
Limitations:

When tracking the total latency(NS_TRACK_TOTAL_LAT) for the jumbo histogram
test (NS_HIST_COMBO_PER_STREAM or L3_HIST_V2_LATENCY_PER_STREAM), the
port will not keep track of the number of frames received in 
sequence(u64InSequence or ulSequenced).

The NS_TRACK_STREAM_ID option mode provides the ability to retrieve histogram test results 
without stopping the test on the port.  This mode is only applicable for the LAN TeraMetrics 
family of modules.  In addition, this mode is only applicable when running the jumbo histogram 
test (NS_HIST_COMBO_PER_STREAM or L3_HIST_V2_LATENCY_PER_STREAM).  For this mode,
the port will not keep track of the minimum latency (ulMinLatency), maximum 
latency (ulMaxLatency), in sequence (u64InSequence) and out of sequence (u64OutOfSequence) 
histogram results.
*/

#define NS_TRACK_MIN_LAT    0
#define NS_TRACK_TOTAL_LAT  1
#define NS_TRACK_STREAM_ID  2

typedef struct tagNSHistLatencyOption
{
    unsigned short uiOption;        /* NS_TRACK_MIN_LAT, NS_TRACK_TOTAL_LAT or 
                                       NS_TRACK_STREAM_ID */
    unsigned char  ucLatencyScale;  /* Set the latency interval scale that will 
												   be used for the latency over time histogram 
													tests(NS_HIST_LATENCY_OVER_TIME and 
													L3_HIST_V2_LATENCY).  
													Possible values are:

													NS_LAT_SCALE_1_MILLISECOND
													NS_LAT_SCALE_100_NANOSECOND

													This field is currently only applicable 
													for the FBC-360x modules. */
    unsigned char  ucReserved[9];   /* Reserved*/
} NSHistLatencyOption;

#define NS_LAT_SCALE_1_MILLISECOND   0  /* Unit of 1 milliseconds   */
#define NS_LAT_SCALE_100_NANOSECOND  1  /* Unit of 100 nano Seconds */

/*********************************************************************************
 * Structure:   NSOAMConfig
 * iType1:      NS_OAM_CONFIG
 * iType2:      0
 * iType3:      0
 * Function:    HTSetStructure
 * Description: Configure OAM settings.
 *
 **********************************************************************************/
/* NSOAMConfig Description:

Configure OAM settings.  This command currently only applies for the LAN-3710AS, LAN-3710AL and LAN-3710AE cards.
*/
typedef struct tagNSOAMConfig
{
    unsigned long ulTotalPatterns;      /* Total number of OAM patterns (max=128, 6 bytes per pattern) */
    unsigned char ucCRC8ErrorEnable;    /* Enable generating CRC8 error for each OAM pattern */
    unsigned char ucOAMEnable;          /* This mode needs to be enabled in order for the port
                                           to transmit and receive frames.  This includes capturing
                                           and gathering statistics(counters) for OAM frames.
	                                       1=enabled, 0=disabled (default) */
    unsigned char ucReserved[58];       /* reserved */
} NSOAMConfig;


/*********************************************************************************
 * Structure:   NSOAMCounterInfo
 * iType1:      NS_OAM_COUNTER_INFO
 * iType2:      0
 * iType3:      0
 * Function:    HTGetStructure
 * Description: Get OAM counters
 *
 **********************************************************************************/
/* NSOAMCounterInfo Description:

Get OAM counters.  This command currently only applies for the LAN-3710AS, LAN-3710AL and LAN-3710AE cards.
*/
typedef struct tagNS0AMCounterInfo
{
    U64     u64TxFrames;        /*Total count of number of transmitted none-OAM Frames excluding error frames.*/
    U64     u64TxOAMFrames;     /*Total count of number of transmitted OAM frames excluding transmitted 
                                  OAM "idle" frames and error frames. */
    U64     u64TxOAMIdleFrames; /*Total count of number of transmitted OAM "idle" frames excluding error frames.*/
    U64     u64RxFrames;        /*Total count of number of received none-OAM Frames excluding error frames.*/
    U64     u64RxOAMFrames;     /*Total count of number of received OAM frames excluding received OAM "idle" 
                                    frames and error frames. */
    U64     u64RxOAMIdleFrames; /*Total count of number of received OAM "idle" frames excluding error frames. */
    U64     u64RxCRC8Errors;    /*Total count of number of received OAM frames which contain CRC8 errors. */
} NSOAMCounterInfo;


/*********************************************************************************
 * Structure:   NSOAMRateInfo
 * iType1:      NS_OAM_RATE_INFO
 * iType2:      0
 * iType3:      0
 * Function:    HTGetStructure
 * Description: Get OAM rates
 *
 **********************************************************************************/
/* NSOAMRateInfo Description:

Get OAM rates.  This command currently only applies for the LAN-3710AS, LAN-3710AL and LAN-3710AE cards.
*/
typedef struct tagNSOAMRateInfo
{
    unsigned long ulTxFrames;       /*Last recorded rate of transmitted none-OAM frames excluding error frames. */
    unsigned long ulTxOAMFrames;    /*Last recorded rate of transmitted OAM frames excluding transmitted 
                                        OAM "idle" frames and error frames. */
    unsigned long ulTxOAMIdleFrames;/*Last recorded rate of transmitted OAM "idle" frames excluding error frames. */
    unsigned long ulRxFrames;       /*Last recorded rate of received none-OAM frames excluding error frames. */
    unsigned long ulRxOAMFrames;    /*Last recorded rate of received OAM frames excluding received OAM "idle" 
                                        frames and error frames. */
    unsigned long ulRxOAMIdleFrames;/*Last recorded rate of received OAM "idle" frames excluding error frames. */
    unsigned long ulRxCRC8Errors;   /*Last recorded rate of received OAM frames which contain CRC8 errors. */
} NSOAMRateInfo;


/*********************************************************************************
 * Structure:   NSPerStreamCounterInfo
 * iType1:      NS_PER_STREAM_COUNTER_INFO
 * iType2:      Requested Starting Stream Index
 * iType3:      Requested Stream Count
 * Function:    HTGetStructure
 * Description: Retrieve Counters per stream.
 *
 **********************************************************************************/
/* 
 NSPerStreamCounterInfo Description:
 Retrieve counters per stream. 

 The rate per stream (transmit) on Terametrics cards can be calculated with 
 this command using values obtained from u64TxTimeStamp and u64TxFrames at
 different time intervals.
 
                         CurrentFrameCount - PreviousFrameCount
  Rate per Stream(TX) =	 --------------------------------------
					     CurrentTimeStamp - PreviousTimeStamp

  The maximum number of stream supported by this command is 1000 streams.
  The time interval for u64TxTimeStamp is 100 nanoseconds.
  Inconsistent results occur if random frame lengths are enabled.             
*/
typedef struct tagNSPerStreamCounterInfo
{
    U64           u64TxTimeStamp;      /* TimeStamp when Tx Frames 
										was collected */
	U64           u64TxFrames;      /* Number of transmitted frames */
    unsigned char ucReserved[128];  /* Reserved */
} NSPerStreamCounterInfo;


/*********************************************************************************
 * Structure:   NSSonetConfig
 * iType1:      NS_SONET_CONFIG
 * Function:    HTSetStructure
 * NSSonetConfig Description: Configures port characteristics
 *
 **********************************************************************************/
typedef struct tagNSSonetConfig
{
	unsigned char ucInterfaceSpeed;		/*	NS_SPEED_OC3 (OC3 - 155),
											NS_SPEED_OC12 (OC12 - 622)*/
	unsigned char ucFramingMode;		/*	Physical layer framing 
											SONET - NS_SONET_FRAMING,
											SDH - NS_SDH_FRAMING */
	unsigned char ucTxClockSource;		/*	Internal Clock - NS_INTERNAL_CLOCK,
											Loop Timed - NS_LOOP_TIMED_CLOCK */
	unsigned char ucPathSignalLabel;	/*	NS_PATH_SIGNAL_LABEL_ATM,
											NS_PATH_SIGNAL_LABEL_PPP,
											NS_PATH_SIGNAL_LABEL_HDLC */
	unsigned char ucSONETCountMode;		/*	Individual - 0,
											Block - 1 */
	unsigned long ulErrorInjection;		/*	NS_SONET_CELL_HEC_ALARM,
											NS_SONET_PATH_RDI_ALARM,
											NS_SONET_PATH_AIS_ALARM,
											NS_SONET_PATH_BIP_ALARM,
											NS_SONET_LINE_RDI_ALARM,
											NS_SONET_LINE_AIS_ALARM,
											NS_SONET_LINE_BIP_ALARM,
											NS_SONET_SECTION_LOS_ALARM,	
											NS_SONET_SECTION_LOF_ALARM,
											NS_SONET_SECTION_BIP_ALARM
										*/
	unsigned char ucReserved[64];
}NSSonetConfig;


/* Start *****************Moved to atmtmitems.h******************************/
//#define AT_SPEED_OC3						0
//#define AT_SPEED_OC12					1

//#define AT_SONET_FRAMING				0
//#define AT_SDH_FRAMING					1

//#define AT_INTERNAL_CLOCK				0
//#define AT_LOOP_TIMED_CLOCK			1

//#define AT_PATH_SIGNAL_LABEL_ATM		0x13
//#define AT_PATH_SIGNAL_LABEL_PPP		0x16
//#define AT_PATH_SIGNAL_LABEL_HDLC	0xcf

//#define AT_SONET_CELL_HEC_ALARM			0x0001
//#define AT_SONET_PATH_RDI_ALARM			0x0002
//#define AT_SONET_PATH_AIS_ALARM			0x0004
//#define AT_SONET_PATH_BIP_ALARM			0x0008
//#define AT_SONET_LINE_RDI_ALARM			0x0010
//#define AT_SONET_LINE_AIS_ALARM			0x0020
//#define AT_SONET_LINE_BIP_ALARM			0x0040
//#define AT_SONET_SECTION_LOS_ALARM		0x0080
//#define AT_SONET_SECTION_LOF_ALARM		0x0100
//#define AT_SONET_SECTION_BIP_ALARM		0x0200
/* End *******************Moved to atmtmitems.h******************************/

#define NS_SPEED_OC3						0
#define NS_SPEED_OC12					1

#define NS_SONET_FRAMING				0
#define NS_SDH_FRAMING					1

#define NS_INTERNAL_CLOCK				0
#define NS_LOOP_TIMED_CLOCK			1

#define NS_PATH_SIGNAL_LABEL_ATM		0x13
#define NS_PATH_SIGNAL_LABEL_PPP		0x16
#define NS_PATH_SIGNAL_LABEL_HDLC	0xcf

#define NS_SONET_CELL_HEC_ALARM			0x0001
#define NS_SONET_PATH_RDI_ALARM			0x0002
#define NS_SONET_PATH_AIS_ALARM			0x0004
#define NS_SONET_PATH_BIP_ALARM			0x0008
#define NS_SONET_LINE_RDI_ALARM			0x0010
#define NS_SONET_LINE_AIS_ALARM			0x0020
#define NS_SONET_LINE_BIP_ALARM			0x0040
#define NS_SONET_SECTION_LOS_ALARM		0x0080
#define NS_SONET_SECTION_LOF_ALARM		0x0100
#define NS_SONET_SECTION_BIP_ALARM		0x0200


/*********************************************************************************
 * Structure:   NSCreateSubprocess
 * iType1:      NS_CREATE_SUBPROCESS
 * Function:    HTSetStructure

 * NSCreateSubprocess Description:
 * Set subprocess creation parameters. Creates a subprocess on a per-card basis,
 * meaning that it ignores the port parameter of the HTSetStructure command.  
***********************************************************************************/
typedef struct tagNSCreateSubprocess
{
   unsigned long  ulUserID; 			/* user ID of subprocess */
   unsigned long  ulGroupID; 			/* group ID of subprocess */
   unsigned short uiModuleID; 			/* module ID */
   unsigned long  ulSharedMemKey; 		/* key for shared memory segment */
   unsigned char  ucCommand[1024];      /* subprocess command line */
   unsigned char  ucReserved[50]; 
   unsigned long  ulSubprocessHandle;   /* output */
} NSCreateSubprocess;

/*********************************************************************************
 * Structure:   NSReadWriteSubprocess
 * iType1:      NS_WRITE_SUBPROCESS and NS_READ_SUBPROCESS
 * Function:    HTSetStructure and HTGetStructure

 * NSReadWriteSubprocess Description:
 * Submits input to and retrieves output from subprocesses and applications
***********************************************************************************/
typedef struct tagNSReadWriteSubprocess
{
   unsigned long ulSubprocessHandle;    /* input */
   unsigned long ulBufferLen;           /* length of buffer field (in bytes) */
   unsigned char ucBuffer[1024]; 		/* output from subprocess */
} NSReadWriteSubprocess;

/*********************************************************************************
 * Structure:   NSSignalSubprocess
 * iType1:      NS_SIGNAL_SUBPROCESS
 * Function:    HTSetStructure

 * NSSignalSubprocess Description:
 * Submits input to and retrieves output from subprocesses and applications
***********************************************************************************/
typedef struct tagNSSignalSubprocess
{
   unsigned long ulSubprocessHandle;    
   unsigned long ulSignal;             /* signal number to send to process */
} NSSignalSubprocess;


/****************************************************************************/
/* structures to be used with HTGetStructure                                */
/****************************************************************************/

/*********************************************************************************
 * Structure:   NSSonetCounterInfo
 * iType1:      NS_SONET_COUNTER_INFO
 * Function:    HTGetStructure
 * NSSonetCounterInfo Description: Get the SONET physical alarms and event counters.
 *
 **********************************************************************************/
/*
NSSonetCounterInfo Description:

 Alarm Constants for uiAlarmCurrent and uiAlarmHistory Fields
    SONET_SECTION_LOS_ALARM        0x0001
    SONET_SECTION_OOF_ALARM        0x0002
    SONET_SECTION_LOF_ALARM        0x0004
    SONET_LINE_AIS_ALARM           0x0008
    SONET_LINE_FERF_ALARM          0x0010
    SONET_LINE_LOP_ALARM           0x0020
    SONET_PATH_AIS_ALARM           0x0040
    SONET_PATH_FERF_ALARM          0x0080
    SONET_PATH_YELLOW_ALARM        0x0100
    SONET_LOCD_ALARM               0x0200
*/

typedef struct tagNSSonetCounterInfo
{
	unsigned short uiAlarmCurrent;      /* Bitmap - All alarms currently active.  The defined
                                           alarm constants are:
    
                                           SONET_SECTION_LOS_ALARM
                                           SONET_SECTION_OOF_ALARM
                                           SONET_SECTION_LOF_ALARM
                                           SONET_LINE_AIS_ALARM
                                           SONET_LINE_FERF_ALARM
                                           SONET_LINE_LOP_ALARM
                                           SONET_PATH_AIS_ALARM
                                           SONET_PATH_FERF_ALARM
                                           SONET_PATH_YELLOW_ALARM
                                           SONET_LOCD_ALARM
                                         */
	unsigned short uiAlarmHistory;      /* Bitmap - All alarms since last counter clear.  The
                                           defined alarm constants are:
   
                                           SONET_SECTION_LOS_ALARM
                                           SONET_SECTION_OOF_ALARM
                                           SONET_SECTION_LOF_ALARM
                                           SONET_LINE_AIS_ALARM
                                           SONET_LINE_FERF_ALARM
                                           SONET_LINE_LOP_ALARM
                                           SONET_PATH_AIS_ALARM
                                           SONET_PATH_FERF_ALARM
                                           SONET_PATH_YELLOW_ALARM
                                           SONET_LOCD_ALARM
                                         */

    /* Error counts since last counter clear */
	unsigned long ulSectionBip8;        /* Number of Section Bit Interleaved Parity errors */ 
	unsigned long ulLineBip24;          /* Number of Line Bit Interleaved Parity errors */
	unsigned long ulLineFebe;           /* Number of Line Far End Block errors */
	unsigned long ulPathBip8;           /* Number of Path Bit Interleaved Parity errors */ 
	unsigned long ulPathFebe;           /* Number of Path Far End Block errors */

    /* Current error rates in events per second */
	unsigned short uiSectionBip8Rate;   /* Section Bit Interleaved Parity error rate */ 
	unsigned short uiLineBip24Rate;     /* Line Bit Interleaved Parity error rate */
	unsigned short uiLineFebeRate;      /* Line Far End Block error rate */
	unsigned short uiPathBip8Rate;      /* Path Bit Interleaved Parity error rate */
	unsigned short uiPathFebeRate;      /* Path Far End Block error rate */

	unsigned char ucCurrentPathSignalLabel; /* Defined constants:
                                               ATM - NS_PATH_SIGNAL_LABEL_ATM (only for ATM TM cards),
                                               PPP - NS_PATH_SIGNAL_LABEL_PPP (only for POS TM cards),
                                               HDLC - NS_PATH_SIGNAL_LABEL_HDLC (only for POS TM cards) */

    unsigned char ucReserved[64];           /* Reserved */
} NSSonetCounterInfo;

#define SONET_SECTION_LOS_ALARM		0x0001
#define SONET_SECTION_OOF_ALARM		0x0002
#define SONET_SECTION_LOF_ALARM		0x0004
#define SONET_LINE_AIS_ALARM		0x0008
#define SONET_LINE_FERF_ALARM		0x0010
#define SONET_LINE_LOP_ALARM		0x0020
#define SONET_PATH_AIS_ALARM		0x0040
#define SONET_PATH_FERF_ALARM		0x0080
#define SONET_PATH_YELLOW_ALARM		0x0100
#define SONET_LOCD_ALARM			0x0200 

/*********************************************************************************
 * Structure:   NSQuerySubprocess
 * iType1:      NS_QUERY_SUBPROCESS
 * Function:    HTGetStructure
 * 
 * NSQuerySubprocess Description:
 * Retrieve subprocess state status.
***********************************************************************************/
typedef struct tagNSQuerySubprocess
{
   unsigned long ulSubprocessHandle; /* input */
   unsigned char ucExited;           /* TRUE = subprocess has exited */
                                     /* FALSE = subprocess has not exited */
   unsigned char ucSignaled; 			 /* TRUE = exited due to a signal */
                                     /* FALSE = otherwise */
   unsigned long ulExitCode;         /* if ucExited is TRUE, it contains */
                                     /* subprocess return code */
   unsigned long ulTermSignal;       /* if ucSignaled is TRUE, it contains */
                                     /* signal number that caused exit */
   unsigned char ucReserved[2]; 
} NSQuerySubprocess;



#define MAX_10GIG_DATA_BUFFER							1920

/*********************************************************************************
 * Structure:   NSCaptureCountInfo
 * iType1:      NS_CAPTURE_COUNT_INFO
 * Function:    HTGetStructure
   NSCaptureCountInfo Description: A simple structure which returns the number of frames 
   which are in the capture buffer. It can be used on all cards that support capture.

 **********************************************************************************/
typedef struct tagNSCaptureCountInfo
{
	unsigned long ulCount;			/* count of frames in capture buffer */
	unsigned char ucReserved[16];	/* reserved */
} NSCaptureCountInfo; 

/*********************************************************************************
 * Structure:   NSCaptureStatsInfo
 * iType1:      NS_CAPTURE_STATS_INFO
 * Function:    HTGetStructure
   NSCaptureStatsInfo Description: Get statistics about one or more captured frames.
 
 **********************************************************************************/
typedef struct tagNSCaptureStatsInfo
{
	unsigned long ulIndex;			/* index of this frame */
	unsigned long ulLength;			/* length of the frame in bytes */
	unsigned long ulStatus;			/* bitmask of status for this frame */
	U64			  u64Timestamp;	/* timestamp, in units of 1ns */
	unsigned char ucPreambleCount;	/* preamble length in bits, for Ethernet cards */
	unsigned short uiVPI;			/* Applicable ONLY for the AT-345x modules */
	unsigned short uiVCI;			/* Applicable ONLY for the AT-345x modules */
	unsigned char ucReserved[15];	/* reserved */
} NSCaptureStatsInfo; 

/*********************************************************************************
 * Structure:   NSCaptureDataInfo
 * iType1:      NS_CAPTURE_DATA_INFO
 * Function:    HTGetStructure
   NSCaptureDataInfo Description: Retrieve a single captured frame. It can be used 
   for all cards that support capture.
 **********************************************************************************/
/*

*/
typedef struct tagNSCaptureDataInfo
{
	unsigned long ulFrameIndex;		/* the frame index (input) */
	unsigned long ulByteOffset;		/* if the total captured frame is greater than 
													2048, use this field as input to specify a 
													byte offset greater than 0 to retrieve the rest
													of the frame (input)*/
	unsigned long ulRequestedLength;	/* the number of bytes of capture 
													data to retrieve (input)*/
	unsigned long ulRetrievedLength;	/* the length of ucData filled 
													with the contents of the captured frame*/
	unsigned char ucReserved[16];		/* reserved */
	unsigned char ucData[2048];		/* the captured frame data */
} NSCaptureDataInfo; 

/* ulStatus values (NSCaptureStatsInfo) */
#define NS_CAPTURE_STATUS_UNDERSIZE                     0x00000001
#define NS_CAPTURE_STATUS_OVERSIZE                      0x00000002
#define NS_CAPTURE_STATUS_TRIGGER                       0x00000004
#define NS_CAPTURE_STATUS_CRC_ERROR                     0x00000008
#define NS_CAPTURE_STATUS_RUN_DISPARITY                 0x00000010
#define NS_CAPTURE_STATUS_DATA_INTEGRITY_ERROR          0x00000040
#define NS_CAPTURE_STATUS_IP_CHECKSUM_ERROR             0x00000080
#define NS_CAPTURE_STATUS_VLAN                          0x00000100
 
#define NS_CAPTURE_STATUS_ALIGNMENT_ERROR               0x00000200
#define NS_CAPTURE_STATUS_SIGNATURE                     0x00000400
#define NS_CAPTURE_STATUS_DATA_INTEGRITY_MARKER         0x00000800
#define NS_CAPTURE_STATUS_OAM_FRAME                     0x00002000

/*********************************************************************************
  Structure:   NSStreamScheduleEntry
 
  iType1:     - NS_STREAM_SCHEDULE
 					- NS_NS_STREAM_SCHEDULE_INFO
  Function:   - HTSetStructure
 					- HTGetStructure
  NSStreamScheduleEntry Description:  
    Configures or retrieves the scheduler for 10 Gig Card.
 					- Set the stream scheduler table to the card
 					- Get the stream scheduler table to the card
 
  Note: the maximum NSStreamScheduleEntry array size is 2048(MAX_SCHED_ENTRIES).
 **********************************************************************************/
typedef struct tagNSStreamScheduleEntry
{
	unsigned short	uiStreamIndex;			/*Index of the stream
														For 10 Gig card: from 0 to 7 inclusive */	
	unsigned short	uiRepeatCount;			/*How many times to repeat that stream
														For 10 Gig card: from 1 to 255 inclusive */
} NSStreamScheduleEntry;


/*********************************************************************************
 * Structure:   NSDiffServ
 * iType1:      - NS_DIFF_SERV
 *				- NS_DIFF_SERV_INFO
 * Function:    - HTGetStructure
 *				- HTGetStructure

 NSDiffServ Description: Set up or retrieve DiffServ settings.
 **********************************************************************************/
typedef struct tagNSDiffServ
{
	unsigned char	ucEnableOffsetFromIP;	/* TRUE diffserv bytes are from IP header 
															FALSE diffserv bytes are from start of frame */
    unsigned short	uiByteOffset;			/* Offset in bytes for tracking DiffServ Counters - 2 bytes */
    unsigned char	ucDestinationIP[4];     /* Non Zero value:
															Only frames whose SmartMetrics 
															Destination IP address field match value 
															in DiffServsDestIP will cause an update of 
															the DiffServCounters.*/
														/* Zero Value:
															All frames which are long enough to include the 
															specified offset value in DiffServBytesOffset will be 
															used for updating the DiffServCounters.*/
	unsigned char ucReserved[20];			 
} NSDiffServ;

/*********************************************************************************
 * Structure:   NSDiffServCounterInfo
 * iType1:      NS_DIFF_SERV_COUNTER_INFO
 * Function:    HTGetStructure
 
NSDiffServCounterInfo Description: Retrieve DiffServ counters.
 **********************************************************************************/
typedef struct tagNSDiffServCounterInfo
{
	unsigned long	ulRxFrame[256];
} NSDiffServCounterInfo;

/*********************************************************************************
 * Structure:  NSPortTransmit
 * iType1:     - NS_PORT_TRANSMIT
 *             - NS_PORT_TRANSMIT_INFO
 * Function:   - HTSetStructure
 *             - HTGetStructure

 NSPortTransmit Description: Sets up or retrieves the transmit and scheduling parameters
 for the port.
 
 NOTE: ucJumboFrameCountEnable field in NS_PORT_TRANSMIT only works for LAN-3710 cards.

 uiGapScale:
 Input for NS_PORT_TRANSMIT. Output for NS_PORT_TRANSMIT_INFO. Notice that besides
 NS_PORT_TRANSMIT, the gap scale can also be set in HTGapAndScale or HTBurstGapAndScale.
 Always the last configured gap scale takes the precedence.

 Using SCHEDULE_MODE_ADVANCED in ucScheduleMode field ensures a smoother transmission 
 of packets between streams. The default mode for ucScheduleMode field is 
 SCHEDULE_MODE_FRAME_RATE.
 SCHEDULE_MODE_ADVANCED functionality is supported LAN-XD, POS-3504A/05A, 
 POS-3510A/11A, POS-3518A/19A, XLW, and XFP test modules

 **********************************************************************************/
typedef struct tagNSPortTransmit
{
		unsigned char	ucTransmitMode;		/*	CONTINUOUS_PACKET_MODE,
												SINGLE_BURST_MODE,
												MULTI_BURST_MODE,
												CONTINUOUS_BURST_MODE, or
												ECHO_MODE. */

		unsigned char	ucScheduleMode; 	/*	SCHEDULE_MODE_GAP,
													SCHEDULE_MODE_FRAME_RATE (default)
													or SCHEDULE_MODE_ADVANCED.
												If gap mode, use ulInterFrameGap to set the gap.  
												If rate mode, use the ulFrameRate field of
												L3StreamExtension to set the
												per-stream frame rate. 
												NOTE:  The stream extension command needs
												to be called first before issuing this command
												in order for this mode to work correctly. */

		unsigned long	ulInterFrameGap;	/*	Gap between each frame in
												units specified by uiGapScale,
												by default in units of bits */

		unsigned long	ulInterBurstGap;	/*	Gap between each burst of
												frames, in units specified
												by uiGapScale, by default
												units of bits */

		unsigned short  uiGapScale;			/*	For ethernet cards, units for gap values
												( ulInterFrameGap,
												  ulInterBurstGap,
												  ulMinRandomGap, and
												  ulMaxRandomGap).  
												Can be 0 for bit times, else
												PICO_SCALE, NANO_SCALE, MICRO_SCALE, 
												or MILLI_SCALE.
												Used as input for NS_PORT_TRANSMIT,
												output for NS_PORT_TRANSMIT_INFO. */

		unsigned long	ulBurstCount;		/*	If ucTransmitMode is
													SINGLE_BURST_MODE or
													MULTI_BURST_MODE, 
													number of frames per burst.
				                                 Otherwise, unused.  */

		unsigned long	ulMultiBurstCount;	/*	If ucTransmitMode is MULTI_BURST_MODE, 
												number of bursts. Otherwise, unused. */

		unsigned char	ucRandomGapEnable;	/*	Enable random gap. */
		unsigned long	ulRandomSeed;		/*	If random gap or random 
												frame length is enabled,
												seed for generating random values. */
		unsigned long	ulMinRandomGap;		/*	If random gap is enabled,
												minimum gap that will be used,
												in units specified by uiGapScale,
												by default in units of bits */
		unsigned long	ulMaxRandomGap;		/*	If random gap is enabled,
												maximum gap that will be used,
												in units specified by uiGapScale,
												by default in units of bits */
		unsigned long	ulMinRandomLength;	/*	If random length is enabled
												in the ucRandomLength 
												field of the stream 
												structure, minimum frame 
												length that will be used. */
		unsigned long	ulMaxRandomLength;	/*	If random length is enabled 
												in the ucRandomLength 
												field of the stream 
												structure, maximum frame 
												length that will be used. */

		unsigned char	ucJumboFrameCountEnable; /* For LAN-3710A only.
                                    If the jumbo frame count is enabled, 
													then it follows the statement below.
												For non-vlan frame, if the frame length 
													is from 1518 to 9018, then counter will 
													count jumbo frames.
												For non-vlan frame, if the frame length 
													is greater than 9018, then the counter 
													will count oversize frame.
												For vlan frame, if the frame length is 
													from 1522 to 9022, then counter 
													will count jumbo frames.
												For vlan frame, if the frame length is 
													greater 9022, then counter will count 
													oversize frames.
												If the jumbo frame is unenabled, 
												the counter will treat any frame 
												as a regular frame regardless the frame size */

		unsigned char	ucIncrementEnable;	/*	For LAN-3710A only. Enable the increment length. 
												If flag is enable, then frame length increases only by 1 */

		unsigned short	uiMinIncrementLength;/* For LAN-3710A only. If increment frame length is enable,
												minimum length will be used.	*/
		unsigned short	uiMaxIncrementLength;/* For LAN-3710A only. If increment frame length is enable,
												maximun length will be used.	*/
		unsigned char	ucEnableExtendedPayload; /* 1 = Enable 128 byte header for streams,
													This will clear all previously configured
													64-byte header streams.
													0 = Disable 128-byte header for streams. */
		unsigned char	ucReserved[57];		 /* reserved */
} NSPortTransmit;


/*********************************************************************************
 * Structure:   NSCaptureSetup
 * iType1:      NS_CAPTURE_SETUP
 * Function:    HTSetStructure
 * Description: Configures the Capture of specified test frames on a specified port.
 *				NS_CAPTURE_SETUP can be used on all cards that support capture. 
 **********************************************************************************/
/*
NSCaptureSetup Description:

Configures the Capture of specified test frames on a specified port.

NOTES:
  
For ulCaptureLength the following cards LAN-3100, SX-7410, SX-7210, GX-1405, GX-1420A/B,
and LAN-3200 do not support CAPTURE_LENGTH_1ST_128_BYTES and CAPTURE_LENGTH_LAST_128_BYTES.

For ulCaptureEvents the following cards LAN-3100, SX-7410 and SX-7210 support only 
CAPTURE_EVENTS_CRC_ERRORS, CAPTURE_EVENTS_RX_TRIGGER and CAPTURE_EVENTS_COLLISIONS.
GX-1405, GX-1420A/B and LAN-3200 cards support only CAPTURE_EVENTS_CRC_ERRORS and
CAPTURE_EVENTS_RX_TRIGGER. For GX-1405, GX-1420A/B and LAN-3200 cards when capturing
trigger frames the interframe gap must be at least 128ns. If  the gap is set to a minimum of
96ns, the card will capture the frame following the trigger frame instead.

The AT-345x modules supports ONLY the following capture mode:
   CAPTURE_MODE_FILTER_ON_EVENTS
   CAPTURE_MODE_START_ON_EVENTS
and ONLY the following capture length:
   CAPTURE_LENGTH_ENTIRE_FRAME
   CAPTURE_LENGTH_1ST_64_BYTES
   CAPTURE_LENGTH_LAST_64_BYTES
   CAPTURE_LENGTH_1ST_128_BYTES
   CAPTURE_LENGTH_LAST_128_BYTES
   CAPTURE_LENGTH_CUSTOM
and ONLY the following capture events:
   CAPTURE_EVENTS_RX_TRIGGER (trigger pattern must be set up within the first 48 bytes(cell) of the frame)
   CAPTURE_EVENTS_ALL_FRAMES
*/
typedef struct tagNSCaptureSetup
{
   unsigned long  ulCaptureMode;		/* start, stop, or filter on events             
													CAPTURE_MODE_FILTER_ON_EVENTS
													CAPTURE_MODE_START_ON_EVENTS
													CAPTURE_MODE_STOP_ON_EVENTS
												*/
   unsigned long  ulCaptureLength;	/* use one of defined below
													CAPTURE_LENGTH_ENTIRE_FRAME	
													CAPTURE_LENGTH_1ST_64_BYTES	
													CAPTURE_LENGTH_LAST_64_BYTES
													CAPTURE_LENGTH_1ST_128_BYTES
													CAPTURE_LENGTH_LAST_128_BYTES													
													CAPTURE_LENGTH_CUSTOM (AT-34xx cards ONLY)
												*/

   unsigned long  ulCaptureEvents;	/* capture events                               
													CAPTURE_EVENTS_CRC_ERRORS
													CAPTURE_EVENTS_UNDERSIZE
													CAPTURE_EVENTS_OVERSIZE
													CAPTURE_EVENTS_VLAN_TAG
													CAPTURE_EVENTS_IP_CHECKSUM_ERROR
													CAPTURE_EVENTS_DATA_INTEGRITY_ERROR
													CAPTURE_EVENTS_RX_TRIGGER
													CAPTURE_EVENTS_RUNNING_DISPARITY_ERRORS
													CAPTURE_EVENTS_ABORT
													CAPTURE_EVENTS_COLLISIONS
													CAPTURE_EVENTS_ALIGNMENT_ERRORS
													CAPTURE_EVENTS_OUT_OF_SEQUENCE
													CAPTURE_EVENTS_SIGNATURE
													CAPTURE_EVENTS_NO_SIGNATURE
													CAPTURE_EVENTS_FILTER_FRAME_LENGTH
                                                    CAPTURE_EVENTS_OAM_FRAME_ONLY
													CAPTURE_EVENTS_IP_OPTION
													CAPTURE_EVENTS_ALL_FRAMES
												*/
   unsigned short uiFilterFrameLength;		/* capture length filter frame; please include the
														CRC length(2 or 4 bytes)                  */
   unsigned short uiCustomCaptureLength;	/* (AT-34xx cards ONLY) Specifies the number of bytes
                                             to capture. ulCaptureLength needs to be set to 
                                             CAPTURE_LENGTH_CUSTOM.  Since these cards capture
                                             frames in cell boundaries, the capture slice count
                                             will be rounded up to the next cell boundary (48 bytes).
                                             For example, if 60 bytes is requested, 96 bytes will
                                             be captured and returned(using NS_CAPTURE_DATA_INFO) */
   unsigned char  ucReserved[52];			/* reserved */

}NSCaptureSetup;

/*********************************************************************************
 * Structure:   NSPortAddress
 * iType1:      NS_PORT_ADDRESS
 * Function:    HTSetStructure
 * Description: Set/Gets IP address on a port.
 **********************************************************************************/
/*
NSPortAdress Description:
   Sets or gets an IP address on a port. 
*/
typedef struct tagNSPortAddress
{
	unsigned char ucMACAddress[6];		/* sets MAC addr of this SmartCard */
	unsigned char ucIPAddress[4];			/* sets IP addr of this SmartCard  */
	unsigned char ucNetmask[4];			/* sets Netmask for this SmartCard */
	unsigned char ucGateway[4];			/* sets Gateway addr for this Card */
	unsigned char ucPingTargetAddress[4]; /* the address where PINGs are sent*/
	unsigned short uiVCI;					/* Reserved */
	unsigned short uiControl;				/* use L3_CTRL_ defines for L3_TX_ADDRESS */
											/* enables PING, ARP, SNMP or RIP */
	unsigned short uiPingTime;				/* in seconds - 0 disables */
	unsigned short uiSNMPTime;				/* in seconds - 0 disables */
	unsigned short uiRIPTime;				/* in seconds - 0 disables */
	unsigned char ucReserved[50];			 /* reserved */
}NSPortAddress;


/*********************************************************************************
 * Structure:   NSFFSInfo
 * iType1:      NS_FFS_INFO
 * Function:    HTGetStructure
 * NSFFSInfo Description: Information about the file system on TeraMetrics cards.
 **********************************************************************************/
typedef struct tagNSFFSInfo
{
		unsigned long ulTotalBlocks;	/* total blocks */
		unsigned long ulUsedBlocks;	/* used blocks */
		unsigned long ulFreeBlocks;	/* free blocks */
		unsigned char ucReserved[52];	/* reserved */
} NSFFSInfo;

/*********************************************************************************
 * Structure:   NSSonetAlarmCounterInfo
 * iType1:      NS_SONET_ALARM_COUNTER_INFO
 * Function:    HTGetStructure
 * Description: Get the SONET alarms and counters for ATM and POS cards.
 *
 * Note: This function only works for these ATM cards: 
 *			AT-9025, 
 *			AT-9155, 
 *			AT-9155C,  
 *			AT-9622 cards.
 **********************************************************************************/
/*
NSSonetAlarmCounterInfo Description:
Get the SONET alarms and counters for ATM and POS cards.
*/
typedef struct tagNSSonetAlarmCounterInfo
{
	/* Alarm conditions	*/
	unsigned short	uiAlarmCurrent;	/* All alarms currently active	
									 Defined constants:
									   SONET_SECTION_LOS_ALARM		0x0001
									   SONET_SECTION_OOF_ALARM		0x0002
									   SONET_SECTION_LOF_ALARM		0x0004
									   SONET_LINE_AIS_ALARM			0x0008
									   SONET_LINE_FERF_ALARM		0x0010
									   SONET_LINE_LOP_ALARM			0x0020
									   SONET_PATH_AIS_ALARM			0x0040
									   SONET_PATH_FERF_ALARM		0x0080
									   SONET_PATH_YELLOW_ALARM		0x0100
									   SONET_LOCD_ALARM				0x0200

									 ATM cards only:
									   ATM25_LOS_ALARM				0x0001*/

	unsigned short	uiAlarmHistory;	/* All alarms since last counter clear
									 Defined constants:
									   SONET_SECTION_LOS_ALARM		0x0001
									   SONET_SECTION_OOF_ALARM		0x0002
									   SONET_SECTION_LOF_ALARM		0x0004
									   SONET_LINE_AIS_ALARM			0x0008
									   SONET_LINE_FERF_ALARM		0x0010
									   SONET_LINE_LOP_ALARM			0x0020
									   SONET_PATH_AIS_ALARM			0x0040
									   SONET_PATH_FERF_ALARM		0x0080
									   SONET_PATH_YELLOW_ALARM		0x0100
									   SONET_LOCD_ALARM				0x0200

									 ATM cards only:
									   ATM25_LOS_ALARM				0x0001*/

	/* Error counts since last counter clear	*/
	unsigned long	ulSectionBIP8;	/* Section Bit Interleaved Parity*/
	unsigned long	ulLineBIP24;	/* Line Bit Interleaved Parity*/
	unsigned long	ulLineFEBE;		/* Line Far End Block Error*/
	unsigned long	ulPathBIP8;		/* Path Bit Interleaved Parity*/
	unsigned long	ulPathFEBE;		/* Path Far End Block Error*/

	/* Current error rates in events per second	*/
	unsigned short	uiSectionBIP8Rate;
	unsigned short	uiLineBIP24Rate;
	unsigned short	uiLineFEBERate;
	unsigned short	uiPathBIP8Rate;
	unsigned short	uiPathFEBERate;

	unsigned char	ucReserved[64];	/*reserved */
}NSSonetAlarmCounterInfo;

/*===============================================================================*/
/*	64 Bit Histogram Structures																	*/
/*===============================================================================*/
/*********************************************************************************
 * Structure:   NSHistLatencyOverTime
 * iType1:      NS_HIST_LATENCY_OVER_TIME
 * Function:    HTSetStructure
 * Description: 64-bit Histogram, Used to setup time intervals
 *              for the Latency Over Time histogram.
 *              Similar to L3_HIST_V2_LATENCY.
 *********************************************************************************/
/*
NSHistLatencyOverTime Description:
 Used to setup time intervals for the Latency Over Time histogram.
 The Latency Over Time histogram provides the Minimum, Maximum, and
 Average Latency for all streams at specified intervals.

 ulInterval is the interval that latency values are checked. For
 example, if ulInterval is 2, latency values are calculated every
 200 nanoseconds (.2us).

 Latency Resolution and accuracy
 -------------------------------
 One unit is 1 millisecond.

* For a pair of 10Mbit ports, accuracy is plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is 
  plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is 
  plus or minus .4 us.
* For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is 
  plus or minus .3 us.

Results are retrieved using the NSHistLatencyOverTimeInfo structure.
*/
typedef struct tagNSHistLatencyOverTime
{
	unsigned long	ulInterval;				/* In units of millisecond         */
	unsigned char	ucReserved[16];		/* Reserved, not used at this time */
} NSHistLatencyOverTime;

/*********************************************************************************
 * Structure:   NSHistLatencyOverTimeInfo
 * iType1:      NS_HIST_LATENCY_OVER_TIME_INFO
 * Function:    HTGetStructure
 * Description: Contains Latency Over Time histogram results. Similar to 
 *              L3_HIST_V2_LATENCY_INFO.
 *********************************************************************************/
/*
NSHistLatencyOverTimeInfo Description:
 Provides the Minimum, Maximum, and Sum of Latency values for frames
 received during specified intervals. The values are the composite
 results of all streams averaged together. 

 Setting the interval
 --------------------
 On the Rx port, use the NSHistLatencyOverTime structure and
 specify the ulInterval. This value determines how often latency
 values are compared.

 One Interval unit is 1 millisecond. 

 The Latency measurements of, Minimum, Maximum, and Average Latency are 
 calculated to the nearest .1 microsecond.

 Each record (Min, Max, and Sum latency values) represents the
 latencies of the frames arriving in each interval.  Use iType2 to
 specify the index of the first record (interval) to retrieve.

 Example
 ---------------
 If ulInterval is set to 10:
 The first Min, Max, and Sum latency value is for the first ten 
 microseconds. The second Min, Max, and Sum latency value is for the 
 second ten microseconds, and so on.

 Latency values are calculated from the timestamp in the signature
 field embedded within each test frame.

 The average latency for each time interval can be calculated by
 dividing the total latency by the number of frames.

 Terametrics cards support u64Total.  Use NS_HIST_LATENCY_OPTION to configure 
 tracking this result.
*/
typedef struct tagNSHistLatencyOverTimeInfo
{
	unsigned long	ulMinLatency; /* Minimum frame latency in units of 100 nanoseconds */
	unsigned long	ulMaxLatency; /* Maximum frame latency in units of 100 nanoseconds */
	U64				u64Total;     /* Sum of all latencies in units of 100 nanoseconds  */
	U64				u64Frames;    /* Frames with signature fields (tags),	*/
		                          /* received in this interval.(seq+lost) */
	unsigned char	ucReserved[128];/* Reserved, not used at this time      */
} NSHistLatencyOverTimeInfo;

/*********************************************************************************
 * Structure:   NSHistLatencyDistPerStream
 * iType1:      NS_HIST_LATENCY_DIST_PER_STREAM 
 *					 & NS_HIST_COMBO_PER_STREAM
 * Function:    HTSetStructure
 * Description: 64-bit Histogram, Defines the time interval ranges used in of the
 *              Latency Distribution histogram. Similar to 
 *              L3_HIST_LATENCY_DISTRIBUTION.
 *********************************************************************************/
/*
NSHistLatencyDistPerStream Description:
Defines the time interval ranges used in of the Latency Distribution histogram.
*/
typedef struct tagNSHistLatencyDistPerStream
{
	unsigned long	ulInterval[16];  		/* In units of 100 nanoseconds */
	unsigned char	ucReserved[16];		/* Reserved, not used at this time */
} NSHistLatencyDistPerStream;

/*********************************************************************************
 * Structure:   NSHistComboPerStreamInfo
 * iType1:      NS_HIST_COMBO_PER_STREAM_INFO
 * Function:    HTGetStructure
 * Description: 64-bit Histogram, Contains results from a combination histogram
 *              Similar to L3_HIST_V2_LATENCY_PER_STREAM_INFO.
 *********************************************************************************/
/*
NSHistComboPerStreamInfo Description:

This histogram tracks: 
1.) Latency Per Stream (Min, Max, Average)
2.) Sequence Tracking
3.) Latency Distribution.

One record is generated for each stream received. Statisics 
are tracked using the signature field embedded within each test 
frame.

To specify this histogram, use  NS_HIST_COMBO_PER_STREAM.

Latency Resolution and accuracy
-------------------------------
One unit is .1 microsecond / 100ns (one clock tick).

* For a pair of 10Mbit ports, accuracy is plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is 
  plus or minus .2 us.
* For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is 
  plus or minus .4 us.
* For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is 
  plus or minus .3 us.

Latency Per Stream Info.
********************************
Latency Per Stream finds the Sum, Min, and Max latency value for each
stream over the duration of the test.

Sequence Tracking Info.
********************************
Sequence Tracking counts the number of frames per stream that are:
*  Out of sequence
*  In of sequence

A separate record is generated for each test stream received
by the specified port.

The Sequence Tracking algorithm is as follows:
-----------------------------------------------
*  As long as frames are received in sequence, the U64InSequenced
   value is incremented.
*  If a frame is received that is greater than the one expected,
   the number of missing frames (hole size) is noted, and a variable
	for the	first of the missing frames is set.
*  Subsequent in-order frames falling after the sequence hole 
   increment the U64InSequenced counter.
*  If the frame from the start of the hole is received, the hole-size
   variable is decremented.
*  If a frame from the middle of the hole is received, the earlier 
   frames still not received from the sequence hole are counted as 
	 (u64OutOfSequence).	The hole-size variable is decremented, and the 	
	start of the hole begins after the received frame. The expected
	frame continues to be one more than the last frame received in
	sequence.
*  The ulSequenced value continues to increment for every frame
   received in sequence after the current sequence hole.
	
	
 For Example:

1,2,3                - Three frames in sequence.
1,2,3,9,10,11,       - Sequence hole five frames. 10,11, in sequence.
1,2,3,9,10,11,4      - Sequence hole is now four frames.
1,2,3,9,10,11,4,15,  - First hole closed, u64OutOfSequence incremented by four.
                      New hole three frames long.

Latency Distribution Info.
********************************
Latency Distribution tracks the number of frames with a latency that
falls within a given range. (There are 16 configurable ranges).

Example Values
-------------- 
If ulInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2us to 1us.

Mechanics
---------
When a frame is received, correct u64Frames[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.
*/
typedef struct tagNSHistComboPerStreamInfo
{
	unsigned long	ulStreamID;			/* A unique Stream Identifier        */

												/* Latency Per Stream info.          */
	U64				u64Total;			/* sum of latencies for this Stream  */
	unsigned long	ulMinLatency;		/* min frame latency for this Stream */
	unsigned long	ulMaxLatency;		/* max frame latency for this Stream */
 
												/* Sequence Tracking info.           */
	U64				u64TotalFrames;	/* total frames rcvd for this Stream */
												/* (u64Sequenced+u64Lost)				 */
	U64				u64InSequence;		/* no. frames rcvd in sequence       */ 
	U64				u64Reserved;      /* Reserved */
	U64				u64OutOfSequence;	/* no. frames that broke the			 */
												/* sequence and were either never	 */
												/* rcvd, or not received before		 */
												/* another out-of-sequence frame     */
												/* was noted.								 */
                             
												/* Latency Distribution info.        */                                
	U64				u64Frames[16];		/* Contains the number of frames     */
												/* with the specified latency range, */
												/* for 16 different ranges .         */
	unsigned char	ucReserved[128];   /* Reserved, not used at this time   */
                             
} NSHistComboPerStreamInfo;

/*********************************************************************************
 * Structure:   NSHistLatencyDistPerStreamInfo
 * iType1:      NS_HIST_LATENCY_DIST_PER_STREAM_INFO
 * Function:    HTGetStructure
 * Description: 64-bit Histogram, Contains Latency Distribution histogram results.
 *              Similar to L3_HIST_LATENCY_DISTRIBUTION_INFO.
 *********************************************************************************/
/*
NSHistLatencyDistPerStreamInfo Description:

Latency Distribution tracks how many frames fall within a given
latency range. There are 16 configurable ranges in units of 
.1 microseconds.

Example Values
-------------- 
If ulInterval[0] is set to 1, it tracks frames with a latency 
value of 0 to .1 us. If the next interval is 10, the range is
from .2 us to 1 us.

Mechanics
---------
When a frame is received, the latency is calculated from the timestamp
in the signature field. The correct u64Frames[i] is incremented by one. A 
separate record containing the 16 different range tallies is generated 
for each stream.

Resolution and accuracy
-----------------------
One unit is .1 microsecond - 100ns (one clock tick).

For a pair of 10Mbit ports accuracy is plus or minus .2 microseconds (.2 us).
For a pair of 10/100Mbit ports transmitting at 100Mbits, accuracy is plus or minus .2 us.
For a pair of 10/100Mbit ports transmitting at 10Mbits, accuracy is plus or minus .4 us.
For 10/100Mbit ports transmitting to a 10Mbit port, accuracy is plus or minus .3 us.

Setting Resolution (different structure) 
----------------------------------------
To set the distribution intervals, use NS_HIST_LATENCY_DIST_PER_STREAM.
*/
typedef struct tagNSHistLatencyDistPerStreamInfo
{
	unsigned long	ulStream;		/* a unique Stream identifier        */
	U64				u64Frames[16];	/* Contains the number of frames     */
											/* with the specified latency range, */
											/* for 16 different ranges.          */
	unsigned char	ucReserved[128];/* Reserved, not used at this time   */
} NSHistLatencyDistPerStreamInfo;

/*********************************************************************************
 * Structure:   NSHistSequencePerStreamInfo
 * iType1:      NS_HIST_SEQUENCE_PER_STREAM_INFO
 * Function:    HTGetStructure
 * Description: 64-bit Histogram, Contains Sequence Tracking histogram results.
 * 
 *********************************************************************************/
/*
NSHistSequencePerStreamInfo Description:

Sequence Tracking counts the number of frames per stream that are:
*  In sequence
*  Out sequence
A separate record is generated for each test stream received
by the specified port.
Sequence is tracked using the signature field embedded in each
test frame.

The Sequence Tracking algorithm is as follows:
-----------------------------------------------
*  As long as frames are received in sequence, the U64InSequenced
   value is incremented.
*  If a frame is received that is greater than the one expected,
   the number of missing frames (hole size) is noted, and a variable
	for the	first of the missing frames is set.
*  Subsequent in-order frames falling after the sequence hole 
   increment the U64InSequenced counter.
*  If the frame from the start of the hole is received, the hole-size
   variable is decremented.
*  If a frame from the middle of the hole is received, the earlier 
   frames still not received from the sequence hole are counted as 
	 (u64OutOfSequence).	The hole-size variable is decremented, and the 	
	start of the hole begins after the received frame. The expected
	frame continues to be one more than the last frame received in
	sequence.
*  The ulSequenced value continues to increment for every frame
   received in sequence after the current sequence hole.
	
	
 For Example:

1,2,3                - Three frames in sequence.
1,2,3,9,10,11,       - Sequence hole five frames. 10,11, in sequence.
1,2,3,9,10,11,4      - Sequence hole is now four frames.
1,2,3,9,10,11,4,15,  - First hole closed, u64OutOfSequence incremented by four.
                      New hole three frames long.

*/
typedef struct tagNSHistSequencePerStreamInfo
{
	unsigned long	ulStream;			/* Stream identifier for this record   */
	U64				u64TotalFrames;	/* no. of frames rcvd for this Stream  */
												/* (u64Sequenced+u64Lost)					*/
	U64				u64InSequence;		/* no. of frames received in sequence  */
	U64				u64OutOfSequence;	/* no. of frames that broke the        */
												/* sequence and were either never	   */
												/* received, or not received before    */
												/* another out-of-sequence frame was.  */
	unsigned long	ulReserved;			/* reserved for no of frames duplicated*/
	unsigned char	ucReserved[128];	/* Reserved, not used at this time     */
} NSHistSequencePerStreamInfo;

/*********************************************************************************
 * Structure:   NSHistRawSignatureInfo
 * iType1:      NS_HIST_RAW_SIGNATURE_INFO
 * Function:    HTGetStructure
 * Description: 64-bit Histogram.
 *              Similar to L3_HIST_RAW_TAGS.
 *********************************************************************************/
/*
NSHistRawSignatureInfo Description:

Contains the signature field information for the Raw Tags histogram.

A separate record in generated for each SmartBits test frame (containing
a signature)received at this port.
*/
typedef struct tagNSHistRawSignatureInfo
{
	unsigned long	ulStream;		/* a unique Stream identifier       */
	unsigned long	ulSequence;		/* frame serial number              */
	unsigned long	ulTransmitTime;/* timestamp of when this frame     */
											/* left its SmartBits port          */
	unsigned long	ulReceiveTime;	/* timestamp of when this frame was */
											/* received by this SmartBits port  */
	unsigned char	ucReserved[128]; /* Reserved, not used at this time  */
} NSHistRawSignatureInfo;

/*********************************************************************************
 * Structure:   NSHistMulticastLatencyPerStreamInfo
 * iType1:      NS_HIST_MULTICAST_LATENCY_PER_STREAM_INFO
 * Function:    HTGetStructure
 * Description: 64-bit Histogram,tracks Multicast Latency information per Stream.
 *              Similar to L3_HIST_MC_LATENCY_PER_STREAM_INFO.
 *********************************************************************************/
/*
NSHistMulticaseLatencyPerStreamInfo Description:

The actual latency information tracked is kept in the following items:

   u64FirstRxTime
   u64LastRxTime

The first frame received for each stream is kept in the  u64FirstRxTime.
The last frame received for each stream is kept in the u64LastRxTime

The Latency information is also tracked  in order to
keep the min, max, and average of all latencies for this
Stream. The second is to keep a distribution of frames received
over 16 different user-specified time ranges.

*/
typedef struct tagNSHistMulticastLatencyPerStreamInfo
{
	unsigned long	ulStreamID;			/* A unique Stream Identifier				*/

												/* Latency Per Stream info.				*/
	U64				u64Total;			/* sum of latencies for this Stream		*/
	unsigned long	ulMinLatency;		/* min frame latency for this Stream	*/
	unsigned long	ulMaxLatency;		/* max frame latency for this Stream	*/
 
												/* Sequenc Tracking info.					*/
	U64				u64TotalFrames;	/* total frames rcvd for this Stream	*/
												/* (u64Sequenced+u64Lost)					*/
	U64				u64FirstRxTime;	/* first timestamp received for the group stream */
	U64				u64LastRxTime;		/* last timestamp received for the group stream	 */
                             
												/* Latency Distribution info.				*/
	U64				u64Frames[16];		/* Contains the number of frames			*/
												/* with the specified latency range,	*/
												/* for 16 different user-specified time ranges */
	unsigned char	ucReserved[184];	/* Reserved, not used at this time		*/
                             
} NSHistMulticastLatencyPerStreamInfo;

/*********************************************************************************
 * Structure:   NSDetailedLibVersionStructure
 * Function:    NSGetDetailedLibVersion
 * Description: This command gives fill in structure with info from commlib.ver
 **********************************************************************************/
#define MAX_VERSION_STRING		32
#define NS_VERSION_UNRELEASED	0
#define NS_VERSION_RELEASED	1

typedef struct tagNSDetailedLibVersionStructure
{
		char szDescription[MAX_VERSION_STRING];/* description string */
		char szVersion[MAX_VERSION_STRING];		/* version string */
		unsigned short	uiMajor;						/* major version number */
		unsigned short	uiMinor;						/* minor version number */
		unsigned short	uiBuild;						/* build number */
		unsigned char	ucReleaseStage;			/* use NS_VERSION_XXX definitions */
		unsigned long	ulCompleteVersion;		/* hex value in the form:
																0xMMmmbbbb, where
																MM = major version (1 byte),
																mm = minor version (1 byte),
																bbbb = build number (2 bytes) */

} NSDetailedLibVersionStructure;

/*********************************************************************************
 * Structure:   NSErrorEntry
 * Function:    NSGetLastError
 * Description: This command returns the last error description and error code.
 **********************************************************************************/
#define MAX_ERROR_STRING			256
typedef struct tagNSErrorEntry
{
	unsigned char	ucCardNumber;								 /* the card slot in the chassis */
	unsigned char	ucPortNumber;								 /* the port on the card */
	unsigned short	uiErrorCode;								 /* the error code returned */
	char			   szErrorDescription[MAX_ERROR_STRING];/* the string describing the error. */
}NSErrorEntry;


/*********************************************************************************
 * Structure:   NSErrorList
 * Function:    NSGetAllLastError
 * Description: This command gives the list of last errors. 
 *              The maximum error description is 10.
 **********************************************************************************/
#define	MAX_ERRORS						10
typedef struct tagErrorList
{
	unsigned short	uiTotalError;						/* the number of the reported errors. */
	NSErrorEntry	pErrorEntryList[MAX_ERRORS];  /* the list of error entries. */
}NSErrorList;


/*********************************************************************************
 * Structure:   NSReportErrorList
 * Function:    NSReportError
 * Description: This command gives the list of last errors. 
 *              The maximum error description is 100.
 **********************************************************************************/
#define MAX_REPORT_ERROR_STRING     256
#define MAX_REPORT_ERRORS		      100
#define MAX_REPORT_ERROR_IP_LEN     20

typedef struct tagNSReportErrorEntry
{
	unsigned short uiHubNumber;			               /* the hub number of the chassis */
	unsigned short uiSlotNumber;			               /* the card slot in the chassis */
	unsigned short uiPortNumber;			               /* the port on the card */
	long           lErrorCode;				               /* the error code returned */
	char szErrorDescription[MAX_REPORT_ERROR_STRING];  /* the string describing the error. */
	char szCmdDescription[MAX_REPORT_ERROR_STRING];    /* the string describing the associated library command */
	char szChassisIP[MAX_REPORT_ERROR_IP_LEN];         /* the IP address of the chassis */
	unsigned char ucReserved[64];			               /* Reserved */
}NSReportErrorEntry;

typedef struct tagNSReportErrorList
{
	unsigned short	uiTotalErrors;	                        /* the number of errors reported. */
	unsigned char ucReserved[64];	                        /* Reserved */
	NSReportErrorEntry	pErrorList[MAX_REPORT_ERRORS];   /* the list of error entries. */
}NSReportErrorList;

/***************************************************************************
 * Structure:   NSHWConfig
 * iType1:      NS_HW_CONFIG/NS_HW_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * Description: This message is used to set and get Port Parameters and 
                configurations.
 ***************************************************************************/
/*
NSHWConfig Description:
Set and get Port Parameters and configurations.

ucTimestampClockSource currently applies to POS-3518/19 and XLW-3720/XLW-3721
only.  
   TIMESTAMP_CLOCK_SOURCE_10_MHZ for 100 nano-second resolution
   TIMESTAMP_CLOCK_SOURCE_40_MHZ  for 25 nano-second resolution

ucLaserMode currently applies to LAN-3310/LAN-3311 
   - XLW-3720/XLW-3721 - POS-3518/POS-3519
*/

#define TIMESTAMP_CLOCK_SOURCE_10_MHZ	0
#define TIMESTAMP_CLOCK_SOURCE_40_MHZ	1

#define LASER_ENABLE                   1
#define LASER_DISABLE                  0
typedef struct tagNSHWConfig
{
   unsigned char ucTimestampClockSource;  /* TimeStamp Clock Source -
                                 TIMESTAMP_CLOCK_SOURCE_10_MHZ (default),
                                 TIMESTAMP_CLOCK_SOURCE_40_MHZ */
   unsigned char ucLaserMode;    /* Laser Mode -
                                 LASER_ENABLE (default),
                                 LASER_DISABLE */
   unsigned char ucReserved[20];
}NSHWConfig;


/*********************************************************************************
 * Structure:   NSCardHardwareInfo
 * iType1:      NS_CARD_HARDWARE_INFO
 * Function:    HHTGetStructure
 * Description: This message is used to get card hardware structure.
 **********************************************************************************/
/*
NSCardHardwareInfo Description:

Get card hardware information.
*/
typedef struct tagNSCardHardwareInfo
{
	unsigned short uiRAMSize;	/* for TeraMetrics cards, size of RAM
											in Megabytes (1048576 bytes) */
   unsigned char ucSerialNumber[35]; /* for Terametric cards,
                                     Serial Number of Card */
	unsigned char ucReserved[91];
}NSCardHardwareInfo;


/*********************************************************************************
 * Structure:   NSCTStorageFile
 * iType1:      NS_CT_CONFIG_STORAGE_FILE
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
/*
NSCTStorageFile Description:

Note that this command should not be called if cut-through capture is in progress.  In this
case, the user needs to stop capturing first(NS_CT_START_CAPTURE) before calling this command.
*/
#define CT_DEFAULT_FILENAME                "/tmp/port"
#define CT_DEFAULT_BUFFER_SIZE_IN_MBYTES   4  
#define CT_MAX_FILENAME_LENGTH             64  /* 64-byte length */
#define CT_DEFAULT_STOP_ON_FULL            0    /* wrap-around    */

typedef struct tagNSCTStorageFile {
	unsigned long   ulFilenameLength;    /* Indicates the number of bytes in the 'ucFilename'
                                            buffer to be used as the file name. The maximum 
                                            length is MAX_FILENAME_LENGTH - 1 (we 
                                            reserve the last byte for the end of string character).
                                            If the ulFilenameLength is 0, then the default 
                                            filename will be used regardless of the content of
                                            the "ucFilename" buffer(Please see the default name
                                            specified below). 
	                                      */

	unsigned char   ucFilename[CT_MAX_FILENAME_LENGTH];	/* Specify the prefix name for all capture 
                                                           files (one file per port).  The default
                                                           prefix name is "port".  The actual file
                                                           name consists of the prefix, the port 
                                                           number starting from 0(i.e. 
                                                           port#0: default setting: port0.cap;
                                                           port#1: default setting: port1.cap) and
                                                           the file extension ".cap".  All capture
                                                           files reside in the "/tmp" directory.
                                                           Attempting to specify any other 
                                                           directory or non-existing subdirectories
                                                           within "/tmp" isn't allowed.
	                                                     */
	unsigned long   ulFileSizeInMBytes;    /* Specify the size of a capture file in Megabytes.  For
                                              now, the minimum size is 1 MB and the maximum size
                                              is 16 MB. If given a value, which is less than the
                                              minimum, the firmware will round it up to the
                                              default size; And, If given a value which is bigger
                                              than the maximum size, the firmware will round it
                                              down to the maximum size.  The default size is 4 MB.
	                                                     */
	unsigned long   ulStopOnFull;          /* Specify whether or not the cut-through capture 
                                              process should stop storing captured frame into a
                                              capture file when the file reaches its "full" state.
                                              The file is considered "full" if the amount of 
                                              leftover bytes is less than the amount required to
                                              store a new captured frame.  The intention is to 
                                              avoid the case where a portion of a captured frame
                                              is stored at the end of the capture file and the 
                                              other portion is stored at the beginning of the file.
                                              Possible values are 0(disable) and 1(enable).  The 
                                              default setting is 0(wrap-around), which means that
                                              the latest captured frames will override the 
                                              existing captured frames in a file when the file is
                                              full.
                                            */
}NSCTStorageFile;


/*********************************************************************************
 * Structure:   NSCTCaptureParams
 * iType1:      NS_CT_CONFIG_CAPTURE_PARAMS
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
/*
NSCTCaptureParams Description:

*/
#define CT_TRAFFIC_DIRECTION_NONE       0x0000
#define CT_TRAFFIC_DIRECTION_TX         0x0001
#define CT_TRAFFIC_DIRECTION_RX         0x0002
#define CT_TRAFFIC_DIRECTION_TXRX       0x0003

#define CT_MODE_HALT                    0x0000
#define CT_MODE_START_ON_REQUEST        0x0020
#define CT_MODE_STOP_ON_REQUEST         0x0800

/* default values */
#define CT_DEFAULT_DIRECTION            CT_TRAFFIC_DIRECTION_TXRX
#define CT_DEFAULT_SLICE_COUNT          1
#define CT_DEFAULT_CAPTURE_MODE         (CT_MODE_START_ON_REQUEST | CT_MODE_STOP_ON_REQUEST)

typedef struct tagNSCTCaptureParams {
	unsigned long  ulTrafficDirection;   /* Specify which data traffic (TX, RX) should be captured.
                                            Possible values are:
                                            
                                            CT_TRAFFIC_DIRECTION_NONE
                                            CT_TRAFFIC_DIRECTION_TX
                                            CT_TRAFFIC_DIRECTION_RX
                                            CT_TRAFFIC_DIRECTION_TXRX
                                          */
	unsigned long  ulSliceCount;         /* Specify the length of a frame to capture in terms of
                                            slices.  Each slice equals to 64 Bytes.  A value of
                                            zero indicates that the whole frame will be captured.
                                            The maximum number of slices is 32.
                                          */
	unsigned long  ulMode;               /* Specify when the capture should begin and/or stop.
                                            Possible values are:

                                            CT_MODE_HALT
                                            CT_MODE_START_ON_REQUEST
                                            CT_MODE_STOP_ON_REQUEST
                                          */
}NSCTCaptureParams;


/*********************************************************************************
 * Structure:   NSCTCaptureFilterParams
 * iType1:      NS_CT_CONFIG_CAPTURE_FILTER_PARAMS
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
/*
NSCTCaptureFilterParams Description:

The cut-through capture process can filter by either protocol IDs only, or pattern only,
or the combination of both protocol IDs and patterns.
*/

#define CT_FILTER_MODE_NONE                     0x0000
#define CT_FILTER_MODE_PROTOCOL                 0x0001
#define CT_FILTER_MODE_PATTERN                  0x0002

#define CT_FILTER_PROTOCOL_ID_IP                0x0001
#define CT_FILTER_PROTOCOL_ID_ARP               0x0002
#define CT_FILTER_PROTOCOL_ID_RARP              0x0004
#define CT_FILTER_PROTOCOL_ID_TCP               0x0008
#define CT_FILTER_PROTOCOL_ID_UDP               0x0010
#define CT_FILTER_PROTOCOL_ID_ICMP              0x0020

#define CT_FILTER_OPERATOR_MATCH_ALL            0x0000
#define CT_FILTER_OPERATOR_PAT1_ONLY            0x0001
#define CT_FILTER_OPERATOR_PAT2_ONLY            0x0002
#define CT_FILTER_OPERATOR_PAT1_OR_PAT2         0x0003
#define CT_FILTER_OPERATOR_PAT1_AND_PAT2        0x0004

#define CT_DEFAULT_CAPTURE_FILTER_MODE          CT_FILTER_MODE_NONE
#define CT_PATTERN_SIZE_IN_BYTES                   16 
typedef struct tagNSCTCaptureFilterParams {
	unsigned long ulMode;               /* Specify cut-through capture filter mode process should.
                                            Different filter modes can be combined together using
                                            the bitwise OR operator.  Using a combination of multiple
                                            filter modes means that frames must meet these filter
                                            conditions to be captured.  Possible filter values
                                            are:
                                            
                                            CT_FILTER_MODE_NONE
                                            CT_FILTER_MODE_PROTOCOL
                                            CT_FILTER_MODE_PATTERN
                                         */
    unsigned long ulProtocolID;         /* Specify Protocol ID(s) for filtering.  Different 
                                           Protocol IDs can be combined using the bitwise OR
                                           operator.  Possible Protocol ID values are:

                                           CT_FILTER_PROTOCOL_ID_IP
                                           CT_FILTER_PROTOCOL_ID_ARP
                                           CT_FILTER_PROTOCOL_ID_RARP
                                           CT_FILTER_PROTOCOL_ID_TCP
                                           CT_FILTER_PROTOCOL_ID_UDP
                                           CT_FILTER_PROTOCOL_ID_ICMP
                                         */
	unsigned long ulPatternsOperator;   /* Specify how to use patterns 1 and/or 2 for filtering.
                                           Possible values are(values can not be combined):

                                           CT_FILTER_OPERATOR_MATCH_ALL
                                           CT_FILTER_OPERATOR_PAT1_ONLY
                                           CT_FILTER_OPERATOR_PAT2_ONLY
                                           CT_FILTER_OPERATOR_PAT1_OR_PAT2
                                           CT_FILTER_OPERATOR_PAT1_AND_PAT2
                                         */
	unsigned long ulPattern1Offset;      /* Specify the offset (starting from 0) from the 
                                            beginning of a frame where the matching Pattern 1
                                            starts.
                                          */
	unsigned long ulPattern1Length;      /* Specify how many bytes of Pattern 1 to use */
	unsigned char ucPattern1Data[CT_PATTERN_SIZE_IN_BYTES];    /* Pattern 1 data */
	unsigned long ulPattern2Offset;      /* Specify the offset (starting from 0) from the 
                                            beginning of a frame where the matching Pattern 1
                                            starts.
                                          */
	unsigned long ulPattern2Length;      /* Specify how many bytes of Pattern 2 to use */
	unsigned char ucPattern2Data[CT_PATTERN_SIZE_IN_BYTES];    /* Pattern 2 data */ 
}NSCTCaptureFilterParams;

/*********************************************************************************
 * Structure:   NSCTCaptureFrameCountInfo
 * iType1:      NS_CT_CAPTURE_FRAME_COUNT_INFO
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
/*
NSCTCaptureFrameCountInfo Description:

Note that the capture count value will not be stable until the capture is completely stopped.
*/
typedef struct tagNSCTCaptureFrameCountInfo {
	unsigned long ulCount;  /* Number of frames captured */
}NSCTCaptureFrameCountInfo;

/*********************************************************************************
 * Structure:   NSCTCaptureFrameInfo
 * iType1:      NS_CT_CAPTURE_FRAME_INFO
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
/*
NSCTCaptureFrameInfo Description:
*/
#define CT_MAX_FRAME_LENGTH       2048
typedef struct tagNSCTCaptureFrameInfo {
	unsigned long ulTimestamp;  /* Specify the time (in seconds) 
                                       at which this frame is captured.  The timestamp represents the number of seconds 
                                       elapsed since 00:00:00 on January 1, 1970, Coordinated Universal Time (UTC).   
                                       Converting ulTimestamp to hour/minute/seconds format:
                                            ulTimestamp = ulTimestamp % (24*60*60);
                                            hours = ulTimestamp / (60*60);
                                            minutes = (ulTimestamp % (60*60)) / 60;
                                            seconds = ulTimestamp % 60;
                                     */
	unsigned long ulDirection;      /* Indicates whether a captured frame was transmitted
                                    from(CT_TRAFFIC_DIRECTION_TX) or 
                                    received(CT_TRAFFIC_DIRECTION_RX) by this port
                                     */
	unsigned long ulPacketLength;   /* Indicates the length of the frame, excluding CRC */
	unsigned long ulCaptureLength;  /* Specify number of bytes in the variable "ucCaptureData" is the length of the 
                                    captured frame.   
                                     */
	unsigned char ucCaptureData[CT_MAX_FRAME_LENGTH]; /* Capture frame */
}NSCTCaptureFrameInfo;

/*********************************************************************************
 * Structure:   NSCTCaptureFrameInfo
 * iType1:      NS_CT_CAPTURE_FRAME_V2_INFO
 * Function:    HTSetStructure
 * Description: 
 **********************************************************************************/
typedef struct tagNSCTCaptureFrameV2Info {
	unsigned long ulTimestamp_sec;  /* Specify the time (in seconds, please see the ulTime_usec for the microseconds part) 
                                       at which this frame is captured.  The timestamp represents the number of seconds 
                                       elapsed since 00:00:00 on January 1, 1970, Coordinated Universal Time (UTC).   
                                       Converting ulTimestamp to hour/minute/seconds format:
                                            ulTimestamp = ulTimestamp % (24*60*60);
                                            hours = ulTimestamp / (60*60);
                                            minutes = (ulTimestamp % (60*60)) / 60;
                                            seconds = ulTimestamp % 60;
                                     */
	unsigned long ulTimestamp_usec; /* Contains the microsecond part of the timestamp. */
	unsigned long ulDirection;      /* Indicates whether a captured frame was transmitted
                                    from(CT_TRAFFIC_DIRECTION_TX) or 
                                    received(CT_TRAFFIC_DIRECTION_RX) by this port
                                     */
	unsigned long ulPacketLength;   /* Indicates the length of the frame, excluding CRC */
	unsigned long ulCaptureLength;  /* Specify number of bytes in the variable "ucCaptureData" is the length of the 
                                    captured frame.   
                                     */
    unsigned char ucReserved[12];    /* reserved */
	unsigned char ucCaptureData[CT_MAX_FRAME_LENGTH]; /* Capture frame */
}NSCTCaptureFrameV2Info;


/*********************************************************************************
 * Structure:   NSHalfDuplexCounterInfo
 * iType1:      NS_HALF_DUPLEX_COUNTER_INFO
 * Function:    HTGetStructure
 * Description: 
		This command is used to query the terametrics cards 
		for Half Duplex counters 
 **********************************************************************************/

typedef struct tagNSHalfDuplexCounterInfo
{
	U64				u64AlignError;
	U64				u64Collision;
	U64				u64XsCollision;
	U64				u64Reserved[5];
}NSHalfDuplexCounterInfo;


/*********************************************************************************
 * Structure:   NSHalfDuplexRateInfo
 * iType1:      NS_HALF_DUPLEX_RATE_INFO
 * Function:    HTGetStructure
 * Description: 
		This command is used to query the terametrics cards 
		for Half Duplex rates 
 *********************************************************************************/

typedef struct tagNSHalfDuplexRateInfo
{
	U64				u64AlignErrorRate;
	U64				u64CollisionRate;
	U64				u64XsCollisionRate;
	U64				u64Reserved[5];
}NSHalfDuplexRateInfo;


/*********************************************************************************
 * Structure:   NSL2StatCounterInfo
 * iType1:      NS_L2_STAT_COUNTER_INFO
 * Function:    HTGetStructure
 * Description: 
		This command is used to get the L2 counters of the terametrics cards 
 **********************************************************************************/
/*
NSL2StatCounterInfo Description:

Get port-level counters.
*/
typedef struct tagNSL2StatCounterInfo
{
	U64     u64TxFrame;
	U64     u64TxByte;
	U64     u64TxTrigger;
	unsigned long		u32TxLatency;
	U64     u64RxFrame;
	U64     u64RxByte;
	U64     u64RxTrigger;
	unsigned long		u32RxLatency;
	U64     u64RxCrcError;
	U64     u64RxOversize;
	U64     u64RxUndersize;
}NSL2StatCounterInfo;


/*********************************************************************************
 * Structure:   NSL2StatRateInfo
 * iType1:      NS_L2_STAT_RATE_INFO
 * Function:    HTGetStructure
 * Description: 
		This command is used to get the L2 rates of the terametrics cards 
 **********************************************************************************/
/*
NSL2StatRateInfo Description:

Get port-level rates.
*/
typedef struct tagNSL2StatRateInfo
{
	unsigned long		u32TxFrameRate;
	unsigned long		u32TxByteRate;
	unsigned long		u32TxTriggerRate;
	unsigned long		u32RxFrameRate;
	unsigned long		u32RxByteRate;
	unsigned long		u32RxTriggerRate;
	unsigned long		u32RxCrcErrorRate;
	unsigned long		u32RxOversizeRate;
	unsigned long		u32RxUndersizeRate;
}NSL2StatRateInfo;


/*********************************************************************************
 * Structure:   NSL3StatInfo
 * iType1:      NS_M_GET_L3_STAT_INFO
 * Function:    HTGetStructure
 * Description: 
		This command is used to get the L3 stats of the terametrics cards 
 **********************************************************************************/

typedef struct tagNSL3StatInfo
{
    U64       u64RxVlanFrames;
    U64       u64RxIPFrames;
    U64       u64IPChecksumError;
    unsigned long       u32ArpReplyRecv;
    unsigned long       u32ArpReplySent;
    unsigned long       u32ArpRequestSent;
    unsigned long       u32ArpReqlyRecv;
    unsigned long       u32PingReplyRecv;
    unsigned long       u32PingReplySent;
    unsigned long       u32PingRequestSent;
    unsigned long       u32PingRequestRecv;
    unsigned long       u32RxStack;
    unsigned long       u32TxStack;
    U64       u64RxDataIntegrityError;
    U64       u64RxSignatureFrame;
    U64       u64TxSignatureFrame;
    U64       u64RxJumboFrames;
}NSL3StatInfo;


/*********************************************************************************
 * Structure:   NSIPv6CounterInfo
 * iType1:      NS_IPV6_COUNTER_INFO
 * Function:    HTGetStructure
 * Description: This command is used to get the IPv6 counters 
**********************************************************************************/
/* NSIPv6CounterInfo Description:
Retrieve port-level counters related to IPv6.
*/

typedef struct tagNSIPv6CounterInfo 
{
    U64  u64RxIPv6Frames;				/* Number of IPv6 frames received */
    U64  u64RxPayloadChecksumError;		/* Number of payload checksum errors received
											   (For now only ICMPv6 checksums) */
    U64  u64NeighborSolicitationSent;	/* Number of neighbor solicitations sent */
    U64  u64NeighborSolicitationRecv;	/* Number of neighbor solicitations received */
    U64  u64NeighborAdvertisementSent;	/* Number of neighbor advertisements sent */
    U64  u64NeighborAdvertisementRecv;	/* Number of neighbor advertisements received */
    U64  u64RouterSolicitationSent;		/* Currently reserved */
    U64  u64RouterAdvertisementRecv;		/* Currently reserved */
    U64  u64PingRequestSent;				/* Number of Ping requests sent */
    U64  u64PingRequestRecv;				/* Number of Ping requests received */
    U64  u64PingReplySent;				/* Number of Ping replies sent */
    U64  u64PingReplyRecv;				/* Number of Ping replies received */
    U64  u64Reserved[20];				/* Reserved */
}NSIPv6CounterInfo;


/*********************************************************************************
 * Structure:   NSIPv6RateInfo
 * iType1:      NS_IPV6_RATE_INFO
 * Function:    HTGetStructure
 * Description: This command is used to get the IPv6 rates 
**********************************************************************************/
/* 
NSIPv6RateInfo Description:
Retrieve port-level rates related to IPv6.
*/

typedef struct tagNSIPv6RateInfo 
{
    unsigned long    ulRxIPv6FramesRate;				/* Number of IPv6 frames received per second */
    unsigned long    ulRxPayloadChecksumErrorRate;		/* Number of payload checksum errors received
														   per second (For now only ICMPv6 checksums) */
    unsigned long    ulNeighborSolicitationSentRate;	/* Number of neighbor solicitations sent per second */
    unsigned long    ulNeighborSolicitationRecvRate;	/* Number of neighbor solicitations received  per second */
    unsigned long    ulNeighborAdvertisementSentRate;	/* Number of neighbor advertisements sent per second */
    unsigned long    ulNeighborAdvertisementRecvRate;	/* Number of neighbor advertisements received per second */
    unsigned long    ulRouterSolicitationSentRate;		/* Currently reserved */
    unsigned long    ulRouterAdvertisementRecvRate;		/* Currently reserved */
    unsigned long    ulPingReqSentRate;					/* Number of Ping requests sent per second */
    unsigned long    ulPingReqRecvRate;					/* Number of Ping requests received per second */
    unsigned long    ulPingRepSentRate;					/* Number of Ping replies sent per second */
    unsigned long    ulPingRepRecvRate;					/* Number of Ping replies received per second */
    unsigned long    ulReserved[20];					/* Reserved */
}NSIPv6RateInfo;


/*********************************************************************************
 * Structure:   NSRealTimeTrackingConfig
 * iType1:      NS_REAL_TIME_TRACKING_TX_CONFIG/NS_REAL_TIME_TRACKING_RX_CONFIG
 * Function:    HTSetStructure
 **********************************************************************************/
/*
NSRealTimeTrackingConfig Description:
Configure streams on transmit/receive side to track and start real
ime tracking.  NS_REAL_TIME_TRACKING_TX_CONFIG and 
NS_REAL_TIME_TRACKING_RX_CONFIG enable and start Real Time 
Tracking on TX and RX respectively. The maximum number of
streams to track currently is 64.
*/
typedef struct tagNSRealTimeTrackingConfig 
{
	unsigned long ulNumStreams;			/* number of streams to configure */
	unsigned long ulStreamIndex[64];	/* stream IDs to track*/
	unsigned char ucReserved[20];
} NSRealTimeTrackingConfig;

/*********************************************************************************
 * Structure:   NSRealTimeTrackingCounters
 * iType1:      NS_REAL_TIME_TRACKING_TX_COUNTERS/NS_REAL_TIME_TRACKING_RX_COUNTERS
 * Function:    HTGetStructure
 **********************************************************************************/
/*
NSRealTimeTrackingCounters Description:
Retrieve counters for streams on 
TX (NS_REAL_TIME_TRACKING_TX_COUNTERS) and RX 
(NS_REAL_TIME_TRACKING_RX_COUNTERS). This command is called after 
NS_REAL_TIME_TRACKING_TX_CONFIG/NS_REAL_TIME_TRACKING_RX_CONFIG.
Real-Time Counters are per stream counters. The timing is in
units of one second.
*/
typedef struct tagRealTimeCounters
{
	unsigned long ulStreamIndex;	/* stream Index */
	U64		u64NumFrames;			/* number of Frames received */
	U64		u64NumBytes;			/* number of Bytes received */
	U64		u64LatencyPerStream;	/* latency per stream, for transmit side its always 0,
									use for only receive side */
	unsigned long ulFramesPerStream;/* the number frames per stream since 
									NS_REAL_TIME_TRACKING_TX_CONFIG was called */
	unsigned char ucReserved[50];
}RealTimeCounters;
typedef struct tagNSRealTimeTrackingCounters
{
	unsigned long ulNumStreams;
	U64 u64CurrentTickCount;		/* Current Time in seconds */
	U64 u64ElapsedTickCount;		/* Elapsed Time in seconds, from when
									real time tracking was started or when
									the last counters was received */
	RealTimeCounters Counters[64];	
	unsigned char ucReserved[50];

}NSRealTimeTrackingCounters;

/*********************************************************************************
 * MDIO Register
 *
 * Structure:   NSMDIORegisters
 * iType1:      NS_READ_MDIO_INFO/NS_WRITE_MDIO
 * Function:    HTSetStructure/HTGetStructure
 ********************************************************************************/
/*
NSMDIORegisters Description:

This structure reads or writes an MDIO register.  When used with
NS_WRITE_MDIO, all three fields are inputs.  When used with
NS_READ_MIDIO, input uiAddress and uiRegister; uiValue will be
returned.  
*/
typedef struct tagNSMDIORegister
{
 unsigned short	uiAddress;	/* specific address */
 unsigned short	uiRegister;	/* specific register */
 unsigned short	uiValue;	/* bit values to write to address/register */
}NSMDIORegister;



/*********************************************************************************
 * Structure:   NSIGMPv3GroupConfig
 * iType1:      NS_IGMPV3_GROUP_CONFIG
 * Function:    HTSetStructure
**********************************************************************************/
/*
 NSIGMPv3GroupConfig Description: 

 Sets the Interface for one or more groups. An array of structures can be 
 
 The message allows users to configure a large number of interfaces with a number
 of multicast groups in each interface at one time.  In each interface, the IP 
 address and MAC address fields are used as the source IP and source MAC address 
 for IGMP packets. To use the port level IP and MAC addresses, these fields should
 be filled with zeroes. Users may change Source IP or VLAN for different interfaces. 
 But if MAC address is changed for different interfaces, Source IP must be changed 
 for each different MAC address.

  Valid values for uiNumInterface is from 1 to 1024.
  Valid values for uiNumGroup is from 1 to 1024. The total multiplication of the
  number of interfaces(uiNumInterface) and number of multicast groups(uiNumGroup)
  in each interface can't be over 1024.

If ucPPPMode is enabled the capture frame will be:
|------------------------------------------------------------------------|
|Dst MAC|Src MAC|0x8864|0x11|0x00|Session_ID|PPPOE Length|0x0021|IP|IGMP |
|------------------------------------------------------------------------|

If PPPOE is combined with VLAN, the frame will look like the following.

|--------------------------------------------------------------------------------------|
|Dst MAC|Src MAC|0x8100|VLAN-ID|0x8864|0x11|0x00|Session_ID|PPPOE Length|0x0021|IP|IGMP|
|--------------------------------------------------------------------------------------|

  This command allows multiples structures, to enable configuration of multiple 
  multicast addresses for Terametric modules.

*/
typedef struct tagIGMPGroupAddressBlock
{
	unsigned char ucStartIPAddress[4];           /* starting address for the IP address list */
	unsigned char ucUpperIPAddressBoundary[4];   /* upper limit for the IP address list (only
                                                applicable for the LAN-3101A/B modules). */
	unsigned short uiIPChangeStep;               /* delta value to increase ucStartIPAddress */
	unsigned short uiNumIP;                      /* number of IP addresses in the list.  The 
                                                maximum value is set by the "uiMaxIPPerBlock"
                                                field for the NS_IGMPV3_CONFIG command. */
	unsigned char ucReserved[30];                /* reserved */
}IGMPGroupAddressBlock;

#define IGMPV3_EXCLUDE_FILTER_MODE	1
#define IGMPV3_INCLUDE_FILTER_MODE	0

typedef struct tagNSIGMPv3GroupConfig
{
	/* interface parameters */
	unsigned char ucIPAddress[4];       /* source IP, interface address */
	unsigned char ucMACAddress[6];      /* MAC address , interface addresss */
	unsigned char ucVLANEnable;           /*1-enable,0-disabled specifies whether or not this 
										multicast group has an associated VLAN tag */
	/* VLAN data for interface */
	unsigned char ucPRI;					/* user priority 0-7 (3 bits) */
	unsigned char ucCFI;					/* 1 = RIF present, 0 = RIF absent  */
	unsigned short uiVID;		            /* VLAN ID (12 bits) */
	
	unsigned short uiNumInterface;      /* number of interfaces to create*/ 
	unsigned short uiIPAddressStepCount; /* delta value to change interface */
	unsigned short uiMACStepCount;		/* delta value to change interface MAC address */
	unsigned short uiVIDStepCount;		/* delta value to change interface VLAN ID */
	
	/* multicast group parameters */ 
	unsigned char ucGroupIPAddress[4];  /* group address */
	
	unsigned short uiNumGroup;			/* number of multicast groups to create per interface*/
	unsigned short uiGroupIPStepCount; /* delta value to change ucGroupIPAddress */	
	
	unsigned long  ulInitialReportGap;  /* time interval to generate reports in microseconds */
	unsigned short uiFilterMode;        /* possible values are IGMPV3_EXCLUDE_FILTER_MODE(suppress 
										listed IP's And IGMPV3_INCLUDE_FILTER_MODE(allow listed IP's) */

   unsigned char ucPPPMode;            /* PPP_USE_NONE(default),
                                       PPP_USE_PPP_SESSION_ID
                                      Only for Terametric cards*/
   unsigned short uiPPPInstance;        /* starting PPP index 
                                        Only for Terametric cards
                                       PPP session index. Currently this is
                                     valid if PPP_USE_PPP_SESSION_ID is on.                                      
                                                                      
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual IGMP
                                     over PPPOE packet. So user can issue IGMP
                                     over PPPOE packet without PPP session in
                                     this case. */
  
   unsigned short uiPPPInstanceStepCount; /*ppp index change step, if this is 0 
                                       only one PPP instance will apply to 
                                       the groups 
                                       Only applicable for the TeraMetrics family of modules */
	
   unsigned short uiVCIndex;           /* Only applicable for the ATM TeraMetrics family of modules */

	unsigned char ucNumAddressBlock;    /* The number of source IP address lists to include for the
                                       groups.  For the LAN-3101A/B modules, the maximum number
                                       of lists that can be included is 2.  For the 
                                       TeraMetrics family of modules, the max is 10. */
	
	unsigned char ucReserved[43];       /* Reserved */
	IGMPGroupAddressBlock IPAddressBlock[100];   /* The source IP address lists that an interface 
                                                wishes to listen to for the groups.  The IP address
                                                lists will be included in the join/leave reports
                                                for the groups. */

} NSIGMPv3GroupConfig;

/*********************************************************************************
 * Structure:   NSIGMPv3GroupMod
 * iType1:      NS_IGMPV3_GROUP_MOD
 * Function:    HTSetStructure
**********************************************************************************/
/*
 NSIGMPv3GroupMod Description: 

 Modify existing multicast group or add a new multicast group if 
 multicast group or interface is new.

 This command allows users to make a single state change in an existing multicast group, 
 or add a new multicast group if the multicast group or interface identity is new.
 The message structure is made to only allow one block change at a time for a specific 
 multicast group, which can be identified by the interface and multicast group information 
 within the structure. It also serves as a simple method to add a new multicast group into 
 the host if the multicast group and/or interface identity does not exist. 
 This message can also serve as a filter mode change. In such a case, the new IP block 
 address will be treated as a new source list and the old address list in stack will be 
 properly reported and cleared.

 If the filter mode stays unchanged and source IP list block is a new block, the new address 
 block will be added only if the total number of IP blocks is still within the maximum allowable 
 limit. 

 This command only modifies uiFilterMode and IPAddressBlockChange, the other fields are
 used to identify the multicast group
*/

typedef struct tagNSIGMPv3GroupMod
{
	unsigned char ucGroupIPAddress[4];  /* group address */
	unsigned char ucVLANEnable;           /* 1 - enable, 0 - disabled specifies whether 
										or not this multicast group has an associated VLAN tag */
	unsigned char ucPRI;					/* user priority 0-7  */
	unsigned char ucCFI;					/* 1 = RIF present, 0 = RIF absent  */
	unsigned short uiVID;		            /* VLAN ID  */

	unsigned char ucIPAddress[4];       /* source IP for interface */
	unsigned char ucMACAddress[6];      /* MAC address for interface */
	unsigned short uiFilterMode;        /* possible values are 
                                       IGMPV3_EXCLUDE_FILTER_MODE
                                       (suppress listed IP's And 
                                       IGMPV3_INCLUDE_FILTER_MODE
                                       (allow listed IP's) */
   unsigned char ucPPPMode;            /* PPP_USE_NONE(default), 
                                      PPP_USE_PPP_SESSION_ID
                                      Only for Terametric cards*/

   unsigned short uiPPPInstance;     /* starting PPP index - Terametric cards
                                     PPP session index. Currently this is
                                     valid if 
                                     PPP_USE_PPP_SESSION_ID is on. 
                                     
                                                                      
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual IGMP
                                     over PPPOE packet. So user can issue IGMP
                                     over PPPOE packet without PPP session in
                                     this case. */	
   unsigned short uiVCIndex;            /* VC index , for ATM cards*/

	IGMPGroupAddressBlock   IPAddressBlockChange;
    unsigned char ucReserved[45];

}NSIGMPv3GroupMod;


/*********************************************************************************
 * Structure:   NSIGMPv3StatsInfo
 * iType1:      NS_IGMPV3_STATS_INFO
 * Function:    HTGetStructure
**********************************************************************************/
/*
 NSIGMPv3StatsInfo Description: 

 Retrieve the join and leave timestamps for a specific multicast 
 group and interface
 
 Message to collect data that are in IGMPv3 only. This message also contains query 
 and membership report of both Version 1 and Version 2.
 The following fields are used as inputs, to identify the Multicast group.
 ucGroupIPAddress, ucVLANEnable, ucPRI, ucCFI,  uiVID, ucIPAddress and ucMACAddress.
*/

typedef struct tagNSIGMPv3StatsInfo
{
	unsigned char ucGroupIPAddress[4];  /* Input - group address */
	unsigned char ucVLANEnable;           /* Input - 1 - enable, 0 - disabled specifies whether 
										or not this multicast group has an associated VLAN tag */
	unsigned char ucPRI;					/* Input - user priority 0-7 (3 bits) */
	unsigned char ucCFI;					/* Input - 1 = RIF present, 0 = RIF absent  */
	unsigned short uiVID;		            /* Input - VLAN ID (12 bits) */

	unsigned char ucIPAddress[4];       /* Input - source IP for interface */
	unsigned char ucMACAddress[6];      /* Input - MAC address for interface */
   
   unsigned char ucPPPMode;            /*Input - PPP_USE_NONE(default),
                                      PPP_USE_PPP_SESSION_ID
                                      Only for Terametric cards*/
   unsigned short uiPPPInstance;       /* Input - starting PPP index - Terametric cards
                                     PPP session index. Currently this is
                                     valid if PPP_USE_PPP_SESSION_ID is on. 
                                     
                                                                      
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual IGMP
                                     over PPPOE packet. So user can issue IGMP
                                     over PPPOE packet without PPP session in
                                     this case. */	

	
	unsigned long ulV3GroupQueryReceived; /*received number of V3 query messages,
								for both group-specific, group-and-source-specific
								and general queries */
	unsigned long ulV2QueryReceived; /* V2 query reports received */
	unsigned long ulV1QueryReceived; /* V1 query reports received */
	unsigned long ulV2ReportReceived; /*received number of version 2 report messages
										when default mode is version 3*/
	unsigned long ulV1ReportReceived; /*received number of version 1 report messages
									when default mode is version 3*/
	unsigned long ulTotalV3ReportSent; /* total number of version 3 reports sent out */

	
	unsigned long ulIsIncludeSent; /* total number of Is Included group record messages sent out */
	unsigned long ulIsExcludeSent; /* total number of Is Excluded group record messages sent out */

	unsigned long ulToIncludeSent; /* total number of To Included group record messages sent out */
	unsigned long ulToExcludeSent; /* total number of To Excluded group record messages sent out */	
	
	unsigned long ulAllowSent; /* total number of Allow group record messages sent out */
	unsigned long ulBlockSent; /* total number of Block group record messages sent out */
	
	unsigned char ucReserved[47];

}NSIGMPv3StatsInfo;


/*********************************************************************************
 * Structure:   NSIGMPv3Config
 * iType1:      NS_IGMPV3_CONFIG
 * Function:    HTSetStructure
**********************************************************************************/
/*
 NSIGMPv3Config Description: 

 Initialize and configure the IGMP stack
 
 Robustness Variable, parameter helps ensure IGMPv3's robustness against packet loss. 
 It allows tuning for the expected packet loss on a network. This variable determines
 the number of times a State-Change Record or an Unsolicited Membership Report is 
 transmitted. Valid values are [0,7]. If zero is specified then the default of 2 
 will be used. It can also be used for IGMPv1 or v2 when the "force unsolicited join"
 is enabled (on Terematric cards), otherwise this parameter will be ignored if the
 operational mode or the host compatibility mode is IGMPv1 or v2. 

 Unsolicited Report Interval parameter determines the maximum interval between 
 repetitions of a host's unsolicited report of membership in a group. Valid values 
 are [0,255] seconds. The default value is 1 second. The default will be 
 used if zero is specified. It can also be used for IGMPv1 or v2 when the "force
 unsolicited join" is enabled (on Terematric cards), otherwise this parameter will
 be ignored if the operational mode or the host compatibility mode is IGMPv1 or v2.
 
 ulInitialReportGap
 The time interval between the first reports of different groups generated as a result
 of the configuration of a block of host/groups.For IGMPv3 this value can be overwritten
 by InitialReportGap field in NSIGMPv3GroupConfig. If InitialReportGap is zero in
 NSIGMPv3GroupConfig, the value in NSIGMPv3Config will be used.
 If the value of ulInitialReportGap in both commands are 0, reports will be sent as 
 fast as possible

 ucOptions possible values:
 IGMP_FORCE_RESPONSE 
 IGMPV3_FORCE_IGMPV2_LEAVES
 IGMPV1_V2_FORCE_UNSOLICITED_JOIN_REPORTS
	
*/
typedef struct tagNSIGMPv3Config
{
	unsigned char	ucVersion;           /* IGMP_V1, IGMP_V2, IGMP_V3
										In the IGMPv1 mode, the implementation will
										ignore any IGMPv2 and IGMPv3 specific packets.
										You are not allowed switch to other two versions.
										In the IGMPv2 mode, the implementation will 
										ignore any IGMPv3 specific packets.In this mode
										you will be capable of inter-operating with 
										IGMPv1.In the IGMPv3 mode, it will be capable
										of inter-operating with both IGMPv1 and IGMPv2. */

	unsigned char	ucOptions;          /* possible bit values, 
										IGMPV3_FORCE_IGMPV2_LEAVES
										(Not Supported on LAN-3101. This is specific to IGMPv2.
										It determines if the implementation will send an 
										IGMPv2 Leave Message regardless of whether it was 
										the last host to report membership or if an IGMPv1
										query is detected).

										IGMPV3_SUPPRESS_IGMPV3_RECORDS
										(determines if the implementation will allow a pending
										IGMPv3 Membership Record to be suppressed by either an 
										IGMPv1 or an IGMPv2 Membership Report. If set 
										IMPV3 Membership Record is suppressed if an 
										IGMPv1/v2 Membership Report is received for the
										same group)

										IGMP_FORCE_RESPONSE
										All joined interfaces must respond to queries,
										IGMP v1/v2 (for only TM cards )

										IGMPV1_V2_FORCE_UNSOLICITED_JOIN_REPORTS
										For IGMPv1/v2, force to send repeated unsolicited IGMP join reports,
										depending on robustness variable and unsolicited 
										report interval. This option is only applicable to 
										IGMPv1/v2  (IGMPv3 already has it by default). 
										This is only for TM cards */

	unsigned short uiMaxNumGroups;      /* The maximum number of groups - it is always required as input. 
                                       The maximum value for the TeraMetrics family of modules is
                                       20000. */
	unsigned char  ucMaxAddressBlock;   /* The maximum number of source IP address lists per 
                                       group.  The maximum value for the TeraMetrics family of 
                                       modules is 10. For the LAN-3101A/B modules, the max is 2. */
	unsigned short uiMaxIPPerBlock;     /* The maximum number of source IP addresses per address
                                       list.  The maximum value is 100. */
	unsigned char ucRobustnessVariable; /* IGMPv3, or IGMPv1/v2 when force unsolicited join 
                                       reports is enabled (on Terematric cards), it is
                                       the number of times to repeat transmission
                                       report of one group. Range 0-7. If zero is entered, default 2
                                       will be used. */
	unsigned char ucUnsolicitedReportInterval;   /* IGMPv3, or IGMPv1/v2 when force unsolicited join
										            reports is enabled (on Terematric cards), it is
										            the time interval in seconds between the 
										            repeated transmission of reports of one group
                                                    default 10 seconds */
	unsigned long ulInitialReportGap;  /* Applicable to IGMPv1/v2/v3. It is the time interval to 
										generate the first reports of different groups in microseconds
										as a result of the configuration of block of host/groups.
										Supported by TeraMetrics Cards only */
	unsigned char ucReserved[46];       /* Reserved */
}NSIGMPv3Config;

#define IGMPV3_FORCE_IGMPV2_LEAVES		0x80
#define IGMPV3_SUPPRESS_IGMPV3_RECORDS	0x40
#define IGMP_FORCE_RESPONSE	            0x20 /*  for all joined interfaces to respond to
                                             queries, IGMP v1/v2  */
#define IGMPV1_V2_FORCE_UNSOLICITED_JOIN_REPORTS   0x10  /* For IGMPv1/v2, force to send repeated unsolicited
                                                       IGMP join reports even after the join, depending
                                                       on robustness variable and unsolicited report interval.
                                                       This option is only applicable to IGMPv1/v2
                                                       (IGMPv3 already has it by default).
                                                       This is only for only TM cards. */
#define IGMP_V1 0x01
#define IGMP_V2 0x02
#define IGMP_V3 0x03


/*********************************************************************************
 * Structure:   NSIGMPv3GroupInfo
 * iType1:      NS_IGMPV3_GROUP_INFO
 * Function:    HTGetStructure
**********************************************************************************/
/*
 NSIGMPv3GroupInfo Description: 

 Retrieve the join and leave timestamp for multicast groups and interfaces.
 
The following fields are used as input when this structure is used with 
 NS_IGMPV3_GROUP_INFO. The Inputs are used to identify the Multicast group.
 ucGroupIPAddress, ucVLANEnable, ucPRI, ucCFI,  uiVID, ucIPAddress and ucMACAddress.
 The leave and join timestamps for the group is returned.
 
 TimeStamps are per multicast group, they are in units of 0.1 micro-seconds.
 TimeStamp values initially start from 0, when Chasis is turned on. Timestamp 
 counter overflows after 430 seconds.

 JoinTimeStamps and LeaveTimeStamps will change for any of these 2 events.

 An event is considered JOIN for IGMPv3, when the mode is INCLUDE with a non-empty
 source list or EXCLUDE with an empty source list.

 An event is considered LEAVE for IGMPv3, when the mode is EXCLUDE with a non-empty
 source list or INCLUDE with an empty source list.
 
 Comments for "ulLastStateTimestamp":

 In IGMP, all the membership reports sent out from a port are called state change reports.  
 Whenever the host wants to change the current state of membership on a specific group, 
 such as different source list, the host should send out a state change report.  

 Therefore, the new state change timestamp of the group should change with each report of 
 that group sent out.  However, there are two special case.  If it is the first report to 
 the group, the IGMP stack will treat it as a join report and save the timestamp to 
 "ulJoinTimestamp".  If the report is trying to INCLUDE NULL, the IGMP stack will treat it 
 as leave report and save the timestamp to "ulLeaveTimestamp".  In these two cases, 
 "ulLastStateTimestamp" would not be updated.

 Example

 Join		      t1
 state change	t2
 state change	t3
 state change	t4
 leave         t5

 => ulJoinTimestamp = t1, ulLastStateTimestamp = t4, and ulLeaveTimestamp = t5
*/
typedef struct tagNSIGMPv3GroupInfo
{
	unsigned char ucGroupIPAddress[4];  /* Input - group address */
	unsigned char ucVLANEnable;           /* Input - 1 - enable, 0 - disabled specifies whether 
										or not this multicast group has an associated VLAN tag */
	unsigned char ucPRI;					/* Input - user priority 0-7 (3 bits) */
	unsigned char ucCFI;					/* Input - 1 = RIF present, 0 = RIF absent  */
	unsigned short uiVID;		            /* Input - VLAN ID (12 bits) */

	unsigned char ucIPAddress[4];       /* Input - source IP for interface */
	unsigned char ucMACAddress[6];      /* Input - MAC address for interface */

   unsigned char ucPPPMode;            /* PPP Mode  possible values are 
                                       PPP_USE_NONE(default)
                                       and PPP_USE_PPP_SESSION_ID 
                                       Only for Terametric cards */
   unsigned short uiPPPInstance;        /* starting PPP index 
                                        Only for Terametric cards */
                                        
	
	unsigned long ulJoinTimestamp;		/* Join Time Stamp */
	unsigned long ulLeaveTimestamp;		/* Leave Time Stamp */
	
   unsigned long ulLastStateTimestamp; /* Output, Timestamp for the last state change.  This
                                       excludes the initial join report and the leave
                                       report.  The timestamp for these 2 events
                                       are available in the previous 2 fields. */
	unsigned char ucReserved[21];       /* Reserved */
}NSIGMPv3GroupInfo;


/*******************************************************************************
Structure: NSWaitForEvent
iType1: NS_WAIT_FOR_EVENT
Function: HTSetStructure
*******************************************************************************/
/*
NSWaitForEvent Description:

This structure sets the input and returns the output for
NS_WAIT_FOR_EVENT command.  The purpose is to wait until the events
specified by ulEventFlag are completed, or until the timeout length
specified by ulTimeout has elapsed.  The ulStatus field is returned to
indicate whether the event or the timeout occurred.
*/


typedef struct tagNSWaitForEvent {
	unsigned long ulEventFlag;   /* flag of events to wait for */
	                             /* NS_TX_SIGNATURE_STOP - wait till stop transmitting signature frames */
	                             /* NS_RX_SIGNATURE_STOP - wait till stop receiving signature frames */
	unsigned long ulTimeout;     /* number of seconds to wait before giving up */
	                             /* set to 0 to use the default timeout value */
	unsigned long ulStatus;	     /* output */
	                             /* NS_WAIT_TIMEOUT  - 1 or more events didn't complete */
	                             /* NS_WAIT_COMPLETE - all events are completed */
} NSWaitForEvent;

#define NS_TX_SIGNATURE_STOP	0x00000001
#define NS_RX_SIGNATURE_STOP	0x00000002

#define NS_WAIT_TIMEOUT			0x00000000
#define NS_WAIT_COMPLETE		0x00000001

/*******************************************************************************
Structure: NSResolveArps
iType1: NS_RESOLVE_ARPS
Function: HTSetStructure
*******************************************************************************/
/*
NSResolveArps Description:

This structure sets the input and returns the output for
NS_RESOLVE_ARPS command.  The purpose is to keep trying to resolve all
ARPs on the port, giving up when the ulTimeout time has elapsed.
*/

typedef struct tagNSResolveArps {
	unsigned long ulTimeout;   /* number of seconds to wait before giving up */
	                           /* set to 0 to use the default timeout value */
	unsigned long ulStatus;    /* output */
	                           /* NS_ARP_TIMEOUT  - ARP was not resolved before timeout */
	                           /* NS_ARP_COMPLETE - ARP is resolved */
} NSResolveArps;

#define NS_ARP_TIMEOUT			0x00000000
#define NS_ARP_COMPLETE			0x00000001


/*********************************************************************************
 * Structure:   NSIPOptions
 * iType1:      NS_IP_OPTION_CONFIG
 * Function:    HTSetStructure
 **********************************************************************************/
/*
NSIPOptions Description: 

Currently, only POS TeraMetrics and LAN TeraMetrics cards are capable of
defining IP options within IPv4 frames.  IPv4 frames with IP options
defined using NS_IP_OPTION_CONFIG can only be captured on POS-35xx
cards using the capture filter, CAPTURE_EVENTS_IP_OPTION, LAN
TeraMetrics cards currently are unable to capture these frames.

This command is used to Configure IP Options for Record Route, Loose
Source and Record Route, and Strict Source and Record Route.
				
When used with MPLS the configurations should be in this order: Define
Streams( L3_DEFINE_XX STREAM), Define MPLS(L3_DEFINE_MPLS/L3_MOD_MPLS)
and then Define IP Options.

iType2 is used as the stream index.

----------------------------------------------------------------------
|NOP|ucCode|uiLength|uiPointer| uiDataLength |-- ucData(36 bytes) ---|
----------------------------------------------------------------------
*/
typedef struct tagNSIPOption
{	
	unsigned char ucCode;		/* Type of IP Option,
                               IP_OPTION_RECORD_ROUTE
                               IP_OPTION_LOOSE_SOURCE_RECORD_ROUTE
                               IP_OPTION_STRICT_SOURCE_RECORD_ROUTE
                                          */
    unsigned short uiLength;	/* Option Length,includes the option type code,
								length octet, pointer octet and route data*/  
    unsigned short  uiPointer;		/* Pointer offset into Route data, bytes */ 
	unsigned short uiDataLength;	/* number of bytes to use from ucData */
	unsigned char ucData[124];		/* Contains route data, for Record Route,
      		LSRR and SSRR it may contain IP address */
	unsigned char ucReserved[50];
}NSIPOption;

#define IP_OPTION_RECORD_ROUTE	0x07
#define IP_OPTION_LOOSE_SOURCE_RECORD_ROUTE		0x83
#define IP_OPTION_STRICT_SOURCE_RECORD_ROUTE	0x89

/*******************************************************************************
* Structure: NSARPConfig
* iType1: NS_ARP_CONFIG and NS_ARP_CONFIG_INFO
* Function: HTSetStructure

*******************************************************************************/
/*
 NSARPConfig Description: 

 This command provides the ability for ARP requests to be sent using
 virtual stream/cyclic flow. Base streams can be defined using
 existing messages (e.g. L3_MOD_IP_STREAM/L3_DEFINE_IP_STREAM, etc.)

 Virtual streams/ cyclic flows are created when varying IP/MAC
 address(s) of defined base stream(s) using existing VFD messages
 (e.g. L3_MOD_VFD, etc.).
 
 L3_SET_ARP_GAP can also be used to set ARP rate.

 NS_ARP_CONFIG with ucARPMode set to ARP_VIRTUAL_MODE(1), is used to
 enable virtual ARP Mode.

 L3_START_ARPS is used to start ARPS.

 L3_ARP_UNRESOLVED is used to Re-ARP streams whose intial ARP's didn't
 get resolved. Its used on base streams.

 VFD1 and VFD2 can be used to vary the Source IP, Destination IP and
 Source MAC of base stream.  
 The possible combination are:
   - Only Source IP
   - Source IP(VFD1) and Destination IP(VFD2)
   - Source IP(VFD1) and Source MAC(VFD2)

 The Total number of virtual streams that can be supported per port is
 4,096,000. If there is one original base stream, 4,000,000 virtual
 streams can be generated per port. If there are 2 original base
 streams, each stream can generate 2,048,000 virtual streams and if
 there are 512 original base streams, each stream can generate 8000
 virtual streams.

 NS_ARP_CONFIG supports the following options for NSVFD
 ucType - L3_VFD1 and L3_VFD2
 ucMode -  L3_VFD_INCR
 uiOffset - Source IP, Dest IP, Source MAC and
 Dest MAC.
 uiRange - 4 or 6
 ulCycleCount - the number of requests for each stream.	
 uiBlockCount - number of times ARP request will be sent for a particular
 virtual stream.
 
 The following fields are also supported ucStepValue,ucStepShift,
 ucSunbetAware, ucSubnetMaskLength and ucPattern.

 ucEnableCarryChaining - not supported


Note: 
 User should not send traffic after resolving NeigborDiscovery because it 
 is not going to store received Mac addresses in virtual mode. Storing of 
 MAC addresses is in only Basic Mode 
 
 Address ranges should be mutually exclusive for source IP address.
 They should not overlap.
 For example:
	Base stream 1: 10.100.10.0
		vfd(uiRange):	    1	  
		vfd(uiBlockCount):  1
		vfd(ulCycleCount)   10
            	vfd(ucStepValue)    10
	Then the next base stream 2: should start from 10.100.10.101


 -----------------------------------
 Comments for ucGratuitousARPEnable
 -----------------------------------

 Gratuitous ARP request: An ARP request sent to either determine if another host is using the
 sender's IPv4 address or to update the ARP cache of a receiving host. The sender IPv4 address and target IPv4 address in the gratuitous ARP request are identical.

 Gratuitous ARP reply: An unsolicited ARP reply sent to update the ARP cache of a receiving 
 host. The sender IPv4 address and target IPv4 address in the gratuitous ARP reply are identical.

 If the gratuitous ARP feature is enabled(ucGratuitousARPEnable is set to GRATUITOUS_ARP_ENABLE) 
 and the card detects a gratuitous ARP packet, it will check the destination IP and gateway 
 addresses of all IPv4-type protocol streams configured and determine if there is a match with 
 the sender IP address of the ARP packet. No response is sent if a gratuitous ARP request is 
 received. If there is a match, the card will perform the following actions:
    Check to see if the port is transmitting. If so, disable the transmitter.
    Wait for the current frame to finish transmitting.
    Update all matching streams with the sender MAC address in the ARP packet. 
    Update all transmit buffers allocated to the matching streams with the sender MAC address
     in the ARP packet.
    If the transmitter was disabled, re-enable the transmitter.

 There are three scenarios during the ARP Address Resolution procedure(initiated by L3_START_ARPS)
 that need to be considered with the gratuitous ARP feature enabled:
    The stream has not sent out an ARP request. A gratuitous ARP packet is then received for the 
     stream.
    The stream has sent out an ARP request but has not received a reply. A gratuitous ARP 
     packet is then received for the stream.
    The stream has sent out an ARP request and has received a reply. A gratuitous ARP packet 
     is then received for the stream.

In all three cases, the gratuitous ARP packet will update the stream's destination MAC address. 
However, the ARP status of the stream will not be updated in order to preserve the behavior of 
the Address Resolution procedure and the recording of the ARP exchange times. Furthermore, the 
transmit engine will not be stopped to prevent disruption of the address resolution process. 
Note that ARP requests transmitted in the address resolution process use the same transmit path 
as the data generated from protocol streams (i.e., there is no cut-through channel on the 3101).

In the second scenario, if an ARP reply is received, the destination MAC address of the stream 
will be overwritten with the sender MAC address in the ARP reply. The assumption is made that 
the value of the sender MAC address in the ARP reply is correct and matches that of the 
gratuitous ARP. If a DUT malfunctions and sends the incorrect MAC address in an ARP reply after 
having transmitted a gratuitous ARP packet, the stream will then have an incorrect MAC address 
and send traffic to the wrong interface.

NOTES:

The gratuitous ARP feature is not intended to operate simultaneously with the cyclic flow 
feature(ucARPMode is set to ARP_VIRTUAL_MODE) if the cyclic flow feature is configured to 
modify the destination MAC of the stream. Configuring both features in such a manner will 
result in the transmission of incorrect data because the transmit engine applies the VFDs 
after the modification to the destination MAC address caused by a gratuitous ARP is performed.

If the cyclic flow feature is configured to modify the destination IPv4 address of the stream, 
only the base destination IPv4 address will be checked for a match with the sender IPv4 address 
of a gratuitous ARP packet.
*/
typedef struct tagNSARPConfig
{
   unsigned char ucARPMode;               /* ARP_NORMAL_MODE, ARP_VIRTUAL_MODE */
   unsigned char ucGratuitousARPEnable;   /* 0 to disable, 1 to enable */
   unsigned char ucVLANARPMode;           /* Possible values:
                                             ARP_ALL_VLAN_TAG - ARP requests/replies will be 
                                             sent/resolved with all vlan tags.
                                             ARP_INNER_VLAN_TAG - ARP requests/replies will be 
                                             sent/resolved with the innermost vlan tag.

                                             Note:  This field is currently only applicable
                                             for the TeraMetrics family of modules.
                                          */
   unsigned char ucReserved[18];
}NSARPConfig;

/* ucARPMode constants */
#define ARP_NORMAL_MODE          0
#define ARP_VIRTUAL_MODE         1

/* ucVLANARPMode constants */
#define ARP_ALL_VLAN_TAG         0
#define ARP_INNER_VLAN_TAG       1


/****************************************************************************
* Structure: NSARPStatusInfo
* iType1:    NS_ARP_STATUS_INFO
* Function:  HTGetStructure
* NSARPStatusInfo Description: 
*  Query the ARP counters.
****************************************************************************/
/*
NSARPStatusInfo Description:
 L3_START_ARPS is used to start ARPS.
 
 For example: 
 
 Before L3_START_ARPS is taken place.
 If the number of configured streams is 100 of 50 IPv4 streams and 50 IPv6 
 streams, then the ARP status counters will show:
    ulRequestsSent	                 = 0
    ulRequestsRecv	                 = 0
    ulRepliesSent                     = 0
    ulRepliesRecv                     = 0

    u64NeighborSolicitationSent.high  = 0
    u64NeighborSolicitationSent.low   = 0

    u64NeighborSolicitationRecv.high  = 0
    u64NeighborSolicitationRecv.low   = 0

    u64NeighborAdvertisementSent.high = 0
    u64NeighborAdvertisementSent.low  = 0

    u64NeighborAdvertisementRecv.high = 0
    u64NeighborAdvertisementRecv.low  = 0

    ulResolved                        = 0
    ulUnresolved                      = 100
    ulTotal                           = 100

 After calling L3_START_ARPS, if only 45 ARP requests have been 
 Resolved (meaning 25 replies have been received for IPv4 and 20 
 ulNeighborAdvertisementRecv ), then the ARP status 
 counters will show:
    ulRequestsSent                    = 50
    ulRequestsRecv                    = 0
    ulRepliesSent                     = 0
    ulRepliesRecv                     = 25

    u64NeighborSolicitationSent.high  = 0
    u64NeighborSolicitationSent.low   = 50

    u64NeighborSolicitationRecv.high  = 0
    u64NeighborSolicitationRecv.low   = 0

    u64NeighborAdvertisementSent.high = 0
    u64NeighborAdvertisementSent.low  = 0

    u64NeighborAdvertisementRecv.high = 0
    u64NeighborAdvertisementRecv.low  = 20

    ulResolved                        = 45
    ulUnresolved                      = 55
    ulTotal                           = 100

NOTE:  L3_ARP_UNRESOLVED can be used to re-ARP for streams whose initial ARPs
did not get resolved.
*/
typedef struct tagNSARPStatusInfo
{
   /* IPv4 */
   unsigned long ulRequestsSent; /* The number of ARP requests sent        */
   unsigned long ulRequestsRecv; /* The number of ARP requests received    */
   unsigned long ulRepliesSent;  /* The number of ARP replies sent         */
   unsigned long ulRepliesRecv;  /* The number of ARP replies received     */
   /* IPv6 */
   U64 u64NeighborSolicitationSent;	
                                 /* Number of neighbor solicitations sent  */
   U64 u64NeighborSolicitationRecv;	
                                 /* Number of neighbor solicitations 
                                    received                               */
   U64 u64NeighborAdvertisementSent;	
                                 /* Number of neighbor advertisements sent */
   U64 u64NeighborAdvertisementRecv;	
                                 /* Number of neighbor advertisements 
                                    received                               */

   /* ARP status info for both IPv4 and IPv6 */
   unsigned long ulResolved;     /* The number of ARP requests and neighbor 
                                    discovery that have been resolved      */
   unsigned long ulUnresolved;   /* The number of ARP requests and neighbor 
                                    that are still unresolved              */
   unsigned long ulTotal;        /* The total number of ARP requests and 
                                    neighbor discovery to be resolved      */
   unsigned long ulGratuitousRecv;  /* the total number of gratuitous ARP 
                                           packets(requests and replies) received 
                                           that match a stream configured on the port */
   unsigned char ucReserved[60]; /* reserved for future use                */
} NSARPStatusInfo;

/****************************************************************************
 * NSARPStatusInfo Comment:
****************************************************************************/

/*********************************************************************************
 * Download and upload file
 *
 * Structure:   NSFileTransferStructure
 * iType1:      NS_DOWNLOAD_FILE/NS_UPLOAD_FILE
 * Function:    HTSetStructure/HTGetStructure
******************************************************************************/
/*
NSFileTransferStructure Description:
 
This structure downloads a file from or uploads a file to Terametrics
card.

Note:
For download file:
  If path_name starts with /, it must be /tmp, /usr, or /opt.  
  If path_name starts with a character, it must match one of CMD
  partition name.

For upload file:
  If path_name is absolute, it must start at with /.
  If path_name does not start with /, first part of name must be one
  of partition name.
*/
typedef struct tagNSFileTransferStructure {
    char             szSourcePathName[128]; /* file name for download or
                                               file name for upload */
    char             szDestPathName[128];   /* file name to download or 
                                               file name to upload */
    unsigned char    ucReserve[256];        /* reserved */
} NSFileTransferStructure;


/*******************************************************************************
Structure: NSCounterInfo
iType1: NS_COUNTER_INFO
Function: HTGetStructure
*******************************************************************************/
/*
NSCounterInfo Description: 
Retrieves port-level counters.

NOTES:

To generate collision errors on the LAN-3101A/B modules when testing back-to-back, 
set the transmitting and receiving ports to half-duplex mode before transmitting.
*/
typedef struct tagNSCounterInfo {
   /* Fields supported by both LAN-3101A/B and TeraMetrics modules */
	U64	u64TxFrames;	/* number of frames transmitted */
	U64	u64RxFrames;	/* number of frames received */
	U64	u64TxBytes;		/* number of bytes transmitted */
	U64	u64RxBytes;		/* number of bytes received */
	U64	u64Undersize;	/* number of undersize errors detected */
	U64	u64Oversize;	/* number of oversize errors detected */
	U64	u64AlignError;  /* number of alignment errors detected */
	U64	u64CRCError;    /* number of CRC errors */
	U64	u64RxTriggers;  /* number of triggers received */
	U64	u64Collisions;  /* number of collisions */
	U64   u64RxJumboFrames;   /* number of jumbo frames received */
	unsigned long	ulTxLatency;
	unsigned long	ulRxLatency;
   
   /* Fields supported by only LAN-3101A/B */
   U64   u64TxJumboFrames;	/* number of jumbo frames transmitted */

   /* Fields supported by only TeraMetric modules */
   U64	u64TxTriggers;  /* number of triggers received ,
                         supported on only Terametric cards */
   U64   u64TxSignature;   /* Tx Signature frame, only TM cards */	
   U64   u64RxSignature;   /* Rx Signature frame, only TM cards */	
   U64   u64TxTimeStamp;   /* Tx Time Stamp, only TM cards */	
   U64   u64RxTimeStamp;   /* Rx Time Stamp, only TM cards */
   U64   u64RxIPChecksumErrors; /* Rx IP Checksum errors */
	unsigned char	ucReserved[252];	
}NSCounterInfo;

/******************************************************************************
* Structure: NSMFGPROM
* iType1: NS_MFG_PROM_CONFIG / NS_MFG_PROM_INFO
* Function: HTSetStructure / HTGetStructure
* NSMFGPROM Description: Write/read data from MFG PROM.
*                        Currently only for TeraMetrics cards.  A special 
*                        jumper must be installed physically on the card in 
*                        order to use this command.
******************************************************************************/
typedef struct tagNSMFGPROM
{
   char szSerialNum[20];
   char szBurnDate[4];
   char szBurnRecordNum[8];
   char szECORevLevel[4];
   char szFinalTestRecordNum[8];
   char szConfigTestDate[4];
   char szConfigTestRecordNum[8];
   char szExtendedTestDate[4];
   char szExtendedTestRecordNum[8];
   char szSalesOrderNum[16];
   unsigned char ucReserved[44];
} NSMFGPROM;

/****************************************************************************
* Structure: NSTrigger
* iType1: NS_TRIGGER_CONFIG / NS_TRIGGER_CONFIG_INFO
* Function: HTSetStructure / HTGetStructure
* NSTrigger Description: Configure trigger(s) / Retrieve Trigger Configurations

Notes: 

The LAN-3201A and LAN-3201B modules do not support triggers in Layer 3 mode (that is,
when streams are defined for a port).

For the AT-345x modules, the trigger pattern must be set up within the first 96 
bytes(2 cells) of the frame.

ucTriggerOutMode is used for External Trigger
External Trigger provides a means of linking an outgoing External Trigger pulse 
to Bitpattern functionality or to an error condition detected in a received frame.
Only trigger "OUT"  functionality is supported. External Trigger is always on,
the default is NS_TRIGGER_OUT_RX.
****************************************************************************/
typedef struct tagNSTrigger
{
   unsigned char ucTriggerCombo;      /* trigger combination               */
                                      /* use the following constants       */
                                      /* to specify combination:           */
                                      /* NS_TRIGGER_OFF (default)          */
                                      /* NS_TRIGGER1_ONLY                  */
                                      /* NS_TRIGGER2_ONLY                  */
                                      /* NS_TRIGGER1_OR_TRIGGER2           */
                                      /* NS_TRIGGER1_AND_TRIGGER2          */
   unsigned long ulTrigger1Offset;    /* offset of trigger 1 (in bits)     */
   unsigned short uiTrigger1Range;    /* range of trigger 1 (in bytes)     */
                                      /* (current valid range = 1~6)       */
   unsigned char ucTrigger1Data[6];   /* trigger 1 data                    */
   unsigned char ucReserved1[26];     /* reserved for future use           */
   unsigned char ucTrigger1Mask[6];   /* trigger 1 mask (default = 0xFF)   */
   unsigned char ucReserved2[26];     /* reserved for future use           */
   unsigned long ulTrigger2Offset;    /* offset of trigger 2 (in bits)     */
   unsigned short uiTrigger2Range;    /* range of trigger 2 (in bytes)     */
                                      /* (current valid range = 1~6)       */
   unsigned char ucTrigger2Data[6];   /* trigger 2 data                    */
   unsigned char ucReserved3[26];     /* reserved for future use           */
   unsigned char ucTrigger2Mask[6];   /* trigger 2 mask (default = 0xff)   */
   unsigned char ucReserved4[26];     /* reserved for future use           */
   /* External Trigger */
   unsigned char ucTriggerOutMode;    /* external trigger mode */
                                      /* for LAN, and POS TM only */
									  /*  use the following constants */
									  /* NS_TRIGGER_OUT_TX */
									  /* NS_TRIGGER_OUT_RX */
                                      /* NS_TRIGGER_OUT_L2_ERROR */
                                      /* NS_TRIGGER_OUT_L3_ERROR */
   /* Card specific */
   /* WAN cards */
   unsigned long ulLineNum;           /* T1/E1 line number                 */
   unsigned long ulChannelNum;        /* Channel number within the T1/E1   */
                                      /* line.                             */
   unsigned char ucDirection;         /* Rx or Tx                          */
                                      /* use the following constants       */
                                      /* to specify:                       */
                                      /* NS_TRIGGER_DIR_RX                 */
                                      /* NS_TRIGGER_DIR_TX                 */
   unsigned char ucReserved5[29];     /* reserved for future use           */
} NSTrigger;

#define NS_MAX_TRIGGER_RANGE 6

#define NS_TRIGGER_OFF           0
#define NS_TRIGGER1_ONLY         1
#define NS_TRIGGER2_ONLY         2
#define NS_TRIGGER1_OR_TRIGGER2  3
#define NS_TRIGGER1_AND_TRIGGER2 4

#define NS_TRIGGER_DIR_RX 0
#define NS_TRIGGER_DIR_TX 1

/* ucTriggerOutMode values */
#define NS_TRIGGER_OUT_TX   0  /* External Trigger Out will be pulsed when a 
                                  Transmitted frame matches  the currently 
                                  configured bitpattern trigger */
#define NS_TRIGGER_OUT_RX   1  /* External Trigger Out will be pulsed when a
                                  Received frame matches the currently 
                                  configured bitpattern trigger */
#define NS_TRIGGER_OUT_L2_ERROR  2 /* External Trigger Out will be pulsed when
                                    a frame arrives with L2 error 
                                   (oversize, undersize, CRC) */
#define NS_TRIGGER_OUT_L3_ERROR   3  /* External Trigger Out will be pulsed when
                                      a frame arrives with L3 error 
                                      (IP header checksum, data integrity error,
                                      out-of-sequence frame) */


/****************************************************************************
* Structure: NSAlternateKeyConfig
* iType1:    NS_ALTERNATE_KEY_CONFIG / NS_ALTERNATE_KEY_CONFIG_INFO
* Function:  HTSetStructure / HTGetStructure
* NSAlternateKeyConfig Description: 
*	Setup and query Alternate Key .
****************************************************************************/
/* NSAlternateKeyConfig Description:

NOTE:  This command currently only applies for the POS-350X, LAN-330X, 
  LAN-331X and Xenpak cards.

  This command applies per port.

  The Alternate Key provides the capability for applications to group 
  received frames for statistical purposes. 
  The grouping is accomplished by creating a key from data in the
  received frames and then using the key to lookup the index in a statistics 
  table.

  The primary look up key for each received frame is the stream identifier
  from the signature field. 
  
  Up to 16 bits of Alternate Key shall be defined at a specified offset 
  within the received frames. 

  The primary and Alternate Keys are logically combined to from the look up
  key.

  The key mask shall not be protocol dependent. If the received frames 
  contains multiple protocols, the statistics data collected will 
  unreliable, as the key mask may not apply to a field for the different
  protocols.

  Note: On POS cards, the offset for the Alternate Key Mask is now from the
        beginning of the 2-byte Address/Control couplet ("FF03") - not from
        the beginning of the Protocol Bytes.  This brings Alternate Key Mask
        offset into conformity with the existing convention of measuring 
        offset for trigger and vfd's from the beginning of the "FF03".
*/    
typedef struct tagNSAlternateKeyConfig
{
   unsigned long ulMode;   /* Enable/disable Alternate Key 
                           with/without prefilter                         
                              NS_ALTERNATE_KEY_DISABLE  = 	0(default)
                              NS_ALTERNATE_KEY_ENABLE
                              NS_ALTERNATE_KEY_TRIG_PREFILTER         
                              NS_ALTERNATE_KEY_INVERSE_TRIG_PREFILTER
                           */
   unsigned long ulOffset; /* Offset in bytes from the byte offset 2 of the
                              frame to the location of the alternate key. 
                              For POS cards, the byte offset starts from 4.
                           */
   unsigned long ulMask;	/* Determines which bits from Alternate Key 
                              will overwrite bits in Lookup Key 

                              Valid value is between 0x00000000 and 
                                                     0x0000FFFF       */
   unsigned char ucReserved[20]; /* reserved for future use*/
} NSAlternateKeyConfig;

/****************************************************************************
 * NSAlternateKeyConfig Comment:

ulEnable: Enable Alternate Key; Other fields are ignored unless this enabled.

    NS_ALTERNATE_KEY_DISABLE   Disable Alternate Key
    NS_ALTERNATE_KEY_ENABLE    Enable Alternate Key (without trigger
                               Prefiltering)

    NS_ALTERNATE_KEY_TRIG_PREFILTER  
                               Enable Alternate Key with trigger prefiltering
                               All incoming frames that match the trigger
                               settings will be processed according to 
                               alternate key settings.
    NS_ALTERNATE_KEY_INVERSE_TRIG_PREFILTER
                               Enable Alternate Key with Inverse Trigger
                               prefiltering. All incoming frames that do not
                               match the trigger settings will be processed
                               according to alternate key settings.

Note that there are two aspects to the interface for the Alternate Key 
feature: transmit and receive.

1 Transmit Port Interface
    Although Alternate Key is strictly speaking a receive port feature, 
    many applications will need to access related functionality on the 
    transmit port as well.  
    That is to write the desired value (if any) to the "Lookup Key" 
    (sometimes called "StreamID") in the signature field.   
    The interface to this functionality already exists via 
    ucEnableCustomStreamID and ulCustomStreamID fields of the 
    L3StreamExtension structure used with the L3_DEFINE_STREAM_EXTENSION 
    message.

2 Receive Port Interface
  A. Alternate Key
    On the receive port, the user will have the capability of configuring
    the Alternate Key settings (globally).
     + The Alternate Key is four bytes (Dword) at a user-specified setback
       from the beginning of the incoming frame.
     + The user specifies a 32bit Mask.  Bits set in this mask are used to 
       determine which bits from the Alternate Key will be combined with
       bits in the 32bit Lookup Key.
     + Note that the lower 16 bits of the Lookup Key are the significant  
       ones and in general most applications will use these lower 16bits only.

   B. Alternate Key with Trigger
    An interface already exists to enable the user to setup triggers on the 
    receive port.  A new interface will be provided to enable the user to use
    the trigger functionality as a pre-filter ahead of Alternate Key.  

    Three settings will be possible:
        + Disable Trigger pre-filter: All incoming frames will be processed 
          according to Alternate Key settings.
        + Enable Trigger pre-filter: All incoming frames that match the 
          trigger settings will be processed according to Alternate Key 
          settings.
        + Enable Inverse Trigger pre-filter:  All incoming frames that do not
          match the trigger settings will be processed.

    C. Related functionality
        An interface exists already to enable the user to retrieve:
        + The number of streams for which histogram(s) are available.  
          This is available in the ulRecords field of the Layer3HistActiveTest
          structure.  
          It is used in conjunction with the L3_HIST_ACTIVE_TEST_INFO message.
        + The "Stream ID" ( Lookup Key ) field associated with the histogram. 
          This field will have already been modified by the "Alternate key". 
          It is already available via the ulStreamID field of the structure 
          corresponding to the histogram currently configured on the port 
          (NSHistComboPerStreamInfo, NSHistLatencyDistPerStreamInfo, etc. )

****************************************************************************/

#define NS_ALTERNATE_KEY_DISABLE                  0x00
#define NS_ALTERNATE_KEY_ENABLE                   0x01
#define NS_ALTERNATE_KEY_TRIG_PREFILTER           0x07
#define NS_ALTERNATE_KEY_INVERSE_TRIG_PREFILTER   0x03


/****************************************************************************
* Structure: NSAlternateKeyHashConfig
* iType1:    NS_ALTERNATE_KEY_HASH_CONFIG / NS_ALTERNATE_KEY_HASH_CONFIG_INFO
* Function:  HTSetStructure / HTGetStructure
* NSAlternateKeyHashConfig Description: 
*   Configure Alternate Key Hash or Query the configured Alternate Key Hash
****************************************************************************/
/* NSAlternateKeyHashConfig Description:

The 32 bits of the "Lookup Key" are divided into two 16-bit regions:  
16 "care" bits and 16 "concern" bits. We are primarily concerned with
the 16 "care" bits as these are the ones that map in a useful and 
straightforward way to a histogram. 

The "care" bits in the existing 32-bit Lookup key are discontiguous.  
The least-significant byte of the Lookup Key contains 8 "care" bits normally
used to encode the stream number.  Another 8 discontiguous bits located in 
the third and fourth bytes are normally used to encode the Hub/Slot/Port.  

Although such an arrangement could have been left intact for Alternate  Key,
it was obviously more desirable to make all 16 bits contiguous. So the 
alternate key feature is being implemented to include "hashing algorithm 
improvements" in hardware whereby the 16 "care" bits will be contiguous.   

Note that two modes will be possible.  When the card is in 
contiguous-hashing-bit mode,  the 16 "care" will all be located contiguously
in the first and second bytes. When the card is not in contiguous-hashing-bit
mode, the old discontiguous arrangement of "care" bits will be in effect. 
Note also that in hardware, the switch to enable/disable the contiguous 
arrangement of "care" bits is independent of Alternate key.  

Note however that differences in the "concern bit" region can cause 
multiple histograms to be accumulated for frames whose "care bit" regions are
identical. This is normally an unintentional side-effect. In order to avoid 
this possibility,  a switch will be provided to zero-out the "concern bit" 
region of the Lookup Key.  This zeroing out will be done after the alternate
key has been anded-in to the Lookup Key.   This means that the user will 
have three choices:

1. NS_LOOKUP_KEY_DISCONTIGUOUS: leave the old discontiguous hashing algorithm
   in effect.

2. NS_LOOKUP_KEY_CONTIGUOUS: enable the contiguous hashing algorithm without 
   zero-ing out the "concern bit" region. This means that all 32 bits can 
   potentially impact the hashing in an unintended way.

3. NS_LOOKUP_KEY_CONTIGUOUS_16BIT_MAX: enable the contiguous hashing 
   algorithm and zero-out the "concern bit" region.  This means that only the
   16 "care" bits will be used in the hashing algorithm and the possibility of
   unintended side-effects is eliminated.

Note: Generally when using alternate key, applications should use the macros
NS_LOOKUP_KEY_CONTIGUOUS_16BIT_MAX. This will limit the effective size of the
Lookup Key to a maximum of 16 bits, zeroing-out or disabling the upper 16 
"concern" bits on the receive port.
*/
typedef struct tagNSAlternateKeyHashConfig
{
   unsigned long ulKeyArrangement;     /* Determines whether the "care bits
                                       in the "Lookup Key" will be contiguous
                                       or discontiguous.
                                          NS_LOOKUP_KEY_DISCONTIGUOUS
                                          NS_LOOKUP_KEY_CONTIGUOUS_16BIT_MAX
                                          NS_LOOKUP_KEY_CONTIGUOUS
                                       */
   unsigned char ucReserved[16];       /* reserved for future use          */
} NSAlternateKeyHashConfig;
/****************************************************************************
 * NSAlternateKeyHashConfig Comment:
****************************************************************************/

#define NS_LOOKUP_KEY_DISCONTIGUOUS             0x01
#define NS_LOOKUP_KEY_CONTIGUOUS_16BIT_MAX      0x02
#define NS_LOOKUP_KEY_CONTIGUOUS                0x03


/****************************************************************************
* Structure: NSIPv6Config
* iType1:    NS_IPV6_CONFIG / NS_IPV6_CONFIG_INFO
* Function:  HTSetStructure / HTGetStructure
* NSIPv6Config Description: 
   Configures and query the IPv6 Protocol Stack
****************************************************************************/
/* NSIPv6Config Description:

  Valid values for uiRouterSolicitationInterval are from 10 to 30,000 
  milliseconds.
  
  Valid values for ucMaxRouterSolicitations are from 1 to 10 router 
  solicitations.

  Valid values for uiVLANRouterSolicitationGap are from 10 to 30,000 
  milliseconds

  Valid values for ucMaxDADNeighborSolicitations are from 0 to 10 Neighbor 
  Solicitations.

  Valid values for uiDADNeighborSolicitationsGap are from 10 to 30,000 
  milliseconds.

  Valid values for ulRetransmissionTime are from 10 to 30,000 milliseconds.

DAD is an abbreviation for Duplicate Address Detection.   

ucSAAInterfaceIDGenMode:
   USE_EUI_64: will form a EUI-64 based interface identifier from the 48-bit
               source MAC of an IPv6 protocol stream.
   USE_STREAM_ID: if specified, the interface ID will be
        [32-bit zero][4-bit hub][4-bit slot][8-bit port][16-bit stream index]
   USE_RANDOM: if specified, the interface ID will be 
    [32-bit pseudo random value][4-bit hub][4-bit slot][8-bit port]
                                                       [16-bit stream index]

ucSAAInterfaceIDBitValue:
   UL_COMPLEMENT: will complement the value of the universal/local bit when
                  forming the EUI-64 based interface identifier
   UL_SET_TO_ZERO: will always set the universal/local bit to zero
   UL_SET_TO_ONE: will set the universal/local bit to one
   UL_UNMODIFIED: will not alter the value of the universal/local bit


ucSourceAddressSelectByDestination:
   If set to TRUE, it will attempt to choose a source
   address that matches the scope of the destination address. 
   If set to FALSE, the address scope preferences defined in the preference 
   fields will be used. If an appropriate address cannot be selected, the 
   preference fields will also be used.

ucNextHopDeterminationMode
   For mode NEXT_HOP_SIMPLE_MODE: 
     + If the defaut router address is specified in the protocol stream 
       configuration, the Next Hop is the specific router.
     + If the default router address is not specified, the Next Hop is the 
       destination.

   For mode NEXT_HOP_RFC_COMPLIANT_MODE: 
      with prefix and router discovery, it will determine if the destination
      of a protocol stream is on-link using the obtained prefix information
      from Router Advertisement. 

*/

typedef struct tagNSIPv6Config {

   /* Interface ID generation */
   unsigned char ucSAAInterfaceIDGenMode;
                                          /* Specifies the method to generate
                                          the IPv6 interface identifier for 
                                          use in Stateless Address 
                                          Auto-configuration. This field is 
                                          not applicable to POS.

                                          Values: 
                                             USE_EUI_64
                                             USE_STREAM_ID
                                             USE_RANDOM                    

                                          Default value: USE_EUI_64        */

   unsigned char ucSAAInterfaceIDBitValue;/* The value of the universal/local
                                          bit in the IPv6 interface 
                                          identifier. This is only applicable
                                          if the USE_EUI_64 option is selected
                                          for ucSAAInterfaceIdentifier. 
                                          This field is not applicable to POS.

                                          Values: 
                                             UL_COMPLEMENT
                                             UL_SET_TO_ZERO
                                             UL_SET_TO_ONE
                                             UL_UNMODIFIED                 

                                          Default value: UL_COMPLEMENT     */

   /* Router Discovery */
   unsigned char ucNextHopDeterminationMode;
                                           /* Specifiy the mode to use the
                                             Next Hop Determination 
                                             Possible values are:
                                               NEXT_HOP_SIMPLE_MODE          
                                               NEXT_HOP_RFC_COMPLIANT_MODE 

                                             Default value: 
                                               NEXT_HOP_SIMPLE_MODE        */

   unsigned char  ucVLANRouterSolicitationEnable;
                                          /* Enables or disables transmission
                                             of a router solicitation per 
                                             unique VLAN as determined by the
                                             VLAN ID from the protocol stream
                                             configuration.

                                             Default value: 1              
                                             */

   unsigned char  ucSendNeighborAdvertisementEnable;
                                          /* Enables or disables 
                                             transmission of a Neighbor 
                                             Advertisement for a protocol 
                                             stream when it receives a 
                                             Neighbor Advertisement in 
                                             response to a Neighbor 
                                             Solicitation that it has sent.

                                             Default value: 0              */

   unsigned short uiRouterSolicitationInterval; 
                                          /* Specifies in milliseconds
                                             the minimum time interval 
                                             between transmissions of Router
                                             Solicitations. This specifies 
                                             also the time after the 
                                             transmission of the last Router
                                             Solicitation that the 
                                             implementation will wait for 
                                             a Router Advertisement.    

                                             Default value: 4,000 
                                                            milliseconds
                                             Valid values: 10 to 30,000 
                                             milliseconds. 
                                             
                                             Resolution is 10
                                             miliseconds. If a specified 
                                             value is not an integer 
                                             multiple of 10 miliseconds,
                                             the number will be rounded down
                                             to closest integer multiple */

   unsigned char ucMaxRouterSolicitations; /* Specifies the maximum 
                                              number of router 
                                              solicitations 

                                             Default: 3 router solicitations
                                             Valid values: 1 to 10 router 
                                                      solicitations.       */

   unsigned short uiVLANRouterSolicitationGap;/* Specifies in milliseconds 
                                             the minimum time interval 
                                             between transmissions of Router
                                             Solicitations with different 
                                             VLAN tags. 
   
                                             This value is only used if the 
                                             ucVLANRouterSolicitationEnable
                                             field is set to 1.               

                                             Default value: 10 milliseconds
                                             Valid values: 10 to 30,000 
                                                            milliseconds
                                             Resolution is 10 miliseconds. */

   unsigned char ucEnableSourceStreamAddressSelection;
                                           /* Specifies whether to perform 
                                             source stream address selection 
                                             when Stateless Address 
                                             Autoconfiguration is used.
                                             
                                             If set to 0, the source IPv6 
                                             address specifies in the protocol 
                                             stream configuration will be used
                                             for frame generated by the 
                                             protocol streams.

                                             Default value: 1               */

   /* Stateless Address Autoconfiguration */
   unsigned char ucMaxDADNeighborSolicitations;
                                          /* Specifies the maximum Neighbor
                                             Solicitations transmitted for 
                                             Duplicate Address Detection 
                                             (DAD) for each tentative address.
                                             A value of zero disables DAD. 

                                             This field is not applicable to 
                                             POS.

                                             Default Value: 1 as specified by
                                                            RFC 2462
                                             Valid values: 0 to 10 Neighbor 
                                                            Solicitations. */
                                 
   unsigned char  ucVerifyLinkLocalEnable;/* Specifies whether or not to only
                                             verify the link local addresses

                                             Default value: 0              */
   unsigned short uiDADNeighborSolicitationsGap;
                                          /* Specifies in milliseconds the 
                                             minimum interval between 
                                             transmissions of Neighbor 
                                             Solicitations for different 
                                             tentative addresses.

                                             This field is not applicable to 
                                             POS.

                                             Default value: 10 milliseconds
                                             Valid values: 10 to 30,000 
                                                             milliseconds. 
                                             Resolution is 10 miliseconds. */

   unsigned long  ulRetransmissionTime;   /* Specifies in milliseconds the 
                                             interval between retransmissions
                                             of Neighbor Solicitations for a 
                                             tentative address. 

                                             Default value:1000 milliseconds
                                             Valid values: 10 to 30,000 
                                                            milliseconds.  
                                             Resolution is 10 miliseconds. */

   /* Source address selection */
   unsigned char  ucSourceAddressFirstChoice;
                                          /*
                                             These fields allow specification 
                                             of the preference for address 
                                             selection. 

                                          Values: 
                                            SOURCE_ADDRESS_LINK_LOCAL_UNICAST
                                            SOURCE_ADDRESS_SITE_LOCAL_UNICAST
                                            SOURCE_ADDRESS_GLOBAL_UNICAST

                                          Default values:
                                          ucSourceAddressFirstChoice: 
                                            SOURCE_ADDRESS_GLOBAL_UNICAST

                                          ucSourceAddressSecondChoice: 
                                            SOURCE_ADDRESS_SITE_LOCAL_UNICAST

                                          ucSourceAddressThirdChoice: 
                                            SOURCE_ADDRESS_LINK_LOCAL_UNICAST
                                                                           */
   unsigned char  ucSourceAddressSecondChoice;
                                          /* See ucSourceAddressFirstChoice*/
   unsigned char  ucSourceAddressThirdChoice;
                                          /* See ucSourceAddressFirstChoice*/

   unsigned char  ucSourceAddressSelectByDestination;
                                          /* The field indicates whether or 
                                             not to attempt to select a 
                                             source address based on the 
                                             scope of the destination 
                                             address.

                                             Default value: 0              */

   unsigned char  ucReserved[64];         /* Reserved for future use       */
} NSIPv6Config;
/****************************************************************************
 * NSIPv6Config Comment:
****************************************************************************/

/* defined constants for ucSAAInterfaceIDGenMode */
#define USE_EUI_64      0x00
#define USE_STREAM_ID   0x01
#define USE_RANDOM      0x02

/* defined constants for ucSAAInterfaceIDBitValue */
#define UL_COMPLEMENT   0x00
#define UL_SET_TO_ZERO  0x01
#define UL_SET_TO_ONE   0x02
#define UL_UNMODIFIED   0x03

/* defined constants for ucSourceAddressFirstChoice */
#define SOURCE_ADDRESS_LINK_LOCAL_UNICAST    0x01
#define SOURCE_ADDRESS_SITE_LOCAL_UNICAST    0x02
#define SOURCE_ADDRESS_GLOBAL_UNICAST        0x03

/* defined constants for ucNextHopDeterminationMode */
#define NEXT_HOP_SIMPLE_MODE              0
#define NEXT_HOP_RFC_COMPLIANT_MODE       1


/****************************************************************************
* Structure: NSIPv6Control
* iType1:    NS_IPV6_CONTROL
* Function:  HTSetStructure 
* NSIPv6Control Description: 
     Controls the IPv6 stack for protocol streams with respect to Router 
     Discovery, Prefix Discovery, Next-Hop Determination and Address 
     Autoconfiguration
****************************************************************************/
/* NSIPv6Control Description:

 Description of ucAction values:
1. ENABLE_ROUTER_DISCOVERY: This action enables processing of router 
      advertisements and initiates the transmission of Router Solicitations.
      This also clears any stored prefix information.
2. DISABLE_ROUTER_DISCOVERY: This action disables processing of router 
      advertisements and halts impending retransmission of Router 
      Solicitations.
3. START_ADDRESS_AUTOCONFIGURATION: This action initiates stateless address
      autoconfiguration for the specified streams. If a stream is not IPv6, 
      it is skipped but is included in the stream_count. DAD will be 
      initiated for the tentative address, if enabled. This also clears any
      configured addresses for protocol streams.
4. STOP_ADDRESS_AUTOCONFIGURATION: This action halts any pending 
      retransmission of Neighbor Solicitations for DAD and the formation of 
      tentative address for protocol streams. If any addresses have been 
      configured for the stream, they will remain configured. However, source
      address selection will not be performed.
5. START_NEXT_HOP_DETERMINATION: This action initiates on-link/off-link 
      processing and the selection of the next-hop for the destinations of 
      IPv6 protocol streams. This also clears the stored results of next-hop 
      determination.
6. STOP_NEXT_HOP_DETERMINATION: This action halts the execution of Next-Hop
      Determination. 
7. CLEAR_STACK_ERRORS: This action clears the error fields in the stack status.
      It will only clear the following errors in the structure NSIPv6StatusInfo:  
      ucNeighborSolicitationError , ucNeighborAdvertisementError, 
      ucRouterAdvertisementError, ucGeneralError.
      It will not clear the following errors in the same structure:
      uiGenericStackError, uiRouterDiscoveryError, 
      uiAddressAutoConfigurationError, uiNextHopError      
8. RESET_STACK: This action resets the stack configuration to the default 
      values and clears any stored results for Router Discovery, 
      Next-Hop Determination, and Stateless Address Autoconfiguration. 
      It will also halt any active tasks and clear any pending commands. 
*/
typedef struct tagNSIPv6Control {
   unsigned long  ulAction;            /* Specifies the action to take upon 
                                          reception of this message. 
                                             ENABLE_ROUTER_DISCOVERY
                                             DISABLE_ROUTER_DISCOVERY
                                             START_ADDRESS_AUTOCONFIGURATION
                                             STOP_ADDRESS_AUTOCONFIGURATION
                                             START_NEXT_HOP_DETERMINATION
                                             STOP_NEXT_HOP_DETERMINATION        
                                             CLEAR_STACK_ERRORS
                                             RESET_STACK                    */
   unsigned char  ucReserved[32];       /* Reserved for future use          */
} NSIPv6Control;
/****************************************************************************
 * NSIPv6Control Comment:

****************************************************************************/
#define ENABLE_ROUTER_DISCOVERY           0x00000001
#define DISABLE_ROUTER_DISCOVERY          0x00000002
#define START_ADDRESS_AUTOCONFIGURATION   0x00000004
#define STOP_ADDRESS_AUTOCONFIGURATION    0x00000008
#define START_NEXT_HOP_DETERMINATION      0x00000010
#define STOP_NEXT_HOP_DETERMINATION       0x00000020
#define CLEAR_STACK_ERRORS                0x40000000
#define RESET_STACK                       0x80000000

/****************************************************************************
* Structure: NSIPv6StatusInfo
* iType1:    NS_IPV6_STATUS_INFO
* Function:  HTGetStructure 
* NSIPv6StatusInfo Description: 
      This message retrieves the status of the IPv6 stack.
****************************************************************************/
/* NSIPv6StatusInfo Description:

 Description of ulStatus values:
1. ROUTER_DISCOVERY_RUNNING: This bit indicates that the implementation is in
      the process of transmitting Router Solicitations and waiting for a 
      Router Advertisement.
2. ROUTER_DISCOVERY_COMPLETED: This bit indicates that the implementation 
      either has received a Router Advertisement, or has not received a 
      Router Advertisment and there are no more retransmissions of Router 
      Solicitations.
3. ROUTER_DISCOVERY_QUEUED: This bit indicates that a command to enable 
      Router Discovery was received but its execution is pending the 
      completion of a current task.
4. ROUTER_DISCOVERY_ENABLED: This bit indicates that a router discovery 
      is enabled.
5. ADDRESS_AUTOCONFIG_RUNNING: This bit indicates that the implementation is
      in the process of forming and assigning addresses to the protocol 
      streams and is performing DAD, if enabled.
6. ADDRESS_AUTOCONFIG_COMPLETED: This bit indicates that DAD, if enabled, has
      been completed for all tentative address and any unique tentative 
      addresses have been assigned to the protocol stream. It also indicates
      that source address selection has been performed.
7. ADDRESS_AUTOCONFIG_QUEUED: This bit indicates that a command to start 
      Stateless Address Autoconfiguration was received but its execution is
      pending the completion of a current task.
8. NEXT_HOP_RUNNING: This bit indicates that the implementation is in the 
      process of performing Next-Hop Determination, if enabled.
9. NEXT_HOP_COMPLETED: This bit indicates that Next-Hop Determination, if 
      enabled, has been completed for all protocol streams.
10. NEXT_HOP_QUEUED: This bit indicates that a command to start Next-Hop 
      Determination was received but its execution is pending the completion
      of a current task.
11. SOURCE_ADDRESS_SELECT_FAILED: This bit indicates that the source address
      for at least an IPv6 protocol stream could not be selected.
12. SOURCE_ADDRESS_SELECT_PASSED: This bit indicates that the source address
      for all IPv6 protocol streams has been performed successfully.

All expected times are in units of milliseconds.
For all expected time fields, a value of 0xFFFFFFFF indicates that the 
expected execution time has not been calculated yet. This may occur if the 
card receives a command to retrieve the status before it has been able to 
obtain all information needed to calculate the expected time. 
The expected time fields are set to zero upon completion of the associated 
task.

  For those fields below:
  ucNeighborSolicitationError,ucNeighborAdvertisementError
  ucRouterAdvertisementError, ucGeneralError
  Once an error is detected, the appropriate field is set until cleared by
  CLEAR_STACK_ERRORS or RESET_STACK action by NS_IPV6_CONTROL command.

  uiGenericStackError, uiRouterDiscoveryError, 
  uiAddressAutoConfigurationError, and uiNextHopError are only cleared by
  RESET_STACK action by NS_IPV6_CONTROL command.   
*/
typedef struct tagNSIPv6StatusInfo {
   U64            u64Status;        /* This field indicates the status of the
                                       stack. This is a bit field for lower 
                                       32 bits.         

                                       Valid values:
                                          ROUTER_DISCOVERY_RUNNING
                                          ROUTER_DISCOVERY_COMPLETED
                                          ROUTER_DISCOVERY_QUEUED
                                          ROUTER_DISCOVERY_ENABLED
                                          ADDRESS_AUTOCONFIG_RUNNING
                                          ADDRESS_AUTOCONFIG_COMPLETED
                                          ADDRESS_AUTOCONFIG_QUEUED
                                          NEXT_HOP_RUNNING
                                          NEXT_HOP_COMPLETED
                                          NEXT_HOP_QUEUED
                                          SOURCE_ADDRESS_SELECT_FAILED
                                          SOURCE_ADDRESS_SELECT_PASSED     */
   unsigned long  ulRouterDiscoveryExpectedTime;
                                    /* This indicates the expected execution
                                       time for Router Discovery. 
                                       Applications can use this to determine
                                       when to poll again for the status of 
                                       Router Discovery.                   */
   unsigned long  ulAddressAutoConfigExpectedTime;
                                    /* This indicates the expected execution
                                       time for Address Autoconfiguration. 
                                       Applications can use this to determine
                                       when to poll again for the status of 
                                       Address Autoconfiguration.          */
   unsigned long  ulNextHopExpectedTime;
                                    /* This indicates the expected execution
                                       time for Next-Hop Determination. 
                                       Applications can use this to determine
                                       when to poll again for the status of 
                                       Next-Hop Determination.             */
   unsigned char  ucNeighborSolicitationError;
                                    /* This indicates detected errors in
                                       Neighbor Solicitation packets.
                                       
                                       Valid values:
                                          INVALID_ICMP_LENGTH
                                          INVALID_DESTINATION_ADDRESS
                                          INVALID_SOURCE_LINK_LAYER_OPTION
                                          TARGET_IS_MULTICAST_ADDRESS   */

   unsigned char  ucNeighborAdvertisementError;
                                    /* This indicates detected errors in 
                                       Neighbor Adverstisement packets.

                                       Valid values:
                                          INVALID_ICMP_LENGTH
                                          INVALID_SOLICITED_FLAG
                                          TARGET_IS_MULTICAST_ADDRESS*/

   unsigned char  ucRouterAdvertisementError;
                                    /* This indictes detected errors in
                                       Router Advertisement packets.

                                       Valid values:
                                          INVALID_ICMP_LENGTH
                                          INVALID_SOURCE_ADDRESS     */

   unsigned char  ucGeneralError;   /* This indicates detected errors in
                                       Neighbor Discovery packets.

                                       Valid values:
                                          MULTICAST_SOURCE_ADDRESS
                                          INVALID_IP_HOP_LIMIT
                                          INVALID_ICMP_CODE
                                          OPTION_LENGTH_IS_ZERO      */

   unsigned short uiGenericStackError; /* This indicates generic stack 
                                       error. That is not related to router
                                       discovery, stateless address 
                                       autoconfiguration and next-hop 
                                       determination.                 */

   unsigned short uiRouterDiscoveryError; /* This indicates error during 
                                       router discovery               */

   unsigned short uiAddressAutoConfigurationError;
                                       /* This indicates error during 
                                       stateless address autoconfiguration */

   unsigned short uiNextHopError;      /* This indicates error during 
                                       stateless address autoconfiguration */

   unsigned char  ucReserved[64];   /* Reserved for future use             */
} NSIPv6StatusInfo;
/****************************************************************************
 * NSIPv6StatusInfo Comment:
****************************************************************************/
#define ROUTER_DISCOVERY_RUNNING       0x00000001
#define ROUTER_DISCOVERY_COMPLETED     0x00000002
#define ROUTER_DISCOVERY_QUEUED        0x00000004
#define ROUTER_DISCOVERY_ENABLED       0x00000008
#define ADDRESS_AUTOCONFIG_RUNNING     0x00000010
#define ADDRESS_AUTOCONFIG_COMPLETED   0x00000020
#define ADDRESS_AUTOCONFIG_QUEUED      0x00000040
#define NEXT_HOP_RUNNING               0x00000080
#define NEXT_HOP_COMPLETED             0x00000100
#define NEXT_HOP_QUEUED                0x00000200
#define SOURCE_ADDRESS_SELECT_FAILED   0x00000400
#define SOURCE_ADDRESS_SELECT_PASSED   0x00000800

/* Defines constants for ucNeighborSolicitationError */
#define INVALID_ICMP_LENGTH               0x01
#define INVALID_DESTINATION_ADDRESS       0x02
#define INVALID_SOURCE_LINK_LAYER_OPTION  0x04
#define TARGET_IS_MULTICAST_ADDRESS       0x08

/* Defines constants for ucNeighborAdvertisementError */
#define INVALID_ICMP_LENGTH               0x01
#define INVALID_SOLICITED_FLAG            0x02
#define TARGET_IS_MULTICAST_ADDRESS       0x08

/* Defines constants for ucRouterAdvertisementError */
#define INVALID_ICMP_LENGTH               0x01
#define INVALID_SOURCE_ADDRESS            0x02

/* Defines constants for ucGeneralError */
#define MULTICAST_SOURCE_ADDRESS          0x01
#define INVALID_IP_HOP_LIMIT              0x02
#define INVALID_ICMP_CODE                 0x04
#define OPTION_LENGTH_IS_ZERO             0x08

/****************************************************************************
* Structure: NSIPv6RouterDiscoveryCountInfo
* iType1:    NS_IPV6_ROUTER_DISCOVERY_COUNT_INFO
* Function:  HTGetStructure 
* NSIPv6RouterDiscoveryCountInfo Description: 
      Retrieve the number of router discovery information obtained from 
      received router advertisements  
****************************************************************************/
/* NSIPv6RouterDiscoveryCountInfo Description:
*/
typedef struct tagNSIPv6RouterDiscoveryCountInfo {
   unsigned long ulCount;    /* The number of router discovery information */
   unsigned char ucReserved[16];    /* Reserved for future use             */
} NSIPv6RouterDiscoveryCountInfo;
/****************************************************************************
 * NSIPv6RouterDiscoveryCountInfo Comment:

****************************************************************************/

/****************************************************************************
* Structure: NSIPv6RouterDiscoveryInfo
* iType1:    NS_IPV6_ROUTER_DISCOVERY_INFO
* Function:  HTGetStructure 
* NSIPv6RouterDiscoveryInfo Description: 
   This message retrieves information obtained from Router Advertisements 
   excluding prefix information.
****************************************************************************/
/* NSIPv6RouterDiscoveryInfo Description:

  Use NS_IPV6_ROUTER_DISCOVERY_COUNT_INFO message to query number of router
  discovery stored and pass the array of this structure to query the router
  discovery information.

  If no Router Advertisement was received, all fields will be set to zero. 
  If the MTU option is not present, the mtu field will be set to zero. 
  If any field is unspecified by the router, that field will be set to zero.
*/
typedef struct tagNSIPv6RouterDiscoveryInfo {
   unsigned char  ucRouterIPAddress[16]; /* The IP address of the router from
                                            the router advertisement.      */
   unsigned char  ucCurrentHopLimit;     /* The current hop limit value 
                                            specified in the router 
                                            advertisement.                 */
   unsigned char  ucFlags;               /* The values of the "managed 
                                            address configuration" flag and 
                                            the other stateful configuration
                                            flag. 
                                            Possible values are:
                                               MANAGED_ADDRESS_CONFIGURATION 
                                               OTHER_STATEFUL_CONFIGURATION
                                            This field is a bit field.     */
   unsigned short uiRouterLifetime;      /* The value of the router lifetime
                                            field from the router 
                                            advertisement in seconds.     */
   unsigned char ucEnableVlan;           /* Indicates if there is a VLAN ID
                                            is associated with.
                                            Valid values: 0 or 1           */
   unsigned char ucVLANPri;              /* VLAN Priority                  
                                            If there is no associated VLAN ID
                                            this will be set to 0          */
   unsigned char ucVLANCfi;              /* VLAN CFI bit                   
                                            If there is no associated VLAN ID
                                            this will be set to 0          */
   unsigned short uiVlanID;              /* The associated 12-bit VLAN ID 
                                            for this router. 
                                            If there is no associated VLAN ID
                                            ,this will be set to 0x00      */
   unsigned long  ulReachableTime;       /* The value of the reachable time
                                           field from the router 
                                            advertisement in milliseconds. */
   unsigned long  ulRetransmissionTime;  /* The value of the retransmission 
                                            time field from the router 
                                            advertisement in milliseconds. */
   unsigned long  ulMTU;                 /* The value of the Maximum 
                                            Transmission Unit in the MTU 
                                            option, if present, in the Router
                                            Advertisement in bytes.        */
   unsigned long ulRouterIndex;          /* Use this value with NS_IPV6_ROUTER_PREFIX_INFO
                                            to retrieve prefix information for this router.
                                            Valid values: 0x0001 to 0xFFFF */
   unsigned short uiPrefixCount;         /* This value indicates the number of prefix 
                                            information that is available for the router.
                                            Use this value as the size of the array of 
                                            prefix structures to pass to 
                                            NS_IPV6_ROUTER_PREFIX_INFO. */
   unsigned char ucReserved[16];         /* Reserved for future use        */
} NSIPv6RouterDiscoveryInfo;
/****************************************************************************
 * NSIPv6RouterDiscoveryInfo Comment:
****************************************************************************/
#define MANAGED_ADDRESS_CONFIGURATION   0x80
#define OTHER_STATEFUL_CONFIGURATION    0x40

/****************************************************************************
* Structure: NSIPv6RouterPrefixCountInfo
* iType1:    NS_IPV6_ROUTER_PREFIX_COUNT_INFO
* Function:  HTGetStructure 
* NSIPv6RouterPrefixCountInfo Description: 
      To retrieve the number of prefix information per port obtained from 
      received router advertisements 
****************************************************************************/
/* NSIPv6RouterPrefixCountInfo Description:
*/
typedef struct tagNSIPv6RouterPrefixCountInfo {
   unsigned long ulCount;           /* The number of prefix information per 
                                       port obtained from received router 
                                       advertisements.                     */
   unsigned char ucReserved[16];    /* Reserved for future use             */
} NSIPv6RouterPrefixCountInfo;
/****************************************************************************
 * NSIPv6RouterPrefixCountInfo Comment:

****************************************************************************/


/****************************************************************************
* Structure: NSIPv6RouterPrefixInfo
* iType1:    NS_IPV6_ROUTER_PREFIX_INFO
* Function:  HTGetStructure 
* NSIPv6RouterPrefixInfo Description: 
      This message retrieves prefix information obtained from received Router 
      Advertisements. Use iType2 for the Router Index and iType3 for
      the number of prefix retrieved.
****************************************************************************/
/* NSIPv6RouterPrefixInfo Description:

This command can be sent with an array of structures.

Use uiPrefixCount of the structure NSIPv6RouterDiscoveryInfo for iType3.

Note for ulRouterIndex:

  This message retrieves prefix information obtained received Router 
   Advertisements

   Valid values for uiVlanId is from 0x0000 to 0x0FFF, and 0xFFFF.
   Valid values for ucPrefixLength is from 0 to 128.
   Valid values for ulLifetime is as defined in RFC 2461.
   Valid values for ulPreferredLifetime is as defined in RFC 2461.
*/
typedef struct tagNSIPv6RouterPrefixInfo {
   unsigned long ulRouterIndex;     /* Output.
                                       The router index of the router to 
                                       which this prefix is associated     
                                       Possible values are:
                                          0x0000 to 0xFFFF                 */

   unsigned short uiVlanID;         /* Specifies the associated 12-bit VLAN
                                       ID for this prefix. 
                                       If there is no associated VLAN ID, 
                                       this will be set to 0xFFFF 
                                                                           */
   unsigned char  ucPrefixLength;   /* The number of leading bits in the 
                                       prefix that are valid               */
   unsigned char  ucFlags;          /* The values of the on-link flag and 
                                       autonomous address-configuration flag.
                                       Possible values are:
                                          ON_LINK
                                          AUTONOMOUS_ADDRESS_CONFIG*/
   unsigned long  ulLifetime;       /* The valid lifetime field.           */

   unsigned long  ulPreferredLifetime; /* The preferred lifetime field.    */
   unsigned char  ucPrefix[16];     /* The prefix in hexadecimal. Any bits 
                                       beyond the prefix length will be set 
                                       to zero.                            */
   unsigned char ucReserved[64];    /* Reserved for future use             */
} NSIPv6RouterPrefixInfo;
/****************************************************************************
 * NSIPv6RouterPrefixInfo Comment:

****************************************************************************/
#define ON_LINK                      0x80
#define AUTONOMOUS_ADDRESS_CONFIG    0x40

/****************************************************************************
* Structure: NSIPv6StatelessAddressCountInfo
* iType1:    NS_IPV6_STATELESS_ADDRESS_COUNT_INFO
* Function:  HTGetStructure 
* NSIPv6StatelessAddressCountInfo Description: 
      To retrieve number configured address currently stored.  
****************************************************************************/
/* NSIPv6StatelessAddressCountInfo Description:
*/
typedef struct tagNSIPv6StatelessAddressCountInfo {
   unsigned long ulCount;   /* The number of configured address currently 
                              stored */
   unsigned char ucReserved[16];    /* Reserved for future use             */
} NSIPv6StatelessAddressCountInfo;
/****************************************************************************
 * NSIPv6StatelessAddressCountInfo Comment:

****************************************************************************/


/****************************************************************************
* Structure: NSIPv6StatelessAddressInfo
* iType1:    NS_IPV6_STATELESS_ADDRESS_INFO
* Function:  HTGetStructure 
* NSIPv6StatelessAddressInfo Description: 
      Retrieves the configured addresses for protocol streams. 
****************************************************************************/
/* NSIPv6StatelessAddressInfo Description:

DAD is an abbreviation for Duplicate Address Detection.

Use ulCount of NSIPv6STatlessAddressCountInfo as input for uiStreamCount of 
this structure.

 Description of ucStatus values:
1. STREAM_SOURCE_ADDRESS: This indicates that this address was chosen to be 
      the source IPv6 address for frames generated by the protocol stream.
2. DAD_FAILED: This bit indicates that Duplicate Address Detection for this
      address failed and this protocol stream will not respond to Neighbor 
      Solicitations targeting this address.
3. DAD_SUCCESSFUL: This bit indicates that Duplicate Address Detection for 
      this address succeeded and the protocol stream will respond to Neighbor
      Solicitations targeting this address. If DAD is disabled, this bit will
      be set and the protocol stream will respond to Neighbor Solicitations 
      targeting this address.   
*/
typedef struct tagNSIPv6StatelessAddressEntry {
   unsigned short uiStreamIndex;    /* Output - the stream associated with 
                                       this address                        */
   unsigned char  ucStatus;         /* Output - the status of this address
                                          STREAM_SOURCE_ADDRESS
                                          DAD_FAILED
                                          DAD_SUCCESSFUL                   */
   unsigned char  ucIPV6Address[16];/* Output - the configured IPv6 address*/
   unsigned char ucReserved;        /* Reserved for future use             */
} NSIPv6StatelessAddressEntry;
/****************************************************************************
 * NSIPv6StatelessAddressEntry Comment:
****************************************************************************/
typedef struct tagNSIPv6StatelessAddressInfo {
   unsigned short uiStreamIndex;     /* Input - indicates the start stream 
                                        associated with this address       */
   unsigned short uiStreamCount;     /* Input - the number of stream to 
                                        retrieved configured address 
                                        information.                       */
   unsigned char  ucRequestedStatus; /* Input - indicates the status of this 
                                        address to be retrieved.
                                        It is bit-wise AND operation between
                                        the status of the address and this 
                                        status.
                                        
                                        Possible combination of these values 
                                        are:
                                             STREAM_SOURCE_ADDRESS
                                             DAD_FAILED
                                             DAD_SUCCESSFUL                */
   unsigned short uiCount;           /* Output - the number of configured 
                                       address structures are in this 
                                       response.                           */
   unsigned char  ucReserved;        /* Reserved */
   NSIPv6StatelessAddressEntry StatelessAddress[512];
} NSIPv6StatelessAddressInfo;
/****************************************************************************
 * NSIPv6StatelessAddressInfo Comment:
****************************************************************************/

#define STREAM_SOURCE_ADDRESS    0x01
#define DAD_FAILED               0x02
#define DAD_SUCCESSFUL           0x04

/****************************************************************************
* Structure: NSSignatureDetectMode
* iType1:    NS_SIGNATURE_DETECT_MODE / NS_SIGNATURE_DETECT_MODE_INFO
* Function:  HTSetStructure /  HTGetStructure
* NSSignatureDetectMode Description: 
****************************************************************************/
/* NSSignatureDetectMode Description:
This command provides the ability to detect the signature field based upon the IP
length(SIGNATURE_IP_LENGTH_MODE) and not just the overall frame size(SIGNATURE_NORMAL_MODE).
Note that this command applies for the receiving side only.

The SIGNATURE_IP_LENGTH_MODE mode is required in the case where a POS module generates
a mininum legal size frame(44 bytes) which will be padded out to 60 bytes(excluding CRC)
before reaching an Ethernet module.  This will result in the signature field
appearing after the IP payload and not as the last 18 bytes of the frame when
received by the Ethernet module.  As a result, the histogram test data would be invalid.

This feature includes:
   + Proper detection of signature field when one or 
     more additional protocol header and/or tags precede IP header ( for 
     example, VLAN, MPLS tags, PPP/PPPoE header). This excludes tunneling
     of IPV4 over IPV6.
   + Proper detection of signature field implies correct IP length field, which
     then sets a requirement that IP header checksum be verified on all 
     received frames. If the verification fails, the frame is dropped without 
     any SmartMetrics processing.

IPV6 and IPv4 fragmentation and tunneling of IPV6 over IPV4 (and vice-versa) is
currently not supported.

For ucSignatureMode:
   SIGNATURE_NORMAL_MODE: this traditional mode assumes right-aligned 
                          signature field.   
   SIGNATURE_IP_LENGTH_MODE: this mode will locate the signature field based
                             on IP length ( not overall frame size ).
*/
typedef struct tagNSSignatureDetectMode {
   unsigned char  ucMode;           /* Signature detection mode 
                                       Values:
                                          SIGNATURE_NORMAL_MODE
                                          SIGNATURE_IP_LENGTH_MODE         */
   unsigned char ucReserved[15];    /* Reserved for future use             */
} NSSignatureDetectMode;
/****************************************************************************
 * NSSignatureDetectMode Comment:
****************************************************************************/
#define SIGNATURE_NORMAL_MODE            0
#define SIGNATURE_IP_LENGTH_MODE         1

/****************************************************************************
* Structure: NSTransmitPaddingMode
* iType1:    NS_TRANSMIT_PADDING_MODE / NS_TRANSMIT_PADDING_MODE_INFO
* Function:  HTSetStructure  /  HTGetStructure
* NSTransmitPaddingMode Description: 
****************************************************************************/
/* NSTransmitPaddingMode Description:

This command provides the ability to place the signature field at the end of
the IP payload and pad the rest of the frame with zeros up to the minimum legal
frame length(60 bytes not including CRC).  The receiving module will need to be
set to IP length signature detection mode using the NS_SIGNATURE_DETECT_MODE
command.

This mode is required for correct detection of the signature field when transmitting
from Ethernet to POS.  The frame generated by an Ethernet interface has IP total length
set to value that does not include the signature field, and when such frame passes through
a router that converts it to POS, the router honors only the IP specified length,
resulting in a truncated signature field.  Using this mode will fix this issue.
  
This command applies for the Ethernet TeraMetrics modules only.
*/

typedef struct tagNSTransmitPaddingMode {
   unsigned char  ucEnable;           /* Enable or disable the padding option
                                      on transmit frames that will satisfy the 
                                      legal frame size.
                                       Values:
                                          TRUE   = 1 
                                          FALSE  = 0 (default)             */
   unsigned char ucReserved[15];    /* Reserved for future use             */
} NSTransmitPaddingMode;
/****************************************************************************
 * NSTransmitPaddingMode Comment:
****************************************************************************/


/****************************************************************************
* Structure: NSIPv6IPv4AddressMapInfo
* iType1:    NS_IPV6_IPV4_ADDRESS_MAP_INFO
* Function:  HTGetStructure 
* NSIPv6IPv4AddressMapInfo Description: 
****************************************************************************/
/* NSIPv6IPv4AddressMapInfo Description:

uiMapUsage specifies the "direction" of address translation. For example, 
if GET_IPV6_FROM_IPV4 is specified in this field, the card will use the 
address map to obtain the correct IPv6 address from the specified IPv4 
address
*/
typedef struct tagNSIPv6IPv4AddressMapInfo {
   unsigned short	uiIndex;                /* Output - the returned index to 
                                             reference this address map.   */
	unsigned char  ucIPv6AddressBase[16];  /* Input - specifies the base 
                                             address for the IPv6 address 
                                             range for this address mapping.
                                          */
	unsigned char  ucIPv6AddressStep[16];  /* Input - specifies the step value
                                             used when generating IPv6 
                                             address in this range.        */
	unsigned char  ucIPv4AddressBase[4];   /* Input - specifies the base 
                                             address for the IPv4 address 
                                             range for this address map.   */
	unsigned char  ucIPv4AddressStep[4];   /* Input - specifies the step 
                                             value used when generating IPv4
                                             address in this range.        */
	unsigned short uiIPv6AddressCount;     /* Input - specifies the number of
                                             IPv6 addresses in this address 
                                             map.                          */
	unsigned short uiIPv4AddressCount;     /* Input - specifies the number of
                                             IPv4 addresses in this address 
                                             map.                          */
	unsigned short uiMapUsage;             /* Input - specifies how this 
                                             address map is to be used. 
                                             This field is a bit field. 
                                             Possible values are:
                                                GET_IPV4_FROM_IPV6
                                                GET_IPV6_FROM_IPV4         */
   unsigned char  ucReserved[64];         /* Reserved for future use       */
} NSIPv6IPv4AddressMapInfo;
/****************************************************************************
 * NSIPv6IPv4AddressMapInfo Comment:
****************************************************************************/
#define GET_IPV4_FROM_IPV6		0x0001
#define GET_IPV6_FROM_IPV4		0x0002

/****************************************************************************
* Structure: NSIPv6IPv4AddressMapDelete
* iType1:    NS_IPV6_IPV4_ADDRESS_MAP_DELETE
* Function:  HTSetStructure 
* NSIPv6IPv4AddressMapDelete Description: 
****************************************************************************/
/* NSIPv6IPv4AddressMapDelete Description:

For uiIndex:
   The value used is the value returned in the index field in the 
   NS_IPV6_IPV4_ADDRESS_MAP_INFO message of NSIPv6IPv4AddressMapInfo 
   structure.
*/
typedef struct tagNSIPv6IPv4AddressMapDelete {
   unsigned short	uiIndex;                /* Specifies the index of the 
                                             address map to delete.        */
   unsigned char  ucReserved[16];         /* Reserved for future use       */
} NSIPv6IPv4AddressMapDelete;
/****************************************************************************
 * NSIPv6IPv4AddressMapDelete Comment:
****************************************************************************/


/****************************************************************************
* Structure: NSIPv6IPv4Translation
* iType1:    NS_IPV6_IPV4_TRANSLATION
* Function:  HTSetStructure 
* NSIPv6IPv4Translation Description: 
****************************************************************************/
/* NSIPv6IPv4Translation Description:

  This command can be sent with an array of structures.

*/
typedef struct tagNSIPv6IPv4Translation {
   unsigned long   ulStreamIndex;      /* Stream index; when multiple 
                                          structures are used, the stream
                                          indices do not have to be	
                                          sequential.                      */
   unsigned short  uiDestinationType;  /* Indicates the value type. 
                                          Possible values are:
                                             DESTINATION_IPV4
                                             DESTINATION_IPV6              */ 
	unsigned char   ucIPAddresss[16];   /* Specifies the value of the 
                                          destination. For the currently 
                                          supported types, the value is 
                                          either an IPv4 address or an IPv6 
                                          address.    
                                          
                                          if uiDestinationType set to  
                                          DESTINATION_IPV4, then 4 bytes are 
                                          used.
                                          if uiDestinationType set to  
                                          DESTINATION_IPV6, then 16 bytes are
                                          used.
                                          */
   unsigned char  ucReserved[16];      /* Reserved for future use       */
} NSIPv6IPv4Translation;
/****************************************************************************
 * NSIPv6IPv4Translation Comment:
****************************************************************************/
#define DESTINATION_IPV4		0x0001
#define DESTINATION_IPV6		0x0002


/*********************************************************************************
 * Structure:   NSIGMPv2GroupID
 * iType1:      NS_IGMPV2_JOIN
 * Function:    HTSetStructure
 * NSIGMPv2GroupID Description: Join a multicast group(v1/v2)  
***********************************************************************************/
 /* NSIGMPv2GroupID Description:
 The following fields uiVID, uiPPPInstance and 
 ucIPAddress  defines an "interface", which is the virtual host in the sense 
 of IGMP. Each interface can be considered as the independent host on the same 
 network. So users can join/leave against each interface and each interface 
 will respond to queries from DUT independently.


If ucPPPMode is enabled the capture frame will be:
|------------------------------------------------------------------------|
|Dst MAC|Src MAC|0x8864|0x11|0x00|Session_ID|PPPOE Length|0x0021|IP|IGMP |
|------------------------------------------------------------------------|

If PPPOE is combined with VLAN, the frame will look like the following.

|--------------------------------------------------------------------------------------|
|Dst MAC|Src MAC|0x8100|VLAN-ID|0x8864|0x11|0x00|Session_ID|PPPOE Length|0x0021|IP|IGMP|
|--------------------------------------------------------------------------------------|

  This command allows multiples structures, to enable configuration of multiple
  multicast addresses for Terametric modules.
  */
typedef struct tagNSIGMPv2GroupID
{
	unsigned char ucGroupIPAddress[4]; /*The IP address of the multicast group*/
   unsigned char ucVLANEnable;        /*1-enable,0-disabled specifies whether
                                      or not this	multicast group has an 
                                      associated VLAN tag */
   unsigned char ucPRI;	             /* VLAN priority 0-7  */
   unsigned char ucCFI;              /* VLAN CFI, 1 = RIF present, 0 = RIF absent */
   unsigned short uiVID;             /* VLAN ID */
   unsigned char ucPPPMode;          /* PPP_USE_NONE, 
                                      PPP_USE_PPP_SESSION_ID
                                      */
   unsigned short uiPPPInstance;     /* PPP session index. Currently this is
                                     valid if PPP_USE_PPP_SESSION_ID are on. 
                                                                                                       
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual IGMP
                                     over PPPOE packet. So user can issue IGMP
                                     over PPPOE packet without PPP session in
                                     this case. */

   unsigned short uiVCIndex;         /* Virtual channel index for ATM  cards*/
   unsigned char ucMACAddress[6]; /*source MAC Address of IGMP Packet,
                                      If it is 0, port MAC address will be 
                                      used as source MAC address of IGMP
                                      packet */
   unsigned char ucIPAddress[4];    /* source IP Address of IGMP Packet,
                                      If it is 0, port address will be used
                                      as source IP address of IGMP packet. */

   unsigned char ucReserved[50];

}NSIGMPv2GroupID;

#define PPP_USE_NONE    0x00       /* No PPP frame */
#define PPP_USE_PPPOE   0x01       /* Reserved - Use PPPOE frame. If this flag is on, 
                                   IGMP frames will have 8 bytes PPPOE header
                                   between IP header and Layer2 header. */
#define PPP_USE_PPP     0x02       /* Reserved - Not supported currently  */
#define PPP_USE_PPP_SESSION_ID 	0x04 /* Use PPPOE frame. If this flag is on, 
                                   IGMP frames will have 8 bytes PPPOE header 
                                   between IP header and Layer2 header.
                                    The difference from USE_PPPOE is that 
                                    with this flag, igmp stack doesn't consult
                                    ppp stack to get PPPOE session id but use
                                    the given ppp_index as PPPOE session id */


/*********************************************************************************
 * Structure:   NSIGMPv2Info
 * iType1:      NS_IGMPV2_INFO
 * Function:    HTGetStructure
 * NSIGMPv2Info Description: Retrieve the join and leave timestamp for a
                specific multicast Group. (v1,v2)  
************************************************************************************/
typedef struct tagNSIGMPv2Info
{
      unsigned char ucGroupIPAddress[4];  /*Input/Output, The IP address of 
                                          the multicast group */          
      unsigned char ucVLANEnable;         /* Input/Output, 1-enable,0-disabled 
                                          specifies whether or not this	
                                          multicast group has an associated 
                                          VLAN tag */
      unsigned char ucPRI;              	/* Input/Output, VLAN 
                                          priority 0-7 */
      unsigned char ucCFI;	               /* Input/Output, VLAN CFI, 1 = RIF present, 
                                          0 = RIF absent  */
      unsigned short uiVID;               /* Input/Output,
                                          VLAN ID  */
      unsigned char ucPPPMode;            /* Input/Output , PPP Mode
                                          possible values are PPP_USE_NONE, 
                                          PPP_USE_PPP_SESSION_ID */
      unsigned short uiPPPInstance;       /* Input/Output, PPP instance */
      unsigned short uiVCIndex;           /* Input/Output ,Virtual channel
                                          index for ATM  cards*/ 
      unsigned char ucMACAddress[6];      /* Output, source MAC address */
      unsigned char ucIPAddress[4];       /* Output, source IP address */
      unsigned long ulJoinTimestamp;      /* Output, Join TimeStamp */
      unsigned long ulLeaveTimestamp;     /* Output, Leave TimeStamp */
      unsigned char ucReserved[50];       /* Reserved */
}NSIGMPv2Info;


/****************************************************************************
* Structure: NSIPv6NextHopResultCountInfo
* iType1:    NS_IPV6_NEXT_HOP_RESULTS_COUNT_INFO
* Function:  HTGetStructure 
* NSIPv6NextHopResultCountInfo Description: 
      Retrieve the number of next-hop determination per port
****************************************************************************/
/* NSIPv6NextHopResultCountInfo Description:
*/
typedef struct tagNSIPv6NextHopResultCountInfo {
   unsigned long ulCount;       /* The number of next-hop determination 
                                 per port */
   unsigned char ucReserved[16];/* Reserved for future use             */
} NSIPv6NextHopResultCountInfo;
/****************************************************************************
 * NSIPv6RouterDiscoveryCountInfo Comment:

****************************************************************************/

/****************************************************************************
* Structure: NSIPv6NextHopResultInfo
* iType1:    NS_IPV6_NEXT_HOP_RESULTS_INFO
* Function:  HTGetStructure 
* NSIPv6NextHopResultInfo Description: 
      To retrieve the results of IPv6 Next-Hop Determination on a 
      per-stream basis. Use iType2 for the start stream index and iType3 for
      the number of protocol stream to retrieve next-hop results.
****************************************************************************/
/* NSIPv6NextHopResultInfo Description:

  Use NS_IPV6_NEXT_HOP_RESULTS_COUNT_INFO message to query number of next-hop
  determination stored and pass the array of this structure to query the next
  hop result information.

*/
typedef struct tagNSIPv6NextHopResultInfo {
   unsigned long ulStreamIndex;     /* Output - the stream associated with 
                                       this next hop result                */
   unsigned char ucNextHopAddress[16];/* Output - the IPv6 address of the 
                                         next hop                          */
   unsigned char ucReserved[16];    /* Reserved for future use             */
} NSIPv6NextHopResultInfo;
/****************************************************************************
 * NSIPv6NextHopResultInfo Comment:
****************************************************************************/


/*********************************************************************************
 * Structure:   NSProtocolCounterInfo
 * iType1:      NS_PROTOCOL_COUNTER_INFO / NS_PROTOCOL_RATE_INFO
 * Function:    HTGetStructure
 ***********************************************************************************/
/* NSProtocolCounterInfo Description:
 This structure reports counters tracked for a port by the card protocol stack.  
 The counters include frames with and without a signature field.

 The structure will either report the number of frames of each type when used
 with NS_PROTOCOL_COUNTER_INFO or the rate per second of frames of each type 
 when used with NS_PROTOCOL_RATE_INFO.

 To calculate rates at your own sampling frequency, repeatedly call
 NS_PROTOCOL_COUNTER_INFO.  Dividing the difference in a counter value by the
 difference in the u64Timestamp value will provide a rate for that interval.
 
 ATM Terametrics cards support the following counters:
    u64TxIPv4  u64RxIPv4  u64TxIPv6  u64RxIPv6  u64TxMPLS  u64RxMPLS 
*/
typedef struct tagNSProtocolCounterInfo
{
   U64 u64Timestamp;	/* in 100ns, used to calculate rates at a 
                     custom frequency */
   U64 u64TxStack;	/* frames transmitted from the protocol stack */
   U64 u64RxStack;    	/* received frames forwarded to the protocol stack */
   U64 u64RxDropped;  	/* frames dropped trying to forward */  
   U64 u64TxIPv4;     	/* IPv4 rate/number of frames transmitted */  
   U64 u64RxIPv4;     	/* IPv4 rate/number of frames received */  
   U64 u64TxIPv6;     	/* IPv6 rate/number of frames transmitted */
   U64 u64RxIPv6;     	/* IPv6 rate/number of frames received */
   U64 u64RxDataIntegrityError; /* Spirent data integrity error frames received */ 
   U64 u64RxMPLS;   	/* MPLS frames received, LAN/ATM TM cards */
   U64 u64TxMPLS;   	/* MPLS frames transmitted */
   U64 u64RxMPLSSignature;   	/* Rx MPLS frames only with signature, 
                                    for only 3310 and 3311 cards*/
   U64 u64TxMPLSSignature;   	/* Reserved - Tx MPLS frames only with signature*/
   unsigned char ucReserved[104];	
}NSProtocolCounterInfo;

/****************************************************************************
* Structure: tagIPForwardConfig 
* Function: HTIPForwardLink
* Description: Setup IP forward.
****************************************************************************/
typedef struct tagIPForwardConfig
{
   unsigned char ucIPAddress[4];        /* IP addr(e.g. 192.100.5.3), 
                                           required for both controller and  
                                           card                              */
   unsigned char ucNetmask[4];          /* Network mask (e.g. 255.255.0.0),
                                           request when config card, set 
                                           0 for controller                  */
   unsigned char ucGateway[4];          /* Default gateway addr (e.g. 192.100.1.1),
                                           request when config card, set 
                                           0 for controller                  */
   unsigned char ucReserved[32];        /* reserved for future use           */
} IPForwardConfig;
/******************************************************************************
 * NSIPforward Comment:

1. The controller will monitor the TCP/IP traffic from the network to filter out 
   the TCP/IP packet with IP address destination to the card IP Forward Address. 

2. When the card receives BINARY command packet, it should strip off the BINARY 
   header and forward raw IP data to its local TCP/IP application. The card 
   should not send back any response to this BINARY command.

******************************************************************************/


#define OFFSET_FROM_START_OF_FRAME  0
#define OFFSET_FROM_IP_HEADER       1

/*********************************************************************************
 * Structure:  NSDiffServConfig
 * iType1:     - NS_DIFF_SERV_CONFIG
 *					- NS_DIFF_SERV_CONFIG_INFO
 * Function:   - HTSetStructure
 *					- HTGetStructure

 NSDiffServConfig Description: 
 Diffserv is a feature used to track frames based upon the value of one byte in the frame.
 This feature provides a set of 256 counters and rates that can be retrieved using the
 NS_DIFF_SERV_COUNTER_INFO and NS_DIFF_SERV_RATE_INFO commands, respectively.
 A common usage is to configure DiffServ to filter on the ToS field in the IP header. Each 
 of the 256 counters and rates would correspond to the frames received with the matching ToS 
 value.  NOTE:  The LAN-33xx modules will automatically detect the ToS/CoS field in the 
 incoming packets.  The ucOffsetMode and ulOffset fields are not applicable for these modules.
 
 This structure is used to configure or retrieve the DiffServ settings on the port.  Set 
 ucEnable to 1 to start data collection.  Since the data collection may be very expansive 
 if the sampling rate is high, please disable data collection when it is not needed.
 
 **********************************************************************************/
typedef struct tagNSDiffServConfig
{
   unsigned char ucEnable; /* Enable(1) or disable(0) traffic counter
                           collection for rate calculation */

   unsigned char ucOffsetMode; /* Specifies where ulOffset begins relative
                               to the frame.

                               Defined constants:

                               OFFSET_FROM_START_OF_FRAME - Offset
                               starts from the beginning of the frame.

                               OFFSET_FROM_IP_HEADER - Offset starts
                               from the beginning of the IP header. */

   unsigned long ulOffset;        /* Offset to start data collection(in bytes). */

   unsigned char ucIPAddress[4];  /* The destination IP address to filter on. */

   unsigned char ucReserved[900]; /* Reserved */

} NSDiffServConfig;


#define MAX_DIFFSERV_VALUES 256

/* DiffServ rate calculation algorithms */
#define SIMPLE_RATE_AVERAGE      0x00000001
#define SIMPLE_COUNTER_AVERAGE   0x00000002

/*********************************************************************************
 * Structure:  NSDiffServRateInfo
 * iType1:     - NS_DIFF_SERV_RATE_INFO
 * Function:   - HTGetStructure

 NSDiffServRateInfo Description:  This command is used to retrieve DiffServ rates.

 For the ulAlgorithm field, there are currently 2 rate calculation algorithms available.
 
 SIMPLE_RATE_AVERAGE:  Calculate the rates for each time interval first before taking an
                       average of these rates.  This algorithm provides a finer resolution
                       for the rate.
 SIMPLE_COUNTER_AVERAGE:   Calculate the average of the counters first before calculating the
                           rate from the average counters.
 
 NOTE:  Currently this command is only applicable for the LAN-33xx and XLW-3720A/3721A 
 TeraMetrics family of modules.

 **********************************************************************************/
typedef struct tagNSDiffServRateInfo
{ 
   unsigned long ulAlgorithm;                         /* (input) The algorithm to use when computing
                                                         the  rates from the counter data.  
                                                         Possible values are:
                                                            SIMPLE_RATE_AVERAGE
                                                            SIMPLE_COUNTER_AVERAGE (default)
                                                      */
   unsigned long ulRxFrameRate[MAX_DIFFSERV_VALUES];  /* (output) The rate for each DiffServ(0 - 255)
                                                         value. */
   unsigned char ucReserved[96];                      /* Reserved */
} NSDiffServRateInfo;


/*********************************************************************************
 * Structure:   NSMLDConfig
 * iType1:      NS_MLD_CONFIG
 * Function:    HTSetStructure
 **********************************************************************************/
/* NSMLDConfig Description:
 
   Initialize and configure the MLD stack

   ulInitialReportGap
   The time interval between the first reports of different groups generated as
   a result of the configuration of a block of host/groups. For MLDv2 this value
   can be overwritten by InitialReportGap field in NSMLDv2GroupConfig. If InitialReportGap 
   is zero in NSMLDv2GroupConfig, the value in NSMLDConfig will be used.

  ucOptions possible values
  MLD_FORCE_LEAVE_RECORDS
  MLDV2_SUPPRESS_RECORDS
  MLD_FORCE_RESPONSE
  MLDV1_FORCE_UNSOLICITED_LISTEN_REPORTS

*/

typedef struct tagNSMLDConfig
{
    unsigned char    ucVersion;           /* MLD_V1 or MLD_V2 */
    unsigned char    ucOptions;           /* possible bit values MLD_FORCE_LEAVE_RECORDS, 
                                          MLDV2_SUPPRESS_RECORDS, MLD_FORCE_RESPONSE
                                          MLDV1_FORCE_UNSOLICITED_LISTEN_REPORTS */
    unsigned short   uiMaxNumGroups;      /* maximum number of Multicast groups  */
    unsigned char    ucMaxAddressBlock;      /* maximum number of address blocks for only MLDv2, limit is 10 */ 
    unsigned short   uiMaxIPPerBlock;        /* maximum IP per block for only MLDv2, limit is 100  */
    unsigned char    ucRobustnessVariable;   /* number of times to repeat transmission report of one
                                              specific group, for only MLDv2 or MLDv1 when the force
                                              unsolicited listen report is enabled. Range: 0-7. If
                                              zero is entered, default value 2 will be used. */ 
    unsigned char    ucUnsolicitedReportInterval;   /* maximum range of the random interval between generation of reports within a
													specific group, for only MLDv2, or MLDv1 when the force unsolicited listen report
													is enabled, default 10 seconds */
	unsigned long    ulInitialReportGap;  /* Applicable to MLDv1/v2. It is the time interval to generate the
	                                   first reports of different groups in microseconds as a result of the 
	                                   configuration of block of host/groups. For MLDv2 this value can be overwritten
	                                   by InitialReportGap field in NSMLDv2GroupConfig. If InitialReportGap
	                                   is zero in NSMLDv2GroupConfig, the value of this field will be used.
	                                   Supported by TeraMetrics Cards only */
    unsigned char    ucReserved[46];         /* Reserved */
}NSMLDConfig;

#define MLD_V1 0x00
#define MLD_V2 0x01

#define MLD_FORCE_LEAVE_RECORDS  0x80
#define MLDV2_SUPPRESS_RECORDS   0x40
#define MLDV2_IGNORE_V1_MESSAGE  0x20
#define MLD_FORCE_RESPONSE       0x10 /* for all joined interfaces to respond to queries, MLDv1 */
#define MLDV1_FORCE_UNSOLICITED_LISTEN_REPORTS     0x08  /* Enable force unsolicited listen report, for MLDv1 only */
 
/*********************************************************************************
 * Structure:   NSMLDCounterInfo
 * iType1:      NS_MLD_COUNTER_INFO
 * Function:    HTGetStructure
 **********************************************************************************/
/* NSMLDCounterInfo Description:
 
   This structure is used to retrieve MLD counter information.
*/

typedef struct tagNSMLDCounterInfo
{
    unsigned long   ulTxFrames;            /* MLD Transmitted frames */
    unsigned long   ulRxFrames;            /* MLD Received Frames */
    unsigned long   ulTxStartListenGroups; /* Number of Groups that had a 
                                           Start Listen */
    unsigned long   ulTxStopListenGroups;  /* Number of Groups that had a 
                                           Stop Listen */   
    unsigned long   ulRxUnknownType;       /* Number of unknown type frames */
    unsigned long   ulRxICMPV6ChecksumErrors; /* Number of Received ICMPV6
                                           Checksum Errors */
    
    unsigned long   ulRxLengthErrors;       /* Number of received frames
                                           with an error in the length of the
                                           received packet*/
   
   unsigned long   ulRxWrongVersionQueries;  /* Number of queries done on the
                                             membership for a specific group
                                             with a wrong version */    
  unsigned char   ucReserved[50];
 } NSMLDCounterInfo;


/*********************************************************************************
 * Structure:   NSMLDv1Listen
 * iType1:      NS_MLDV1_LISTEN
 * Function:    HTSetStructure
 **********************************************************************************/
/* NSMLDv1CounterInfo Description:
 
   This structure is used to specify a Multicast address to Start or Stop Listening.
	This command also allows multiples structures, to enable configuration of multiple 
	multicast addresses. 
*/

typedef struct tagNSMLDv1Listen
{
    unsigned char ucAction; /* MLDV1_START_LISTEN, MLDV1_STOP_LISTEN
                          specify if Group should start or stop listening */ 

    unsigned char ucGroupIPAddress[16]; /*The address of the multicast group*/
    unsigned char ucVLANEnable;         /*1-enable,0-disabled */

    unsigned char ucPRI;      /* user priority 0-7  */
    unsigned char ucCFI;      /* 1 = RIF present, 0 = RIF absent */	 
    unsigned short uiVID;     /* VLAN ID  */
    unsigned char ucPPPMode;  /* PPP_USE_NONE(default), 
                              PPP_USE_PPP_SESSION_ID */  
    
    unsigned short uiPPPInstance;   /* starting PPP index 
                                        Only for Terametric cards
                                       PPP session index. Currently this is
                                     valid if PPP_USE_PPP_SESSION_ID are on.                                                       
                                 
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual MLD
                                     over PPPOE packet. So user can issue MLD
                                     over PPPOE packet without PPP session in
                                     this case. */

    unsigned short uiVCIndex;     /* Reserved,Virtual channel index for ATM  cards*/
    unsigned char ucMACAddress[6]; /* source MAC Address of IGMP Packet,
                                      If it is 0's, port MAC address will be 
                                      used as source MAC address of IGMP
                                      packet */
    unsigned char ucIPAddress[16]; /* source Address of IGMP Packet,
                                      If it is 0's, port address will be used
                                      as source IP address of IGMP packet. */
    unsigned char ucReserved[50];
}NSMLDv1Listen;


#define MLDV1_START_LISTEN   0x01
#define MLDV1_STOP_LISTEN      0x02


/*********************************************************************************
 * Structure:   NSMLDTimestampInfo
 * iType1:      NS_MLD_TIMESTAMP_INFO
 * Function:    HTGetStructure
 **********************************************************************************/
/* NSMLDTimestampInfo Description:
 
 Retrieve join and leave timestamps for all multicast groups.
 Applicable to both MLDv1 and MLDv2. No Inputs are needed.

 Comments for "ulLastStateTimestamp":

 In MLDv2, all the membership reports sent out from a port are called state change reports.  
 Whenever the host wants to change the current state of membership on a specific group, 
 such as different source list, the host should send out a state change report.  

 Therefore, the new state change timestamp of the group should change with each report of 
 that group sent out.  However, there are two special case.  If it is the first report to 
 the group, the MLD stack will treat it as a join report and save the timestamp to 
 "ulJoinTimestamp".  If the report is trying to INCLUDE NULL, the MLD stack will treat it 
 as leave report and save the timestamp to "ulLeaveTimestamp".  In these two cases, 
 "ulLastStateTimestamp" would not be updated.

 Example

 Join		      t1
 state change	t2
 state change	t3
 state change	t4
 leave         t5

 => ulJoinTimestamp = t1, ulLastStateTimestamp = t4, and ulLeaveTimestamp = t5
*/

typedef struct tagNSMLDTimestampInfo
{
    unsigned char ucGroupIPAddress[16]; /*The address of the multicast group*/
    unsigned char ucVLANEnable;         /*1-enable,0-disabled */

    unsigned char ucPRI;      /* user priority 0-7 */
    unsigned char ucCFI;      /* 1 = RIF present, 0 = RIF absent */	 
    unsigned short uiVID;     /* VLAN ID  */
    unsigned char ucPPPMode;  /* PPP_USE_NONE(default), 
                              PPP_USE_PPP_SESSION_ID */  
    
    unsigned short uiPPPInstance;   /* starting PPP index 
                                        Only for Terametric cards
                                       PPP session index. Currently this is
                                     valid if PPP_USE_PPP_SESSION_ID are on.                                                        
                                 
                                     PPP_USE_PPP_SESSION_ID - The least
                                     significant two bytes of this value are
                                     considered as 'session id' in actual MLD
                                     over PPPOE packet. So user can issue MLD
                                     over PPPOE packet without PPP session in
                                     this case. */

    unsigned short uiVCIndex;     /* Reserved,Virtual channel index for ATM  cards*/
    unsigned char ucMACAddress[6]; /* source MAC Address of IGMP Packet,
                                      If it is 0's, port MAC address will be 
                                      used as source MAC address of IGMP
                                      packet */
    unsigned char ucIPAddress[16]; /* source Address of IGMP Packet,
                                      If it is 0's, port address will be used
                                      as source IP address of IGMP packet. */

    unsigned long ulJoinTimestamp;		   /* Join timestamp */
	 unsigned long ulLeaveTimestamp;		   /* Leave timestamp */
    unsigned long ulLastStateTimestamp;   /* Timestamp for the last state change.  This
                                          excludes the initial join report and the leave
                                          report.  The timestamp for these 2 events
                                          are available in the previous 2 fields.  */
    unsigned char ucReserved[20];
}NSMLDTimestampInfo;

/*********************************************************************************
 * Structure:   NSSubscriptionInfo
 * iType1:      NS_GET_SUBSCRIPTION
 * Function:    HTSetStructure
 **********************************************************************************/
/* NSSubscriptionInfo Description:
   This structure is to get the percentage of linespeed bandwidth that can be utilized,
   given the current active streams, their size, checksumming method, and framerate settings.
   
   The ulSubscription is a decimal number, indicating the percentage of the linespeed that is
   currently utilized, upon adding all the active streams' bandwith utilization together. If
   this number exceeds 100 (percent), the line is oversubscribed. In this case it is recommended
   to delete some streams, reduce the frame size of one or more streams, or reduce the frame rate
   of one or more streams.

   NOTE: This is an internal command for debugging purpose.
*/

typedef struct tagNSSubscriptionInfo
{
	unsigned long ulSubscription; /* percentage of linespeed bandwidth that can be utilized */
	unsigned char ucReserved[64];
} NSSubscriptionInfo;

/*********************************************************************************
 * Structure:   NSIPv6ExtHopByHop
 * iType1:      NS_DEFINE_IPV6_EXT_HOP_BY_HOP/NS_MOD_IPV6_EXT_HOP_BY_HOP
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtHopByHop Description:
 This command provides the ability to define IPv6 Hop-By-Hop Extension headers for
 existing (already defined) IPv6 Streams.

 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.

 The Hop-by-Hop Options header is used to carry optional information that must be 
 examined by every node along the packet's delivery path.  The Hop-by-Hop Options
 header is identified by Next Header value of 0 in the IPv6 header.
 For TM LAN cards maximum accepted total length for any IPv6 header is 74 bytes(non-VLAN) 
 and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)

 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ENCAPULATING_SECURITY	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/

typedef struct tagNSIPv6ExtHopByHop
{
   unsigned char  ucNextHeader;   /* Identifies the type of header immediately 
                                   following the Hop-by-Hop Options header */
   unsigned char  ucHeaderExtensionLength;   /* Length of the Hop-by-Hop 
                                  Options header in 8-byte units, including all fields */
   /* Options */
   unsigned char  ucOptionDataLength; /* Length of the Option Data field of 
                                to be used, bytes */
   unsigned char  ucOptionData[255];  /* Option-Type-specific data */  
  unsigned char    ucReserved[20];
}NSIPv6ExtHopByHop;

#define IPV6_EXT_HOP_BY_HOP			   0
#define IPV6_EXT_FRAGMENT			      44
#define IPV6_EXT_AUTHENTICATION			51
#define IPV6_EXT_ESP                	50
#define IPV6_EXT_ROUTING_TYPE_0			43
#define IPV6_EXT_DESTINATION        	60
#define IPV6_EXT_NONE        	         59

/*********************************************************************************
 * Structure:   NSIPv6ExtFragment
 * iType1:      NS_DEFINE_IPV6_EXT_FRAGMENT/NS_MOD_IPV6_EXT_FRAGMENT
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtFragment Description:
 This command provides the ability to define IPv6 Fragment Extension headers for 
 existing (already defined) IPv6 Streams.
 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.
 The Fragment header is used by an IPv6 source to send a packet larger than 
 would fit in the path MTU to its destination.  The Fragment header is 
 identified by a Next Header value of 44 in the immediately preceding header.  
 For TM LAN cards maximum accepted total length for any IPv6 header is 74(non-VLAN) 
 bytes and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)
 
 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ESP                  	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/

typedef struct tagNSIPv6ExtFragment
{
   unsigned char ucNextHeader;   /* Identifies the type of header immediately 
                                 following the Fragment header */
   unsigned short uiFragmentOffset;  /* The offset, in 8-byte units, of the
                                     data following this header is relative to
                                     the start of the Fragment-able Part of 
                                     the original packet. */
 
   unsigned char ucMFlag;            /* 1 = more fragments; 0 = last fragment */
   unsigned long ulIdentification;   /* Unique Identification for packet that 
                                    need to be fragmented*/ 
  unsigned char    ucReserved[20];
}NSIPv6ExtFragment;

/*********************************************************************************
 * Structure:   NSIPv6ExtDestination
 * iType1:      NS_DEFINE_IPV6_EXT_DESTINATION/NS_MOD_IPV6_EXT_DESTINATION
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtDestination Description:
 This command provides the ability to define IPv6 Destination Extension
 headers for existing (already defined) IPv6 Streams.
 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.
 The Destination Options header is used to carry optional information
 that need be examined only by a packet's destination node(s).  The 
 Destination Options header is identified by a Next Header value of
 60 in the immediately preceding header.
 For TM LAN cards maximum accepted total length for any IPv6 header
 is 74 bytes(non-VLAN) and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)

 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ESP                  	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/

typedef struct tagNSIPv6ExtDestination
{
   unsigned char ucNextHeader;   /* Identifies the type of header immediately 
                                 following the Destination  header */
   unsigned char ucHeaderExtensionLength;   /* Length of the Destination header
                                            in 8-byte units, including all
                                            fields */ 
  
   unsigned char ucOptionDataLength;   /* Length of the Option Data field of 
                                    to be used, in bytes*/
   unsigned char ucOptionData[255];         /* Option-Type-specific data*/ 
 
  unsigned char ucReserved[20];

}NSIPv6ExtDestination;


/*********************************************************************************
 * Structure:   NSIPv6ExtRouting
 * iType1:      NS_DEFINE_IPV6_EXT_ROUTING/NS_MOD_IPV6_EXT_ROUTING
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtRouting Description:
 This command provides the ability to define IPv6 Routing(Type 0)
 Extension headers for existing (already defined) IPv6 Streams.
 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.
 The Routing header is used by an IPv6 source to list one or more 
 intermediate nodes to be "visited" on the way to a packet's destination.  
 For TM LAN cards maximum accepted total length for any IPv6 header is 
 74 bytes(non-VLAN) and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)

 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ESP                  	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/
typedef struct tagNSIPv6Address
{
	unsigned char ucIPAddress[16];
} NSIPv6Address;

typedef struct tagNSIPv6ExtRouting
{
   unsigned char ucNextHeader;   /* Identifies the type of header 
                                    immediately following the Routing header*/
   unsigned char ucHeaderExtensionLength;   /* Length of the Routing header
                                             in 8-byte units, including all
                                             fields */
   unsigned char ucSegmentsLeft; /* Number of route segments remaining,
                                  i.e., number of explicitly listed 
                                  intermediate nodes still to be visited
                                  before reaching the final destination */
   NSIPv6Address IPAddress[20];   /* The maximum accepted number of addresses
                                 for Terametrics LAN cards and for
                                 Terametrics POS cards is 4 */

  unsigned char ucNumAddress;  /* Number of addresses to use in IPAddress */
  unsigned char ucReserved[20];

}NSIPv6ExtRouting;


/*********************************************************************************
 * Structure:   NSIPv6ExtAuthentication
 * iType1:      NS_DEFINE_IPV6_EXT_AUTHENTICATION/NS_MOD_IPV6_EXT_AUTHENTICATION
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtAuthentication Description:
 This command provides the ability to define IPv6 Authentication Extension 
 headers for existing (already defined) IPv6 Streams.
 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.
 The IP Authentication Header (AH) is used to provide connectionless integrity
 and data origin authentication for IP datagrams, and to provide protection against
 replays. The protocol immediately preceding the AH header will contain the value
 51 in its Protocol (IPv4) or Next Header (IPv6, Extension) field.
 For TM LAN cards maximum accepted total length for any IPv6 header is 74 bytes(non-VLAN)
 and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)

 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ESP                  	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/


typedef struct tagNSIPv6ExtAuthentication
{   
   unsigned char ucNextHeader; /* Identifies the type of header immediately
                              following the Authentication header */
   unsigned char ucHeaderExtensionLength; /*Length of AH in 4-byte units, 
                            including all fields */  
   unsigned long ulSPI; /* Security Parameters index, an arbitrary value that,
                      in combination with the destination IP address and 
                      security protocol (AH), uniquely identifies the 
                      security association for this packet */

   unsigned long ulSeqNumber; /* monotonically increasing counter value
                              (sequence number).  However, in this MRQ  
                              implementation, this field won't be 
                              incremented with each packet but a static 
                              value configured by user.  Or user may enable
                              a VFD field to do the increment. */

   unsigned char ucAuthenticationDataLength; /* Length of Authenication
                                            Data field */
   unsigned char ucAuthenticationData[255];  /*contains the Integrity 
                                         Check Value (ICV) for this packet */

  unsigned char    ucReserved[20];
}NSIPv6ExtAuthentication;

/*********************************************************************************
 * Structure:   NSIPv6ExtRouting
 * iType1:      NS_DEFINE_IPV6_EXT_ESP/NS_MOD_IPV6_EXT_ESP
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6ExtESP Description:
 If the specified stream has an existing IPv6 Extension header, the new one 
 will be appended to it.
 This command provides the ability to define IPv6 Encapsulated security 
 payload(ESP)  Extension headers for existing (already defined) IPv6 Streams.
 The Encapsulating Security Payload (ESP) header is designed to provide a mix
 of security services in and IPv6.  ESP may be applied alone, in combination 
 with the IP Authentication Header (AH), or in a nested fashion, e.g., through
 the use of tunnel mode. The protocol header immediately preceding the ESP
 header will contain the value 50.
 For TM LAN cards maximum accepted total length for any IPv6 header is 74 bytes(non-VLAN)
 and for POS TM is 84 bytes.
 Maximum length of payload in TeraMetric cards is 128, so maximum for for 
 Extension header is 128 -12(MAC) - 2(Protocol) -40(IPv6) = 74 (LAN TM)
 For POS TM cards 128 - 4(HDLC) -40(IPv6)

 Possible ucNextHeader values:
 #define IPV6_EXT_HOP_BY_HOP			      0
 #define IPV6_EXT_FRAGMENT			         44
 #define IPV6_EXT_AUTHENTICATION			   51
 #define IPV6_EXT_ESP                  	50
 #define IPV6_EXT_ROUTING_TYPE_0			   43
 #define IPV6_EXT_DESTINATION       	   60
*/

typedef struct tagNSIPv6ExtESP
{
   unsigned char ucNextHeader; /* Identifies the type of header immediately
                               following the ESP header */ 
  unsigned long ulSPI; /* Security Parameters index, an arbitrary value that,
                      in combination with the destination IP address and
                      security protocol (ESP), uniquely identifies the 
                      security association for this packet */
   unsigned long ulSeqNumber; /* monotonically increasing counter value
                              (sequence number).  However, in this MRQ
                              implementation, this field won't be incremented
                              with each packet but a static value configured
                              by user.  Or user may enable a VFD field to
                              do the increment. */

   unsigned char ucPadding[255];   /* The sender MAY add 0-255 bytes of padding.
                             Inclusion of the Padding field in an ESP 
                             packet is optional, Note: for Terametrics LAN
                             maximum accepted length is 74 bytes and for
                             POS TM is 84 bytes */

   unsigned char ucPaddingLength;  /* Length in bytes of ucPadding */

   unsigned char ucPayloadData[255];  /* a variable-length field 
                             containing data described by the Next Header 
                            field. The Payload Data field is mandatory and
                            is an integral number of bytes in length */
   unsigned char ucPayloadDataLength; /* Length of Payload Data field */
   unsigned char ucAuthenticationData[255] ;  /*contains the Integrity 
                                   Check Value (ICV) for this packet */
   unsigned char ucAuthenticationDataLength; /* Length of Authenication Data field */
  unsigned char ucReserved[20];

}NSIPv6ExtESP;

/*********************************************************************************
 * Structure:   NSIPv6OverIPv4Tunneling
 * iType1:      NS_DEFINE_IPV6_OVER_IPV4_TUNNELING/NS_MOD_IPV6_OVER_IPV4_TUNNELING
                NS_DEFINE_MULTI_IPV4_OVER_IPV4_TUNNELING
 * Function:    HTSetStructure
 **********************************************************************************
 NSIPv6OverIPv4Tunneling Description:
 Tunneling is used to tunnel IPv6 datagrams over regions of IPv4 routing topology by 
 encapsulating them within IPv4 packets.
 This structure holds IPv4 information to be used to encapsulate existing IPv6 streams.
 IPv6 streams should be defined first. 
 If L3_DEFINE_XX_STREAM or L3_MOD_XX_STREAM are called on streams with IPv6-over-IPv4
 tunneling, they will will be replaced
 L3_DEFINE_MULTI_XX_STREAMS can't be used on IPv6-over-IPv4 streams. Use 
 NS_DEFINE_MULTI_IPV6_OVER_IPV4_TUNNELING

  ucIgnoreTunneling field is only applicable when NS_DEFINE_IPV6_OVER_IPV4_TUNNELING
  is used.

 The behavior of NS_DEFINE_IPV6_OVER_IPV4_TUNNELING on streams with the following 
 configurations are:
 Non-IPv6 stream  -  Stream will be left untouched without an error being returned.
 IPv6 stream		-	Stream will become Tunneled
 Tunneled stream	-  IPv4 part of Tunneled stream will be replaced with new  IPv4 configuration
 Mixture of non-IPv6 and IPv6 streams -
 	                  Non-IPv6 streams will be left untouched, IPv6 streams will be Tunneled.
 Mixture of non-IPv6 and Tunneled streams -
                     Non-IPv6 streams will be left untouched, IPv4 portion of Tunneled stream will
                     be replaced.
 Mixture of IPv6 and Tunneled streams -
	                  IPv6 streams will be Tunneled, IPv4 portion of Tunneled stream will be replaced.

 Mixture of non-IPv6, IPv6 and Tunneled streams - 
	            Non-IPv6 streams will be left untouched, IPv6 streams will become Tunneled and 
               IPv4 portion of Tunneled stream will be replaced.


  The behavior of NS_DEFINE_MULTI_IPV6_OVER_IPV4_TUNNELING on streams with the following 
  configurations are (delta values are only applicable to IPv4 portion of the Tunneled stream
  if command is successful):
  Base streams
  Non-IPv6 Streams   -   An error will be returned
  IPv6 Streams   -   An error will be returned
  Tunneled Streams - IPv4 Portion of Tunneled stream wil be copied.

  Destination streams
  Non-IPv6 stream -  Stream will be left untouched without an error being returned.
  IPv6 stream		-	Stream will become Tunneled.
  Mixture of non-IPv6 and IPv6 streams -
 	                  Non-IPv6 streams will be left untouched, IPv6 streams will be Tunneled.
  Mixture of non-IPv6 and Tunneled streams -
                     Non-IPv6 streams will be left untouched, IPv4 portion of Tunneled stream will
                     be replaced.
  Mixture of IPv6 and Tunneled streams -
	                  IPv6 streams will be Tunneled, IPv4 portion of Tunneled stream will be replaced.
  Mixture of non-IPv6, IPv6 and Tunneled streams - 
	            Non-IPv6 streams will be left untouched, IPv6 streams will become Tunneled and 
               IPv4 portion of Tunneled stream will be replaced.

  The behavior of NS_MOD_IPV6_OVER_IPV4_TUNNELING on streams with the following 
  configurations are:
  Non-IPv6 Streams   -   An error will be returned
  IPv6 stream		-	Stream will become Tunneled
  Tunneled stream	-  IPv4 part of Tunneled stream will be replaced with new IPv4 configuration


*/

typedef struct tagNSIPv6OverIPv4Tunneling
{
   unsigned char  ucIgnoreTunneling;   /* specifies if tunneling should be enabled,
                              0 - (default) enable Tunneling, 1 - disable tunneling */
   unsigned char  ucTypeOfService;  /* Used to indicate the quality of the service desired */
   unsigned char  ucTimeToLive;	/* number of "hops" until frame	*/
				                     /* will be dropped	 */
   unsigned short uiInitialSequenceNumber;	/* Initial sequence number	 */
   unsigned char  ucDestinationIP[4];		/* Dest IP addr(e.g. 192.100.5.3) */
   unsigned char  ucSourceIP[4];		/* Src IP addr (e.g. 192.100.5.4) */
   unsigned char  ucNetmask[4];		/* Network Mask (e.g. 255.255.0.0)	*/
   unsigned char  ucGateway[4];		/* Gateway addr (e.g. 192.100.1.1)	*/

   unsigned char ucReserved[64];

}NSIPv6OverIPv4Tunneling;

/****************************************************************************
 * Structure:   NSPhyConfig
 * iType1:      NS_PHY_CONFIG/NS_PHY_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 * NSPhyConfig Description:

This command NS_PHY_CONFIG configures or NS_PHY_CONFIG_INFO queries the 
Layer 2 protocol mode of operation for dual media card.

Note for ulMediaMode: 
Currently only support MEDIA_USER_EXPLICIT_MODE. 
* MEDIA_USER_EXPLICIT_MODE       0

Note for ucActiveMedia: 
 * FIBER_MODE            0
 * COPPER_MODE          1

 ***************************************************************************/
typedef struct tagNSPhyConfig {
   unsigned long ulMediaMode;    /* Currently only support this mode below
                                    + MEDIA_USER_EXPLICIT_MODE (default)
                                 */         
      
   unsigned char  ucActiveMedia;/* To determine which medium (copper or 
                                    fiber). There are two modes:
                                    + FIBER_MODE (default)
                                    + COPPER_MODE
                                 */
   unsigned char ucReserved[59]; /* Reserved */
} NSPhyConfig;

//
// Define constants for ulMode
//
#define PHY_MODE_POS       0
#define PHY_MODE_LAN       1 
#define PHY_MODE_WAN       2

//
// Define constants for ulMediaMode
//
#define MEDIA_USER_EXPLICIT_MODE 0
#define MEDIA_AUTO_SENSE_MODE    1

//
// Define constants for ucActiveMedia
//
#define FIBER_MODE   0
#define COPPER_MODE  1

/****************************************************************************
* Structure: SlotUserInfo 
* Function: HTGetSlotUserInfo
* Description: Gets Information on users logged in.
****************************************************************************/
#define MAX_NAME 256

typedef struct tagSlotUserInfo
{
  unsigned char ucIPAddress[4];  /* IPAddress */
  unsigned short uiPortNumber;   /* Port Number */
  unsigned char ucName[MAX_NAME]; /* Host name */
  unsigned char ucReserved[64];
}SlotUserInfo;


/*********************************************************************************
 * Structure:   NSRateInfo
 * iType1:      NS_RATE_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 NSRateInfo Description:
 Retrieve Rates for Terametric cards
*/

typedef struct tagNSRateInfo
{         
   unsigned long  ulTxFrames;	   /* rate of frames transmitted  */
	unsigned long	ulRxFrames;	   /* rate of frames received */
	unsigned long	ulTxBytes;	   /* rate of bytes transmitted */
	unsigned long	ulRxBytes;	   /* rate of bytes received */
	unsigned long	ulUndersize;	/* rate of undersize error frames detected(received)  */
	unsigned long	ulOversize;	   /* rate of oversize error frames detected(received) */
	unsigned long	ulAlignError;  /* rate of alignment error frames detected(received) */
	unsigned long	ulCRCError;    /* rate of CRC error frames received */
	unsigned long	ulTxTriggers;  /* rate of trigger frames received  */
   unsigned long	ulRxTriggers;  /* rate of trigger frames received  */
	unsigned long	ulCollisions;  /* rate of collisions  */	
	unsigned long  ulRxJumboFrames;  /* rate of jumbo frames received */
	unsigned long  ulTxSignature;    /* Tx Signature frames  */	
   unsigned long  ulRxSignature;    /* Rx Signature frames */
   unsigned long  ulRxIPChecksumErrors; /* Rx IP Checksum errors */
	unsigned char	ucReserved[300];	
}NSRateInfo;




/*********************************************************************************
 * Structure:   NSMultiCounterInfo
 * iType1:      NS_MULTI_COUNTER_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 NSMultiCounterInfo Description:
 Retrieve all counters supported by Terametric cards
 
 Possible values for ulMode:
 NS_EVENTS_MODE    0x0001
 NS_RATES_MODE       0x0002

 Possible values for ulCounterType:
 NS_MULTI_L2_COUNTERS      0x0001
 NS_MULTI_IPV4_COUNTERS    0x0002
 NS_MULTI_IPV6_COUNTERS    0x0004
 NS_MULTI_ERROR_COUNTERS   0x0008

 NS_MULTI_MPLS_COUNTERS    0x0010
 NS_MULTI_ETH_COUNTERS     0x0020
 NS_MULTI_IPV4_PING_COUNTERS     0x0040
 NS_MULTI_IPV4_ARP_COUNTERS      0x0080
 NS_MULTI_IPV6_NEIGHBOR_SOLICITATION_COUNTERS   0x0100
 NS_MULTI_IPV6_PING_COUNTERS     0x0200
 NS_MULTI_VLAN_PRIORITY_COUNTERS	0x0400 - Received VLAN tagged frames indexed by the Priority Field
                                          within the VLAN tag. If a received frame has multiple VLAN
                                          tags, only the first VLAN tag after the MAc header is counted.
														Other tags within that same frame are not counted.

 NS_MULTI_HW_RATE_COUNTERS		0x0800 - Rate counters Received from the HW, available in only rates mode(NS_RATES_MODE).
 NS_MULTI_LINK_FAULT_SIGNALING_COUNTERS  0x1000 - Counters of Link Fault Signaling, available in only events mode(NS_EVENTS_MODE).

 Counters are grouped as follows:
 NS_MULTI_L2_COUNTERS
   Tx Frames 				
   Tx Signature Frames
   Tx Bytes 
   Tx Trigger   		
   Tx Latency
	Tx Timestamp
   Rx Timestamp
   Rx Frame
   Rx Signature Frame
   Rx Bytes
   Rx Trigger
   Rx Latency
	Tx Stack
	Rx Stack
	Rx Dropped Frames

 NS_MULTI_IPV4_COUNTERS
	Tx IPv4 
    Rx IPv4
	ICMPv4 Unreachable Frames

 NS_MULTI_IPV6_COUNTERS
	Tx IPv6 
	Rx IPv6 	
	ICMPv6 Unreachable Frames

 NS_MULTI_ERROR_COUNTERS
	Rx CRC Error
	Rx Data Integrity Error
	IPv4 Checksum Error
	IPV6 Rx Payload Checksum Error
	Alignment Error	

 NS_MULTI_MPLS_COUNTERS
	Rx MPLS
   Tx MPLS
   Rx Signature MPLS
   Tx Signature MPLS

 NS_MULTI_ETH_COUNTERS
   Collision
   Xs Collision
   Rx Undersize
   Rx Oversize
   Rx Vlan
   Rx_Pause
   Rx Jumbo

NS_MULTI_IPV4_ARP_COUNTERS
	ARP Replies Received
   ARP Replies Sent
   ARP Requests Sent
   ARP Requests Received


NS_MULTI_IPV4_PING_COUNTERS
	Ping Replies Received
   Ping Replies Sent
   Ping Requests Sent
   Ping Requests Received

NS_MULTI_IPV6_NEIGHBOR_SOLICITATION_COUNTERS
   Neighbor Solicitation Sent 
   Neighbor Solicitation Received
   Neighbor Advertisement Sent
   Neighbor Advertisement Received

NS_MULTI_IPV6_PING_COUNTERS
   IPv6 Ping Replies Received
   IPv6 Ping Replies Sent
   IPv6 Ping Requests Sent
   IPv6 Ping Requests Receive

NS_MULTI_VLAN_PRIORITY_COUNTERS - Applicable to only XENPAK and Terametric XD cards. Received VLAN
										    tagged frames indexed by 3-bit user priority field within the VLAN tag.
										    For multiple VLAN tags, only the first tag after the MAC header will be
										    considered.
	VLAN Tags with PRI 0 Rx
	VLAN Tags with PRI 1 Rx
	VLAN Tags with PRI 2 Rx
	VLAN Tags with PRI 3 Rx
	VLAN Tags with PRI 4 Rx
	VLAN Tags with PRI 5 Rx
	VLAN Tags with PRI 6 Rx
	VLAN Tags with PRI 7 Rx

NS_MULTI_HW_RATE_COUNTERS
	Tx Frames sent in the previous second, available in only rates mode(NS_RATES_MODE).
	Rx Frames received in the previous second, available in only rate mode(NS_RATES_MODE).

NS_MULTI_LINK_FAULT_SIGNALING_COUNTERS
	Local Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE).
	Local Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE).
	Remote Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE).
	Remote Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE).

 Indices for referencing the counters:
 NS_MULTI_TX_FRAMES		            0	Tx Frames  
 NS_MULTI_RX_FRAMES       	         1  Rx Frame

 NS_MULTI_TX_SIGNATURE_FRAMES		   2	Tx Signature Frames
 NS_MULTI_RX_SIGNATURE_FRAMES		   3	Rx Signature Frame 

 NS_MULTI_TX_BYTES				      4	Tx Bytes 
 NS_MULTI_RX_BYTES				      5	Rx Bytes

 NS_MULTI_TX_TRIGGER			         6	Tx Trigger
 NS_MULTI_RX_TRIGGER			         7	Rx Trigger

		
 NS_MULTI_TX_LATENCY			         8	Tx Latency
 NS_MULTI_RX_LATENCY			         9	Rx Latency

 NS_MULTI_TX_TIMESTAMP			      10
 NS_MULTI_RX_TIMESTAMP			      11

 NS_MULTI_TX_STACK				      12
 NS_MULTI_RX_STACK				      13

 NS_MULTI_RX_DROPPED_FRAMES		   14

 NS_MULTI_TX_IPV4_FRAMES			15	Tx IPv4 
 NS_MULTI_RX_IPV4_FRAMES			16	Rx IPv4

 NS_MULTI_TX_IPV6_FRAMES			17	Tx IPv6 
 NS_MULTI_RX_IPV6_FRAMES			18	Rx IPv6

 NS_MULTI_RX_CRC_ERROR				19	Rx CRC Error
 NS_MULTI_RX_DATA_INTEGRITY_ERROR	20	Rx Data Integrity Error
 NS_MULTI_IPV4_CHECKSUM_ERROR		21	IPv4 Checksum Error
 NS_MULTI_IPV6_PAYLOAD_CHECKSUM_ERROR	    22	IPV6 Payload Checksum Error (only ICMPv6 Informational messages supported)
 NS_MULTI_ALIGNMENT_ERROR			23	Alignment Error 

 NS_MULTI_TX_MPLS_FRAMES			24	Tx MPLS ,not supported
 NS_MULTI_RX_MPLS_FRAMES			25	Rx MPLS

 NS_MULTI_TX_SIGNATURE_MPLS_FRAMES	26	Tx Signature MPLS , not supported
 NS_MULTI_RX_SIGNATURE_MPLS_FRAMES	27	Rx Signature MPLS

 NS_MULTI_COLLISION					28	Collision
 NS_MULTI_XS_COLLISION				29	Xs Collision
 NS_MULTI_RX_UNDERSIZE				30  Rx Undersize
 NS_MULTI_RX_OVERSIZE				31	Rx Oversize
 NS_MULTI_RX_VLAN					32	Rx Vlan
 NS_MULTI_RX_PAUSE					33	Rx_Pause
 NS_MULTI_RX_JUMBO					34	Rx Jumbo

 NS_MULTI_ARP_REPLIES_TX			35	ARP Replies Sent
 NS_MULTI_ARP_REPLIES_RX			36	ARP Replies Received

 NS_MULTI_ARP_REQUESTS_TX			37	ARP Requests Sent
 NS_MULTI_ARP_REQUESTS_RX			38	ARP Requests Received

 NS_MULTI_IPV4_PING_REPLIES_TX		39	Ping Replies Sent
 NS_MULTI_IPV4_PING_REPLIES_RX		40	Ping Replies Received
 
 NS_MULTI_IPV4_PING_ REQUESTS _TX	41	Ping Requests Sent
 NS_MULTI_IPV4_PING_ REQUESTS _RX	42	Ping Requests Received

 NS_MULTI_NEIGHBOR_SOLICITATION_TX	43	Neighbor Solicitation Sent 
 NS_MULTI_NEIGHBOR_SOLICITATION_RX	44	Neighbor Solicitation Received

 NS_MULTI_NEIGHBOR_ADVERT_TX			45	Neighbor Advertisement Sent
 NS_MULTI_NEIGHBOR_ADVERT_RX			46	Neighbor Advertisement Received

 NS_MULTI_IPV6_PING_REPLIES_TX		47	IPv6 Ping Replies Sent
 NS_MULTI_IPV6_PING_REPLIES_RX		48	IPv6 Ping Replies Received

 NS_MULTI_IPV6_PING_REQUESTS_TX		49	IPv6 Ping Requests Sent
 NS_MULTI_IPV6_PING_REQUESTS_RX		50	IPv6 Ping Requests Receive

 NS_MULTI_IPV4_ICMP_UNREACHABLE_RX	51  ICMP IPv4 Unreachable frames 
 NS_MULTI_IPV6_ICMP_UNREACHABLE_RX	52  ICMP IPv6 Unreachable frames 

 NS_MULTI_VLAN_PRI_0_RX				53  VLAN PRI 0 Received 
 NS_MULTI_VLAN_PRI_1_RX				54  VLAN PRI 1 Received 
 NS_MULTI_VLAN_PRI_2_RX				55  VLAN PRI 2 Received 
 NS_MULTI_VLAN_PRI_3_RX				56  VLAN PRI 3 Received 
 NS_MULTI_VLAN_PRI_4_RX				57  VLAN PRI 4 Received 
 NS_MULTI_VLAN_PRI_5_RX				58  VLAN PRI 5 Received 
 NS_MULTI_VLAN_PRI_6_RX				59  VLAN PRI 6 Received 
 NS_MULTI_VLAN_PRI_7_RX				60  VLAN PRI 7 Received 

 NS_MULTI_HW_TX_FRAMES				61  Tx Frames sent in the previous second, available in only rates mode(NS_RATES_MODE).
 NS_MULTI_HW_RX_FRAMES				62  Rx Frame received in the previous second, available in only rates mode(NS_RATES_MODE).

 NS_MULTI_LFS_LOCAL_START     63  Local Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE)
 NS_MULTI_LFS_LOCAL_CONTINUE  64  Local Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE)
 NS_MULTI_LFS_REMOTE_START    65  Remote Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE)
 NS_MULTI_LFS_REMOTE_CONTINUE 66  Remote Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE)

 This command is applicable to only Terametric cards

  Tcl Example 1:
	Getting Error Counters
	(ulMode field is set to NS_EVENTS_MODE and ulCounterType field is set to 
	NS_MULTI_ERROR_COUNTERS)

	struct_new multi_counter NSMultiCounterInfo
	set multi_counter(ulMode) $::NS_EVENTS_MODE
	set multi_counter(ulCounterType) $::NS_MULTI_ERROR_COUNTERS

  Tcl Example 2:
	Getting Error and IPv4 Counters/Rates
	(ulMode field is set to NS_EVENTS_MODE|NS_RATES_MODE and ulCounterType 
	field is set to NS_MULTI_ERROR_COUNTERS|NS_MULTI_TX_IPV4_FRAMES)

	struct_new multi_counter NSMultiCounterInfo
	set multi_counter(ulMode) [expr $::NS_EVENTS_MODE | NS_RATES_MODE]
	set multi_counter(ulCounterType) [expr $::NS_MULTI_ERROR_COUNTERS | $::NS_MULTI_TX_IPV4_FRAMES]

*/

typedef struct tagNSMultiCounterInfo
{         
   unsigned long  ulMode;   /* retrieve Events, Rates or both Rates and Events */
   unsigned long ulCounterType; /* Determines what type of counters you want to
                                   retrieve, it can be 'OR' it to obtain two or more
                                   counters */

    U64 u64Events[300];    /* Events */
    U64 u64Rates[300];     /* Rates */
    unsigned char ucReserved[64];
}NSMultiCounterInfo;


#define NS_EVENTS_MODE    0x0001
#define NS_RATES_MODE       0x0002

#define NS_MULTI_L2_COUNTERS      0x0001
#define NS_MULTI_IPV4_COUNTERS    0x0002
#define NS_MULTI_IPV6_COUNTERS    0x0004
#define NS_MULTI_ERROR_COUNTERS   0x0008

#define NS_MULTI_MPLS_COUNTERS    0x0010
#define NS_MULTI_ETH_COUNTERS     0x0020
#define NS_MULTI_IPV4_PING_COUNTERS     0x0040
#define NS_MULTI_IPV4_ARP_COUNTERS      0x0080
#define NS_MULTI_IPV6_NEIGHBOR_SOLICITATION_COUNTERS   0x0100
#define NS_MULTI_IPV6_PING_COUNTERS     0x0200
#define NS_MULTI_VLAN_PRIORITY_COUNTERS 0x0400
#define NS_MULTI_HW_RATE_COUNTERS		 0x0800
#define NS_MULTI_LINK_FAULT_SIGNALING_COUNTERS		 0x1000

#define NS_MULTI_TX_FRAMES		            0	/* Tx Frames */  
#define NS_MULTI_RX_FRAMES       	      1  /* Rx Frame */

#define NS_MULTI_TX_SIGNATURE_FRAMES		2	/* Tx Signature Frames */
#define NS_MULTI_RX_SIGNATURE_FRAMES		3	/* Rx Signature Frame */

#define NS_MULTI_TX_BYTES				      4	/* Tx Bytes */
#define NS_MULTI_RX_BYTES				      5	/* Rx Bytes */

#define NS_MULTI_TX_TRIGGER			      6	/* Tx Trigger */
#define NS_MULTI_RX_TRIGGER			      7	/* Rx Trigger */
		
#define NS_MULTI_TX_LATENCY			      8	/* Tx Latency */
#define NS_MULTI_RX_LATENCY			      9	/* Rx Latency */

#define NS_MULTI_TX_TIMESTAMP			      10
#define NS_MULTI_RX_TIMESTAMP			      11

#define NS_MULTI_TX_STACK				      12
#define NS_MULTI_RX_STACK				      13

#define NS_MULTI_RX_DROPPED_FRAMES		   14

#define NS_MULTI_TX_IPV4_FRAMES			   15	/* Tx IPv4 */ 
#define NS_MULTI_RX_IPV4_FRAMES			   16	/* Rx IPv4 */

#define NS_MULTI_TX_IPV6_FRAMES			   17	/* Tx IPv6 */ 
#define NS_MULTI_RX_IPV6_FRAMES			   18	/* Rx IPv6 */

#define NS_MULTI_RX_CRC_ERROR				   19	/* Rx CRC Error */
#define NS_MULTI_RX_DATA_INTEGRITY_ERROR	20	/* Rx Data Integrity Error */
#define NS_MULTI_IPV4_CHECKSUM_ERROR		21	/* IPv4 Checksum Error */
#define NS_MULTI_IPV6_PAYLOAD_CHECKSUM_ERROR	22	/* IPV6 Payload Checksum Error */
#define NS_MULTI_ALIGNMENT_ERROR			   23	/* Alignment Error */

#define NS_MULTI_TX_MPLS_FRAMES			   24	/* Tx MPLS */
#define NS_MULTI_RX_MPLS_FRAMES			   25	/* Rx MPLS */

#define NS_MULTI_TX_SIGNATURE_MPLS_FRAMES	   26	/* Tx Signature MPLS */
#define NS_MULTI_RX_SIGNATURE_MPLS_FRAMES	   27	/* Rx Signature MPLS */

#define NS_MULTI_COLLISION				      28	/* Collision */
#define NS_MULTI_XS_COLLISION				   29	/* Xs Collision */
#define NS_MULTI_RX_UNDERSIZE				   30	/* Rx Undersize */
#define NS_MULTI_RX_OVERSIZE				   31	/* Rx Oversize */
#define NS_MULTI_RX_VLAN					   32	/* Rx Vlan */
#define NS_MULTI_RX_PAUSE                 33	/* Rx_Pause */
#define NS_MULTI_RX_JUMBO				      34	/* Rx Jumbo */

#define NS_MULTI_IPV4_ARP_REPLIES_TX			   35	/* ARP Replies Sent */
#define NS_MULTI_IPV4_ARP_REPLIES_RX			   36	/* ARP Replies Received */

#define NS_MULTI_IPV4_ARP_REQUESTS_TX			   37	/* ARP Requests Sent */
#define NS_MULTI_IPV4_ARP_REQUESTS_RX			   38	/* ARP Requests Received */
 
#define NS_MULTI_IPV4_PING_REPLIES_TX		39	/* Ping Replies Sent */
#define NS_MULTI_IPV4_PING_REPLIES_RX		40	/* Ping Replies Received */
 
#define NS_MULTI_IPV4_PING_REQUESTS_TX	41	/* Ping Requests Sent */
#define NS_MULTI_IPV4_PING_REQUESTS_RX	42	/* Ping Requests Received */

#define NS_MULTI_NEIGHBOR_SOLICITATION_TX	43	/* Neighbor Solicitation Sent */ 
#define NS_MULTI_NEIGHBOR_SOLICITATION_RX	44	/* Neighbor Solicitation Received */

#define NS_MULTI_NEIGHBOR_ADVERT_TX			45	/* Neighbor Advertisement Sent */
#define NS_MULTI_NEIGHBOR_ADVERT_RX			46	/* Neighbor Advertisement Received */

#define NS_MULTI_IPV6_PING_REPLIES_TX		47	/* IPv6 Ping Replies Sent */
#define NS_MULTI_IPV6_PING_REPLIES_RX		48	/* IPv6 Ping Replies Received */

#define NS_MULTI_IPV6_PING_REQUESTS_TX		49	/* IPv6 Ping Requests Sent */
#define NS_MULTI_IPV6_PING_REQUESTS_RX		50	/* IPv6 Ping Requests Receive */

#define NS_MULTI_IPV4_ICMP_UNREACHABLE_RX	51  /* ICMP IPv4 Unreachable frames */
#define NS_MULTI_IPV6_ICMP_UNREACHABLE_RX	52  /* ICMP IPv6 Unreachable frames */

#define NS_MULTI_VLAN_PRI_0_RX				53  /* VLAN PRI 0 Received */
#define NS_MULTI_VLAN_PRI_1_RX				54  /* VLAN PRI 1 Received */
#define NS_MULTI_VLAN_PRI_2_RX				55  /* VLAN PRI 2 Received */
#define NS_MULTI_VLAN_PRI_3_RX				56  /* VLAN PRI 3 Received */
#define NS_MULTI_VLAN_PRI_4_RX				57  /* VLAN PRI 4 Received */
#define NS_MULTI_VLAN_PRI_5_RX				58  /* VLAN PRI 5 Received */
#define NS_MULTI_VLAN_PRI_6_RX				59  /* VLAN PRI 6 Received */
#define NS_MULTI_VLAN_PRI_7_RX				60  /* VLAN PRI 7 Received */

#define NS_MULTI_HW_TX_FRAMES					61  /* Number of transmitted frames in the previous second.
																 This value is updated every second, its not cumulative. */ 
#define NS_MULTI_HW_RX_FRAMES					62  /* Number of received frames in the previous second.
																 This value is updated every second, its not comulative. */ 
#define NS_MULTI_LFS_LOCAL_START     63  /* Local Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE)*/
#define NS_MULTI_LFS_LOCAL_CONTINUE  64  /* Local Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE)*/
#define NS_MULTI_LFS_REMOTE_START    65  /* Remote Link Fault Signaling Start counter, available in only events mode(NS_EVENTS_MODE)*/
#define NS_MULTI_LFS_REMOTE_CONTINUE 66  /* Remote Link Fault Signaling Continue counter, available in only events mode(NS_EVENTS_MODE)*/


/*********************************************************************************
 * Structure:   NSMLDv2GroupConfig
 * iType1:      NS_MLDV2_GROUP_CONFIG
 * Function:    HTSetStructure
 **********************************************************************************
 NSMLDv2GroupConfig Description:
 The message allows users to configure a large number of interfaces with a number
 of multicast groups in each interface at one time. 
 Valid values for uiNumInterface is from 1 to 4096.
 Valid values for uiNumGroup is from 1 to 20000. The total multiplication of the
 number of interfaces(uiNumInterface) and number of multicast groups(uiNumGroup)
 in each interface can't be over 20000.
 This command allows multiples structures, to enable configuration of multiple 
 multicast addresses 

*/

typedef struct tagMLDGroupAddressBlock
{
	unsigned char ucStartIPAddress[16];    /* starting address for IP address block */
	unsigned char ucUpperIPAddressBoundary[16]; /* upper limit for IP address block */
	unsigned short uiIPChangeStep;        /* delta value to increase ucStartIPAddress */
	unsigned short uiIPAddressOffSet;        /* offset into address,
                                        Range is (0 - 12) and no carry over beyond 4 byte range*/
   unsigned short uiNumIP;               /* number of IP address in block, 1 - 100 */   
	unsigned char ucReserved[30];
}MLDGroupAddressBlock;

#define MLDV2_EXCLUDE_FILTER_MODE	1
#define MLDV2_INCLUDE_FILTER_MODE	0

typedef struct tagNSMLDv2GroupConfig
{
   /* group configuration */
   unsigned char ucGroupIPAddress[16]; /* address of the multicast group */
   unsigned short uiFilterMode; /* possible values are MLDV2_EXCLUDE_FILTER_MODE, suppress listed IP's and                                   MLDV2_INCLUDE_FILTER_MODE, allow listed IP's  */
   unsigned long ulInitialReportGap;  /*setup the interval between each first report of the Join,
									  in microseconds, default is 10 millisecond */
   unsigned short uiNumGroup; /* number of multicast groups to create per interface*/
   
   unsigned short uiGroupIPStepCount;  /* delta value to change ucGroupIPAddress */
   unsigned short uiGroupIPAddressOffset;	/* the offset of Group IPv6 address to be increased. 
                                       Range is (0 - 12) and no carry over beyond 4 byte range */
   
   /* interface configuration */
   unsigned char ucIPAddress[16];   /* interface address */
   unsigned char ucMACAddress[6];   /* interface MAC address */
   unsigned char ucVLANEnable;   /* 1-enable,0-disabled */
   unsigned short uiNumInterface;      /* number of interfaces to create*/
   
   unsigned short uiIPAddressStepCount; /* delta value to change interface */
   unsigned short uiMACStepCount;		/* delta value to change interface MAC address */
   unsigned short uiVIDStepCount;		/* delta value to change interface VLAN ID */
   unsigned short uiIPAddressOffset; 	/* The offset of interface IPv6 address to be increased. 
                                       Range is (0 - 12) and no carry over beyond 4 byte range */   
   
   /* VLAN configurations for interface */
   unsigned char ucPRI; /* user priority 0-7 */
   unsigned char ucCFI; /* 1 = RIF present, 0 = RIF absent */	 
   unsigned short uiVID;   /* VLAN ID */   
  
   unsigned char ucPPPMode; /* PPP_USE_NONE(default) ,  PPP_USE_PPP_SESSION_ID */	       	
   unsigned short uiPPPInstance; /* starting PPP index. Currently this is valid if PPP_USE_PPP_SESSION_ID is on.                                      
                                                     PPP_USE_PPP_SESSION_ID - The least significant two bytes of this value are
                                     Considered as 'session id' in actual MLD over PPPOE packet. So user can issue MLD
                                     Over PPPOE packet without PPP session */ 	      	
   unsigned short uiPPPInstanceStepCount;  	/* ppp index change step, if this is 0 only one PPP instance will apply to the                                           groups */

   unsigned char ucNumAddressBlock;   /* number of address blocks to include, maximum 10 */

   unsigned char ucReserved[50];
   MLDGroupAddressBlock IPAddressBlock[100]; /*IPv6 address blocks maximum 10 */

} NSMLDv2GroupConfig;


/*********************************************************************************
 * Structure:   NSMLDv2GroupMod
 * iType1:      NS_MLDV2_GROUP_MOD
 * Function:    HTSetStructure
 **********************************************************************************
 NSMLDv2GroupMod Description:
 This command allows users to make a single state change in an existing multicast group, 
 or add a new multicast group if the multicast group or interface identity is new.
 The message structure is made to only allow one block change at a time for a specific 
 multicast group, which can be identified by the interface and multicast group information 
 within the structure. It also serves as a simple method to add a new multicast group into 
 the host if the multicast group and/or interface identity does not exist. 
 This message can also serve as a filter mode change. In such a case, the new IPv6 block 
 address will be treated as a new source list and the old address list in stack will be 
 properly reported and cleared.

 If the filter mode stays unchanged and source IP list block is a new block, the new address 
 block will be added only if the total number of IP blocks is still within the maximum allowable 
 limit. 

 This command only modifies uiFilterMode and IPAddressBlock, the other fields are
 used to identify the multicast group.


*/

typedef struct tagNSMLDv2GroupMod
{
   /* interface configuration */
   unsigned char ucIPAddress[16];   /* interface address */
   unsigned char ucMACAddress[6];   /* interface MAC address */
   unsigned char ucVLANEnable;   /* 1-enable,0-disabled */
 
   /* group configuration */
   unsigned char ucGroupIPAddress[16]; /* address of the multicast group */
   unsigned short uiFilterMode; /* possible values are MLDV2_EXCLUDE_FILTER_MODE, 
                                   suppress listed IP's and MLDV2_INCLUDE_FILTER_MODE,
                                   allow listed IP's */
   
   /* VLAN configurations for interface */
   unsigned char ucPRI; /* user priority 0-7 */
   unsigned char ucCFI; /* 1 = RIF present, 0 = RIF absent */	 
   unsigned short uiVID;   /* VLAN ID */   
  
   unsigned char ucPPPMode; /* PPP_USE_NONE(default) ,  PPP_USE_PPP_SESSION_ID */	       	
   unsigned short uiPPPInstance; /* starting PPP index. Currently this is valid if 
                                 PPP_USE_PPP_SESSION_ID is on.                                      
                                 PPP_USE_PPP_SESSION_ID - The least significant 
                                 two bytes of this value are considered as 'session id'
                                 in actual MLD over PPPOE packet. So user can issue MLD
                                 Over PPPOE packet without PPP session */	      	
   
   unsigned char ucReserved[50];
   MLDGroupAddressBlock IPAddressBlock; /* IPv6 address blocks maximum 10 */
 
} NSMLDv2GroupMod;


/*********************************************************************************
 * Structure:   NSMLDv2StatsInfo
 * iType1:      NS_MLDV2_STATS_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 NSMLDv2StatsInfo Description:
 Retrieve report counters for a specific multicast group.
 Applicable to only MLDv2. The following fields are used as inputs
 ucGroupIPAddress, ucVLANEnable, ucPRI, ucCFI,  uiVID, ucIPAddress
 and ucMACAddress.
*/

typedef struct tagNSMLDv2StatsInfo
{
   /* group configuration */
   unsigned char ucGroupIPAddress[16]; /* Input - address of the multicast group */
 
   /* interface configuration */
   unsigned char ucIPAddress[16];   /* Input - interface address */
   unsigned char ucMACAddress[6];   /* Input - interface MAC address */
   unsigned char ucVLANEnable;   /* Input - 1-enable,0-disabled */
 
 
   
   /* VLAN configurations for interface */
   unsigned char ucPRI; /* Input - user priority 0-7 */
   unsigned char ucCFI; /* Input - 1 = RIF present, 0 = RIF absent */	 
   unsigned short uiVID;   /* Input - VLAN ID */   
  
   unsigned char ucPPPMode; /* PPP_USE_NONE(default) ,  PPP_USE_PPP_SESSION_ID */	       	
   unsigned short uiPPPInstance; /* starting PPP index. Currently this is valid
                                 if PPP_USE_PPP_SESSION_ID is on.                                      
                                 PPP_USE_PPP_SESSION_ID - The least significant 
                                 two bytes of this value are considered as
                                 'session id' in actual MLD over PPPOE packet. 
                                 So user can issue MLD over PPPOE packet without
                                 PPP session */	

  /* output fields */
   unsigned long ulV2QueryReceived; /* v2 query reports received */  
   unsigned long ulV1QueryReceived; /* v1 queries received */
   unsigned long ulV1ReportReceived; /* v1 query reports received */
   unsigned long ulTotalV2ReportSent; /* total number of version 2 reports sent out */  
 
   unsigned long ulIsIncludeSent; /* total number of Is Included group record
                                     messages sent out */
   unsigned long ulIsExcludeSent; /* total number of Is Excluded group record
                                     messages sent out */
   unsigned long ulToIncludeSent; /* total number of To Included group record
                                     messages sent out */
   unsigned long ulToExcludeSent; /* total number of To Excluded group record
                                     messages sent out */	
   unsigned long ulAllowSent; /* total number of Allow group record messages
                                 sent out */
   unsigned long ulBlockSent; /* total number of Block group record messages
                                 sent out */
   unsigned char ucReserved[50];
} NSMLDv2StatsInfo;


/*********************************************************************************
 * Structure:   NSMLDGroupInfo
 * iType1:      NS_MLD_GROUP_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 NSMLDGroupInfo Description:
 Retrieve the join and leave timestamp for multicast groups and interfaces (MLDv1
 and MLDv2).
 
 No inputs are need when used with NS_MLD_ALL_GROUP_INFO, information for all
 groups are returned.
 When used with NS_MLD_GROUP_INFO the following fields are used as inputs 
 ucGroupIPAddress, ucVLANEnable, ucPRI, ucCFI,  uiVID, ucIPAddress and ucMACAddress. 
 The Inputs are used to identify the  Multicast group, the leave and join timestamps
 for the group is returned.
 
 TimeStamps are per multicast group, they are in units of 0.1 micro-seconds.
 TimeStamp values initially start from 0, when Chasis is turned on. Timestamp 
 counter overflows after 430 seconds.

 JoinTimeStamps and LeaveTimeStamps will change for any of these 2 events.

 An event is considered JOIN for MLDv2, when the mode is INCLUDE with a non-empty
 source list or EXCLUDE with an empty source list.

 An event is considered LEAVE for MLDv2, when the mode is EXCLUDE with a non-empty
 source list or INCLUDE with an empty source list.

 Comments for "ulLastStateTimestamp":

 In MLDv2, all the membership reports sent out from a port are called state change reports.  
 Whenever the host wants to change the current state of membership on a specific group, 
 such as different source list, the host should send out a state change report.  

 Therefore, the new state change timestamp of the group should change with each report of 
 that group sent out.  However, there are two special case.  If it is the first report to 
 the group, the MLD stack will treat it as a join report and save the timestamp to 
 "ulJoinTimestamp".  If the report is trying to INCLUDE NULL, the MLD stack will treat it 
 as leave report and save the timestamp to "ulLeaveTimestamp".  In these two cases, 
 "ulLastStateTimestamp" would not be updated.

 Example

 Join		      t1
 state change	t2
 state change	t3
 state change	t4
 leave         t5

 => ulJoinTimestamp = t1, ulLastStateTimestamp = t4, and ulLeaveTimestamp = t5
*/

typedef struct tagNSMLDGroupInfo
{
 /* inputs */
  unsigned char ucGroupIPAddress[16]; /* address of the multicast group */
  unsigned char ucIPAddress[16];   /* interface address */
  unsigned char ucMACAddress[6];   /* interface MAC address */
  unsigned char ucVLANEnable;   /* 1-enable,0-disabled */
  unsigned char ucPRI; /* user priority 0-7 */
  unsigned char ucCFI; /* 1 = RIF present, 0 = RIF absent */	 
  unsigned short uiVID;   /* VLAN ID */   
  unsigned char ucPPPMode; /* PPP_USE_NONE(default) ,  PPP_USE_PPP_SESSION_ID */	       	
  unsigned short uiPPPInstance; /* starting PPP index. Currently this is valid
                                if PPP_USE_PPP_SESSION_ID is on.                                      
                                PPP_USE_PPP_SESSION_ID - The least significant
                                two bytes of this value are considered as
                                'session id' in actual MLD over PPPOE packet.
                                So user can issue MLD over PPPOE packet
                                without PPP session */
  
 /* outputs */
 unsigned long ulJoinTimestamp;        /* Join Time Stamp */
 unsigned long ulLeaveTimestamp;       /* Leave Time Stamp */
 unsigned long ulLastStateTimestamp;   /* Timestamp for the last state change.  This
                                       excludes the initial join report and the leave
                                       report.  The timestamp for these 2 events
                                       are available in the previous 2 fields.  */
 unsigned char ucReserved[46];
}NSMLDGroupInfo;


/*********************************************************************************
 * Structure:   NSMLDv2ListenerReportConfig
 * iType1:      NS_MLDV2_LISTENER_REPORT_CONFIG
 * Function:    HTSetStructure
 **********************************************************************************
 NSMLDv2ListenerReportConfig Description:
 Configures the Type (ICMPv6 header) and the Destination Address field
 (Destination IP in IPv6 header, address where reports are sent to.
 All MLDv2-capable multicast routers listen to this address) in Version 2 Multicast 
 Listener Report.
 Currently the value for Version 2 Multicast Listener Report is not yet
 available so users can set it with this command.

  If this command is not used, the default value for Type field is 206
*/

typedef struct tagNSMLDv2ListenerReportConfig
{
   unsigned char ucType;    /* value to use in Type field */
   unsigned char ucDestinationIP[16];  /* address of destination IP ,
                                    address where reports are sent to*/
   unsigned char ucReserved[20]; 
} NSMLDv2ListenerReportConfig;

/*********************************************************************************
 * Structure:  NSMulticastKeepAliveConfig
 * iType1:     NS_MULTICAST_KEEP_ALIVE_CONFIG
 * Function:   HTSetStructure
 ********************************************************************************* 
 NSMulticastKeepAliveConfig Description: This structure is to start or stop the sending
 of multicast "keep-alive" UDP packets periodically to multicast group addresses, to extend
 the PIM-SM timers to prevent the multicast router entries from being deleted. This is a
 port based command, it will control the multicast "keep-alive" packet sending for the streams
 which have the flag "ucMulticastKeepAliveEnable" enabled in stream extension.
 
 uiAction possible values
 NS_MULTICAST_KEEP_ALIVE_START
 NS_MULTICAST_KEEP_ALIVE_STOP

 Configuration procedures for the multicast keep alive
   1. Configure any streams (except StreamSmartBits/SmartBits128) by using either L3 stream
      command or NS new stream command. Note that only one single VLAN is supported.
   2. (Optional) Configure VFD using L3 VFD command or NS new stream VFD command
   3. Enable multicast keep alive in L3 stream extension or NS new stream command
      NSTxConfig
   4. Start transmitting the multicast keep alive packets using NS_MULTICAST_KEEP_ALIVE_START 
      with NSMulticastKeepAliveConfig.
   5. Stop transmitting the multicast keep alive packets using NS_MULTICAST_KEEP_ALIVE_STOP
      with NSMulticastKeepAliveConfig.
 By default, multicast keep alive should be disabled to avoid resource waste and receive
 unexpected packets.
 
 NOTES for multicast keep alive:
   1. Any type of streams (execpt StreamSmartBits/SmartBits128) can be configured to use
      multicast keep alive. However the transmitted packets will always be UDP packets
      with frame length 100.
   2. The fields of Ethernet/IPv4/IPv6 header are from the stream configuration.
   3. If UDP streams are configured, the UDP header is from the stream configuration.
      If non-UDP streams are configured, the default value 1055/537 will be used for the
      Src/Dest UDP port. UDP length is fixed since the frame length is always 100.
   4. The regular stream transmission parameter (Tx mode, burst count, gap) is not applicable
      to the multicast keep alive. The transmission is completely controlled by
      NS_MULTICAST_KEEP_ALIVE_CONFIG.
   5. Netcom signature fields will never be in the packets.
   6. The field "uiBlockCount" in NSVFD is always fixed value 1 for multicast keep alive.
   7. Since MLD/IGMP and stream configuration are in separate process, user should properly
      configure streams with appropriate group address of IGMP/MLD to use multicast keep alive.
   8. Default keep alive time is 30 sec. Minimum value can be configured as 1 sec and Max 65355.
      If minimum value is configured then the card will not do any evenly distributed configuration.
      It will just try to burst all the packets after 1 sec.
   9. For large number of keep alive packets (> 3000), the packets will be evenly distributed
      instead of burst after each time interval, e.g. if 1 stream configured with 100000 using
      VFD, time interval 30 seconds, the card will send approximately 3333 packets after 1 second. 
*/

typedef struct tagNSMulticastKeepAliveConfig
{
    unsigned short   uiAction;  /* Start or stop sending the multicast "keep-alive"
                                  UDP packet, possible values
                                    NS_MULTICAST_KEEP_ALIVE_START
                                    NS_MULTICAST_KEEP_ALIVE_STOP */
    unsigned short  uiTimeInterval;  /* Time interval to send the multicast "keep-alive"
                                        UDP packet, in the unit of seconds, valid range 1-65565,
                                        default 30. Applicable when ucAction is Start. 
                                        If zero is entered, it will use the default 30 */
    unsigned char    ucReserved[64];
}NSMulticastKeepAliveConfig;

#define NS_MULTICAST_KEEP_ALIVE_START    0x01 /* Start sending multicast "keep-alive" UDP packet */
#define NS_MULTICAST_KEEP_ALIVE_STOP     0x02 /* Stop sending multicast "keep-alive" UDP packet */

/*********************************************************************************
 * Structure:  NSPortConfig
 * iType1:     - NS_PORT_CONFIG
 *					- NS_PORT_CONFIG_INFO
 * Function:   - HTSetStructure
 *					- HTGetStructure

 NSPortConfig Description: Configure port settings.  This command is applicable for 
 all TeraMetrics modules (LAN, POS and ATM).

 ucARPUniqueMACPattern field:
 To configure Reply to Unique MAC address use  L3_CTRL_ARP_RESPONSES_WITH_UNIQUE_MAC 
 in control field of L3_TX_ADDRESS and  NS_PORT_ADDRESS, or 
 L3_CTRL_IPV6_ND_RESPONSES_WITH_UNIQUE_MAC in ulControl field of L3_TX_IPV6_ADDRESS 
 command.

 **********************************************************************************/
typedef struct tagNSPortConfig
{
   unsigned char  ucEnableFullCustomStreamID; /* Allow usage of the upper nibble of the stream
                                                 id by disabling the firmware from automatically
                                                 overwriting this nibble with protocol values.  
                                                 The stream id can be customized for each stream 
                                                 by using the ucEnableCustomStreamID and 
                                                 ulCustomStreamID fields for the 
                                                 L3_DEFINE_STREAM_EXTENSION and
                                                 L3_MOD_STREAM_EXTENSION message functions.
                                                 Note that this field is only applicable for 
                                                 the TeraMetrics family of modules.
                                                */
   unsigned char ucARPUniqueMACPattern[2];    /* 2 byte Pattern to be used as the MSB in response 
	                                              to ARP request,when Reply to Unique MAC address 
	                                              is enabled. Reply to Unique MAC address is enabled 
	                                              with L3_TX_ADDRESS, NS_PORT_ADDRESS or 
	                                              L3_TX_IPV6_ADDRESS.  
	                                            */
   unsigned char	ucReserved[129];  /* reserved */
} NSPortConfig;



/*********************************************************************************
 * Structure:   NSCTConfig
 * iType1:      NS_CT_CONFIG/NS_CT_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
   NSCTCRCConfig Description: To setup/retrieve cut-through configurations  
 **********************************************************************************

  ucCRCErrorEnable - Injects or resets CRC Errors into Frames from the Cut-through channel.
  For Lan Terametric cards (Lan-33xx,Terametrics XD and Xenpak cards)
*/
typedef struct tagNSCTConfig
{
   unsigned char ucCRCErrorEnable; /* 1 - enable (inject CRC errors)
								   0 - reset CRC errors */

   unsigned char ucReserved[64]; 
}NSCTConfig;



/*********************************************************************************
 * Structure:   NSDOT1XSupplicantPortConfig
 * iType1:      NS_DOT1X_SUPPLICANT_PORT_CONFIG/NS_DOT1X_SUPPLICANT_PORT_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantPortConfig Description: Port Configuration for Supplicants.
  
 ucSessionControlMode:
 Default mode is DOT1X_SESSION_CONTROL_EVEN_BURST. In this mode sessions will be
 started every Session Setup Delay time (ulSessionSetupDelay). If there are
 ulSessionMaxPending number of pending sessions, no more session will be started
 until after the next delay.  Teardown of sessions will be done the same way except
 that ulSessionMaxPending will not apply as teardown of session is a one-way handshaking
 protocol exchange.

 The other mode is Varied Burst Mode (DOT1X_SESSION_CONTROL_VARIED_BURST). In this mode,
 the number of sessions to start in each time slot is configured and hence can creates
 an uneven profile. In that case,  session burst size (ulSessionBurstSize) is not
 applicable.

 EAP types supported (Authentication Types): 
 DOT1X_EAP_TYPE_EAPMD5		0x00000001
 DOT1X_EAP_TYPE_EAPTLS		0x00000002
 DOT1X_EAP_TYPE_EAPPEAP	   0x00000004 
 DOT1X_EAP_TYPE_TTLS			0x00000010
  
 Authentication Modes
 DOT1X_PORT_MODE_MULTI_AUTHENTICATION			1
 DOT1X_PORT_MODE_SINGLE_HOST						2
 DOT1X_PORT_MODE_MULTI_HOST						3

 ucPEAPPhase2Type 
 DOT1X_EAP_TYPE_PHASE2_MSCHAPV2					1

 ucTTLSPhase2Type 
 DOT1X_TTLS_PHASE2_UNDEFINED			0		
 DOT1X_TTLS_PHASE2_PAP					1		
 DOT1X_TTLS_PHASE2_CHAP					2		
 DOT1X_TTLS_PHASE2_MSCHAP				3
 DOT1X_TTLS_PHASE2_MSCHAPV2			4

  
*/


typedef struct tagNSDOT1XSupplicantPortConfig 
{      
    
	unsigned char ucSessionControlMode;	  /* possible values are DOT1X_SESSION_CONTROL_EVEN_BURST (default) or
														   DOT1X_SESSION_CONTROL_VARIED_BURST */

	unsigned char ucSessionBurstNumSlots; /* number of slots to be used in ucSessionControlSlots,
	                                            default is 1 */

	unsigned short uiSessionMaxPending;   /* Maximum number of supplicants in pending state
	                                       allowed. No more session will be started unless the number drops,
	                                       1 - 256 default is 100 */  

	unsigned long ulSessionSetupDelay;    /* time in milliseconds that sessions are started,
	                                        20 ms - 65536 ms , default and minimum is 20 ms */ 

   unsigned long ulSessionTearDownDelay;  /* time in milliseconds that sessions are terminated,
	                                        20 ms - 65536 ms,  default and minimum is 20 ms */ 

   unsigned long ulSessionBurstSize;      /* Number of supplicants started or terminated back-to-back, 
	                                       1 - 256 default is 1 */

   unsigned short uiSessionBurstSlots[100]; /* each slot is the number of supplicants to be started
	                                              in each time interval,
	                                              1-256 per slot, default is 1 for each slot */


   unsigned long ulAuthenticationType; /* List of EAP type supported (one or more) 
                                             DOT1X_EAP_TYPE_EAPMD5		 
                                             DOT1X_EAP_TYPE_EAPTLS		 
                                             DOT1X_EAP_TYPE_EAPPEAP
															DOT1X_EAP_TYPE_TTLS
															
                                        */

	unsigned char ucAuthenticationMode;	 /* Specifies if port-based authentication or MAC -based authentication
													   is used

                                          DOT1X_PORT_MODE_MULTI_AUTHENTICATION  (default) 
														Allows multiple supplicants with unique MAC addresses to be 
														authenticated independently. MAC-based authentication will be used. 
														Group MAC address is not allowed as destination MAC address for 
														incoming 802.1x packets

                                          DOT1X_PORT_MODE_SINGLE_HOST, DOT1X_PORT_MODE_MULTI_HOST
														Allows only the supplicant with index 0 to be authenticated. 
														Port-based authentication will be used
	                                     */

	unsigned char ucEnableMulticastDestinationMac; /* If set, multicast destination address (01:80:C2:00:00:03)
																	is used for all outgoing frames. Otherwise unique 
																	authenticator MAC address is used once if its known.
																	Default is 0 (not set) */

		 
	unsigned char ucEnableCNCheck[32];   /* Verify that the server certificate has this value in it's CN field.
												   Default is NULL */

   unsigned char ucEnableCNExact;   /* If set, use exact CN match. Default 0 (not set) */

   unsigned short uiFragmentSize;   /* Fragment size of TLS packets. Ranges from 500-1400. Default is 1380 */

	unsigned char ucEnableSessionResume;   /* If set, enable TLS session resumption. Default 0 (not set) */

	unsigned char ucPEAPPhase2Type;  /* Phase 2 EAP type for EAP-PEAP: MSCHAPV2. Default is MSCHAPV2,
	                                    DOT1X_EAP_TYPE_PHASE2_MSCHAPV2*/

	unsigned char ucTTLSPhase2Type;  /* Phase 2 EAP type for EAP-TTLS:  Default is PAP,
	                                    DOT1X_TTLS_PHASE2_UNDEFINED,		
													DOT1X_TTLS_PHASE2_PAP,		
													DOT1X_TTLS_PHASE2_CHAP,		
													DOT1X_TTLS_PHASE2_MSCHAP,
													DOT1X_TTLS_PHASE2_MSCHAPV2 */

	unsigned char ucUserCertificateFileName[32];   /* User certificate file name */

   unsigned char ucUserKeyFileName[32];				/* User certificate file name */

   unsigned char ucKeyPassword[16];				/* Key password */

	unsigned char ucRootCertificateFileName[32];	/* Root certificate file name */

   unsigned char ucRandomFileName[32];				/* Name of random file */

	unsigned char ucReserved[255];         /* Reserved */

}NSDOT1XSupplicantPortConfig;

/* Possible values for ucSessionControlMode */
#define 	DOT1X_SESSION_CONTROL_EVEN_BURST				1
#define 	DOT1X_SESSION_CONTROL_VARIED_BURST		   2

/* Possible values for ucAuthenticationMode */
#define DOT1X_PORT_MODE_MULTI_AUTHENTICATION			1
#define DOT1X_PORT_MODE_SINGLE_HOST						2
#define DOT1X_PORT_MODE_MULTI_HOST						3

/* List of supported EAP types for port */
#define DOT1X_EAP_TYPE_EAPMD5		0x00000001
#define DOT1X_EAP_TYPE_EAPTLS		0x00000002
#define DOT1X_EAP_TYPE_EAPPEAP	0x00000004 
#define DOT1X_EAP_TYPE_TTLS		0x00000010 

#define DOT1X_EAP_TYPE_MSCHAPV2	0x00000008 
#define DOT1X_EAP_TYPE_SIM			0x00000020 /* Reserved */
#define DOT1X_EAP_TYPE_OTP			0x00000040 /* Reserved */
#define DOT1X_EAP_TYPE_LEAP		0x00000080 /* Reserved */

/* Define constants for ucPEAPPhase2Type field */
#define DOT1X_EAP_TYPE_PHASE2_MSCHAPV2	0x00000001

/* Define constants for ucTTLSPhase2Type field */
#define DOT1X_TTLS_PHASE2_UNDEFINED			0		
#define DOT1X_TTLS_PHASE2_PAP					1		
#define DOT1X_TTLS_PHASE2_CHAP				2		
#define DOT1X_TTLS_PHASE2_MSCHAP				3
#define DOT1X_TTLS_PHASE2_MSCHAPV2			4

/*********************************************************************************
 * Structure:   NSDOT1XSupplicantConfig
 * iType1:      NS_DOT1X_SUPPLICANT_CONFIG/NS_DOT1X_SUPPLICANT_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantConfig Description: Configure one or more Supplicants
 
 If two or more supplicants are configured with one call to NS_DOT1X_SUPPLICANT_CONFIG, 
 the supplicants will have the same configuration, including source MAC address,
 Supplicant ID and User Password. 
 You have to use other modification messages (NS_DOT1X_SUPPLICANT_MODIFY,
 NS_DOT1X_SUPPLICANT_FILL) to change the fields.
  
 Currently a maximum of 256 Supplicants are supported

 Use DOT1X_ALL as iType3(Count) to retrieve configuration of all the 
 supplicants on the port.
 
 Supplicant process will be active for both the modes.

 uiAuthenticationTime:
 It is the time period that a supplicant waits for a response from the Authenticator
 before timing it out.

 uiHeldTime:
 Its the time period during which a supplicant will not attempt to acquire an Authenticator, 
 after authentication failure

 EAP types supported (Authentication Types): 
 DOT1X_EAP_TYPE_EAPMD5		0x00000001
 DOT1X_EAP_TYPE_EAPTLS		0x00000002
 DOT1X_EAP_TYPE_EAPPEAP	   0x00000004 
 DOT1X_EAP_TYPE_TTLS			0x00000010
*/


typedef struct tagNSDOT1XSupplicantConfig 
{      
    unsigned long ulIndex;	         /* starting index number of supplicants,
	                                 range of possible values is 0 - 255 */

    unsigned long ulCount;		      /* Number of supplicants to configure with consecutive indexes,
	                                  maximum is 256 */

    unsigned char ucSourceMAC[6];	/* Unique source MAC address of supplicant */  

    unsigned char ucAuthenticatorMAC[6];  /* Optional, in most cases, this should not be defined (all zeros).
	                                          The authenticator MAC address is learnt during protocol exchanges.
	                                          If configured, it forces supplicant to send its packets to this 
	                                          destination MAC address */   

    unsigned char ucEnableSendEAPStart;  /* If set, supplicant sends out EAPOL-start message when session
	                                         authentication is attempted. Otherwise, it waits for the 
	                                         authenticator (DUT) to send an ID Request. Default is 1 (set) */  
	 
    unsigned char ucAuthenticationType;	/* EAP-MD5,  EAP-TLS ,EAP-PEAP possible values are 
														DOT1X_EAP_TYPE_EAPMD5 (default),
														DOT1X_EAP_TYPE_EAPTLS 
	                                       DOT1X_EAP_TYPE_EAPPEAP 
	                                       DOT1X_EAP_TYPE_TTLS	*/
	 
    unsigned short uiMaxStart;		   /* Maximum successive EAPOL-start packets, default is 3 */  

    unsigned short uiStartTime;	   /* Start Period, time when EAPOL start packet is to be 
	                                    transmitted, default is 30 s */

    unsigned short uiAuthenticationTime; 	/* Authentication period, range is 1 to 255 seconds,
	                                          default is 30 s */ 

    unsigned short uiHeldTime;		   /* Time to hold after a failure: 1 to 255 seconds, default is 60 s*/  

    unsigned short uiRetryCount;	         /* Number of times to retry authentication after failure,
	                                                default is 0,maximum 65535 */   
    unsigned char ucSupplicantID[256];	   /* Supplicant ID, This is the ID used in EAPOL-response/Identity 
	                                          and used by authentication server for EAP */   
	 
    unsigned char ucUserPassword[16];	/* This is used for MD5 or MSCHAPV2 and corresponds to the password 
														used in authentication server database. It is also used as 
	                                       password for phase two EAP exchanges */ 


	 unsigned char ucUserName[256];   /* This is the user name used in MD5 and PEAP phase two protocol such
	                                    as MSCHAPV2 */

    
    unsigned char ucEnableAuthWithoutResponse;	/* If set, supplicant becomes authenticated 
																	when there is no response to maxStart number of  START packet */

	/* VLAN Configuration */
	 unsigned char ucVLANEnable;    /*1 - enable,0 - disabled specifies whether or not this 
													supplicant has an associated VLAN tag */
		
	unsigned char ucPRI;					/* user priority 0-7 (3 bits) */
	unsigned char ucCFI;					/* 1 = RIF present, 0 = RIF absent  */
	unsigned short uiVID;		      /* VLAN ID (12 bits) */

   unsigned char ucKeyPassword[16];				/* Key password */
	
	unsigned char ucUserMode;					/* Reserved -
														DOT1X_USER_MODE_NORMAL (default) or 
	                                       DOT1X_USER_MODE_FORCE_FAILURE */

	unsigned char ucCertificateUseMode;  /* Use Port level certificate or Supplicant Level certificate.
												   0 = Use Port Level Certificate Files (default) 
													1 = Use Supplicant Certificate Files
												*/
	 
	unsigned short uiIgnoreEAPIDRequest;	/* Reserved -
														If non-zero, do not respond to EAP-ID Resquest for this number
														of times.  Range from 0 to 65535. Default is 0 */

   unsigned short uiIgnoreEAPAuthMessage;		/* Reserved -
																If non-zero, do not respond to EAP authentication messages for 
														this number of times. Range from 0 to 65535. Default is 0. */

	unsigned char ucReserved[234];	/* Reserved field */


}NSDOT1XSupplicantConfig;

/* ucUserMode constants */
#define DOT1X_USER_MODE_NORMAL				1 /* Reserved */
#define DOT1X_USER_MODE_FORCE_FAILURE		2 /* Reserved */


#define DOT1X_ALL  0xFFFF


/*********************************************************************************
 * Structure:   NSDOT1XSupplicantStatsInfo
 * iType1:      NS_DOT1X_SUPPLICANT_STATS_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantStatsInfo Description: Retrieve Statistics of one or more Supplicant 
 Use DOT1X_ALL as iType3 (Count) to retrieve statistics of all the 
 supplicants on the port.All Tx Statistics are to be considered as "attempted.
  
*/


typedef struct tagNSDOT1XSupplicantStatsInfo 
{      
    unsigned long ulIndex;		            /* index number of supplicant */  
    unsigned long ulTxEAPOLStartFrames;   /* The number of EAPOL Start frames that 
	                                          have been transmitted by this Supplicant */   
    unsigned long ulTxEAPOLLogOffFrames;  /* The number of EAPOL Logoff frames that
	                                           have been transmitted by this Supplicant */  
    unsigned long ulTxEAPOLResponseIDFrames; /* The number of EAPOL Resp/Id frames that
	                                             have been transmitted by this Supplicant */   
    unsigned long ulTxEAPOLResponseFrames; /* The number of valid EAPOL Response frames
	                                           (other than Resp/Id frames) that hve been 
	                                           transmitted by this Supplicant */   
    unsigned long ulTxEAPOLKeyFrames;      /* The number of EAPOL-Key frames that have 
	                                           been sent by this Supplicant */   
    unsigned long ulTxEAPOLFrames;         /* The number of EAPOL frames of any type that 
	                                           have been transmitted by this Supplicant */
    unsigned long ulRxEAPOLFrames;         /* The number of EAPOL frames of any type that
	                                           have been received by this Supplicant */ 
    unsigned long ulRxEAPOLRequestIDFrames; /* The number of EAPOL Request frames 
	                                             that have been received by this Supplicant */  
    unsigned long ulRxEAPOLRequestFrames;    /* number of EAPOL request frames received */ 
    unsigned long ulRxEAPOLInvalidFrames;    /* number of invalid EAPOL frames received */ 
    unsigned long ulRxEAPOLLengthErrorFrames;/* The number of EAPOL frames that have 
	                                             been received by this Supplicant in which 
	                                             the Packet Body Length field  is invalid */ 
    unsigned long ulRxEAPOLKeyFrames;        /* number of EAPOL key frames received */  
    unsigned long ulRxEAPOLSuccessFrames;    /* number of EAPOL success frames received */   
    unsigned long ulRxEAPOLFailureFrames;    /* number of EAPOL failure frames received */  
    unsigned long ulRxEAPOLAlertFrames;   
	 unsigned long ulEAPOLFrameVersion;       /* protocol version number carried in the most 
	                                             recently received EAPOL frame */  
    unsigned char ucLastFrameMACAddress[6];  /* source MAC address carried in the
	                                             most recently received frame */   
    unsigned char ucReserved[128];           /* Reserved */

}NSDOT1XSupplicantStatsInfo;


/*********************************************************************************
 * Structure:   NSDOT1XSupplicantControl
 * iType1:      NS_DOT1X_SUPPLICANT_CONTROL
 * Function:    HTSetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantControl Description: Send an action on one or more supplicants
 Use DOT1X_ALL as ulCount to control all the supplicants on the port.

 DOT1X_SUPPLICANT_START
 Start one or more supplicants. The actual starting rate of supplicants will depend
 on the rate control setting (in NSDOT1XSupplicantPortConfig). 
 Only supplicant in idle or disconnected session state will be started

 DOT1X_SUPPLICANT_STOP
 Stop one or more supplicants. The actual stopping rate of supplicants will depend 
 on the the rate control setting.

 DOT1X_SUPPLICANT_CLEAR_SUPPLICANT_STATS
 It clears the statistics counter of the supplicants and reset the failure code

 DOT1X_SUPPLICANT_DELETE
 It removes/deletes one or more supplicant entities of the card. The supplicant will
 first logoff if it is in authenticated session state. Otherwise, it will simply be 
 removed and destroyed, including its statistics.

 DOT1X_SUPPLICANT_RETRY 
 It retries one or more failed supplicants. In the case of retrying all supplicants,
 only supplicant with failed status in disconnected session will be retried.

 DOT1X_SUPPLICANT_REAUTHENTICATE
 It does not stop the supplicant authentication. It will however send a EAPOL START
 packet to the authenticator to start the authentication again. During this time, 
 the supplicant is maintained as authenticated though. This option is only available
 when a supplicant is in AUTHENTICATED state.No logoff will be sent first.

 DOT1X_SUPPLICANT_CLEAR_SESSION_STATS
 It clears the session statistics for the port.
*/


typedef struct tagNSDOT1XSupplicantControl 
{      
    unsigned long ulIndex;		/* Starting index number of supplicant */
    unsigned long ulCount;		/* The number of consecutive supplicant to control */   
    unsigned long ulAction; 	/* Action on the supplicant: Start/Stop/ClearStats 
	                             possible values are,
	                             DOT1X_SUPPLICANT_START,
	                             DOT1X_SUPPLICANT_STOP,
	                             DOT1X_SUPPLICANT_CLEAR_SUPPLICANT_STATS,
	                             DOT1X_SUPPLICANT_DELETE,
	                             DOT1X_SUPPLICANT_RETRY,
	                             DOT1X_SUPPLICANT_REAUTHENTICATE 
	                             DOT1X_SUPPLICANT_CLEAR_SESSION_STATS*/ 
    unsigned char ucReserved[64];

}NSDOT1XSupplicantControl;

/* ulAction constants */
#define DOT1X_SUPPLICANT_START				1 /* Start supplicant authentication */
#define DOT1X_SUPPLICANT_STOP					2 /* Stop supplicant authentication */
#define DOT1X_SUPPLICANT_CLEAR_SUPPLICANT_STATS		3 /* Clear supplicant protocol statistics */
#define DOT1X_SUPPLICANT_DELETE				4 /* Delete supplicant  */
#define DOT1X_SUPPLICANT_RETRY				5 /* Retry supplicant authentication */
#define DOT1X_SUPPLICANT_REAUTHENTICATE	    6 /* Reauthenticate */
#define DOT1X_SUPPLICANT_CLEAR_SESSION_STATS	7 /* Clear session statistics for the port */

/*********************************************************************************
 * Structure:   NSDOT1XSupplicantStatusInfo
 * iType1:      NS_DOT1X_SUPPLICANT_STATUS_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantStatusInfo Description: 
 Retrieve the status information for one or multiple supplicants including the
 following, 802.1x supplicant state, Supplicant session state, Failure code, 
 Session setup time and number of retries.
 Use DOT1X_ALL as iType3(Count) to retrieve status information of all the
 supplicants on the port. 
  
 ucSessionState constants:
 DOT1X_SUPPLICANT_SESSION_IDLE
 DOT1X_SUPPLICANT_SESSION_PENDING_TO_START
 DOT1X_SUPPLICANT_SESSION_AUTHENTICATING
 DOT1X_SUPPLICANT_SESSION_AUTHENTICATED
 DOT1X_SUPPLICANT_SESSION_PENDING_TO_TERMINATE
 DOT1X_SUPPLICANT_SESSION_DISCONNECTED

 SupplicantState constants: 
 DOT1X_SUPPLICANT_LOG_OFF
 DOT1X_SUPPLICANT_DISCONNECTED
 DOT1X_SUPPLICANT_CONNECTING	
 DOT1X_SUPPLICANT_ACQUIRED
 DOT1X_SUPPLICANT_AUTHENTICATING
 DOT1X_SUPPLICANT_HELD
 DOT1X_SUPPLICANT_AUTHENTICATED	

 FailureCode constants:
 DOT1X_SUPPLICANT_FAILURE_NONE
 DOT1X_SUPPLICANT_FAILURE_UNKNOWN
 DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED
 DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED
 DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE
 DOT1X_SUPPLICANT_FAILURE_EAP_NOT_SUPPORTED     
 DOT1X_SUPPLICANT_FAILURE_USER_LOGOFF           
 DOT1X_SUPPLICANT_FAILURE_AUTH_LOGOFF    
 DOT1X_SUPPLICANT_FAILURE_AUTH_PERIOD_TIMEOUT  
 DOT1X_SUPPLICANT_FAILURE_EAPOL_START_NO_RESPONSE  


*/

typedef struct{    
	unsigned long  ulSecond;   
	unsigned long ulMicrosecond;
} NSSetupTime;

typedef struct tagNSDOT1XSupplicantStatusInfo 
{      
   
    unsigned long ulIndex;		      /* Index number of supplicant */
    unsigned char ucSessionState; 	/* Supplicant session state
	                                    possible values are 
	                                    DOT1X_SUPPLICANT_SESSION_IDLE,
	                                    DOT1X_SUPPLICANT_SESSION_PENDING_TO_START,
	                                    DOT1X_SUPPLICANT_SESSION_AUTHENTICATING,
	                                    DOT1X_SUPPLICANT_SESSION_AUTHENTICATED,
	                                    DOT1X_SUPPLICANT_SESSION_PENDING_TO_TERMINATE
	                                    DOT1X_SUPPLICANT_SESSION_DISCONNECTED */
    unsigned char ucSupplicantState; /* Supplicant state machine state 
	                                    possible values are, 
	                                    DOT1X_SUPPLICANT_LOG_OFF,
	                                    DOT1X_SUPPLICANT_DISCONNECTED,
	                                    DOT1X_SUPPLICANT_CONNECTING,
	                                    DOT1X_SUPPLICANT_ACQUIRED,
	                                    DOT1X_SUPPLICANT_AUTHENTICATING,
	                                    DOT1X_SUPPLICANT_HELD,
	                                    DOT1X_SUPPLICANT_AUTHENTICATED */

    unsigned char ucFailureCode; 	/* Failure code, possible values are
                                       DOT1X_SUPPLICANT_FAILURE_NONE
                                       DOT1X_SUPPLICANT_FAILURE_UNKNOWN
                                       DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED
                                       DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED
                                       DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE
	                                    DOT1X_SUPPLICANT_FAILURE_EAP_NOT_SUPPORTED     
													DOT1X_SUPPLICANT_FAILURE_USER_LOGOFF           
													DOT1X_SUPPLICANT_FAILURE_AUTH_LOGOFF    
													DOT1X_SUPPLICANT_FAILURE_AUTH_PERIOD_TIMEOUT  
													DOT1X_SUPPLICANT_FAILURE_EAPOL_START_NO_RESPONSE */

    unsigned long ulRetries; 		   /* Number of retries attempted */ 
	 
	 NSSetupTime LastSetupTime; 		/* The last attemped Session setup time */   
    unsigned char ucReserved[64];
                                       
}NSDOT1XSupplicantStatusInfo;

/* ucSessionState constants */
#define DOT1X_SUPPLICANT_SESSION_IDLE									1
#define DOT1X_SUPPLICANT_SESSION_PENDING_TO_START					2
#define DOT1X_SUPPLICANT_SESSION_AUTHENTICATING						3
#define DOT1X_SUPPLICANT_SESSION_AUTHENTICATED						4
#define DOT1X_SUPPLICANT_SESSION_PENDING_TO_TERMINATE				5
#define DOT1X_SUPPLICANT_SESSION_DISCONNECTED						6

/* SupplicantState constants */
#define DOT1X_SUPPLICANT_LOG_OFF				1
#define DOT1X_SUPPLICANT_DISCONNECTED		2
#define DOT1X_SUPPLICANT_CONNECTING 		3	
#define DOT1X_SUPPLICANT_ACQUIRED			4
#define DOT1X_SUPPLICANT_AUTHENTICATING	5
#define DOT1X_SUPPLICANT_HELD					6
#define DOT1X_SUPPLICANT_AUTHENTICATED		7

/* FailureCode constants */
#define DOT1X_SUPPLICANT_FAILURE_NONE                     0   /* No failure */
#define DOT1X_SUPPLICANT_FAILURE_UNKNOWN                  1   /* Unknown failure code */
#define DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED   2 /* In ACQUIRED state,
                                       a FAILURE packet is received instead of
                                       an EAP Request (non ID) packet. This could
                                       be a mismatched ID */
#define DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED      3 /* In AUTHENTICATING state,
                                       a FAILURE packet is received instead of
                                       a EAP Request packet or SUCCESS packet.
                                       This could be a mismatched ID or password */
#define DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE    4  /* MaxStart EAPOL start
                                       has been sent; session is forced to successful */

#define DOT1X_SUPPLICANT_FAILURE_EAP_NOT_SUPPORTED    5  /* EAP method not supported */
#define DOT1X_SUPPLICANT_FAILURE_USER_LOGOFF          6  /* User logoff after authentiacted */
#define DOT1X_SUPPLICANT_FAILURE_AUTH_LOGOFF          7  /* Logoff or failure received after
                                                        authenticated from authenticator */
#define DOT1X_SUPPLICANT_FAILURE_AUTH_PERIOD_TIMEOUT  8  /* AuthPeriod time out - send 
                                                         EAPOL start again */
#define DOT1X_SUPPLICANT_FAILURE_EAPOL_START_NO_RESPONSE  9 /* MaxStart EAPOL start has been sent; session is forced to fail */


/*********************************************************************************
 * Structure:   NSDOT1XSupplicantSessionStatsInfo
 * iType1:      NS_DOT1X_SUPPLICANT_SESSION_STATS_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantSessionStatsInfo Description: 
 RRetrieve global supplicant statistics for a port.
  
  
*/


typedef struct tagNSDOT1XSupplicantSessionStatsInfo 
{      
     NSSetupTime SessionRetrievedTime;	/* time of day statistics was collected */   
	  NSSetupTime SessionUpdateTime;	/* time of day statistics was last updated */  
     U64	u64SetupTime;	            /* The aggregate time to complete successfully 
		                                 each of the supplicants. It does not count 
		                                 any failed attempts, in seconds */   
	  unsigned long ulSetupRate;   /* This is the number of supplicants authenticated
		                                  per seconds. */   
     unsigned long ulAuthenticationAttempted;	/* Total number of times sessions are 
	                                 initiated (go into active queues) including any retries */  
     unsigned long ulAuthenticationSuccessful;  /* Total number of times sessions are 
		                                    sucessful established */  
     unsigned long ulAuthenticationFailed;  /* Total number of times sessions have failed, 
		                                      including multiple retries */ 
     unsigned long ulAuthenticationRetries;  /* Total number of times supplicants are retried */ 
     unsigned long ulRetried;         /* Number of supplicant being retried */  
     unsigned long ulFailed;          /* Failed - all retries exhausted - in IDLE state 
		                                     Supplicant not considered failed once is restarted 
		                                     by the user */  
     unsigned long ulConfigured;     /* Number of supplicants configured by the user */ 
     unsigned long ulAuthenticating;	/* authenticating supplicant */  
     unsigned long ulAuthenticated;  /* Number of supplicants currently authenticated */  
     unsigned long ulIdle;           /* Number of supplicants configured, but not in action */      
     unsigned long ulPending;	      /* Number of supplicants started or being retried, but in Pending state */  
     unsigned long ulTerminatedPending;  /* Number of supplicants stopped by user, but in pending state */ 
	  NSSetupTime   AuthenticationStartTime;
                         /* time of day when first START packet is
                            sent after statistics is cleared */
     NSSetupTime   LastSuccessTime;
                        /* time of day when last SUCCESS packet is 
                           received */
     U64           u64MinSetupTime; /* Min authentication time, in microsecond */
     U64           u64MaxSetupTime; /* Max authentication time, in microsecond */

     unsigned long ulReAuthenticationSuccessful; /* Total number of successful re-authentication 
                                                    from authenticator */
     unsigned long ulReAuthenticationFailed;     /* Total number of failed re-authentication
                                                    from authenticator */
     unsigned long ulReAuthenticationAttempted; /* Total number of re-authentication attempts
                                                    from authenticator */

     unsigned long ulFirstAttempted;         /* Total number of supplicant 1st attempts  */
     unsigned long ulPassiveAttempted;       /* Total number of times passive authentication are tried */

     unsigned long ulRetriedSuccessful;      /* Number of supplicant retries successful */
     unsigned long ulRetriedFailed;          /* Number of supplicant retries failed */
     unsigned long ulFirstAttemptSuccessful; /* Number of successful supplicants 1st attempts*/
     unsigned long ulFirstAttemptFailed;     /* Number of failed supplicants 1st attempts */

     unsigned long ulUserRetried;            /* Number of user retries */
     unsigned long ulUserRetriedSuccessful;  /* Number of user retry successful */
     unsigned long ulUserRetriedFailed;      /* Number of user retry failed */

}NSDOT1XSupplicantSessionStatsInfo;

/*********************************************************************************
 * Structure:   NSDOT1XSupplicantCopy
 * iType1:      NS_DOT1X_SUPPLICANT_COPY
 * Function:    HTSetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantCopy Description: Copy configuration of one supplicant to other
 supplicants  
  
*/

typedef struct tagNSDOT1XSupplicantCopy 
{      
    unsigned long	ulBaseIndex; /* starting index of supplicant to copy from */    
    unsigned long	ulDestinationIndex; /* destination index of supplicant to copy to */   
    unsigned long ulCount;     /* number of supplicant to copy to beginning with 
	                               destination index */ 
    unsigned char ucReserved[24];

}NSDOT1XSupplicantCopy;


/*********************************************************************************
 * Structure:   NSDOT1XSupplicantModify
 * iType1:      NS_DOT1X_SUPPLICANT_MODIFY
 * Function:    HTSetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantModify Description: Modify one parameter for one or multiple 
 supplicants.
  
 ulField possible values
 DOT1X_SUPPLICANT_MAX_START					1 (2 bytes)
 DOT1X_SUPPLICANT_START_TIME					2 (2 bytes)
 DOT1X_SUPPLICANT_AUTHENTICATION_TIME	   3 (2 bytes)
 DOT1X_SUPPLICANT_HELD_TIME					4 (2 byte)s
 DOT1X_SUPPLICANT_ID			               5 (256 bytes)
 DOT1X_SUPPLICANT_USER_PASSWORD	6 (16 bytes)
 DOT1X_SUPPLICANT_AUTHENTICATION_TYPE	7 (1 byte)
 DOT1X_SUPPLICANT_SEND_EAP_START 		8 (1 byte)
 DOT1X_SUPPLICANT_RETRY_COUNT					9 (2 bytes)
 DOT1X_SUPPLICANT_SRC_MAC						10 (6 bytes)

 DOT1X_SUPPLICANT_USER_NAME					12 (256) 
 DOT1X_SUPPLICANT_VLAN_ENABLE					13 (1 byte)
 DOT1X_SUPPLICANT_VLAN_CONFIGURATION		14 (2 bytes) All fields in VLAN (PRI,CFI,VLAN ID)
																		 [ 3 bits Priority] [1 bit CFI] [12 bits VLAN ID]

 DOT1X_SUPPLICANT_CERTIFICATE_USEMODE		15 (1 byte)
 DOT1X_SUPPLICANT_KEY_PASSWORD				16 (16 bytes)

Example 1:

 ulIndex = 2 (starting supplicant index)
 ulCount = 5 (total number of supplicant to modify)
 uiField = DOT1X_SUPPLICANT_MAX_START (ucMaxStart - Maximum successive EAPOL-start packets)
 ucData = [0] [5] [0] [7] [0] [9] [0] [2] [0] [3] [0] [8] [0] [4] [0] [6] (pattern definitions)
     
	 (Total fields changed 5)
	  
		  Before			         After
	Index  ucMaxStart-Value     Index  ucMaxStart-Value
	0         1                 0         1
	1         1                 1         1
	2         1                 2         5
	3         1                 3         7
	4         1                 4         9
	5         1                 5         2
	6         1                 6         3
	7         1                 7         1
	8         1                 8         1
	9         1                 9         1
	10       1                  10        1

Example 2:

	  ulIndex = 0 (start here)
	  ulCount = 3 (total number of supplicant to modify)
	  uiField = DOT1X_SUPPLICANT_SRC_MAC (ucSourceMAC[6] - Unique source MAC address of supplicant)
	  ucData = [9] [7] [9] [2] [3] [8] [7] [5] [6] [4] [1] [9] [8] [7] [8] [9] [3] [5] [4] [6] 
	  (pattern definitions)
     	  
		  Before								After
	Index  ucSourceMAC[6] -Value     Index  ucSourceMAC[6] - Value
	0         11.11.11.11.11.11      0         9.7.9.2.3.8
	1         1.1.1.1.1.1            1         7.5.6.4.1.9
	2         2.2.2.2.2.2            2         8.7.8.9.3.5
	3         3.3.3.3.3.3            3         3.3.3.3.3.3                           
	4         4.4.4.4.4.4            4         4.4.4.4.4.4                           
	5         5.5.5.5.5.5            5         5.5.5.5.5.5                           
	6         6.6.6.6.6.6            6          6.6.6.6.6.6                           
	7         7.7.7.7.7.7            7         7.7.7.7.7.7
	8         8.8.8.8.8.8            8         8.8.8.8.8.8 
	9         9.9.9.9.9.9            9         9.9.9.9.9.9 
	10       10.10.10.10.10.10       10       10.10.10.10.10.10 

Example 3: There is a gap in the configured supplicant

	ulIndex = 0 (start here)
	ulCount = 3 (total number of supplicants to modify)
	uiField = DOT1X_SUPPLICANT_SRC_MAC
	(ucSourceMAC[6] - source MAC address of supplicant)
	ucData [9] [7] [9] [2 [3] [8] [7] [5] [6] [4] [1] [9] [8] [7] [8] [9] [3] [5] [4]
	[6] [9] [1]
 
	If a supplicant of index 1 does not exist in the configured supplicants, 
	only supplicants in the range (supplicant 0 and supplicant 2) are modified,
	as shown below:

	Before								After
	Index ucSourceMAC[6] - Value	Index ucSourceMAC[6] - Value
	0		11.11.11.11.11.11			0		9.7.9.2.3.8
	2		2.2.2.2.2.2					2		7.5.6.4.1.9
	3		3.3.3.3.3.3					3		3.3.3.3.3.3
	4		4.4.4.4.4.4					4		4.4.4.4.4.4
	5		5.5.5.5.5.5					5		5.5.5.5.5.5
	6		6.6.6.6.6.6					6		6.6.6.6.6.6
	7		7.7.7.7.7.7					7		7.7.7.7.7.7

Example 4: There is no supplicant of index ulIndex
	
	  
	ulIndex = 0 (start here)
	ulCount = 3 (total number of supplicant to modify)
	uiField = DOT1X_SUPPLICANT_SRC_MAC
	(ucSourceMAC[6] - source MAC address of supplicant)
	ucData [9] [7] [9] [2 [3] [8] [7] [5] [6] [4] [1] [9] [8] [7] [8] [9] [3] [5] [4]
	[6] [9] [1]
	(pattern definitions)
	
	Index ucSourceMAC[6] -Value
	1		1.1.1.1.1.1
	2		2.2.2.2.2.2
	3		3.3.3.3.3.3
	4		4.4.4.4.4.4
	5		5.5.5.5.5.5
	6		6.6.6.6.6.6
	7		7.7.7.7.7.7
	
	In Example 4 above, if the supplicant of index 0 does not exist, 
	no modification is made and an error is returned.

Example 5: Example for Supplicant User Name
           (similarly to Supplicant ID ,User Password, Supplicant Key Password which uses uiFieldDataLength)	
	  
	ulIndex = 0 (start here)
	ulCount = 3 (total number of supplicant to modify)
	uiField = DOT1X_SUPPLICANT_USER_NAME (ucUserName[256] - user name of supplicant)
	uiFieldDataLength = 11
	ucData [M] [y] [U] [s] [e] [r] [N] [a] [m] [e] [1] [M] [y] [U] [s] [e] [r] [N] [a] [m] [e] [2] 
	       [M] [y] [U] [s] [e] [r] [N] [a] [m] [e] [3] [M] [y] [U] [s] [e] [r] [N] [a] [m] [e] [4]
	(pattern definitions)
	
	Before								After
	Index ucUserName[256] -Value        Index ucUserName[256] -Value
	1		OldUserName1                MyUserName1
	2		OldUserName2                MyUserName2
	3		OldUserName3                MyUserName3
	4		OldUserName4                OldUserName4
	5		OldUserName5                OldUserName5
	6		OldUserName6                OldUserName6
	7		OldUserName7                OldUserName7   

*/

#define MAX_MOD_SUPPLICANT_ARRAY 20000

typedef struct tagNSDOT1XSupplicantModify 
{      
    unsigned long	ulIndex;  /* starting index of supplicant to modify */
    unsigned long	ulCount;  /* number of supplicant to modify beginning with start index */
    unsigned short uiField; /* field ID which is to be modified, values are defined below 

                                DOT1X_SUPPLICANT_MAX_START           1 (2 bytes)
                                DOT1X_SUPPLICANT_START_TIME          2 (2 bytes)
                                DOT1X_SUPPLICANT_AUTHENTICATION_TIME 3 (2 bytes)
                                DOT1X_SUPPLICANT_HELD_TIME           4 (2 byte)s
                                DOT1X_SUPPLICANT_ID                  5 (length specified by uiFieldDataLength)
                                DOT1X_SUPPLICANT_USER_PASSWORD       6 (length specified by uiFieldDataLength)
                                DOT1X_SUPPLICANT_AUTHENTICATION_TYPE 7 (1 byte)
                                DOT1X_SUPPLICANT_SEND_EAP_START      8 (1 byte)
                                DOT1X_SUPPLICANT_RETRY_COUNT         9 (2 bytes)
                                DOT1X_SUPPLICANT_SRC_MAC             10 (6 bytes)
                                DOT1X_SUPPLICANT_USER_NAME           12 (length specified by uiFieldDataLength) 
                                DOT1X_SUPPLICANT_VLAN_ENABLE         13 (1 byte)
                                DOT1X_SUPPLICANT_VLAN_CONFIGURATION  14 (2 bytes)
								                                         All fields in VLAN (PRI,CFI,VLAN ID)
																		 [3 bits Priority] [1 bit CFI] [12 bits VLAN ID]
                                DOT1X_SUPPLICANT_CERTIFICATE_USEMODE 15 (1 byte)
                                DOT1X_SUPPLICANT_KEY_PASSWORD        16 (length specified by uiFieldDataLength)
                            */
	 unsigned short uiFieldDataLength; /* number of bytes to be used from ucData for each Supplicant,
	                                    its only applicable to Supplicant ID ,User Password
	                                    User Name, and Supplicant Key Password fields */
    unsigned char ucData[MAX_MOD_SUPPLICANT_ARRAY]; /* values to be used to modify the
	                                                field specified in uiField */
	 unsigned char	ucReserved[24]; /* Reserved */
}NSDOT1XSupplicantModify;

/* The uiField field to be modified is specified as follows */
#define DOT1X_SUPPLICANT_MAX_START					1
#define DOT1X_SUPPLICANT_START_TIME					2
#define DOT1X_SUPPLICANT_AUTHENTICATION_TIME	   3	
#define DOT1X_SUPPLICANT_HELD_TIME					4
#define DOT1X_SUPPLICANT_ID			            5
#define DOT1X_SUPPLICANT_USER_PASSWORD	         6
#define DOT1X_SUPPLICANT_AUTHENTICATION_TYPE	   7
#define DOT1X_SUPPLICANT_SEND_EAP_START 	      8
#define DOT1X_SUPPLICANT_RETRY_COUNT		      9
#define DOT1X_SUPPLICANT_SRC_MAC						10
#define DOT1X_SUPPLICANT_AUTHENTICATION_ADDR		11
#define DOT1X_SUPPLICANT_USER_NAME					12

#define DOT1X_SUPPLICANT_VLAN_ENABLE				13  
#define DOT1X_SUPPLICANT_VLAN_CONFIGURATION		14  
#define DOT1X_SUPPLICANT_CERTIFICATE_USEMODE		15  
#define DOT1X_SUPPLICANT_KEY_PASSWORD				16  



/*********************************************************************************
 * Structure:   NSDOT1XSupplicantFill
 * iType1:      NS_DOT1X_SUPPLICANT_FILL
 * Function:    HTSetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantFill Description: Increment a single configuration parameter for 
 one or multiple supplicants.  

 NSDOT1XSupplicantConfigFill is used to modify a parameter field of a given number
 of supplicants which already exist, using a Source supplicant instance as a base,
 a starting destination instance, and count, whose contents are to be modified, 
 based on the parameter-id, followed by a delta value which will be used as the 
 successive incremental value.

 uiField possible values
 DOT1X_SUPPLICANT_ID			               5 (256 bytes)
 DOT1X_SUPPLICANT_USER_PASSWORD	          6 (16 bytes)
 DOT1X_SUPPLICANT_SRC_MAC						10 (6 bytes) 
 DOT1X_SUPPLICANT_VLAN_CONFIGURATION      14 (2 byte) All fields in VLAN (PRI,CFI,VLAN ID)
													[ 3 bits Priority] [1 bit CFI] [12 bits VLAN ID]
 DOT1X_SUPPLICANT_KEY_PASSWORD				16 (16 bytes)
 
 There are 2 different configuration mechanisms for Source MAC fields,
 Supplicant  ID/User Password,VLAN configuration and Supplicant Key fields.
 For Source MAC field and VLAN configuration, delta values are from the ucDelta field.
 For Supplicant  ID/User and Supplicant Key password, the incrementation can be made in two places using
 ucMode1 and ucMode2 fields with the corresponding ucOffset, ucStepValue, ucWidth ,uiStartValue and
 uiMaxValue2 fields. 
 
 ucMode1 and ucMode2 fields (for Supplicant  ID and User Password fields):
 For the ucMode1/ucMode2, there are three options:
 DOT1X_SUPPLICANT_FILL_LEFT  - there will be no leading or trailing zeroes.
 DOT1X_SUPPLICANT_FILL_RIGHT - the length of the field will always be fixed,
                               e.g. a value of "4" is "004" in this mode using a width of 3.
 DOT1X_SUPPLICANT_FILL_OFF   - this is to turn off incrementation.
 
 The Destination Supplicant will have the inital StartValues at the specified offsets.
 While maintaining StartValue1 for Mode1(Offset1),StartValue2 for Mode2 will be incremented 
 by StepValue2 untill MaxValue2 is reached. 
 When MaxValue2 is reached, incrementation will be done on StartValue1 untill MaxValue1 is reached.
 Incrementation will be altenatively done on Offset1 and Offset2 untill both MaxValue1 and MaxValue2
 are reached.
	

 
 Example 1 (Source Mac Address) :
 
 Configuration:
 ulBaseIndex = 10 (base supplicant)	
 ulDestinationndex = 5 (destination supplicant)	 
 ulCount = 3 (total number of supplicant to modify)
 uiField = DOT1X_SUPPLICANT_SRC_MAC   
    (ucSourceMAC[6] - Unique source MAC address of supplicant)	
 
 ucDelta[] =  0 0 0 0 0 2      	  
 
 Result:
	Before								After	
	Index		ucSourceMAC				Index		ucSourceMAC
	0			11.11.11.11.11.11    0        11.11.11.11.11.11
	1			1.1.1.1.1.1				1			1.1.1.1.1.1
	2			2.2.2.2.2.2				2			2.2.2.2.2.2
	3			3.3.3.3.3.3				3			3.3.3.3.3.3
	4			4.4.4.4.4.4				4			4.4.4.4.4.4
	5			5.5.5.5.5.5				5			10.10.10.10.10.12  <- first modified supplicant	
	6			6.6.6.6.6.6				6			10.10.10.10.10.14  <- second modified supplicant
	7			7.7.7.7.7.7				7			10.10.10.10.10.16  <- third modified supplicant
	8			8.8.8.8.8.8				8			8.8.8.8.8.8
	9			9.9.9.9.9.9				9			9.9.9.9.9.9	
	10			10.10.10.10.10.10		10			10.10.10.10.10.10   <- Base supplicant


  Example 2 (Supplicant ID)
  
	Initial Supplicant ID field : test@spirent.com
	
	Configuration:
	ulBaseIndex = 0
   ulDestinationIndex = 1

	ucMode1    = DOT1X_SUPPLICANT_FILL_RIGHT
	ucOffset1  = 4
	ucStepValue1  = 2
	ucWidth1   = 3 
	uiStartValue1  = 1
	uiMaxValue2   = 5

	ucMode2    = DOT1X_SUPPLICANT_FILL_LEFT
	ucOffset2  = 12
	ucStepValue2 = 1
	ucWidth2 = N/A
	uiStartValue2 = 3
	uiMaxValue2  = 4

   Results:

   Index		Supplicant ID    
	1			test001@spirent3.com
	2			test001@spirent4.com 
	3		   test003@spirent3.com
	4			test003@spirent4.com
	5			test005@spirent3.com
	6			test005@spirent4.com
 
*/

#define MAX_SUPPLICANT_DELTA 32



typedef struct tagNSDOT1XSupplicantFill 
{      
   unsigned long ulBaseIndex; /* Index of supplicant whose value is to used for the
	                              desired parameter is to be used as an initial value
	                              for the fill. */ 
   unsigned long ulDestinationIndex; /* supplicant index of the first supplicant
	                                     whose parameter is to be filled. */
   unsigned long ulCount;     /* number of supplicants to be modified  */
	unsigned short uiField;  /* Field ID which is to be modified.
                               Possible values are:
                               DOT1X_SUPPLICANT_ID 
                               DOT1X_SUPPLICANT_USER_PASSWORD 
                               DOT1X_SUPPLICANT_SRC_MAC
							   DOT1X_SUPPLICANT_VLAN_CONFIGURATION
                               DOT1X_SUPPLICANT_KEY_PASSWORD
                               */  
	unsigned char ucDelta[MAX_SUPPLICANT_DELTA]; /*delta values */
	
	/* the following are only applicable to Supplicant ID and User Password Parameters 
	 An ASCII string is inserted before the @domain in the ID fields and appended to 
	the password string */  
   unsigned char ucMode1;         /* possible values are 
	                                  DOT1X_SUPPLICANT_FILL_OFF, DOT1X_SUPPLICANT_FILL_LEFT
	                                  and DOT1X_SUPPLICANT_FILL_RIGHT */ 
   unsigned char ucOffset1;       /* offset to first fill pattern */ 
	unsigned char ucStepValue1;    /* Stepping value size for first pattern */
	unsigned char ucWidth1;        /* Width of first fill pattern */ 
	unsigned short uiStartValue1;  /* Starting Value for first pattern*/
	unsigned short uiMaxValue1;       /* maximum value of first fill pattern */       
   unsigned char ucMode2;         /* possible values are 
	                                  DOT1X_SUPPLICANT_FILL_OFF, DOT1X_SUPPLICANT_FILL_LEFT
	                                  and DOT1X_SUPPLICANT_FILL_RIGHT */ 
   unsigned char ucOffset2;       /* offset to second fill pattern */ 
	unsigned char ucStepValue2;    /* Stepping value size for second pattern*/
	unsigned char ucWidth2;        /* Width of second fill pattern */ 
	unsigned short uiStartValue2;  /* Starting Value of second  fill pattern */
	unsigned short uiMaxValue2;       /* maximum value f second fill pattern */  
   
	unsigned char ucReserved[24];
}NSDOT1XSupplicantFill;

#define DOT1X_SUPPLICANT_FILL_OFF	0
#define DOT1X_SUPPLICANT_FILL_LEFT	1
#define DOT1X_SUPPLICANT_FILL_RIGHT 2


/*********************************************************************************
 * Structure:   NSDOT1XSupplicantStatusSearchInfo
 * iType1:      NS_DOT1X_SUPPLICANT_STATUS_SEARCH_INFO
 * Function:    HTGetStructure
 **********************************************************************************
 
 NSDOT1XSupplicantStatusSearchInfo Description: Retrieve a particular field in
 the NSDOT1XSupplicantStatus structure, which falls within the range specified
 by the u64SearchRangeLow and u64SearchRangeHigh values.  It uses the uiSearchField
 as a basis for the search and returns the values of the uiReturnField using the
 u64Data array.

 SupplicantState constants: 
 DOT1X_SUPPLICANT_LOG_OFF
 DOT1X_SUPPLICANT_DISCONNECTED
 DOT1X_SUPPLICANT_CONNECTING	
 DOT1X_SUPPLICANT_ACQUIRED
 DOT1X_SUPPLICANT_AUTHENTICATING
 DOT1X_SUPPLICANT_HELD
 DOT1X_SUPPLICANT_AUTHENTICATED	

 FailureCode constants:
 DOT1X_SUPPLICANT_FAILURE_NONE
 DOT1X_SUPPLICANT_FAILURE_UNKNOWN
 DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED
 DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED
 DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE
 DOT1X_SUPPLICANT_FAILURE_EAP_NOT_SUPPORTED     
 DOT1X_SUPPLICANT_FAILURE_USER_LOGOFF           
 DOT1X_SUPPLICANT_FAILURE_AUTH_LOGOFF    
 DOT1X_SUPPLICANT_FAILURE_AUTH_PERIOD_TIMEOUT  
 DOT1X_SUPPLICANT_FAILURE_EAPOL_START_NO_RESPONSE

 uiReturnField/uiSearchField possible values
 DOT1X_SUPPLICANT_STATUS_INDEX				0 (4 bytes)
 DOT1X_SUPPLICANT_STATUS_SUPPICANT_STATE 	1 (1 byte)
 DOT1X_SUPPLICANT_STATUS_FAILURE_CODE		2 (1 byte)
 DOT1X_SUPPLICANT_STATUS_SETUP_TIME			3 (8 bytes)

 DOT1X_SUPPLICANT_STATUS_COUNT			0xFFFF (Only for uiReturnField)

 

Example 1:     	  
Index  SupplicantState                    FailureCode                                     SetupTime 
0      DOT1X_SUPPLICANT_HELD(6)           DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  15 seconds 10 microseconds
1      DOT1X_SUPPLICANT_LOG_OFF(1)        DOT1X_SUPPLICANT_FAILURE_UNKNOWN(1)                  10 seconds 20 microseconds
2      DOT1X_SUPPLICANT_DISCONNECTED(2)   DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED(2)          03 seconds 05 microseconds
3      DOT1X_SUPPLICANT_CONNECTING(3)     DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED(3)    05 seconds 02 microseconds
4      DOT1X_SUPPLICANT_ACQUIRED(4)       DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  25 seconds 18 microseconds
5      DOT1X_SUPPLICANT_AUTHENTICATING(5) DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  10 seconds 50 microseconds
6      DOT1X_SUPPLICANT_HELD(6)           DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  20 seconds 35 microseconds
7      DOT1X_SUPPLICANT_AUTHENTICATED(7)  DOT1X_SUPPLICANT_FAILURE_EAP_ID_REJECTED(2)          10 seconds 19 microseconds
8      DOT1X_SUPPLICANT_CONNECTING(3)     DOT1X_SUPPLICANT_FAILURE_EAP_RESPONSE_REJECTED(3)    08 seconds 20 microseconds
9      DOT1X_SUPPLICANT_ACQUIRED(4)       DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  50 seconds 30 microseconds
10     DOT1X_SUPPLICANT_AUTHENTICATING(5) DOT1X_SUPPLICANT_SUCCESS_EAPOL_START_NO_RESPONSE(4)  02 seconds 45 microseconds

	  Input:
	  ulIndex = 0 (starting index)
	  ulCount = 9 (total number of supplicant to search)
	  uiSearchField = DOT1X_SUPPLICANT_STATUS_SUPPICANT_STATE
	  uiReturnField = DOT1X_SUPPLICANT_STATUS_INDEX
	  u64SearchRangeLow.low= 1
	  u64SearchRangeHigh.low= 5

	  output:
	  ulReturnCount =  6  (number of  matched supplicants)
	  u64Data[0].high =	00 
	  u64Data[0].low	=	01
	  u64Data[1].high	=	00
	  u64Data[1].low	=	02
	  u64Data[2].high	=	00
	  u64Data[2].low	=	03 
	  u64Data[3].high	=	00
	  u64Data[3].low	=	04
	  u64Data[4].high	=	00
	  u64Data[4].low	=	05
	  u64Data[5].high	=	00
	  u64Data[5].low	=	08
                  

Example 2:
	  ulIndex = 0 (starting index)
	  ulCount = 9 (total number of supplicant to search)
	  uiSearchField = DOT1X_SUPPLICANT_STATUS_FAILURE_CODE
	  uiReturnField = DOT1X_SUPPLICANT_STATUS_SETUP_TIME
	  u64SearchRangeLow.low= 2
	  u64SearchRangeHigh.low= 3

	  output:
	  ulReturnCount =  4 (number of matched supplicant)
	  u64Data[0].low	=	03
	  u64Data[0].high	=	05
	  u64Data[1].low	=	05
	  u64Data[1].high	=	02
	  u64Data[2].low	=	10 
	  u64Data[2].high	=	19
	  u64Data[3].low	=	08
	  u64Data[3].low	=	20
		
	
 */

#define MAX_SEARCH_SUPPLICANT_ARRAY 7000

typedef struct tagNSDOT1XSupplicantStatusSearchInfo 
{      
    /* Inputs */
	 unsigned long	ulIndex; /* starting index of supplicant to start from */
    unsigned long	ulCount;      /* number of supplicants to search starting from ulIndex */
    unsigned short	uiSearchField; /* search parameter */
	 unsigned short	uiReturnField; /* returned parameter */
    U64	u64SearchRangeLow;          /* search criteria - low limit */
    U64	u64SearchRangeHigh;         /* search criteria - high limit */
    
	 /* Outputs */
	 unsigned long	ulReturnCount;      /* number of supplicants which match the search criteria */
    U64	u64Data[MAX_SEARCH_SUPPLICANT_ARRAY];
	 
	 unsigned char		ucReserved[24];
}NSDOT1XSupplicantStatusSearchInfo;

/* uiReturnField/uiSearchField possible values */
#define DOT1X_SUPPLICANT_STATUS_INDEX              0
#define DOT1X_SUPPLICANT_STATUS_SUPPICANT_STATE    1
#define DOT1X_SUPPLICANT_STATUS_FAILURE_CODE       2
#define DOT1X_SUPPLICANT_STATUS_SETUP_TIME         3

/* Only for uiReturnField used when retrieving only the matching count using ulReturnCount */
#define DOT1X_SUPPLICANT_STATUS_COUNT         0xFFFF 



/*************************************************************************************
 * Structure:   NSStreamIDTableInfo
 * iType1:      NS_STREAM_ID_TABLE_INFO
 * iType2:      0
 * iType3:      0
 * iType4:      0
 * Function:    HTGetStructure
 * Description: Configure a port to keep track of either the minimum or total latency
 *				when running the latency histogram tests.
 *************************************************************************************/
/* NSStreamIDTableInfo Description:

This command returns the stream IDs currently being tracked by a receiving port.  This 
information will be useful when retrieving histogram test results associated with the stream 
IDs.  The total number of stream IDs currently being tracked can be retrieved using the 
NS_HIST_ACTIVE_TEST_INFO message function.

NOTE:  The command is only applicable for the LAN TeraMetrics family of modules.  
Additional, this command is only applicable when the jumbo histogram test is enabled and the 
port is configured to track stream id related results.  The jumbo histogram test is enabled 
using the NS_HIST_COMBO_PER_STREAM message function.   To configure the port to track stream 
id related results, use the NS_HIST_LATENCY_OPTION message function with the "uiOption" field 
set to NS_TRACK_STREAM_ID

Following are some examples demonstrating the command behavior:			

                     Ex. 1	Ex. 2	Ex. 3	Ex. 4	Ex. 5
ulRequestIndex       0     25    12    99    33
ulRequestCount       10    10    10    400   2
# of Streams Learned 500   33    33    500   33
ulRetrievedIndex     0     25    12    99    33*
ulRetrievedCount     10    8     10    400   0

* Note that if ulRequestIndex refers to an invalid entry, then ulRetrievedIndex will return the 
total number of stream IDs being tracked on the port.

Explanation of the examples:
Ex. 1:  A total of 500 streams had been learned.  The user requested 10 starting at the first.  
They were all returned.
Ex. 2: Only 33 streams had been learned.  The user requested 10 starting at index 
25 (zero-based).  Only 8 streamID's were returned, corresponding to the following 
indexes:  25, 26, 27, 28, 29, 30, 31, 32.  
Ex. 3: Only 33 streams had been learned.  The user requested 10 starting at index 12.  All 10 
were available so they were all returned.
Ex. 4: A total of 500 streams had been learned.  The user requested 400 starting at index 99.
All 400 were returned.
Ex. 5: A total of 33 streams had been learned.   The user requested only 2 of them starting at
index 33.  Since the last stream was at index#32, no streams were available starting at 
index #33, so no streams were returned.
*/

#define NS_MAX_STREAM_ID_ARRAY   486

typedef struct tagNSStreamIDTableInfo{
   /* input */   
   unsigned long ulRequestIndex;    /* Starting index of the first stream ID being requested */
   unsigned long ulRequestCount;    /* Number of stream IDs being requested  */

   /* output */
   unsigned long ulRetrievedIndex;  /* Index value for the first stream ID retrieved.  If the 
                                       value of ulRetrievedCount is 0, then this field returns
                                       the total number of  stream IDs currently being tracked
                                       on the port. */   
   unsigned long ulRetrievedCount;  /* Number of stream IDs retrieved */   
   unsigned long ulStreamID[NS_MAX_STREAM_ID_ARRAY];  /* Retrieved stream IDs */
   unsigned char ucReserved[32];
}NSStreamIDTableInfo;

/*********************************************************************************
 * Structure:   NSPhyDefaultConfig
 * iType1:      NS_PHY_DEFAULT_CONFIG/NS_PHY_DEFAULT_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 **********************************************************************************
 
 NSPhyDefaultConfig Description: 

 This structure is used to configure PHY default settings (media mode, 
 auto-negotiation, speed, duplex, etc) for TM LAN port at boot time.
 It is also used to read back the PHY default settings on the port.  
 
 The following configurations are supported for this release 
 DualMediaMode = {copper,fiber}
 AutoNegotiate = {enable.disable} 
 CopperSpeed = {10,100,1000} FiberSpeed = {1000} 
 CopperDuplex = {half,full}
 
 Currently uiLinkConfiguration can only be used to control/query the default setting
 for the duplex mode, uiLinkConfigurationMask should be set 0x0060 to make the change.
 Set uiLinkConfigurationMask field to 0 if NO change is being made for duplex mode.
 The value 0xFFFF will always be returned for uiLinkConfigurationMask in the 
 query/readback.
 
 For other fields, if no change being made, it is required to use NS_FIELD_UNCHANGED(0xFFFF).
 And if want to restore the original card default value, use
 NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE(0xFFFE).

*/

typedef struct tagNSPhyDefaultConfig{
	
	unsigned short uiActiveMedia;    /* possible values are
	                                FIBER_MODE
	                                COPPER_MODE
                                    NS_FIELD_UNCHANGED (used if NO change being made)
                                    NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE (used to restore original card default value)
	                                */
	unsigned short uiAutoNegotiationEnable;  /* possible values are
	                                0 disable
	                                1 enable 
	                                NS_FIELD_UNCHANGED (used if NO change being made)
                                    NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE (used to restore original card default value)
	                                */
	unsigned short uiAutoNegotiationRestart;  /* possible values are
	                                0 disable
	                                1 enable 
	                                NS_FIELD_UNCHANGED (used if NO change being made)
                                    NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE (used to restore original card default value)
	                                */
	unsigned short uiSpeed;         /* possible values are
	                                NS_PHY_DEFAULT_SPEED_10MHZ
	                                NS_PHY_DEFAULT_SPEED_100MHZ
	                                NS_PHY_DEFAULT_SPEED_1GHZ
	                                NS_PHY_DEFAULT_SPEED_10GHZ
	                                NS_FIELD_UNCHANGED (used if NO change being made)
                                    NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE (used to restore original card default value)
	                                */
	unsigned short uiLinkConfigurationMask; /* Use 0x0060 to make change in link configuration
                                            (duplex). Use 0 if don't want to change the link
                                            configuration (duplex)
                                            0xFFFF is always returned in the query/readback.
                                            */
	unsigned short uiLinkConfiguration;    /* possible values are
                                           NS_PHY_DEFAULT_FULL_DUPLEX 
                                           NS_PHY_DEFAULT_HALF_DUPLEX
                                           Use the above value for uiLinkConfiguration(duplex), and
                                           use  0x0060 for uiLinkConfigurationMask to make change
										   in link configuration (duplex).   
                                           Set link config mask to 0 if no change being made for
										   the link configuration (duplex).
										   And to restore the original card default uiLinkConfiguration(deplex), use
                                           NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE (used to restore original card default value)
	                                */
	unsigned char ucReserved[256];

}NSPhyDefaultConfig;

/* constants to set for field which is not being changed */
#define NS_FIELD_UNCHANGED 0xFFFF

/* constants to set for field to restore original card default value */
#define NS_PHY_DEFAULT_RESTORE_ORIGINAL_VALUE  0xFFFE

/* uiSpeed */
#define NS_PHY_DEFAULT_SPEED_10MHZ             10 
#define NS_PHY_DEFAULT_SPEED_100MHZ            100        
#define NS_PHY_DEFAULT_SPEED_1GHZ              1000
#define NS_PHY_DEFAULT_SPEED_10GHZ             10000

/* uiLinkConfiguration */
#define NS_PHY_DEFAULT_FULL_DUPLEX  0x0020
#define NS_PHY_DEFAULT_HALF_DUPLEX  0x0040


/*********************************************************************************
 * Structure:   NSWISConfig
 * iType1:      NS_WIS_CONFIG /NS_WIS_CONFIG_INFO
 * Function:    HTSetStructure/HTGetStructure
 **********************************************************************************
 
 NSWISConfig Description: This structure is used to configure or read back
 WAN Interface Sublayer setting for XLW-3720/21 and XFP-3730/31A test modules
 in WAN PHY mode.

 ulErrorInjection possible values
 NS_WIS_INJECT_FRAMING_ERRORS   
 NS_WIS_INJECT_SECTION_BIP_ERRORS 
 NS_WIS_INJECT_LINE_BIP_ERRORS            
 NS_WIS_INJECT_PATH_BIP_ERRORS           
 NS_WIS_INJECT_LINE_AIS_ALARM                
 NS_WIS_INJECT_LINE_RDI_ALARM                
 NS_WIS_INJECT_PATH_AIS_ALARM              
 NS_WIS_INJECT_SECTION_LOS_ALARM 

 ucFramingMode possible values
 NS_WIS_SONET_FRAMING
 NS_WIS_SDH_FRAMING

 ucPathSignalLabel value
 NS_WIS_PATH_SIGNAL_LABEL_10G_ETHERNET_WAN

 ucTxClockSource possible values
 NS_WIS_INTERNAL_TX_CLOCK
 NS_WIS_LOOP_TX_CLOCK

*/

typedef struct tagNSWISConfig
{
  unsigned long ulErrorInjection; /* Inject errors and alarms,
                                  NS_WIS_INJECT_FRAMING_ERRORS   
                                  NS_WIS_INJECT_SECTION_BIP_ERRORS 
                                  NS_WIS_INJECT_LINE_BIP_ERRORS            
                                  NS_WIS_INJECT_PATH_BIP_ERRORS           
                                  NS_WIS_INJECT_LINE_AIS_ALARM                
                                  NS_WIS_INJECT_LINE_RDI_ALARM                
                                  NS_WIS_INJECT_PATH_AIS_ALARM              
                                  NS_WIS_INJECT_SECTION_LOS_ALARM 
                                  */
 unsigned char ucFramingMode;     /* framing mode,
                                  NS_WIS_SONET_FRAMING
                                  NS_WIS_SDH_FRAMING
                                  */                                            
 unsigned char ucSectionScramble; /* 1 enable scramble, 0 disable scramble (unscramble) */
 unsigned char ucPathSignalLabel; /* Path signal label
                                     NS_WIS_PATH_SIGNAL_LABEL_10G_ETHERNET_WAN 
                                   */                                                                      
 unsigned char ucCRC32Enable;      /* 1 enable CRC32, 0 enable  CRC16, for only LAN PHY*/
 unsigned char ucTxClockSource;    /* Clock Source,
                                      NS_WIS_INTERNAL_TX_CLOCK
                                      NS_WIS_LOOP_TX_CLOCK
                                    */
 unsigned char ucLoopbackEnable;    /* 1 enable, 0 disable, for only LAN PHY */
 unsigned char ucReserved[128];

}NSWISConfig; 

#define NS_WIS_INJECT_FRAMING_ERRORS        0x00000001
#define NS_WIS_INJECT_SECTION_BIP_ERRORS    0x00000002
#define NS_WIS_INJECT_LINE_BIP_ERRORS       0x00000004
#define NS_WIS_INJECT_PATH_BIP_ERRORS       0x00000008
#define NS_WIS_INJECT_LINE_AIS_ALARM        0x00000010
#define NS_WIS_INJECT_LINE_RDI_ALARM        0x00000020
#define NS_WIS_INJECT_PATH_AIS_ALARM        0x00000040
#define NS_WIS_INJECT_SECTION_LOS_ALARM     0x00000080

/* ucFramingMode constants */
#define NS_WIS_SONET_FRAMING                0
#define NS_WIS_SDH_FRAMING                  1

/* ucTxClockSource constants */
#define NS_WIS_INTERNAL_TX_CLOCK            0
#define NS_WIS_LOOP_TX_CLOCK                1

/* ucPathSignalLabel constants */
#define NS_WIS_PATH_SIGNAL_LABEL_10G_ETHERNET_WAN  0x1A
  


/*********************************************************************************
 * Structure:   NSWISLineStatusInfo
 * iType1:      NS_WIS_LINE_STATUS_INFO
 * Function:    HTGetStructure
 * NSWISLineStatusInfo Description: This structure is used to retrieve 
                                    WAN Interface Sublayer counters (events and rates).
 **********************************************************************************
 
 NSWISConfig Description: This structure is used to retrieve WAN Interface Sublayer
 counters (events and rates).

 Alarm Constants for uiAlarmCurrent and uiAlarmHistory Fields
    NS_WIS_SECTION_LOS_ALARM        0x0001
    NS_WIS_SECTION_OOF_ALARM        0x0002
    NS_WIS_SECTION_LOF_ALARM        0x0004
    NS_WIS_LINE_AIS_ALARM           0x0008
    NS_WIS_LINE_FERF_ALARM          0x0010
    NS_WIS_LINE_LOP_ALARM           0x0020
    NS_WIS_PATH_AIS_ALARM           0x0040
    NS_WIS_PATH_FERF_ALARM          0x0080
    NS_WIS_PATH_YELLOW_ALARM        0x0100
    NS_WIS_LOCD_ALARM               0x0200
    NS_WIS_PSLM_ALARM               0x0400
*/

typedef struct tagNSWISLineStatusInfo
{
	unsigned short uiAlarmCurrent;      /* Bitmap - All alarms currently active.  The defined
                                           alarm constants are:
                                           NS_WIS_SECTION_LOS_ALARM
                                           NS_WIS_SECTION_OOF_ALARM
                                           NS_WIS_SECTION_LOF_ALARM
                                           NS_WIS_LINE_AIS_ALARM
                                           NS_WIS_LINE_FERF_ALARM
                                           NS_WIS_LINE_LOP_ALARM
                                           NS_WIS_PATH_AIS_ALARM
                                           NS_WIS_PATH_FERF_ALARM
                                           NS_WIS_PATH_YELLOW_ALARM
                                           NS_WIS_LOCD_ALARM
                                           NS_WIS_PSLM_ALARM 
                                         */
	unsigned short uiAlarmHistory;      /* Bitmap - All alarms since last counter clear.  The
                                           defined alarm constants are:
   
                                           NS_WIS_SECTION_LOS_ALARM
                                           NS_WIS_SECTION_OOF_ALARM
                                           NS_WIS_SECTION_LOF_ALARM
                                           NS_WIS_LINE_AIS_ALARM
                                           NS_WIS_LINE_FERF_ALARM
                                           NS_WIS_LINE_LOP_ALARM
                                           NS_WIS_PATH_AIS_ALARM
                                           NS_WIS_PATH_FERF_ALARM
                                           NS_WIS_PATH_YELLOW_ALARM
                                           NS_WIS_LOCD_ALARM
                                           NS_WIS_PSLM_ALARM 
                                         */

    /* Error counts since last counter clear */
	U64 u64SectionBipCount;          /* Number of Section Bit Interleaved Parity errors */ 
	U64 u64LineBipCount;             /* Number of Line Bit Interleaved Parity errors */
	U64 u64LineFebeCount;            /* Number of Line Far End Block errors */
	U64 u64PathBipCount;             /* Number of Path Bit Interleaved Parity errors */ 
	U64 u64PathFebeCount;            /* Number of Path Far End Block errors */

    /* Current error rates in events per second */
	unsigned long ulSectionBipRate;  /* Section Bit Interleaved Parity error rate */ 
	unsigned long ulLineBipRate;     /* Line Bit Interleaved Parity error rate */
	unsigned long ulLineFebeRate;    /* Line Far End Block error rate */
	unsigned long ulPathBipRate;     /* Path Bit Interleaved Parity error rate */
	unsigned long ulPathFebeRate;    /* Path Far End Block error rate */

    unsigned char ucReserved[128];   /* Reserved */
}NSWISLineStatusInfo;


#define NS_WIS_SECTION_LOS_ALARM        0x0001
#define NS_WIS_SECTION_OOF_ALARM        0x0002
#define NS_WIS_SECTION_LOF_ALARM        0x0004
#define NS_WIS_LINE_AIS_ALARM           0x0008
#define NS_WIS_LINE_FERF_ALARM          0x0010
#define NS_WIS_LINE_LOP_ALARM           0x0020
#define NS_WIS_PATH_AIS_ALARM           0x0040
#define NS_WIS_PATH_FERF_ALARM          0x0080
#define NS_WIS_PATH_YELLOW_ALARM        0x0100
#define NS_WIS_LOCD_ALARM               0x0200
#define NS_WIS_PSLM_ALARM               0x0400




/****************************************************************************
* Structure:	NSRunTimeHistStats 
* Function:		NSRunTimeHistStatsInfo
* Description: Used with NSRunTimeHistStats to specify what type of
*					Histograms records to retrieve when Run-Time Histogram stats
*					is enabled. It also returns the number of histogram records
*					being returned
****************************************************************************
 
 Run-Time stats feature provides a mechanism whereby users can request fresh
 statistics on a subset of received streams (for now 64 streams are supported).
 HHistogram updates takes place in cycles at a fixed refresh rate.  This feature
 gives users a way to see very fresh statistics on a limited number of streams.
 
 NSRunTimeHistStatsInfo will return an error if streams has not been configured
 to be tracked with NS_RUNTIME_HIST_STATS_CONFIG.
 If any of the old histogram commands are called when RunTime stats is enabled,
 the settings specified using NS_RUNTIME_HIST_STATS_CONFIG will be erased.

 NSRunTimeHistStatsInfo can be called repeatedly.

 Command syntax is (in C):
 NSRunTimeHistStatsInfo(NSRunTimeHistStats* pHistStatsInfo,void* pHistData,
									unsigned int uiHistDataLen, int iHub, int iSlot, int iPort)

 Command syntax is (in TCL):
 NSRunTimeHistStatsInfo pHistStatsInfo pHistData "" $Hub $Slot $Port

 pHistData can be any type of Histogram data, but currently only NSHistComboPerStreamInfo
 is supported.

 uiHistDataLen is the size of pHistData (in bytes)

 These are the fields which are supported in NSHistComboPerStreamInfo, when its
 used with NSRunTimeHistStatsInfo
		ulStreamID
		u64Total
		u64TotalFrames
		u64Frames.

  The rest of the fields in NSHistComboPerStreamInfo are currently not supported.
  
 ulHistType possible values
 HIST_COMBO_PER_STREAM_INFO

*/
#define HIST_COMBO_PER_STREAM_INFO 1

typedef struct tagNSRunTimeHistStats {

	unsigned long  ulHistType;  /* Input - Type of Histogram data to retrieve,
	                               HIST_COMBO_PER_STREAM_INFO */  
	unsigned long	ulCount;     /* Output - Number of records returned */

	unsigned char ucReserved[128];

}NSRunTimeHistStats;


/*********************************************************************************
 * Structure:   NSRunTimeHistStatsConfig
 * iType1:      NS_RUNTIME_HIST_STATS_CONFIG
 * Function:    HTSetStructure
 * NSRunTimeHistStatsConfig Description: This command is used to specify the stream 
                                     ID's to be tracked for Run-Time stats
 **********************************************************************************
 
 Run-Time stats feature provides a mechanism whereby users can request fresh
 statistics on a subset of received streams (for now 64 streams are supported).
 Histogram updates takes place in cycles at a fixed refresh rate.  This feature
 gives users a way to see very fresh statistics on a limited number of streams.

 Set the latency option to NS_TRACK_STREAM_ID in NS_HIST_LATENCY_OPTION.

 If NS_ALTERNATE_KEY_HASH_CONFIG is used to set hashing mode to contiguous, it should be
 done as a first step and can't be changed when the test is started.

 A stream is identified and distinguished by a unique 32-bit StreamID.  
 A stream is said to be "learned" by a port if at least one frame from that stream has
 arrived on the port.  Each histogram on a receive port corresponds to one unique
 "learned" StreamID

 uiMode possible values
 RUNTIME_MODE_NORMAL
 RUNTIME_MODE_DETAIL
 RUNTIME_MODE_OFF

*/

typedef struct tagNSRunTimeHistStatsConfig
{
	unsigned short uiMode; /* Input - possible values are
								 RUNTIME_MODE_NORMAL - In this mode only the number of user
								 specified StreamID's learned will be returned in ulLearnedStreamCount. 

								 RUNTIME_MODE_DETAIL - In this mode, the number of learned streams
								 will be returned in the ulLearnedStreamCount field. This number will 
								 always be less than or equal to ulStreamCount .  
								 If ulLearnedStreamCount is less than ulStreamCount, 
								 then all of the learned StreamID's themselves will be returned in the
								 ulLearnedStreamIDs array. 

								 RUNTIME_MODE_OFF - In this mode run time stats is disabled and all other
								 fields are ignored.
                          */
	
   unsigned long ulStreamCount;			/* Input - number of streams ID's being specified */

	unsigned long ulStreamsIDs[512];		/* Input - stream ID's to be tracked, maximum is 64 */ 
	
	unsigned long ulLearnedStreamCount;	 /*  OutPut - number of learned streams*/ 

	unsigned long ulLearnedStreamIDs[512]; /*  Output - learned stream IDs, max is 64.
                                               Valid only when uiMode is in RUNTIME_MODE_DETAIL
                                               and the resulted ulLearnedCount is less than
                                               ulStreamCount 
                                           */

	unsigned char ucReserved[512];	/* Reserved */

}NSRunTimeHistStatsConfig;


#define RUNTIME_MODE_NORMAL	0
#define RUNTIME_MODE_DETAIL	1
#define RUNTIME_MODE_OFF		3



/*********************************************************************************
 * Structure:  NSDiffServV2Config
 * iType1:     - NS_DIFF_SERV_V2_CONFIG
 *					- NS_DIFF_SERV_V2_CONFIG_INFO
 * Function:   - HTSetStructure
 *					- HTGetStructure

 NSDiffServV2Config Description: 
 Differentiated services is a feature used to track frames based upon the value of one 
 byte in the frame.
 This feature provides a set of 256 counters and rates that can be retrieved using the
 NS_DIFF_SERV_V2_COUNTER_INFO and NS_DIFF_SERV_V2_RATE_INFO commands, respectively.
 A common usage is to configure DiffServ to filter on the ToS field in IPv4 header 
 and the IPv6 Traffic Class octet.
 Each of the 256 counters and rates would correspond to the frames received with the 
 matching ToS or Traffic class octet value.  
 
 This structure is used to configure or retrieve the DiffServ settings on the port.  Set 
 ucEnable to 1 for rate counters. Disable rate calculation when not being used.

 This is supported on Terametrics XD, XENPAK and 10G XFP cards only.

 ucRateCounterMode possible values
 DIFFSERV_IPV4_COUNTERS
 DIFFSERV_IPV6_COUNTERS
 DIFFSERV_AGGREGATE_IPV4_IPV6_COUNTERS

 ucOffsetMode possible value
 DIFFSERV_OFFSET_FROM_IPV4_HEADER
 
 **********************************************************************************/
typedef struct tagNSDiffServV2Config
{
   unsigned char ucEnable; /* Enable or disable traffic counter
                           collection for rate calculation.
									Possible values are:

									0 - disable rates, counters are enabled
									1 - enable rates */

	unsigned char ucConfigMode; /* (IPv4 only) Specify if values from filter (destination addresses) and/or
										 Offset are to be used for configuration 
										 Possible values are:
										
										 0 - disable ConfigMode, previous values are used for filter and Offset  
										 1 - enable ConfigMode, values for filter and Offset are used */
			
   unsigned char ucRateCounterMode; /* Rate Counter mode, IPv4, IPv6 or both
												DIFFSERV_IPV4_COUNTERS
												DIFFSERV_IPV6_COUNTERS
												DIFFSERV_AGGREGATE_IPV4_IPV6_COUNTERS
											*/
	unsigned char ucOffsetMode; /* Specifies where ulOffset begins relative
                               to the frame, for IPv6 its always from start of IPv6 frame.                               
										
										Default is from the start of the frame (0)	

										DIFFSERV_OFFSET_FROM_IPV4_HEADER - Offset starts
                               from the beginning of the IP header (for only IPv4).											
										

                               */

   unsigned long ulOffset;        /* Offset to start data collection(in bytes),
	                                 based on ucOffsetMode (applicable to only IPv4) */

   unsigned char ucIPv4Address[4];  /* The destination IPv4 address to filter on, 
	                                    if its 0's there is no filtering */
	unsigned char ucIPv6Address[16];  /* The destination IPv6 address to filter on,
	                                     if its 0's there is no filtering */

   unsigned char ucReserved[784];/* Reserved */

} NSDiffServV2Config;


/* Offset */
#define DIFFSERV_OFFSET_FROM_IPV4_HEADER		0x00000002


/* Counter Types */
#define DIFFSERV_IPV4_COUNTERS						0x00000001
#define DIFFSERV_IPV6_COUNTERS						0x00000002
#define DIFFSERV_AGGREGATE_IPV4_IPV6_COUNTERS	0x00000003



/*********************************************************************************
 * Structure:   NSDiffServV2CounterInfo
 * iType1:      NS_DIFF_SERV_V2_COUNTER_INFO
 * Function:    HTGetStructure
 
 NSDiffServV2CounterInfo Description: Retrieve DiffServ counters.
 This is supported on Terametrics XD, Xenpak and 10G XFP cards only.
 
ucRateCounterMode possible values
 DIFFSERV_IPV4_COUNTERS
 DIFFSERV_IPV6_COUNTERS
 DIFFSERV_AGGREGATE_IPV4_IPV6_COUNTERS
**********************************************************************************/
typedef struct tagNSDiffServV2CounterInfo
{
	unsigned char ucCounterMode; /* Input - Counter mode, IPv4, IPv6 or both
												DIFFSERV_IPV4_COUNTERS
												DIFFSERV_IPV6_COUNTERS
												DIFFSERV_AGGREGATE_IPV4_IPV6_COUNTERS
											*/
	U64	u64RxFrame[MAX_DIFFSERV_VALUES];
	unsigned char ucReserved[256];                      /* Reserved */
} NSDiffServV2CounterInfo;


/*********************************************************************************
 * Structure:  NSDiffServV2RateInfo
 * iType1:     - NS_DIFF_SERV_V2_RATE_INFO
 * Function:   - HTGetStructure

 NSDiffServV2RateInfo Description:  This command is used to retrieve DiffServ rates.

 For the ulAlgorithm field, there are currently 2 rate calculation algorithms available.
 
 SIMPLE_RATE_AVERAGE:  Calculate the rates for each time interval first before taking an
                       average of these rates.  This algorithm provides a finer resolution
                       for the rate.
 SIMPLE_COUNTER_AVERAGE:   Calculate the average of the counters first before calculating the
                           rate from the average counters.
 
 This is supported on Terametrics XD, Xenpak and 10G XFP cards only.
 **********************************************************************************/
typedef struct tagNSDiffServV2RateInfo
{ 
   unsigned long ulAlgorithm;		/* Input - The algorithm to use when computing
                                 the  rates from the counter data.  
                                 Possible values are:
                                 SIMPLE_RATE_AVERAGE
                                 SIMPLE_COUNTER_AVERAGE (default)
                                 */

	unsigned long ulRxFrameRate[MAX_DIFFSERV_VALUES];  /* Output - The rate for each DiffServ(0 - 255)
                                                         value. */
   unsigned char ucReserved[256];                      /* Reserved */
} NSDiffServV2RateInfo;



/*********************************************************************************
 * Structure:  NSDOT1XDownloadCertificateFiles
 * iType1:     - NS_DOT1X_DOWNLOAD_CERTIFICATE_FILES
 * Function:   - HTSetStructure

 NSDOT1XDownloadCertificateFiles Description:  
 Download Certificate and Key Files. All files with extension pem, cer, der, 
 p12 are copied from the specified source directories onto the card.

 Random File should also be in the same folder

 Example of folder formats:
	Windows
		C:/ 
		C:/temp
		C:/temp/temp2

  Unix
	/home/username/temp
	
 Note:
	This message is per port.
 **********************************************************************************/
typedef struct tagNSDOT1XDownloadCertificateFiles { 
	
	char szDirectory[128];  /* Directory where root certificates, certificate files and random files 
	                           are copied from */  

	
	char szRandomFileName[128];  /* File name for Random file, specify only the file name.
	                                The file should also be under szDirectory folder */ 

	char szKeyDirectory[128];  /* Directory where key files are copied from */

	unsigned char ucReserved[384];     /* Reserved */

}NSDOT1XDownloadCertificateFiles;



/*********************************************************************************
 * Structure:  NSIPv4Header
 * iType1:     - NS_IPV4_PROTOCOL_HEADER_INFO
 * Function:   - HTGetStructure

 Retrieve IPv4 Protocol information for a stream.
 Applicable to both old and new stream commands. Stream index for which information
 is desired, should be passed as iType2.
 This command is suported on all Terametric LAN and POS test modules.
 
 **********************************************************************************/

/*********************************************************************************
 * Structure:  NSIPv6Header
 * iType1:     - NS_IPV6_PROTOCOL_HEADER_INFO
 * Function:   - HTGetStructure

 Retrieve IPv6 Protocol information for a stream.
 Applicable to both old and new stream commands. Stream index for which information
 is desired, should be passed as iType2.
 This command is suported on all Terametric LAN and POS test modules.
 **********************************************************************************/


/*********************************************************************************
 * Structure:  NSProtocolHeaderInfo
 * iType1:     - NS_PROTOCOL_HEADER_INFO
 * Function:   - HTGetStructure

 Retrieve Protocol header information for a stream.
 Applicable to both old and new stream commands. Stream index for which information
 is desired, should be passed as iType2.
 This command is suported on all Terametric LAN and POS test modules.
 Note: For old stream commands VLAN is part of the Ethernet header.
 The following header values are used for uiHeader field:

 NS_ETHERNET_HEADER                1
 NS_VLAN_HEADER                    2
 NS_IPV4_HEADER                    3
 NS_IPV4_OPTION_HEADER             4
 NS_IPV6_HEADER                    5
 NS_TCP_HEADER                     6
 NS_UDP_HEADER                     7
 NS_CUSTOM_HEADER                  8  
 NS_ICMP_HEADER                    9
 NS_MPLS_HEADER                    10
 NS_IPV6_EXTENSION_HEADER          11
 NS_IPX_HEADER                     17
 NS_PPP_HEADER                     19
 NS_GRE_HEADER                     20
 **********************************************************************************/
#define NS_IPV6_EXTENSION_HEADER 11
#define NS_PROTOCOL_HEADER_MAX 100

typedef struct tagNSProtocolHeaderInfo
{
	unsigned short uiHeaderCount; 	 /* The number of protocol headers in the stream's protocol stack. */
	unsigned short uiHeader[NS_PROTOCOL_HEADER_MAX];	    /* Contains information about the protocol type for the 
                                                different headers that make up the stream's protocol 
                                                stack.  "uiHeader[0]" is the protocol type for the 
                                                first header in the stack. */
   
   unsigned char  ucReserved[32];  	         /* Reserved */
}NSProtocolHeaderInfo;

/****************************************************************************
* Structure:	NSModStreamArray 
* Function:		NSModStreamArrayConfig
* Description:	NSModStreamArrayConfig has the same functionality as 
*					using Layer3ModifyStreamArray with L3_MOD_STREAMS_ARRAY. 
*					This works on only Terametric XD cards.
*****************************************************************************


 NSModStreamArrayConfig Description:

 C Syntax:  NSModStreamArrayConfig(NSModStreamArray *pModStreamArray, 
					unsigned long *ulData,unsigned long ulDataLen, int iHub, int iSlot, int iPort)

 TCL syntax:	NSModStreamArrayConfig myModStreamArray myUL "" $iHub $iSlot $iPort

 NSModStreamArray:  Configuration for NSModStreamArrayConfig.
 ulData:				  Data used to overwrite four bytes of a specified field in a
						  block of streams already defined on the SmartBits module.
						  Maximum elements is 40,000 (160000 bytes).
 ulDataLen:			  Size in bytes of ulData.

 NSModStreamArrayConfig has the same functionality as 
 using Layer3ModifyStreamArray with L3_MOD_STREAMS_ARRAY. This works on only Terametric XD cards.

 Modify a field in a block of streams by overlaying an element from an array.
 For use with IP, UDP, and TCP streams, as well as the L3StreamExtension structure.
 The ulData field is used to overwrite four bytes of a specified field in a
 block of streams already defined on the SmartBits module.

 Identify the first stream to be modified using the ulIndex member of NSModStreamArray.
 The total number of streams to be modified is calculated by the number of array elements to use, 
 multiplied by the number of times in a row each element will be repeated:
     ulCount * ulFieldRepeat (of NSModStreamArray)

 The byte patterns are defined in the elements of the ulData[] array. Each pattern is four bytes long.
 One full pattern per stream is written into the specified field from the least significant bit.

 The field to be modified is specified by ulField of NSModStreamArray. The acceptable field values are 
 listed below.

 If the field is smaller than four bytes, fewer than four bytes will be overwritten.

  Note: For MAC addresses, the least significant four bytes are overwritten. Since the count starts
  with 0, that means bytes 2, 3, 4, and 5 are overwritten.
 
 For the constants L3MS_FIELD_DIPV6, L3MS_FIELD_SIPV6, and L3MS_FIELD_ROUTER_ADDR, each stream modified
 will use a total of 8 elements of ulData[]. The first 4 elements are the IPv6 address to replace, and
 the last 4 elements are the bit mask value indicating which bits of the address to change.

 The fields supported on Terametrics XD modules are the same fields supported by Terametric modules
 using Layer3ModifyStreamArray.

 The maximum number of streams supported if L3MS_FIELD_DIPV6, L3MS_FIELD_SIPV6 or L3MS_FIELD_ROUTER_ADDR
 are used on all the streams is 2047.

The follow are supported on Terametrics XD cards
L3MS_FIELD_DMAC     0    Dest MAC address bytes 2, 3, 4 and 5
L3MS_FIELD_SMAC     1    Source MAC address bytes 2, 3, 4 and 5
L3MS_FIELD_TTL      2    Time to Live field
L3MS_FIELD_ISEQNUM  3    Initial Sequence Number field
L3MS_FIELD_DIP      4    Dest IP address
L3MS_FIELD_SIP      5    Source IP address 
L3MS_FIELD_NETMASK  6    The Netmask field
L3MS_FIELD_GATEWAY  7    Gateway address in the stream structure
L3MS_FIELD_SPRT     8    Source port number
L3MS_FIELD_DPRT     9    Dest port number
L3MS_FIELD_FRAMELEN 10
L3MS_FIELD_DIPA     11   First octet in dest IP address in the stream structure
L3MS_FIELD_DIPB     12    Second octet in dest IP address in the stream structure
L3MS_FIELD_DIPC     13   Third octet in dest IP address in the stream structure 
L3MS_FIELD_DIPD     14   Fourth octet in dest IP address in the stream structure
L3MS_FIELD_SIPA     15   First octet in source IP address in the stream structure
L3MS_FIELD_SIPB     16   Second octet in source IP address in the stream structure
L3MS_FIELD_SIPC     17   Third octet in source IP address in the stream structure 
L3MS_FIELD_SIPD     18   Fourth octet in source IP address in the stream structure
L3MS_FIELD_GATEWAYA 19   First octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYB 20   Second octet in Gateway address in the stream structure
L3MS_FIELD_GATEWAYC 21   Third octet in Gateway address in the stream structure 
L3MS_FIELD_GATEWAYD 22   Fourth octet in Gateway address in the stream structure
L4MS_FIELD_VLANID			   23  Vlan ID (2 bytes) in the packet
L4MS_FIELD_TCP_SEQUENCE    24  TCP Sequence in the Stream struc
L4MS_FIELD_TCP_WINDOW      25  TCP Window size in the Stream struc
L4MS_FIELD_TCP_FLAGS       26  TCP Flags in the Stream struc
L3MS_FIELD_STREAM_ACTIVE   28  Modify the stream active bit      
L3MS_FIELD_STREAM_SIGNATURE 32  ucTagField in the stream struct
L3MS_FIELD_DMAC_BYTE01      37  Dest MAC address bytes 0 and 1
L3MS_FIELD_SMAC_BYTE01      38  Source MAC address bytes 0 and 1
L3MS_FIELD_DIPV6            40  Destination IPv6 address
L3MS_FIELD_SIPV6            41  Source IPv6 address
L3MS_FIELD_ROUTER_ADDR      42  IPv6 router address
L3MS_FIELD_TRAFFIC_CLASS    43  IPv6 traffic class
L3MS_FIELD_FLOW_LABEL       44  IPv6 flow label
L3MS_FIELD_HOP_LIMIT        45  IPv6 hop limit
L3MS_FIELD_NEXT_HEADER      46  IPv6 next header
L3MS_FIELD_SIG_SEQ_ID 		           49	Initial Signature sequence number
L3MS_FIELD_STREAM_FRAME_RATE		   50	stream frame rate
L3MS_FIELD_CUSTOM_STREAM_ID     	   51	custom stream id
L3MS_FIELD_BG_INDEX			           52	background index
L3MS_FIELD_IP_CHECKSUM_ERROR_ENABLE	   53	enable IP header checksum error
L3MS_FIELD_DATA_CHECK_ENABLE		   54	enable data integrity
L3MS_FIELD_DATA_INTEGRITY_ERROR_ENABLE 55	enable data integrity error
L3MS_FIELD_CRC_ERROR_ENABLE    	   	   56	enable CRC error
L3MS_FIELD_RANDOM_BG_ENABLE            57	enable random background
L3MS_FIELD_CUSTOM_STREAM_ID_ENABLE	   58	enable custom stream id
*/

typedef struct tagNSModStreamArray {

	unsigned long ulIndex; /* Index of the first stream to modify  */
	unsigned long ulCount; /* The total number of patterns to use  */
                        /* If ulCount is larger than ulFieldCount, */
                        /* patterns will be repeated.           */

	unsigned long ulField; /* Field in the stream structure to mod */
                        /* See L3MS_FIELD_n defines             */
 
	unsigned long ulFieldCount;  
                        /* Number of patterns/elements to use   */
                        /* from ulData array                  */

	unsigned long ulFieldRepeat;	
                        /* number of times each pattern will be  */
                        /* repeated in a row.                    */
                        /* ulFieldRepeat = 1 does the same thing */
                        /* as ulFieldRepeat = 0 */

}NSModStreamArray;


/*********************************************************************************
 * Structure:   NSLinkFaultConfig
 * iType1:      NS_LINK_FAULT_CONFIG 
 * Function:    HTSetStructure
 * NSLinkFaultConfig Description: Configure/Clear Remote and Local Faults for XFP 
               test modules.
 **********************************************************************************
 
 The command is currently supported on only XFP test modules.

*/

typedef struct tagNSLinkFaultConfig{
	unsigned char   ucType;		/* Type of fault, Local,  Remote or Reset the fault. 
											Possible values are:  
											NS_LINK_FAULT_CLEAR,
											NS_LINK_FAULT_LOCAL,   
											NS_LINK_FAULT_REMOTE
											NS_LINK_FAULT_COUNTER_RESET   */
	unsigned char   ucDurationType;	/*  1 = Timed Fault Generation , 
													0 = Continous Fault Generation */ 
	unsigned long   ulDuration;		/* Fault Generation Time in milliseconds  */
	unsigned char   ucReserved[120];

} NSLinkFaultConfig;


#define NS_LINK_FAULT_CLEAR	0
#define NS_LINK_FAULT_LOCAL   1
#define NS_LINK_FAULT_REMOTE	2
#define NS_LINK_FAULT_COUNTER_RESET	3

/*********************************************************************************
 * Structure:   NSLinkFaultInfo
 * iType1:      NS_LINK_FAULT_INFO 
 * Function:    HTGetStructure
 * NSLinkFaultConfig Description: Retrieve the type of fault present on the port.
 **********************************************************************************
 
 The command is currently supported on only XFP test modules.

*/

typedef struct tagNSLinkFaultInfo{
	unsigned char   ucType;		/* Type of fault, Local,  Remote or Reset the fault. 
											Possible values are:  
											NS_LINK_FAULT_CLEAR,
											NS_LINK_FAULT_LOCAL,   
											NS_LINK_FAULT_REMOTE   */
	
	unsigned char   ucReserved[120];

} NSLinkFaultInfo;

/*********************************************************************************
 * Structure:   NSHistEnhancedLatencyOption
 * iType1:      NS_HIST_ENHANCED_LATENCY_OPTION/NS_HIST_ENHANCED_LATENCY_OPTION_INFO 
 * Function:    HTSetStructure/HTGetStructure
 * NSHistV2LatencyOption Description: Configure a port to keep track of a specifed 
 *              latency type when running latency histogram tests.
 **********************************************************************************
 
 This message supersedes NS_HIST_LATENCY_OPTION/NS_HIST_LATENCY_OPTION_INFO.
 The different modes can be "OR" together for ulOption field.           
 The default mode for Teremetrics XD, XFP and XLW test modules is NS_HIST_EN_ENHANCED_RUNTIME , 
 so there is no need to set this mode on these cards. In this mode all of these counters are 
 available simultaneously:

	Total Latency  
	Frame Count       (In Sequence + Out-of-Sequence)
	Latency Buckets   (16 Buckets)
	Time Stamp        (First or Last, switchable during runtime)
	In Sequence
	Out-of-Sequence
	Min Latency
	Max Latency
	
	This comand works on LAN XD Terametrics, XLW-3720/21, XFP-3730/31A  and LAN33xx, 
	POS 3504,05,10,11 test modules with Terametric Firmware greater than 5.50   

*/

typedef struct tagNSHistEnhancedLatencyOption
{    
	unsigned long ulOption;        /* possible values, 
											NS_HIST_EN_MIN_LATENCY
											NS_HIST_EN_TOTAL_LATENCY
											NS_HIST_EN_STREAMID_IN_STATS 
											NS_HIST_EN_ENHANCED_RUNTIME -  This mode is only supported on LAN XD 
																					Terametrics, XLW-3720/21 and XFP-3730/31A 
																					test modules. 
											NS_HIST_EN_LAST_TIMESTAMP 
											NS_HIST_EN_FIRST_TIMESTAMP  
		
											NS_HIST_EN_SCALE_1_MILLISECOND
											NS_HIST_EN_SCALE_100_NANOSECOND  
											*/        
	unsigned char  ucReserved[128];   /* Reserved*/
} NSHistEnhancedLatencyOption; 

/* Latency (Rx Engine) Modes */
#define NS_HIST_EN_MIN_LATENCY           0x00000001      
#define NS_HIST_EN_TOTAL_LATENCY         0x00000002
#define NS_HIST_EN_STREAMID_IN_STATS     0x00000003
#define NS_HIST_EN_ENHANCED_RUNTIME      0x00000004 /* This mode is only supported on LAN XD Terametrics,
                                                       XLW-3720/21 and XFP-3730/31A test modules */
/*Timestamp modes */
#define NS_HIST_EN_FIRST_TIMESTAMP        0x00000010  /*First TimeStamp */
#define NS_HIST_EN_LAST_TIMESTAMP         0x00000020  /* Last TimeStamp */

/* Latency units ( Ignored on all modules except FBC-360x) */
#define NS_HIST_EN_SCALE_1_MILLISECOND    0x00000100  /* Unit of 1 milliseconds   */
#define NS_HIST_EN_SCALE_100_NANOSECOND   0x00000200  /* Unit of 100 nano Seconds */

/****************************************************************************
* Structure:	NSEnhancedRunTimeHistStats  
* Function:		NSEnhancedRunTimeHistStatsInfo
* Description:	Makes available at runtime the following counters that are 
*              normally available at the end of the test. Any combination of 
*              these counters can be requested and retrieved
*****************************************************************************


 NSEnhancedRunTimeHistStatsInfo Description:
 Makes available at runtime the following counters that are normally available at the end
 of the test. Any combination of these counters can be requested and retrieved.

	Total Latency   
	Frame Count        (In Sequence + Out-of-Sequence)
	Latency Buckets    (16 Buckets)
	Time Stamp         (First or Last, switchable during runtime)
	In Sequence
	Out-of-Sequence
	Min Latency
	Max Latency

 Syntax:
 NSEnhancedRunTimeHistStatsInfo (unsigned long ulCounterType,  unsigned long *pulNumRecords, 
							NSEnhancedRunTimeHistStats *pEnhancedRunTimeHistStats, unsigned long ulDataLen,
							int iHub, int iSlot, int iPort)

 ulCounterType:	(Input) Determines what type of (fields) counters to retrieve, possible values are,
						NS_EN_RUNTIME_TOTAL_LATENCY
						NS_EN_RUNTIME_MIN_LATENCY  
						NS_EN_RUNTIME_MAX_LATENCY 
						NS_EN_RUNTIME_TOTAL_FRAMES
						NS_EN_RUNTIME_IN_SEQUENCE  
                  NS_EN_RUNTIME_OUT_SEQUENCE
						NS_EN_RUNTIME_TIMESTAMP    
                  NS_EN_RUNTIME_LATENCY_BUCKETS

 ulDataLen:			(Input)Size in bytes of data in pEnhancedRunTimeHistStats being requested.

 pulNumRecords:	(Output)Number  of Histogram records returned  Each record contains the StreamID followed by
						the fields (counters) requested.

 pEnhancedRunTimeHistStats:	(Output)Structure containg histogram records (0 - 64), Each structure contains 
										the StreamIDs followed by the fields (counters) requested.  

 
	iHub            Identifies the hub where the card is located. 
	iSlot           Identifies the slot where the card is located.
	iPort           Identifies the port on the card or module.

 Use NSRunTimeHistStats to configure streams to be tracked, the maximum is 64 streams.It is allowed not to 
 request any fields (ulCounterType  can be 0), this can be used to find out if any frames has arrived on a 
 port. This mode is supported on LAN XD Terametrics,   XLW-3720/21 and XFP-3730/31A test modules.

*/

typedef struct tagNSEnhancedRunTimeHistStats {

     unsigned long ulStreamID;    /* Stream Identifier */     
     U64 u64HistData[64];    /* Histogram results, use the following as indices in u64HistData to get the                           
                                corresponding counters:
                             NS_EN_RUNTIME_TOTAL_LATENCY_INDEX
                             NS_EN_RUNTIME_MIN_LATENCY_INDEX
                             NS_EN_RUNTIME_MAX_LATENCY_INDEX
                             NS_EN_RUNTIME_TOTAL_FRAMES_INDEX
                             NS_EN_RUNTIME_IN_SEQUENCE_INDEX
                             NS_EN_RUNTIME_OUT_SEQUENCE_INDEX
                             NS_EN_RUNTIME_TIMESTAMP_INDEX (First/Last Timestamp) 
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_0
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_1
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_2
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_3
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_4
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_5
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_6
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_7
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_8
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_9
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_10
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_11
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_12
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_13
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_14
                             NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_15
                             */ 
       unsigned char ucReserved[128];

}NSEnhancedRunTimeHistStats;


/* reference bit masks for ulCounterType field to specify which fields (counter) to retrieve */
#define  NS_EN_RUNTIME_TOTAL_LATENCY      0x0001   /* Sum of lantencies for this stream */
#define  NS_EN_RUNTIME_MIN_LATENCY        0x0002   /* Minimum Latency */
#define  NS_EN_RUNTIME_MAX_LATENCY        0x0004   /* Maximum Latency */
#define  NS_EN_RUNTIME_TOTAL_FRAMES       0x0008   /*Total Frames Received, in sequence+out of sequence */
#define  NS_EN_RUNTIME_IN_SEQUENCE        0x0010   /* Frame Received in Sequence */
#define  NS_EN_RUNTIME_OUT_SEQUENCE       0x0020   /* Frame Received out of Sequence */
#define  NS_EN_RUNTIME_TIMESTAMP          0x0040   /* TimeStamp (First/Last Timestamp) */ 
#define  NS_EN_RUNTIME_LATENCY_BUCKETS    0x0080   /* Number of frames within the specifed latency range, 
																		for 16 different ranges, lantency buckets.
                                                      If set all 16 buckets are returned, if not set all 16
																		buckets will be empty.
                                                    */
#define NS_EN_RUNTIME_RETRIEVE_AFTER_TEST     0x40000000 /* !!!obsolete!!! Retrieve Counters after test is stopped, not at 
																			runtime */


/* indices for referencing fields(counters) in u64HistData */
#define  NS_EN_RUNTIME_TOTAL_LATENCY_INDEX			0
#define  NS_EN_RUNTIME_MIN_LATENCY_INDEX				1
#define  NS_EN_RUNTIME_MAX_LATENCY_INDEX           2
#define  NS_EN_RUNTIME_TOTAL_FRAMES_INDEX          3    
#define  NS_EN_RUNTIME_IN_SEQUENCE_INDEX           4
#define  NS_EN_RUNTIME_OUT_SEQUENCE_INDEX          5
#define  NS_EN_RUNTIME_TIMESTAMP_INDEX             6
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_0      7
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_1      8
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_2      9
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_3      10
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_4      11
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_5      12
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_6      13
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_7      14
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_8      15
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_9      16
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_10     17
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_11     18
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_12     19
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_13     20
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_14     21  
#define  NS_EN_RUNTIME_LATENCY_BUCKET_INDEX_15     22


#define MAX_CARD_NAME_LENGTH          32

typedef struct tagCardTRDVersionStructure
{
	int iMajorNumber;     
	int iMinorNumber;     
	int iBuildNumber;   
	unsigned char ucReserved[24];
}NSCardTRDVersion;

typedef struct tagNSCardFirmwareVersion
{
	int iReleaseType;     /* can be one of the constants: xxx_RELEASE  */
	int iMajorNumber;     /* range: 1 - 99                             */
	int iMinorNumber;     /* range: 1 - 99                             */
	int iBuildNumber;     /* range: 1 - 999                            */
	int iPatchNumber;     /* range: 1 - 99                             */
}NSCardFirmwareVersion;

#define MAX_SLOTS_NUMBER				20

typedef struct tagNSCardInfo 
{
	int           iOwnership; /* Contains the slot ownership
										possible values
										0 SLOT_RESERVED_BY_OTHER
										1 SLOT_RESERVED_BY_USER
										2 SLOT_AVAILABLE */
	int           iPortType;           /* Port type of of the card,  possible values see HTPortType */
	int           iModel;          /* The card model,  possible values see HTGetCardModel */
	char          szModule[MAX_CARD_NAME_LENGTH];   /* a character string which matches the card model 
												written at the top of the SmartCard front panel for 
												the module on the chassis. */
	unsigned long ulPortProperties;	/* The port properties of the card. The value is filled with
										the logical OR values as specified in HTPortProperty. The
										value can be ANDed against the values as specified in 
										HTPortProperty to determine if the Port Property is present. */
	NSCardFirmwareVersion  FirmwareVersion; /* Card firmware version, same to HTGetStandardFWVersion */	
	NSCardHardwareInfo     HardwareInfo;	/* card hardware version */
	NSCardTRDVersion       TRDVersion;             /* card TRDversion */
	unsigned char          ucReserved[128];              /* Reserved */
}NSCardInfo;

typedef struct tagNSChassisCardInfo 
{
    int        iHub;                  /* Input */
    NSCardInfo CardInfo[MAX_SLOTS_NUMBER];   /* Output */
}NSChassisCardInfo;

typedef struct tagNSSlotInfo
{
	int           iHub;	  /*Input*/
	int           iSlot;	  /*Input*/
	int           iStatus;  /* Output. Return the reserve status after the command call.
							possible values
							0 SLOT_RESERVED_BY_OTHER
							1 SLOT_RESERVED_BY_USER
							2 SLOT_AVAILABLE   */

	unsigned char ucReserved[24];              /* Reserved */
}NSSlotInfo;



/****************************************************************************
* Structure: NSStreamARPStatusInfo
* iType1:    NS_STREAM_ARP_STATUS_INFO
* Function:  HTGetStructure
* NSStreamARPStatusInfo Description: 
*  Query the ARP status of specified number of streams. iType2 is the starting
#  stream index, iType3 is the number of streams to query
****************************************************************************/
/*
NSStreamARPStatusInfo Description:
 Query the ARP status of specified number of streams.
*/
typedef struct tagNSStreamARPStatusInfo
{
   unsigned long ulARPStatus;  /* Output
							    1 - ARP resolved for all specified streams
								0 - ARP unresolved for at least one stream
								*/
   unsigned char ucReserved[64]; /* reserved for future use                */
}NSStreamARPStatusInfo;

/******************************************************************************
* Function:		NSGetMultiCaptureData 
* Structure:	NSMultiCaptureDataInfo 
  NSGetMultiCaptureData Description:
  Retrieve a range of specified captured packets. The retured capture data include
  the packet descriptor and the packet data for each packet. User will parse the
  returned captured buffer to get each packet. The total number of the captured
  packets and the capture data buffer size are also returned in two fields of the
  structure NSMultiCaptureDataInfo. It can be used for all TM cards. See details
  for the packet descriptor under comments below.
 ******************************************************************************/
/*
   NSGetMultiCaptureData Description:
   Retrieve a range of specified captured packets. The retured capture data include
   the packet descriptor and the packet data for each packet. User will parse the
   returned captured buffer to get each packet. The total number of the captured
   packets and the capture data buffer size are also returned in two fields of the
   structure NSMultiCaptureDataInfo. It can be used for all TM cards. See details
   for the packet descriptor below.

   Usage Notes:
   NSGetMultiCaptureData(NSMultiCaptureDataInfo *pNSMultiCaptureDataInfo,
                unsigned char *ucData,unsigned long ulDataLenInKB, 
                int iHub, int iSlot, int iPort)

   Parameters:
 
   1. char* ucData is to return the captured data buffer, which include the packet
     descriptor and the packet data for each packet.
     - For Spirent format, 24 bytes of packet descripter is followed by the captured
	   packets data.
	   typedef struct {
	   unsigned long   frame_index;            
	   unsigned long   frame_length;            
	   unsigned long   conn_index;            
	   unsigned long   timestamp;            
	   unsigned long   flags;            
	   unsigned long   window_frm_length;   //sub-section of full frame length (if specified)
	   } MULTI_CAPTURE_DESC;
	 - For Ethereal format, 16 bytes of packet descriptor is followed by the captured
	   packets data
	   typedef struct {
	   unsigned long   timestamp_sec;
	   unsigned long   timestamp_us;
	   unsigned long   window_frm_length;   //sub-section of full frame length (if specified)
	   unsigned long   full_frame_length;
	   } CAP_DESC_ETHEREAL;

   2. unsigned long ulDataLengthInKB is the size the ucData in KB (1024 bytes) allocated by user.
      It is the maximum buffer size which can be returned, the maximum value is
	  NS_MULTI_CAPTURE_MAX_DATA_SIZE_IN_KB (2000) - 2 MB. It includes the  descriptor header and capture data
	  for each packet.	  
*/

#define NS_MULTI_CAPTURE_MAX_DATA_SIZE_IN_KB   2000   /* Maximum allowed capture buffer size */

#define NS_MULTI_CAPTURE_DESCRIPTOR_FORMAT_SPIRENT   0   /* Spirent capture format */
#define NS_MULTI_CAPTURE_DESCRIPTOR_FORMAT_ETHEREAL   1   /* Ethereal capture format */

typedef struct tagNSMultiCaptureDataInfo
{
	unsigned long ulIndex; /* Index of the first packet to capture (input) */
	unsigned long ulCount; /* The total number of packets to capture
	                          starting from the specified index (input) */
	unsigned long ulRetrievedCount;  /* The actual retrieved number of packets (output)*/
	unsigned long ulRetrievedLength; /* The length of ucData filled with the contents of
										the captured frame, including the packet descriptor 
										and the packet data for each packet, in unit of bytes
										(output)*/ 
	unsigned char ucFormat;		/* The packet descriptor header format to return (input),
								 valid values
								    NS_MULTI_CAPTURE_DESCRIPTOR_FORMAT_SPIRENT (0)
								    NS_MULTI_CAPTURE_DESCRIPTOR_FORMAT_ETHEREAL (1)
								*/
	unsigned char ucReserved[63];		/* reserved */
} NSMultiCaptureDataInfo;

#endif
